import { createVNode as _createVNode } from "vue";
import "./styles/button-group.css";
import { reactive, toRef } from "vue";
import { defineComponent } from "../../utils";
import { makeDisabledProps } from "../../composables/disabled";
import { makePaperProps, usePaper } from "../../composables/paper";
import { provideDefaults } from "../../composables/defaults";
const ButtonGroup = defineComponent({
  name: "VeButtonGroup",
  props: {
    /**
     * @zh 是否有分割线
     */
    divided: Boolean,
    ...makeDisabledProps(),
    ...makePaperProps({
      shape: "rounded-sm"
    })
  },
  setup(props, {
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    provideDefaults(reactive({
      VeButton: {
        disabled: toRef(props, "disabled"),
        height: "auto",
        color: toRef(props, "color"),
        variant: toRef(props, "variant")
      }
    }));
    return () => {
      return _createVNode(props.tag, {
        "class": ["ve-button-group", {
          "ve-button-group--divided": props.divided
        }, paperClasses.value],
        "style": [paperStyles.value]
      }, slots);
    };
  }
});
export {
  ButtonGroup
};
//# sourceMappingURL=button-group.mjs.map
