import type { Ref } from 'vue';
import type { MakeSlots } from '../../utils';
export interface InputControlSlot {
    isActive: boolean;
    isDirty: boolean;
    isFocused: boolean;
    inputRef: Ref<HTMLInputElement | undefined>;
    controlRef: Ref<HTMLElement | undefined>;
    blur: () => void;
    focus: () => void;
}
export type InputControlDefaultSlot = InputControlSlot & {
    props: Record<string, unknown>;
};
export type InputControlSlots = MakeSlots<{
    'prepend-inner': [InputControlSlot];
    prefix: [InputControlSlot];
    default: [InputControlDefaultSlot];
    suffix: [InputControlSlot];
    'append-inner': [InputControlSlot];
    clear: [InputControlSlot];
}>;
export declare const makeInputControlProps: <Defaults extends {
    shape?: unknown;
    color?: unknown;
    textColor?: unknown;
    variant?: unknown;
    appendInnerIcon?: unknown;
    clearable?: unknown;
    clearIcon?: unknown;
    disabled?: unknown;
    prependInnerIcon?: unknown;
    prefix?: unknown;
    prefixIcon?: unknown;
    suffix?: unknown;
    suffixIcon?: unknown;
} = {}>(defaults?: Defaults | undefined) => {
    shape: unknown extends Defaults["shape"] ? Omit<{
        type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
        default: string;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
        default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
    } : Omit<Omit<{
        type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
        default: string;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
        default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
    }, "type" | "default"> & {
        type: import("vue").PropType<unknown extends Defaults["shape"] ? NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill"> : NonNullable<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">> | Defaults["shape"]>;
        default: unknown extends Defaults["shape"] ? NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill"> : NonNullable<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">> | Defaults["shape"];
    };
    color: unknown extends Defaults["color"] ? StringConstructor : {
        type: import("vue").PropType<unknown extends Defaults["color"] ? string : string | Defaults["color"]>;
        default: unknown extends Defaults["color"] ? string : string | Defaults["color"];
    };
    textColor: unknown extends Defaults["textColor"] ? StringConstructor : {
        type: import("vue").PropType<unknown extends Defaults["textColor"] ? string : string | Defaults["textColor"]>;
        default: unknown extends Defaults["textColor"] ? string : string | Defaults["textColor"];
    };
    variant: unknown extends Defaults["variant"] ? Omit<{
        type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
    } : Omit<Omit<{
        type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
    }, "type" | "default"> & {
        type: import("vue").PropType<unknown extends Defaults["variant"] ? NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined"> : NonNullable<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">> | Defaults["variant"]>;
        default: unknown extends Defaults["variant"] ? NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined"> : NonNullable<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">> | Defaults["variant"];
    };
    appendInnerIcon: unknown extends Defaults["appendInnerIcon"] ? (StringConstructor | ObjectConstructor)[] : {
        type: import("vue").PropType<unknown extends Defaults["appendInnerIcon"] ? unknown : {} | Defaults["appendInnerIcon"]>;
        default: unknown extends Defaults["appendInnerIcon"] ? unknown : {} | Defaults["appendInnerIcon"];
    };
    clearable: unknown extends Defaults["clearable"] ? BooleanConstructor : {
        type: import("vue").PropType<unknown extends Defaults["clearable"] ? boolean : boolean | Defaults["clearable"]>;
        default: unknown extends Defaults["clearable"] ? boolean : boolean | Defaults["clearable"];
    };
    clearIcon: unknown extends Defaults["clearIcon"] ? {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    } : Omit<{
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    }, "type" | "default"> & {
        type: import("vue").PropType<unknown extends Defaults["clearIcon"] ? string : string | Defaults["clearIcon"]>;
        default: unknown extends Defaults["clearIcon"] ? string : string | Defaults["clearIcon"];
    };
    disabled: unknown extends Defaults["disabled"] ? BooleanConstructor : {
        type: import("vue").PropType<unknown extends Defaults["disabled"] ? boolean : boolean | Defaults["disabled"]>;
        default: unknown extends Defaults["disabled"] ? boolean : boolean | Defaults["disabled"];
    };
    prependInnerIcon: unknown extends Defaults["prependInnerIcon"] ? (StringConstructor | ObjectConstructor)[] : {
        type: import("vue").PropType<unknown extends Defaults["prependInnerIcon"] ? unknown : {} | Defaults["prependInnerIcon"]>;
        default: unknown extends Defaults["prependInnerIcon"] ? unknown : {} | Defaults["prependInnerIcon"];
    };
    prefix: unknown extends Defaults["prefix"] ? StringConstructor : {
        type: import("vue").PropType<unknown extends Defaults["prefix"] ? string : string | Defaults["prefix"]>;
        default: unknown extends Defaults["prefix"] ? string : string | Defaults["prefix"];
    };
    prefixIcon: unknown extends Defaults["prefixIcon"] ? (StringConstructor | ObjectConstructor)[] : {
        type: import("vue").PropType<unknown extends Defaults["prefixIcon"] ? unknown : {} | Defaults["prefixIcon"]>;
        default: unknown extends Defaults["prefixIcon"] ? unknown : {} | Defaults["prefixIcon"];
    };
    suffix: unknown extends Defaults["suffix"] ? StringConstructor : {
        type: import("vue").PropType<unknown extends Defaults["suffix"] ? string : string | Defaults["suffix"]>;
        default: unknown extends Defaults["suffix"] ? string : string | Defaults["suffix"];
    };
    suffixIcon: unknown extends Defaults["suffixIcon"] ? (StringConstructor | ObjectConstructor)[] : {
        type: import("vue").PropType<unknown extends Defaults["suffixIcon"] ? unknown : {} | Defaults["suffixIcon"]>;
        default: unknown extends Defaults["suffixIcon"] ? unknown : {} | Defaults["suffixIcon"];
    };
};
export declare function filterInputControlSlots(slots: Record<string, unknown>): [yes: Partial<Pick<Record<string, unknown>, string>>, no: Omit<Record<string, unknown>, string>];
export declare const InputControlEmits: {
    'click:clear': (_event: MouseEvent) => boolean;
    'click:prepend-inner': (_event: MouseEvent) => boolean;
    'click:prefix': (_event: MouseEvent) => boolean;
    'click:suffix': (_event: MouseEvent) => boolean;
    'click:append-inner': (_event: MouseEvent) => boolean;
    'click:control': (_event: MouseEvent) => boolean;
    'update:active': (_active: boolean) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
};
export declare const InputControlSlots: string[];
export declare const InputControl: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            disabled: boolean;
            variant: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }> & Omit<Readonly<import("vue").ExtractPropTypes<{
            shape: Omit<{
                type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
                default: string;
            }, "type" | "default"> & {
                type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
                default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "type" | "default"> & {
                type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        } & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "disabled" | "variant" | "shape" | "active" | "clearable" | "clearIcon" | "dirty">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot | undefined;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<import("vue").ExtractPropTypes<{
            shape: Omit<{
                type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
                default: string;
            }, "type" | "default"> & {
                type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
                default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "type" | "default"> & {
                type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        }, {
            inputRef: Ref<HTMLInputElement | undefined>;
            controlRef: Ref<HTMLElement | undefined>;
        }, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {
            'click:clear': (_event: MouseEvent) => boolean;
            'click:prepend-inner': (_event: MouseEvent) => boolean;
            'click:prefix': (_event: MouseEvent) => boolean;
            'click:suffix': (_event: MouseEvent) => boolean;
            'click:append-inner': (_event: MouseEvent) => boolean;
            'click:control': (_event: MouseEvent) => boolean;
            'update:active': (_active: boolean) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            disabled: boolean;
            variant: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: import("vue").DebuggerEvent) => void) | ((e: import("vue").DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof import("vue").nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: import("vue").WatchOptions<boolean> | undefined): import("vue").WatchStopHandle;
    } & Readonly<import("vue").ExtractPropTypes<{
        shape: Omit<{
            type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
            default: string;
        }, "type" | "default"> & {
            type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
            default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
        };
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "type" | "default"> & {
            type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
        };
        appendInnerIcon: (StringConstructor | ObjectConstructor)[];
        clearable: BooleanConstructor;
        clearIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        disabled: BooleanConstructor;
        prependInnerIcon: (StringConstructor | ObjectConstructor)[];
        prefix: StringConstructor;
        prefixIcon: (StringConstructor | ObjectConstructor)[];
        suffix: StringConstructor;
        suffixIcon: (StringConstructor | ObjectConstructor)[];
        active: BooleanConstructor;
        dirty: BooleanConstructor;
    } & {
        $children: () => import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | {
            'prepend-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
            default?: import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            'prepend-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:active"?: ((_active: boolean) => any) | undefined;
    } & import("vue").ShallowUnwrapRef<{
        inputRef: Ref<HTMLInputElement | undefined>;
        controlRef: Ref<HTMLElement | undefined>;
    }> & {} & import("vue").ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & import("vue").ComponentOptionsBase<Readonly<import("vue").ExtractPropTypes<{
    shape: Omit<{
        type: import("vue").PropType<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
        default: string;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">>;
        default: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
    };
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: import("vue").PropType<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "type" | "default"> & {
        type: import("vue").PropType<NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
    };
    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
    clearable: BooleanConstructor;
    clearIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    disabled: BooleanConstructor;
    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
    prefix: StringConstructor;
    prefixIcon: (StringConstructor | ObjectConstructor)[];
    suffix: StringConstructor;
    suffixIcon: (StringConstructor | ObjectConstructor)[];
    active: BooleanConstructor;
    dirty: BooleanConstructor;
} & {
    $children: () => import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
        [key: string]: any;
    }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
        [key: string]: any;
    }>[]) | {
        'prepend-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
        default?: import("vue").VNodeChild | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: import("vue").VNodeChild | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        'prepend-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: InputControlDefaultSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
    "onUpdate:active"?: ((_active: boolean) => any) | undefined;
}, {
    inputRef: Ref<HTMLInputElement | undefined>;
    controlRef: Ref<HTMLElement | undefined>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {
    'click:clear': (_event: MouseEvent) => boolean;
    'click:prepend-inner': (_event: MouseEvent) => boolean;
    'click:prefix': (_event: MouseEvent) => boolean;
    'click:suffix': (_event: MouseEvent) => boolean;
    'click:append-inner': (_event: MouseEvent) => boolean;
    'click:control': (_event: MouseEvent) => boolean;
    'update:active': (_active: boolean) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
}, string, {
    disabled: boolean;
    variant: NonNullable<"contained" | "outlined" | "plain" | "text" | "contained-text" | "contained-outlined">;
    shape: NonNullable<"circle" | "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill">;
    active: boolean;
    clearable: boolean;
    clearIcon: string | Record<string, any>;
    dirty: boolean;
}, {}, string> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & (new () => {
    $slots: InputControlSlots;
});
export declare function filterInputControlProps(attrs: Record<string, unknown>): [yes: Partial<Pick<Record<string, unknown>, string>>, no: Omit<Record<string, unknown>, string>];
export type InputControl = InstanceType<typeof InputControl>;
