import { computed } from "vue";
import { getCurrentInstanceName, propsFactory } from "@veno-ui/utils";
import { makeTagProps } from "../tag";
import { makeThemeProps, provideTheme } from "../theme";
import { makeVariantProps, useVariant } from "../variant";
import { makePositionProps, usePosition } from "../position";
import { makeDimensionProps, useDimension } from "../dimension";
import { makeSizeProps, useSize } from "../size";
import { makeDensityProps, useDensity } from "../density";
import { makeBorderProps, useBorder } from "../border";
import { makeShapeProps, useShape } from "../shape";
import { makeElevationProps, useElevation } from "../elevation";
import { genOverlays } from "../variant";
const makePaperProps = propsFactory({
  ...makeTagProps(),
  ...makeThemeProps(),
  ...makeVariantProps(),
  ...makePositionProps(),
  ...makeDimensionProps(),
  ...makeSizeProps(),
  ...makeDensityProps(),
  ...makeBorderProps(),
  ...makeShapeProps(),
  ...makeElevationProps()
}, "paper");
function usePaper(props, name = getCurrentInstanceName()) {
  const { themeClasses } = provideTheme(props);
  const { colorClasses, variantClasses, colorStyles } = useVariant(props, name);
  const { positionClasses, positionStyles } = usePosition(props, name);
  const { dimensionStyles } = useDimension(props);
  const { sizeClasses, sizeStyles } = useSize(props, name);
  const { densityClasses } = useDensity(props, name);
  const { borderClasses } = useBorder(props, name);
  const { shapeClasses } = useShape(props, name);
  const { elevationClasses } = useElevation(props, name);
  const paperClasses = computed(() => [
    themeClasses.value,
    colorClasses.value,
    variantClasses.value,
    positionClasses.value,
    sizeClasses.value,
    densityClasses.value,
    borderClasses.value,
    shapeClasses.value,
    elevationClasses.value
  ]);
  const paperStyles = computed(() => [
    colorStyles.value,
    positionStyles.value,
    dimensionStyles.value,
    sizeStyles.value
  ]);
  return {
    paperClasses,
    paperStyles
  };
}
export {
  genOverlays,
  makePaperProps,
  usePaper
};
//# sourceMappingURL=index.mjs.map
