import * as vue from 'vue';
import { Ref, VNode, defineComponent as defineComponent$1, ComponentPropsOptions, ComputedOptions, MethodOptions, ComponentOptionsMixin, EmitsOptions, DefineComponent, ComponentOptionsWithObjectProps, VNodeChild, ComponentInternalInstance, InjectionKey, PropType, ComputedRef, nextTick, ExtractPropTypes, ComponentPublicInstance, FunctionalComponent, Prop, WritableComputedRef, ObjectDirective, DirectiveBinding, ToRefs, Component } from 'vue';
import * as vue_router from 'vue-router';
import * as _veno_ui_utils from '@veno-ui/utils';
import { Anchor as Anchor$1, deepEqual } from '@veno-ui/utils';
import { Highlighter } from 'shiki';

declare const SIZES: string[];
type Size = string | number | typeof SIZES[number];

interface BaseColors {
    background: string;
    surface: string;
    primary: string;
    secondary: string;
    success: string;
    warning: string;
    error: string;
    info: string;
}
interface BaseOnColors {
    'on-background': string;
    'on-surface': string;
    'on-primary': string;
    'on-secondary': string;
    'on-success': string;
    'on-warning': string;
    'on-error': string;
    'on-info': string;
}
interface Colors extends BaseColors {
    [key: string]: string;
}

interface InternalThemeDefinition {
    dark: boolean;
    colors: Colors;
    variables: Record<string, string | number>;
}
interface ThemeDefinitionColors extends BaseColors, Partial<BaseOnColors> {
    [key: string]: string | undefined;
}
interface ThemeDefinition {
    dark: boolean;
    colors: ThemeDefinitionColors;
    variables: Record<string, string | number>;
}
type ThemeOptions = false | {
    defaultTheme?: string;
    themes?: Record<string, ThemeDefinition>;
};
interface ThemeInstance {
    isDisabled: boolean;
    themes: Ref<Record<string, InternalThemeDefinition>>;
    current: Ref<string>;
    themeClasses: Ref<string | undefined>;
    setTheme: (key: string, theme: ThemeDefinition) => void;
    getTheme: (key: string) => InternalThemeDefinition;
}
declare function useTheme(): ThemeInstance;

declare function classToHex(color: string, colors: Record<string, Record<string, string>>, currentTheme: Partial<ThemeDefinition['colors']>): string;
declare function parseGradient(gradient: string, colors: Record<string, Record<string, string>>, currentTheme: Partial<ThemeDefinition['colors']>): string;

declare function consoleInfo(message: string, vm?: any, parent?: any): void;
declare function consoleWarn(message: string, vm?: any, parent?: any): void;
declare function consoleError(message: string, vm?: any, parent?: any): void;

declare function propIsDefined(vnode: VNode, prop: string): boolean | undefined;
declare const defineComponent: typeof defineComponent$1;
type ToListeners<T extends string | number | symbol> = {
    [K in T]: K extends `on${infer U}` ? Uncapitalize<U> : K;
}[T];
type SlotsToProps<T extends Record<string, Slot>> = {
    $children: () => (T['default'] | VNodeChild | {
        [K in keyof T]?: T[K] | VNodeChild;
    });
    'v-slots': new () => {
        [K in keyof T]?: T[K] | false;
    };
};
type Slot<T extends any[] = any[]> = (...args: T) => VNode | VNode[];
type MakeSlots<T extends Record<string, any[]>> = {
    [K in keyof T]: Slot<T[K]>;
};
declare function genericComponent<T extends (new () => {
    $slots?: Record<string, Slot>;
})>(exposeDefaults?: boolean): <PropsOptions extends Readonly<ComponentPropsOptions>, RawBindings, D, C extends ComputedOptions = {}, M extends MethodOptions = {}, Mixin extends ComponentOptionsMixin = ComponentOptionsMixin, Extends extends ComponentOptionsMixin = ComponentOptionsMixin, E extends EmitsOptions = Record<string, any>, EE extends string = string, I = InstanceType<T>, Base = DefineComponent<(I extends Record<'$props', any> ? Omit<PropsOptions, keyof I['$props']> : PropsOptions) & (I extends Record<'$slots', any> ? SlotsToProps<I['$slots']> : {}), RawBindings, D, C, M, Mixin, Extends, E extends any[] ? E : I extends Record<'$props', any> ? Omit<E, ToListeners<keyof I['$props']>> : E, EE>>(options: ComponentOptionsWithObjectProps<PropsOptions, RawBindings, D, C, M, Mixin, Extends, E, EE>) => Base & T;

declare const UI_NAME: string;
declare const UI_VERSION: string;

declare function findChildren(vnode?: VNodeChild): ComponentInternalInstance[];
declare function findChildrenWithProvide(provide: InjectionKey<any>, vnode?: VNodeChild): ComponentInternalInstance[];

declare function createSymbol(key: string): symbol;

type index$3_MakeSlots<T extends Record<string, any[]>> = MakeSlots<T>;
declare const index$3_UI_NAME: typeof UI_NAME;
declare const index$3_UI_VERSION: typeof UI_VERSION;
declare const index$3_classToHex: typeof classToHex;
declare const index$3_consoleError: typeof consoleError;
declare const index$3_consoleInfo: typeof consoleInfo;
declare const index$3_consoleWarn: typeof consoleWarn;
declare const index$3_createSymbol: typeof createSymbol;
declare const index$3_defineComponent: typeof defineComponent;
declare const index$3_findChildren: typeof findChildren;
declare const index$3_findChildrenWithProvide: typeof findChildrenWithProvide;
declare const index$3_genericComponent: typeof genericComponent;
declare const index$3_parseGradient: typeof parseGradient;
declare const index$3_propIsDefined: typeof propIsDefined;
declare namespace index$3 {
  export {
    index$3_MakeSlots as MakeSlots,
    index$3_UI_NAME as UI_NAME,
    index$3_UI_VERSION as UI_VERSION,
    index$3_classToHex as classToHex,
    index$3_consoleError as consoleError,
    index$3_consoleInfo as consoleInfo,
    index$3_consoleWarn as consoleWarn,
    index$3_createSymbol as createSymbol,
    index$3_defineComponent as defineComponent,
    index$3_findChildren as findChildren,
    index$3_findChildrenWithProvide as findChildrenWithProvide,
    index$3_genericComponent as genericComponent,
    index$3_parseGradient as parseGradient,
    index$3_propIsDefined as propIsDefined,
  };
}

declare const alertTypes: readonly ["success", "info", "warning", "error"];
type AlertType = typeof alertTypes[number];
type AlertSlots = MakeSlots<{
    prepend: [];
    default: [];
    append: [];
}>;
declare const Alert: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            type: "success" | "info" | "warning" | "error";
            icon: string | false;
            closable: boolean;
            closeIcon: string | Record<string, any>;
            transition: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                }>;
            } | NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            loading: boolean;
            link: boolean;
            hover: boolean;
            divided: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: Omit<Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            }, "default" | "type"> & {
                type: PropType<NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>>;
                default: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            }, "default" | "type"> & {
                type: PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
                default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            disabled: BooleanConstructor;
            loading: BooleanConstructor;
            href: StringConstructor;
            replace: BooleanConstructor;
            to: PropType<vue_router.RouteLocationRaw>;
            link: BooleanConstructor;
            hover: BooleanConstructor;
            image: StringConstructor;
            prependAvatar: StringConstructor;
            prependIcon: StringConstructor;
            appendAvatar: StringConstructor;
            appendIcon: StringConstructor;
            title: StringConstructor;
            subtitle: StringConstructor;
            divided: BooleanConstructor;
            text: StringConstructor;
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<{
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                    }>;
                } | NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>>;
                default: {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                    }>;
                } | NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
            };
            modelValue: {
                type: BooleanConstructor;
                default: boolean;
            };
            type: {
                type: PropType<"success" | "info" | "warning" | "error">;
                default: string;
                validator: (val: AlertType) => boolean;
            };
            icon: {
                type: PropType<string | false>;
                default: boolean;
            };
            closable: BooleanConstructor;
            closeIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            closeText: StringConstructor;
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "type" | "icon" | "closable" | "closeIcon" | "transition" | "loading" | "link" | "hover" | "divided" | "ripple" | "replace" | "fixed" | "disabled" | "tag" | "variant" | "absolute" | "size" | "density" | "shape">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _: boolean) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: Omit<Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            }, "default" | "type"> & {
                type: PropType<NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>>;
                default: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            }, "default" | "type"> & {
                type: PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
                default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            disabled: BooleanConstructor;
            loading: BooleanConstructor;
            href: StringConstructor;
            replace: BooleanConstructor;
            to: PropType<vue_router.RouteLocationRaw>;
            link: BooleanConstructor;
            hover: BooleanConstructor;
            image: StringConstructor;
            prependAvatar: StringConstructor;
            prependIcon: StringConstructor;
            appendAvatar: StringConstructor;
            appendIcon: StringConstructor;
            title: StringConstructor;
            subtitle: StringConstructor;
            divided: BooleanConstructor;
            text: StringConstructor;
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<{
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                    }>;
                } | NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>>;
                default: {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                    }>;
                } | NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
            };
            modelValue: {
                type: BooleanConstructor;
                default: boolean;
            };
            type: {
                type: PropType<"success" | "info" | "warning" | "error">;
                default: string;
                validator: (val: AlertType) => boolean;
            };
            icon: {
                type: PropType<string | false>;
                default: boolean;
            };
            closable: BooleanConstructor;
            closeIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            closeText: StringConstructor;
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_: boolean) => boolean;
        }, string, {
            modelValue: boolean;
            type: "success" | "info" | "warning" | "error";
            icon: string | false;
            closable: boolean;
            closeIcon: string | Record<string, any>;
            transition: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                }>;
            } | NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            loading: boolean;
            link: boolean;
            hover: boolean;
            divided: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        elevation: {
            type: (StringConstructor | NumberConstructor)[];
            validator(v: any): boolean;
        };
        shape: Omit<Omit<{
            type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        }, "default" | "type"> & {
            type: PropType<NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>>;
            default: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        };
        border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: PropType<Size | undefined>;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        absolute: BooleanConstructor;
        bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        fixed: BooleanConstructor;
        left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        position: {
            type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
            validator: (v: any) => boolean;
        };
        right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<Omit<{
            type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        }, "default" | "type"> & {
            type: PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
            default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        };
        theme: StringConstructor;
        tag: {
            type: StringConstructor;
            default: string;
        };
        disabled: BooleanConstructor;
        loading: BooleanConstructor;
        href: StringConstructor;
        replace: BooleanConstructor;
        to: PropType<vue_router.RouteLocationRaw>;
        link: BooleanConstructor;
        hover: BooleanConstructor;
        image: StringConstructor;
        prependAvatar: StringConstructor;
        prependIcon: StringConstructor;
        appendAvatar: StringConstructor;
        appendIcon: StringConstructor;
        title: StringConstructor;
        subtitle: StringConstructor;
        divided: BooleanConstructor;
        text: StringConstructor;
        ripple: {
            type: BooleanConstructor;
            default: boolean;
        };
        transition: Omit<{
            type: PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: PropType<{
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                }>;
            } | NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>>;
            default: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                }>;
            } | NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
        };
        modelValue: {
            type: BooleanConstructor;
            default: boolean;
        };
        type: {
            type: PropType<"success" | "info" | "warning" | "error">;
            default: string;
            validator: (val: AlertType) => boolean;
        };
        icon: {
            type: PropType<string | false>;
            default: boolean;
        };
        closable: BooleanConstructor;
        closeIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        closeText: StringConstructor;
    } & {
        $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild | {
            prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<Omit<{
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    }, "default" | "type"> & {
        type: PropType<NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>>;
        default: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<Omit<{
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    }, "default" | "type"> & {
        type: PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
        default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    disabled: BooleanConstructor;
    loading: BooleanConstructor;
    href: StringConstructor;
    replace: BooleanConstructor;
    to: PropType<vue_router.RouteLocationRaw>;
    link: BooleanConstructor;
    hover: BooleanConstructor;
    image: StringConstructor;
    prependAvatar: StringConstructor;
    prependIcon: StringConstructor;
    appendAvatar: StringConstructor;
    appendIcon: StringConstructor;
    title: StringConstructor;
    subtitle: StringConstructor;
    divided: BooleanConstructor;
    text: StringConstructor;
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    transition: Omit<{
        type: PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: PropType<{
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        } | NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>>;
        default: {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        } | NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
    };
    modelValue: {
        type: BooleanConstructor;
        default: boolean;
    };
    type: {
        type: PropType<"success" | "info" | "warning" | "error">;
        default: string;
        validator: (val: AlertType) => boolean;
    };
    icon: {
        type: PropType<string | false>;
        default: boolean;
    };
    closable: BooleanConstructor;
    closeIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    closeText: StringConstructor;
} & {
    $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | vue.VNodeChild | {
        prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_: boolean) => boolean;
}, string, {
    modelValue: boolean;
    type: "success" | "info" | "warning" | "error";
    icon: string | false;
    closable: boolean;
    closeIcon: string | Record<string, any>;
    transition: {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
        }>;
    } | NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })>;
    loading: boolean;
    link: boolean;
    hover: boolean;
    divided: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: AlertSlots;
});
type Alert = InstanceType<typeof Alert>;

interface LayoutInstance {
    register: (vm: ComponentInternalInstance, id: string, props: Ref<LayoutItemProps & {
        name?: string;
    }>) => {
        layoutItemStyles: Ref<Record<string, unknown>>;
        layoutItemScrimStyles: Ref<Record<string, unknown>>;
    };
    unregister: (id: string) => void;
    mainStyles: Ref<Record<string, unknown>>;
    getLayoutItem: (id: string) => LayoutItem$1 | undefined;
    items: Ref<LayoutItem$1[]>;
    layoutRect: Ref<DOMRectReadOnly | undefined>;
    rootZIndex: Ref<number>;
    overlays: Ref<number[]>;
}
interface LayoutItem$1 extends Required<LayoutItemProps>, LayoutLayer {
    id: string;
    size: number;
    layoutSize: number;
    priority: number;
    active: boolean;
}
interface LayoutLayer {
    top: number;
    right: number;
    bottom: number;
    left: number;
}
interface LayoutItemProps {
    position?: 'absolute' | 'fixed';
    anchor?: LayoutAnchor;
    active?: boolean;
    size: string | number;
    layoutSize?: string | number;
    priority?: string | number;
    disableTransition?: boolean;
}
type LayoutAnchor = 'top' | 'right' | 'bottom' | 'left';

declare const App: vue.DefineComponent<{
    overlaps: vue.Prop<string[], string[]>;
    fullHeight: {
        type: vue.PropType<boolean>;
        default: boolean;
    };
    theme: StringConstructor;
}, {
    theme: ThemeInstance;
    getLayoutItem: (id: string) => LayoutItem$1 | undefined;
    items: vue.ComputedRef<LayoutItem$1[]>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    overlaps: vue.Prop<string[], string[]>;
    fullHeight: {
        type: vue.PropType<boolean>;
        default: boolean;
    };
    theme: StringConstructor;
}>>, {
    fullHeight: boolean;
}>;

type AnchorItemProps = {
    [key: string]: any;
    text: string;
    value: string;
};
declare const Anchor: vue.DefineComponent<{
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    scrollTarget: {
        type: PropType<string | HTMLElement>;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 锚点项
     */
    items: PropType<AnchorItemProps[]>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    scrollTarget: {
        type: PropType<string | HTMLElement>;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 锚点项
     */
    items: PropType<AnchorItemProps[]>;
}>>, {
    offset: string | number;
    activeColor: string;
}>;
type Anchor = InstanceType<typeof Anchor>;

declare const AnchorItem: vue.DefineComponent<{
    value: {
        type: StringConstructor;
        required: true;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 文本
     */
    text: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    value: {
        type: StringConstructor;
        required: true;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 文本
     */
    text: StringConstructor;
}>>, {
    activeColor: string;
}>;
type AnchorItem = InstanceType<typeof AnchorItem>;

declare const Avatar: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string; /**
         * @zh 图像
         */
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        /**
         * @zh 图像
         */
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    start: BooleanConstructor;
    end: BooleanConstructor;
    image: StringConstructor;
    icon: (StringConstructor | ObjectConstructor)[];
    text: StringConstructor;
    link: BooleanConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string; /**
         * @zh 图像
         */
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        /**
         * @zh 图像
         */
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    start: BooleanConstructor;
    end: BooleanConstructor;
    image: StringConstructor;
    icon: (StringConstructor | ObjectConstructor)[];
    text: StringConstructor;
    link: BooleanConstructor;
}>>, {
    link: boolean;
    fixed: boolean;
    tag: string;
    color: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    start: boolean;
    end: boolean;
}>;
type Avatar = InstanceType<typeof Avatar>;

type Badge = InstanceType<typeof Badge>;
declare const Badge: vue.DefineComponent<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    /**
     * @zh 标记是否存在边框
     */
    bordered: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标记的颜色
     */
    color: StringConstructor;
    /**
     * @zh 标记的内容
     */
    content: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记是否显示为点
     */
    dot: BooleanConstructor;
    /**
     * @zh 是否为浮动的标记
     */
    floating: BooleanConstructor;
    /**
     * @zh 标记的图标
     */
    icon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 是否为内联的标记
     */
    inline: BooleanConstructor;
    /**
     * @zh 标记的位置
     */
    location: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * @zh 标记的数量最大值
     */
    max: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的数量
     */
    modelValue: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标记的 X 偏移值
     */
    offsetX: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的 Y 偏移值
     */
    offsetY: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的文本颜色
     */
    textColor: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    /**
     * @zh 标记是否存在边框
     */
    bordered: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标记的颜色
     */
    color: StringConstructor;
    /**
     * @zh 标记的内容
     */
    content: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记是否显示为点
     */
    dot: BooleanConstructor;
    /**
     * @zh 是否为浮动的标记
     */
    floating: BooleanConstructor;
    /**
     * @zh 标记的图标
     */
    icon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 是否为内联的标记
     */
    inline: BooleanConstructor;
    /**
     * @zh 标记的位置
     */
    location: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * @zh 标记的数量最大值
     */
    max: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的数量
     */
    modelValue: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标记的 X 偏移值
     */
    offsetX: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的 Y 偏移值
     */
    offsetY: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 标记的文本颜色
     */
    textColor: StringConstructor;
}>>, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
    tag: string;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    bordered: boolean;
    dot: boolean;
    floating: boolean;
    inline: boolean;
    location: string;
}>;

type Breadcrumb = InstanceType<typeof Breadcrumb>;
declare const Breadcrumb: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            tag: string;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "tag">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _value: any) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_value: any) => boolean;
        }, string, {
            tag: string;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        tag: Omit<{
            type: StringConstructor;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<string>;
            default: string;
        };
    } & {
        $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild | {
            default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
} & {
    $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | vue.VNodeChild | {
        default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_value: any) => boolean;
}, string, {
    tag: string;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: MakeSlots<{
        default: [
        ];
        separator: [
        ];
    }>;
});

type BreadcrumbItem = InstanceType<typeof BreadcrumbItem>;
declare const BreadcrumbItem: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            type: string;
            loading: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            stacked: boolean;
            block: boolean;
            overlay: boolean;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            value: null;
            disabled: BooleanConstructor;
            selectedClass: StringConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: vue.PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
                default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            };
            theme: StringConstructor;
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
            href: StringConstructor;
            replace: BooleanConstructor;
            to: vue.PropType<vue_router.RouteLocationRaw>;
            loading: BooleanConstructor;
            type: {
                type: StringConstructor;
                default: string;
            };
            icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
            prependIcon: (StringConstructor | ObjectConstructor)[];
            appendIcon: (StringConstructor | ObjectConstructor)[];
            stacked: BooleanConstructor;
            block: BooleanConstructor;
            text: (StringConstructor | NumberConstructor)[];
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            overlay: {
                type: BooleanConstructor;
                default: boolean;
            };
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "type" | "loading" | "ripple" | "replace" | "fixed" | "disabled" | "tag" | "variant" | "absolute" | "size" | "density" | "shape" | "stacked" | "block" | "overlay">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            value: null;
            disabled: BooleanConstructor;
            selectedClass: StringConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: vue.PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
                default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            };
            theme: StringConstructor;
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
            href: StringConstructor;
            replace: BooleanConstructor;
            to: vue.PropType<vue_router.RouteLocationRaw>;
            loading: BooleanConstructor;
            type: {
                type: StringConstructor;
                default: string;
            };
            icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
            prependIcon: (StringConstructor | ObjectConstructor)[];
            appendIcon: (StringConstructor | ObjectConstructor)[];
            stacked: BooleanConstructor;
            block: BooleanConstructor;
            text: (StringConstructor | NumberConstructor)[];
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            overlay: {
                type: BooleanConstructor;
                default: boolean;
            };
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            type: string;
            loading: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            absolute: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            stacked: boolean;
            block: boolean;
            overlay: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        value: null;
        disabled: BooleanConstructor;
        selectedClass: StringConstructor;
        elevation: {
            type: (StringConstructor | NumberConstructor)[];
            validator(v: any): boolean;
        };
        shape: Omit<{
            type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        };
        border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        density: {
            type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: vue.PropType<Size | undefined>;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        absolute: BooleanConstructor;
        bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        fixed: BooleanConstructor;
        left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        position: {
            type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
            validator: (v: any) => boolean;
        };
        right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<Omit<{
            type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
            default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        };
        theme: StringConstructor;
        tag: Omit<{
            type: StringConstructor;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<string>;
            default: string;
        };
        href: StringConstructor;
        replace: BooleanConstructor;
        to: vue.PropType<vue_router.RouteLocationRaw>;
        loading: BooleanConstructor;
        type: {
            type: StringConstructor;
            default: string;
        };
        icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
        prependIcon: (StringConstructor | ObjectConstructor)[];
        appendIcon: (StringConstructor | ObjectConstructor)[];
        stacked: BooleanConstructor;
        block: BooleanConstructor;
        text: (StringConstructor | NumberConstructor)[];
        ripple: {
            type: BooleanConstructor;
            default: boolean;
        };
        overlay: {
            type: BooleanConstructor;
            default: boolean;
        };
    } & {
        $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild | {
            default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>>;
        default: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    loading: BooleanConstructor;
    type: {
        type: StringConstructor;
        default: string;
    };
    icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
    prependIcon: (StringConstructor | ObjectConstructor)[];
    appendIcon: (StringConstructor | ObjectConstructor)[];
    stacked: BooleanConstructor;
    block: BooleanConstructor;
    text: (StringConstructor | NumberConstructor)[];
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    overlay: {
        type: BooleanConstructor;
        default: boolean;
    };
} & {
    $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | vue.VNodeChild | {
        default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        separator?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        separator?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    type: string;
    loading: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    stacked: boolean;
    block: boolean;
    overlay: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: MakeSlots<{
        default: [
        ];
        separator: [
        ];
    }>;
});

declare const Button: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    loading: BooleanConstructor;
    type: {
        type: StringConstructor;
        default: string;
    };
    icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
    prependIcon: (StringConstructor | ObjectConstructor)[];
    appendIcon: (StringConstructor | ObjectConstructor)[];
    stacked: BooleanConstructor;
    block: BooleanConstructor;
    text: (StringConstructor | NumberConstructor)[];
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    overlay: {
        type: BooleanConstructor;
        default: boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    click: (_event: MouseEvent) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    loading: BooleanConstructor;
    type: {
        type: StringConstructor;
        default: string;
    };
    icon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
    prependIcon: (StringConstructor | ObjectConstructor)[];
    appendIcon: (StringConstructor | ObjectConstructor)[];
    stacked: BooleanConstructor;
    block: BooleanConstructor;
    text: (StringConstructor | NumberConstructor)[];
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    overlay: {
        type: BooleanConstructor;
        default: boolean;
    };
}>> & {
    onClick?: ((_event: MouseEvent) => any) | undefined;
}, {
    type: string;
    loading: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    stacked: boolean;
    block: boolean;
    overlay: boolean;
}>;
type Button = InstanceType<typeof Button>;

declare const ButtonGroup: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    disabled: BooleanConstructor;
    /**
     * @zh 是否有分割线
     */
    divided: BooleanConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    disabled: BooleanConstructor;
    /**
     * @zh 是否有分割线
     */
    divided: BooleanConstructor;
}>>, {
    divided: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
}>;

declare const ButtonToggle: vue.DefineComponent<{
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: vue.PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
}, {
    next: () => void;
    prev: () => void;
    select: (id: string, isSelected: boolean) => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_value: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: vue.PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
}>> & {
    "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
}, {
    modelValue: string | number | boolean | Record<string, any> | unknown[];
    disabled: boolean;
    selectedClass: string;
    multiple: boolean;
}>;

declare const Card: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    disabled: BooleanConstructor;
    loading: BooleanConstructor;
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    link: BooleanConstructor;
    hover: BooleanConstructor;
    image: StringConstructor;
    prependAvatar: StringConstructor;
    prependIcon: StringConstructor;
    appendAvatar: StringConstructor;
    appendIcon: StringConstructor;
    title: StringConstructor;
    subtitle: StringConstructor;
    divided: BooleanConstructor;
    text: StringConstructor;
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    disabled: BooleanConstructor;
    loading: BooleanConstructor;
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    link: BooleanConstructor;
    hover: BooleanConstructor;
    image: StringConstructor;
    prependAvatar: StringConstructor;
    prependIcon: StringConstructor;
    appendAvatar: StringConstructor;
    appendIcon: StringConstructor;
    title: StringConstructor;
    subtitle: StringConstructor;
    divided: BooleanConstructor;
    text: StringConstructor;
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
}>>, {
    loading: boolean;
    link: boolean;
    hover: boolean;
    divided: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
}>;

declare const CardImage: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardAvatar: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardHeader: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardHeaderText: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardTitle: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardSubtitle: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardActions: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const CardText: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const Carousel: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: Omit<{
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined> | undefined>;
        default: NonNullable<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined> | undefined;
    };
    size: Omit<{
        type: vue.PropType<Size | undefined>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Size | undefined> | undefined>;
        default: NonNullable<Size | undefined> | undefined;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: {
        type: vue.PropType<NonNullable<boolean | "force">>;
        default: NonNullable<boolean | "force">;
    };
    max: NumberConstructor;
    selectedClass: StringConstructor;
    disabled: BooleanConstructor;
    /**
     * @zh 自动播放
     */
    autoplay: BooleanConstructor;
    /**
     * @zh 播放的时间间隔
     */
    interval: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_value: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: Omit<{
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined> | undefined>;
        default: NonNullable<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined> | undefined;
    };
    size: Omit<{
        type: vue.PropType<Size | undefined>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Size | undefined> | undefined>;
        default: NonNullable<Size | undefined> | undefined;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: {
        type: vue.PropType<NonNullable<boolean | "force">>;
        default: NonNullable<boolean | "force">;
    };
    max: NumberConstructor;
    selectedClass: StringConstructor;
    disabled: BooleanConstructor;
    /**
     * @zh 自动播放
     */
    autoplay: BooleanConstructor;
    /**
     * @zh 播放的时间间隔
     */
    interval: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
}>> & {
    "onUpdate:modelValue"?: ((_value: any) => any) | undefined;
}, {
    modelValue: string | number | boolean | Record<string, any> | unknown[];
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: NonNullable<Size | undefined> | undefined;
    density: NonNullable<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined> | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    multiple: boolean;
    mandatory: NonNullable<boolean | "force">;
    autoplay: boolean;
    interval: string | number;
}>;
type Carousel = InstanceType<typeof Carousel>;

declare const CarouselItem: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
}>>, {
    disabled: boolean;
    tag: string;
}>;
type CarouselItem = InstanceType<typeof CarouselItem>;

declare const Checkbox: vue.DefineComponent<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    trueIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
    /**
     * @zh 不确定的
     */
    indeterminate: BooleanConstructor;
    /**
     * @zh 不确定的图标
     */
    indeterminateIcon: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_val: any) => true;
    'update:indeterminate': (_val: boolean) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    trueIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
    /**
     * @zh 不确定的
     */
    indeterminate: BooleanConstructor;
    /**
     * @zh 不确定的图标
     */
    indeterminateIcon: {
        type: StringConstructor;
        default: string;
    };
}>> & {
    "onUpdate:modelValue"?: ((_val: any) => any) | undefined;
    "onUpdate:indeterminate"?: ((_val: boolean) => any) | undefined;
}, {
    type: string;
    error: boolean;
    disabled: boolean;
    color: string;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: boolean | null;
    falseIcon: string;
    trueIcon: string;
    readonly: boolean;
    valueComparator: typeof _veno_ui_utils.deepEqual;
    indeterminate: boolean;
    indeterminateIcon: string;
}>;

interface CheckboxGroupItemProps {
    value: any;
    [key: string]: any;
}
declare const CheckboxGroup: vue.DefineComponent<{
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: {
        type: PropType<string>;
        default: string;
    };
    trueIcon: {
        type: PropType<string>;
        default: string;
    };
    multiple: Omit<{
        type: PropType<boolean | null>;
        default: null;
    }, "default" | "type"> & {
        type: PropType<NonNullable<boolean | null>>;
        default: NonNullable<boolean | null>;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: {
        type: PropType<string>;
        default: string;
    };
    modelValue: null;
    /**
     * @zh 复选框的所有可选项
     */
    items: PropType<(string | CheckboxGroupItemProps)[]>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_val: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: {
        type: PropType<string>;
        default: string;
    };
    trueIcon: {
        type: PropType<string>;
        default: string;
    };
    multiple: Omit<{
        type: PropType<boolean | null>;
        default: null;
    }, "default" | "type"> & {
        type: PropType<NonNullable<boolean | null>>;
        default: NonNullable<boolean | null>;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: {
        type: PropType<string>;
        default: string;
    };
    modelValue: null;
    /**
     * @zh 复选框的所有可选项
     */
    items: PropType<(string | CheckboxGroupItemProps)[]>;
}>> & {
    "onUpdate:modelValue"?: ((_val: any) => any) | undefined;
}, {
    type: string;
    disabled: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: NonNullable<boolean | null>;
    falseIcon: string;
    trueIcon: string;
    readonly: boolean;
}>;

declare const Code: vue.DefineComponent<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    shape: {
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    theme: StringConstructor;
    /**
     * @zh 需要高亮的代码
     */
    code: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 背景颜色
     */
    color: StringConstructor;
    /**
     * @zh 显示代码语言
     */
    showLanguage: BooleanConstructor;
    /**
     * @zh 显示行号
     */
    showLineNumbers: BooleanConstructor;
    /**
     * @zh 高亮的行号
     */
    highlightedLineNumbers: PropType<number[] | number[][]>;
    /**
     * @zh 使用行内样式
     */
    inline: BooleanConstructor;
    /**
     * @zh 代码语言
     */
    language: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    shape: {
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    theme: StringConstructor;
    /**
     * @zh 需要高亮的代码
     */
    code: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 背景颜色
     */
    color: StringConstructor;
    /**
     * @zh 显示代码语言
     */
    showLanguage: BooleanConstructor;
    /**
     * @zh 显示行号
     */
    showLineNumbers: BooleanConstructor;
    /**
     * @zh 高亮的行号
     */
    highlightedLineNumbers: PropType<number[] | number[][]>;
    /**
     * @zh 使用行内样式
     */
    inline: BooleanConstructor;
    /**
     * @zh 代码语言
     */
    language: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    inline: boolean;
    beautifyScrollbar: boolean;
    showLanguage: boolean;
    showLineNumbers: boolean;
    language: string;
}>;

type CounterSlot = {
    counter: string;
    max: number;
    value: number;
};
type CounterSlots = MakeSlots<{
    default: [CounterSlot];
}>;
declare const Counter: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            active: boolean;
            value: string | number;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            active: BooleanConstructor;
            max: (StringConstructor | NumberConstructor)[];
            value: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "transition" | "active" | "value">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            active: BooleanConstructor;
            max: (StringConstructor | NumberConstructor)[];
            value: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            active: boolean;
            value: string | number;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        transition: Omit<{
            type: vue.PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        };
        active: BooleanConstructor;
        max: (StringConstructor | NumberConstructor)[];
        value: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
        };
    } & {
        $children: () => vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            default?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            default?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    active: BooleanConstructor;
    max: (StringConstructor | NumberConstructor)[];
    value: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
} & {
    $children: () => vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        default?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        default?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
    active: boolean;
    value: string | number;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: CounterSlots;
});

interface InputControlSlot {
    isActive: boolean;
    isDirty: boolean;
    isFocused: boolean;
    inputRef: Ref<HTMLInputElement | undefined>;
    controlRef: Ref<HTMLElement | undefined>;
    blur: () => void;
    focus: () => void;
}
type InputControlDefaultSlot = InputControlSlot & {
    props: Record<string, unknown>;
};
type InputControlSlots = MakeSlots<{
    'prepend-inner': [InputControlSlot];
    prefix: [InputControlSlot];
    default: [InputControlDefaultSlot];
    suffix: [InputControlSlot];
    'append-inner': [InputControlSlot];
    clear: [InputControlSlot];
}>;
declare const InputControlSlots: string[];
declare const InputControl: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "disabled" | "variant" | "shape" | "active" | "clearable" | "clearIcon" | "dirty">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        }, {
            inputRef: Ref<HTMLInputElement | undefined>;
            controlRef: Ref<HTMLElement | undefined>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:clear': (_event: MouseEvent) => boolean;
            'click:prepend-inner': (_event: MouseEvent) => boolean;
            'click:prefix': (_event: MouseEvent) => boolean;
            'click:suffix': (_event: MouseEvent) => boolean;
            'click:append-inner': (_event: MouseEvent) => boolean;
            'click:control': (_event: MouseEvent) => boolean;
            'update:active': (_active: boolean) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        shape: Omit<{
            type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        };
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        };
        appendInnerIcon: (StringConstructor | ObjectConstructor)[];
        clearable: BooleanConstructor;
        clearIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        disabled: BooleanConstructor;
        prependInnerIcon: (StringConstructor | ObjectConstructor)[];
        prefix: StringConstructor;
        prefixIcon: (StringConstructor | ObjectConstructor)[];
        suffix: StringConstructor;
        suffixIcon: (StringConstructor | ObjectConstructor)[];
        active: BooleanConstructor;
        dirty: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:active"?: ((_active: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        inputRef: Ref<HTMLInputElement | undefined>;
        controlRef: Ref<HTMLElement | undefined>;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
    clearable: BooleanConstructor;
    clearIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    disabled: BooleanConstructor;
    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
    prefix: StringConstructor;
    prefixIcon: (StringConstructor | ObjectConstructor)[];
    suffix: StringConstructor;
    suffixIcon: (StringConstructor | ObjectConstructor)[];
    active: BooleanConstructor;
    dirty: BooleanConstructor;
} & {
    $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
    "onUpdate:active"?: ((_active: boolean) => any) | undefined;
}, {
    inputRef: Ref<HTMLInputElement | undefined>;
    controlRef: Ref<HTMLElement | undefined>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'click:clear': (_event: MouseEvent) => boolean;
    'click:prepend-inner': (_event: MouseEvent) => boolean;
    'click:prefix': (_event: MouseEvent) => boolean;
    'click:suffix': (_event: MouseEvent) => boolean;
    'click:append-inner': (_event: MouseEvent) => boolean;
    'click:control': (_event: MouseEvent) => boolean;
    'update:active': (_active: boolean) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
}, string, {
    disabled: boolean;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    active: boolean;
    clearable: boolean;
    clearIcon: string | Record<string, any>;
    dirty: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: InputControlSlots;
});
type InputControl = InstanceType<typeof InputControl>;

type ValidationResult = string | true;
type ValidationRule = ValidationResult | PromiseLike<ValidationResult> | ((value: any) => ValidationResult) | ((value: any) => PromiseLike<ValidationResult>);

type FormControlSlot = {
    isDisabled: ComputedRef<boolean>;
    isReadonly: ComputedRef<boolean>;
    isPristine: Ref<boolean | null>;
    isValid: ComputedRef<boolean | null>;
    isValidating: Ref<boolean>;
    reset: () => void;
    resetValidation: () => void;
    validate: () => void;
};
type FormControlSlots = MakeSlots<{
    prepend: [FormControlSlot];
    label: [FormControlSlot];
    default: [FormControlSlot & {
        props: Record<string, unknown>;
    }];
    append: [FormControlSlot];
    details: [FormControlSlot];
}>;
declare const FormControlSlots: string[];
declare const FormControl: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 布局方向
             */
            direction: {
                type: PropType<"vertical" | "horizontal">;
                default: string;
                validator: (v: any) => boolean;
            };
            /**
             * @zh 聚焦的
             */
            focused: BooleanConstructor;
            /**
             * @zh 隐藏详情
             */
            hideDetails: PropType<boolean | "auto">;
            /**
             * @zh 存在提示
             */
            hint: StringConstructor;
            /**
             * @zh 内联
             */
            inline: BooleanConstructor;
            /**
             * @zh 标签文本
             */
            label: (BooleanConstructor | StringConstructor)[];
            /**
             * @zh 标签ID
             */
            labelId: StringConstructor;
            /**
             * @zh 标签宽度
             */
            labelWidth: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 提示消息
             */
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 名称
             */
            name: StringConstructor;
            /**
             * @zh 后置图标
             */
            prependIcon: StringConstructor;
            /**
             * @zh 持续显示的提示
             */
            persistentHint: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "readonly" | "direction" | "errorMessages" | "focused" | "persistentHint" | "messages" | "maxErrors" | "rules">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 布局方向
             */
            direction: {
                type: PropType<"vertical" | "horizontal">;
                default: string;
                validator: (v: any) => boolean;
            };
            /**
             * @zh 聚焦的
             */
            focused: BooleanConstructor;
            /**
             * @zh 隐藏详情
             */
            hideDetails: PropType<boolean | "auto">;
            /**
             * @zh 存在提示
             */
            hint: StringConstructor;
            /**
             * @zh 内联
             */
            inline: BooleanConstructor;
            /**
             * @zh 标签文本
             */
            label: (BooleanConstructor | StringConstructor)[];
            /**
             * @zh 标签ID
             */
            labelId: StringConstructor;
            /**
             * @zh 标签宽度
             */
            labelWidth: (StringConstructor | NumberConstructor)[];
            /**
             * @zh 提示消息
             */
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 名称
             */
            name: StringConstructor;
            /**
             * @zh 后置图标
             */
            prependIcon: StringConstructor;
            /**
             * @zh 持续显示的提示
             */
            persistentHint: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        }, {
            isDisabled: ComputedRef<boolean>;
            isReadonly: ComputedRef<boolean>;
            isPristine: Ref<boolean>;
            isValid: ComputedRef<boolean | null>;
            isValidating: Ref<boolean>;
            reset: () => void;
            resetValidation: () => void;
            validate: () => Promise<string[]>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:prepend': (_event: MouseEvent) => boolean;
            'click:label': (_event: MouseEvent) => boolean;
            'click:append': (_event: MouseEvent) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        disabled: BooleanConstructor;
        error: BooleanConstructor;
        errorMessages: {
            type: PropType<string | string[]>;
            default: () => never[];
        };
        maxErrors: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
        };
        readonly: BooleanConstructor;
        rules: {
            type: PropType<ValidationRule[]>;
            default: () => never[];
        };
        modelValue: null;
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: PropType<Size | undefined>;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        /**
         * @zh 后置图标
         */
        appendIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 布局方向
         */
        direction: {
            type: PropType<"vertical" | "horizontal">;
            default: string;
            validator: (v: any) => boolean;
        };
        /**
         * @zh 聚焦的
         */
        focused: BooleanConstructor;
        /**
         * @zh 隐藏详情
         */
        hideDetails: PropType<boolean | "auto">;
        /**
         * @zh 存在提示
         */
        hint: StringConstructor;
        /**
         * @zh 内联
         */
        inline: BooleanConstructor;
        /**
         * @zh 标签文本
         */
        label: (BooleanConstructor | StringConstructor)[];
        /**
         * @zh 标签ID
         */
        labelId: StringConstructor;
        /**
         * @zh 标签宽度
         */
        labelWidth: (StringConstructor | NumberConstructor)[];
        /**
         * @zh 提示消息
         */
        messages: {
            type: (StringConstructor | ArrayConstructor)[];
            default: () => never[];
        };
        /**
         * @zh 名称
         */
        name: StringConstructor;
        /**
         * @zh 后置图标
         */
        prependIcon: StringConstructor;
        /**
         * @zh 持续显示的提示
         */
        persistentHint: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        isDisabled: ComputedRef<boolean>;
        isReadonly: ComputedRef<boolean>;
        isPristine: Ref<boolean>;
        isValid: ComputedRef<boolean | null>;
        isValidating: Ref<boolean>;
        reset: () => void;
        resetValidation: () => void;
        validate: () => Promise<string[]>;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    errorMessages: {
        type: PropType<string | string[]>;
        default: () => never[];
    };
    maxErrors: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    readonly: BooleanConstructor;
    rules: {
        type: PropType<ValidationRule[]>;
        default: () => never[];
    };
    modelValue: null;
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 后置图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 布局方向
     */
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
        validator: (v: any) => boolean;
    };
    /**
     * @zh 聚焦的
     */
    focused: BooleanConstructor;
    /**
     * @zh 隐藏详情
     */
    hideDetails: PropType<boolean | "auto">;
    /**
     * @zh 存在提示
     */
    hint: StringConstructor;
    /**
     * @zh 内联
     */
    inline: BooleanConstructor;
    /**
     * @zh 标签文本
     */
    label: (BooleanConstructor | StringConstructor)[];
    /**
     * @zh 标签ID
     */
    labelId: StringConstructor;
    /**
     * @zh 标签宽度
     */
    labelWidth: (StringConstructor | NumberConstructor)[];
    /**
     * @zh 提示消息
     */
    messages: {
        type: (StringConstructor | ArrayConstructor)[];
        default: () => never[];
    };
    /**
     * @zh 名称
     */
    name: StringConstructor;
    /**
     * @zh 后置图标
     */
    prependIcon: StringConstructor;
    /**
     * @zh 持续显示的提示
     */
    persistentHint: BooleanConstructor;
} & {
    $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
}, {
    isDisabled: ComputedRef<boolean>;
    isReadonly: ComputedRef<boolean>;
    isPristine: Ref<boolean>;
    isValid: ComputedRef<boolean | null>;
    isValidating: Ref<boolean>;
    reset: () => void;
    resetValidation: () => void;
    validate: () => Promise<string[]>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'click:prepend': (_event: MouseEvent) => boolean;
    'click:label': (_event: MouseEvent) => boolean;
    'click:append': (_event: MouseEvent) => boolean;
    'update:modelValue': (_modelValue: any) => boolean;
}, string, {
    error: boolean;
    disabled: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    readonly: boolean;
    direction: "vertical" | "horizontal";
    errorMessages: string | string[];
    focused: boolean;
    persistentHint: boolean;
    messages: string | unknown[];
    maxErrors: string | number;
    rules: ValidationRule[];
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: FormControlSlots;
});
type FormControl = InstanceType<typeof FormControl>;

type InputSlots = FormControlSlots & InputControlSlots & MakeSlots<{
    counter: [CounterSlot];
    default: [InputControlDefaultSlot];
}>;
declare const Input: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            type: string;
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            autofocus: boolean;
            autoResize: boolean;
            noResize: boolean;
            persistentCounter: boolean;
            rows: string | number;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            autofocus: BooleanConstructor;
            autoResize: BooleanConstructor;
            counter: PropType<string | number | true>;
            counterValue: PropType<(value: any) => number>;
            id: StringConstructor;
            inputAttach: PropType<string | boolean | Element>;
            maxRows: {
                type: (StringConstructor | NumberConstructor)[];
                validator: (v: any) => boolean;
            };
            controlValue: null;
            modelValue: null;
            name: StringConstructor;
            noResize: BooleanConstructor;
            persistentCounter: BooleanConstructor;
            placeholder: StringConstructor;
            rows: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
                validator: (v: any) => boolean;
            };
            type: {
                type: StringConstructor;
                default: string;
            };
            width: (StringConstructor | NumberConstructor)[];
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: string) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:controlValue"?: ((_: string) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "type" | "disabled" | "variant" | "shape" | "autofocus" | "autoResize" | "noResize" | "persistentCounter" | "rows" | "clearable" | "clearIcon">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _: string) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void) & ((event: "update:controlValue", _: string) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            autofocus: BooleanConstructor;
            autoResize: BooleanConstructor;
            counter: PropType<string | number | true>;
            counterValue: PropType<(value: any) => number>;
            id: StringConstructor;
            inputAttach: PropType<string | boolean | Element>;
            maxRows: {
                type: (StringConstructor | NumberConstructor)[];
                validator: (v: any) => boolean;
            };
            controlValue: null;
            modelValue: null;
            name: StringConstructor;
            noResize: BooleanConstructor;
            persistentCounter: BooleanConstructor;
            placeholder: StringConstructor;
            rows: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
                validator: (v: any) => boolean;
            };
            type: {
                type: StringConstructor;
                default: string;
            };
            width: (StringConstructor | NumberConstructor)[];
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: string) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:controlValue"?: ((_: string) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        }, {
            formControlRef: vue.Ref<({
                $: vue.ComponentInternalInstance;
                $data: {};
                $props: Partial<{
                    error: boolean;
                    disabled: boolean;
                    size: Size | undefined;
                    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
                    inline: boolean;
                    readonly: boolean;
                    direction: "vertical" | "horizontal";
                    errorMessages: string | string[];
                    focused: boolean;
                    persistentHint: boolean;
                    messages: string | unknown[];
                    maxErrors: string | number;
                    rules: ValidationRule[];
                }> & Omit<Readonly<vue.ExtractPropTypes<{
                    disabled: BooleanConstructor;
                    error: BooleanConstructor;
                    errorMessages: {
                        type: PropType<string | string[]>;
                        default: () => never[];
                    };
                    maxErrors: {
                        type: (StringConstructor | NumberConstructor)[];
                        default: number;
                    };
                    readonly: BooleanConstructor;
                    rules: {
                        type: PropType<ValidationRule[]>;
                        default: () => never[];
                    };
                    modelValue: null;
                    density: {
                        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                        default: string;
                        validator: (v: any) => boolean;
                    };
                    size: {
                        type: PropType<Size | undefined>;
                        default: string;
                    };
                    height: (StringConstructor | NumberConstructor)[];
                    maxHeight: (StringConstructor | NumberConstructor)[];
                    maxWidth: (StringConstructor | NumberConstructor)[];
                    minHeight: (StringConstructor | NumberConstructor)[];
                    minWidth: (StringConstructor | NumberConstructor)[];
                    width: (StringConstructor | NumberConstructor)[];
                    appendIcon: (StringConstructor | ObjectConstructor)[];
                    direction: {
                        type: PropType<"vertical" | "horizontal">; /**
                         * @zh 输入框 name
                         */
                        default: string;
                        validator: (v: any) => boolean;
                    };
                    focused: BooleanConstructor;
                    hideDetails: PropType<boolean | "auto">;
                    hint: StringConstructor;
                    inline: BooleanConstructor;
                    label: (BooleanConstructor | StringConstructor)[];
                    labelId: StringConstructor;
                    labelWidth: (StringConstructor | NumberConstructor)[];
                    messages: {
                        type: (StringConstructor | ArrayConstructor)[];
                        default: () => never[];
                    };
                    name: StringConstructor;
                    prependIcon: StringConstructor;
                    persistentHint: BooleanConstructor;
                } & {
                    $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | {
                        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                            props: Record<string, unknown>;
                        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                    };
                    'v-slots': new () => {
                        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        default?: false | ((args_0: FormControlSlot & {
                            props: Record<string, unknown>;
                        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                    };
                }>> & {
                    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                    "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
                } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "readonly" | "direction" | "errorMessages" | "focused" | "persistentHint" | "messages" | "maxErrors" | "rules">;
                $attrs: {
                    [x: string]: unknown;
                };
                $refs: {
                    [x: string]: unknown;
                };
                $slots: Readonly<{
                    [name: string]: vue.Slot | undefined;
                }>;
                $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
                $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
                $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void);
                $el: any;
                $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
                    disabled: BooleanConstructor;
                    error: BooleanConstructor;
                    errorMessages: {
                        type: PropType<string | string[]>;
                        default: () => never[];
                    };
                    maxErrors: {
                        type: (StringConstructor | NumberConstructor)[];
                        default: number;
                    };
                    readonly: BooleanConstructor;
                    rules: {
                        type: PropType<ValidationRule[]>;
                        default: () => never[];
                    };
                    modelValue: null;
                    density: {
                        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                        default: string;
                        validator: (v: any) => boolean;
                    };
                    size: {
                        type: PropType<Size | undefined>;
                        default: string;
                    };
                    height: (StringConstructor | NumberConstructor)[];
                    maxHeight: (StringConstructor | NumberConstructor)[];
                    maxWidth: (StringConstructor | NumberConstructor)[];
                    minHeight: (StringConstructor | NumberConstructor)[];
                    minWidth: (StringConstructor | NumberConstructor)[];
                    width: (StringConstructor | NumberConstructor)[];
                    appendIcon: (StringConstructor | ObjectConstructor)[];
                    direction: {
                        type: PropType<"vertical" | "horizontal">; /**
                         * @zh 输入框 name
                         */
                        default: string;
                        validator: (v: any) => boolean;
                    };
                    focused: BooleanConstructor;
                    hideDetails: PropType<boolean | "auto">;
                    hint: StringConstructor;
                    inline: BooleanConstructor;
                    label: (BooleanConstructor | StringConstructor)[];
                    labelId: StringConstructor;
                    labelWidth: (StringConstructor | NumberConstructor)[];
                    messages: {
                        type: (StringConstructor | ArrayConstructor)[];
                        default: () => never[];
                    };
                    name: StringConstructor;
                    prependIcon: StringConstructor;
                    persistentHint: BooleanConstructor;
                } & {
                    $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | {
                        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                            props: Record<string, unknown>;
                        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                    };
                    'v-slots': new () => {
                        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        default?: false | ((args_0: FormControlSlot & {
                            props: Record<string, unknown>;
                        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                    };
                }>> & {
                    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                    "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
                }, {
                    isDisabled: vue.ComputedRef<boolean>;
                    isReadonly: vue.ComputedRef<boolean>;
                    isPristine: vue.Ref<boolean>;
                    isValid: vue.ComputedRef<boolean | null>;
                    isValidating: vue.Ref<boolean>;
                    reset: () => void;
                    resetValidation: () => void;
                    validate: () => Promise<string[]>;
                }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
                    'click:prepend': (_event: MouseEvent) => boolean;
                    'click:label': (_event: MouseEvent) => boolean;
                    'click:append': (_event: MouseEvent) => boolean;
                    'update:modelValue': (_modelValue: any) => boolean;
                }, string, {
                    error: boolean;
                    disabled: boolean;
                    size: Size | undefined;
                    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
                    inline: boolean;
                    readonly: boolean;
                    direction: "vertical" | "horizontal";
                    errorMessages: string | string[];
                    focused: boolean;
                    persistentHint: boolean;
                    messages: string | unknown[];
                    maxErrors: string | number;
                    rules: ValidationRule[];
                }, {}, string> & {
                    beforeCreate?: ((() => void) | (() => void)[]) | undefined;
                    created?: ((() => void) | (() => void)[]) | undefined;
                    beforeMount?: ((() => void) | (() => void)[]) | undefined;
                    mounted?: ((() => void) | (() => void)[]) | undefined;
                    beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
                    updated?: ((() => void) | (() => void)[]) | undefined;
                    activated?: ((() => void) | (() => void)[]) | undefined;
                    deactivated?: ((() => void) | (() => void)[]) | undefined;
                    beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
                    beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
                    destroyed?: ((() => void) | (() => void)[]) | undefined;
                    unmounted?: ((() => void) | (() => void)[]) | undefined;
                    renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                    renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                    errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
                };
                $forceUpdate: () => void;
                $nextTick: typeof nextTick;
                $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
            } & Readonly<vue.ExtractPropTypes<{
                disabled: BooleanConstructor;
                error: BooleanConstructor;
                errorMessages: {
                    type: PropType<string | string[]>;
                    default: () => never[];
                };
                maxErrors: {
                    type: (StringConstructor | NumberConstructor)[];
                    default: number;
                };
                readonly: BooleanConstructor;
                rules: {
                    type: PropType<ValidationRule[]>;
                    default: () => never[];
                };
                modelValue: null;
                density: {
                    type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                    default: string;
                    validator: (v: any) => boolean;
                };
                size: {
                    type: PropType<Size | undefined>;
                    default: string;
                };
                height: (StringConstructor | NumberConstructor)[];
                maxHeight: (StringConstructor | NumberConstructor)[];
                maxWidth: (StringConstructor | NumberConstructor)[];
                minHeight: (StringConstructor | NumberConstructor)[];
                minWidth: (StringConstructor | NumberConstructor)[];
                width: (StringConstructor | NumberConstructor)[];
                appendIcon: (StringConstructor | ObjectConstructor)[];
                direction: {
                    type: PropType<"vertical" | "horizontal">; /**
                     * @zh 输入框 name
                     */
                    default: string;
                    validator: (v: any) => boolean;
                };
                focused: BooleanConstructor;
                hideDetails: PropType<boolean | "auto">;
                hint: StringConstructor;
                inline: BooleanConstructor;
                label: (BooleanConstructor | StringConstructor)[];
                labelId: StringConstructor;
                labelWidth: (StringConstructor | NumberConstructor)[];
                messages: {
                    type: (StringConstructor | ArrayConstructor)[];
                    default: () => never[];
                };
                name: StringConstructor;
                prependIcon: StringConstructor;
                persistentHint: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
            } & vue.ShallowUnwrapRef<{
                isDisabled: vue.ComputedRef<boolean>;
                isReadonly: vue.ComputedRef<boolean>;
                isPristine: vue.Ref<boolean>;
                isValid: vue.ComputedRef<boolean | null>;
                isValidating: vue.Ref<boolean>;
                reset: () => void;
                resetValidation: () => void;
                validate: () => Promise<string[]>;
            }> & {} & vue.ComponentCustomProperties & {} & {
                $slots: MakeSlots<{
                    prepend: [FormControlSlot];
                    label: [FormControlSlot];
                    default: [FormControlSlot & {
                        props: Record<string, unknown>;
                    }];
                    append: [FormControlSlot];
                    details: [FormControlSlot];
                }>;
            }) | undefined>;
            inputControlRef: vue.Ref<({
                $: vue.ComponentInternalInstance;
                $data: {};
                $props: Partial<{
                    disabled: boolean;
                    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    active: boolean;
                    clearable: boolean;
                    clearIcon: string | Record<string, any>;
                    dirty: boolean;
                }> & Omit<Readonly<vue.ExtractPropTypes<{
                    shape: Omit<{
                        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                        default: string;
                    }, "default" | "type"> & {
                        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    };
                    color: StringConstructor;
                    textColor: StringConstructor;
                    variant: Omit<{
                        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                        default: string;
                        validator: (v: any) => boolean;
                    }, "default" | "type"> & {
                        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    };
                    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
                    clearable: BooleanConstructor;
                    clearIcon: {
                        type: (StringConstructor | ObjectConstructor)[];
                        default: string;
                    };
                    disabled: BooleanConstructor;
                    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
                    prefix: StringConstructor;
                    prefixIcon: (StringConstructor | ObjectConstructor)[];
                    suffix: StringConstructor;
                    suffixIcon: (StringConstructor | ObjectConstructor)[];
                    active: BooleanConstructor;
                    dirty: BooleanConstructor;
                } & {
                    $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | {
                        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                    };
                    'v-slots': new () => {
                        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                    };
                }>> & {
                    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
                    "onUpdate:active"?: ((_active: boolean) => any) | undefined;
                } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "disabled" | "variant" | "shape" | "active" | "clearable" | "clearIcon" | "dirty">;
                $attrs: {
                    [x: string]: unknown;
                };
                $refs: {
                    [x: string]: unknown;
                };
                $slots: Readonly<{
                    [name: string]: vue.Slot | undefined;
                }>;
                $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
                $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
                $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
                $el: any;
                $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
                    shape: Omit<{
                        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                        default: string;
                    }, "default" | "type"> & {
                        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    };
                    color: StringConstructor;
                    textColor: StringConstructor;
                    variant: Omit<{
                        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                        default: string;
                        validator: (v: any) => boolean;
                    }, "default" | "type"> & {
                        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    };
                    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
                    clearable: BooleanConstructor;
                    clearIcon: {
                        type: (StringConstructor | ObjectConstructor)[];
                        default: string;
                    };
                    disabled: BooleanConstructor;
                    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
                    prefix: StringConstructor;
                    prefixIcon: (StringConstructor | ObjectConstructor)[];
                    suffix: StringConstructor;
                    suffixIcon: (StringConstructor | ObjectConstructor)[];
                    active: BooleanConstructor;
                    dirty: BooleanConstructor;
                } & {
                    $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | {
                        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]);
                    };
                    'v-slots': new () => {
                        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                            [key: string]: any;
                        }>[]) | undefined;
                    };
                }>> & {
                    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
                    "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
                    "onUpdate:active"?: ((_active: boolean) => any) | undefined;
                }, {
                    inputRef: vue.Ref<HTMLInputElement | undefined>;
                    controlRef: vue.Ref<HTMLElement | undefined>;
                }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
                    'click:clear': (_event: MouseEvent) => boolean;
                    'click:prepend-inner': (_event: MouseEvent) => boolean;
                    'click:prefix': (_event: MouseEvent) => boolean;
                    'click:suffix': (_event: MouseEvent) => boolean; /**
                     * @zh 持续显示的计数器
                     */
                    'click:append-inner': (_event: MouseEvent) => boolean;
                    'click:control': (_event: MouseEvent) => boolean;
                    'update:active': (_active: boolean) => boolean;
                    'update:modelValue': (_modelValue: any) => boolean;
                }, string, {
                    disabled: boolean;
                    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    active: boolean;
                    clearable: boolean;
                    clearIcon: string | Record<string, any>;
                    dirty: boolean;
                }, {}, string> & {
                    beforeCreate?: ((() => void) | (() => void)[]) | undefined;
                    created?: ((() => void) | (() => void)[]) | undefined;
                    beforeMount?: ((() => void) | (() => void)[]) | undefined;
                    mounted?: ((() => void) | (() => void)[]) | undefined;
                    beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
                    updated?: ((() => void) | (() => void)[]) | undefined;
                    activated?: ((() => void) | (() => void)[]) | undefined;
                    deactivated?: ((() => void) | (() => void)[]) | undefined;
                    beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
                    beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
                    destroyed?: ((() => void) | (() => void)[]) | undefined;
                    unmounted?: ((() => void) | (() => void)[]) | undefined;
                    renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                    renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                    errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
                };
                $forceUpdate: () => void;
                $nextTick: typeof nextTick;
                $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
            } & Readonly<vue.ExtractPropTypes<{
                shape: Omit<{
                    type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    default: string;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                    default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                };
                color: StringConstructor;
                textColor: StringConstructor;
                variant: Omit<{
                    type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    default: string;
                    validator: (v: any) => boolean;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                    default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                };
                appendInnerIcon: (StringConstructor | ObjectConstructor)[];
                clearable: BooleanConstructor;
                clearIcon: {
                    type: (StringConstructor | ObjectConstructor)[];
                    default: string;
                };
                disabled: BooleanConstructor;
                prependInnerIcon: (StringConstructor | ObjectConstructor)[];
                prefix: StringConstructor;
                prefixIcon: (StringConstructor | ObjectConstructor)[];
                suffix: StringConstructor;
                suffixIcon: (StringConstructor | ObjectConstructor)[];
                active: BooleanConstructor;
                dirty: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
                "onUpdate:active"?: ((_active: boolean) => any) | undefined;
            } & vue.ShallowUnwrapRef<{
                inputRef: vue.Ref<HTMLInputElement | undefined>;
                controlRef: vue.Ref<HTMLElement | undefined>;
            }> & {} & vue.ComponentCustomProperties & {} & {
                $slots: MakeSlots<{
                    'prepend-inner': [InputControlSlot];
                    prefix: [InputControlSlot];
                    default: [InputControlDefaultSlot];
                    suffix: [InputControlSlot];
                    'append-inner': [InputControlSlot];
                    clear: [InputControlSlot];
                }>;
            }) | undefined>;
            blur: () => void;
            focus: () => void;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_: string) => boolean;
            'update:controlValue': (_: string) => boolean;
            'click:clear': (_event: MouseEvent) => boolean;
            'click:prepend-inner': (_event: MouseEvent) => boolean;
            'click:prefix': (_event: MouseEvent) => boolean;
            'click:suffix': (_event: MouseEvent) => boolean; /**
             * @zh 持续显示的计数器
             */
            'click:append-inner': (_event: MouseEvent) => boolean;
            'click:control': (_event: MouseEvent) => boolean;
            'update:active': (_active: boolean) => boolean;
            'click:prepend': (_event: MouseEvent) => boolean;
            'click:label': (_event: MouseEvent) => boolean;
            'click:append': (_event: MouseEvent) => boolean;
        }, string, {
            type: string;
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            autofocus: boolean;
            autoResize: boolean;
            noResize: boolean;
            persistentCounter: boolean;
            rows: string | number;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        shape: Omit<{
            type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        };
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        };
        appendInnerIcon: (StringConstructor | ObjectConstructor)[];
        clearable: BooleanConstructor;
        clearIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        disabled: BooleanConstructor;
        prependInnerIcon: (StringConstructor | ObjectConstructor)[];
        prefix: StringConstructor;
        prefixIcon: (StringConstructor | ObjectConstructor)[];
        suffix: StringConstructor;
        suffixIcon: (StringConstructor | ObjectConstructor)[];
        autofocus: BooleanConstructor;
        autoResize: BooleanConstructor;
        counter: PropType<string | number | true>;
        counterValue: PropType<(value: any) => number>;
        id: StringConstructor;
        inputAttach: PropType<string | boolean | Element>;
        maxRows: {
            type: (StringConstructor | NumberConstructor)[];
            validator: (v: any) => boolean;
        };
        controlValue: null;
        modelValue: null;
        name: StringConstructor;
        noResize: BooleanConstructor;
        persistentCounter: BooleanConstructor;
        placeholder: StringConstructor;
        rows: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        type: {
            type: StringConstructor;
            default: string;
        };
        width: (StringConstructor | NumberConstructor)[];
    } & {
        $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]));
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_: string) => any) | undefined;
        "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:controlValue"?: ((_: string) => any) | undefined;
        "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:active"?: ((_active: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        formControlRef: vue.Ref<({
            $: vue.ComponentInternalInstance;
            $data: {};
            $props: Partial<{
                error: boolean;
                disabled: boolean;
                size: Size | undefined;
                density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
                inline: boolean;
                readonly: boolean;
                direction: "vertical" | "horizontal";
                errorMessages: string | string[];
                focused: boolean;
                persistentHint: boolean;
                messages: string | unknown[];
                maxErrors: string | number;
                rules: ValidationRule[];
            }> & Omit<Readonly<vue.ExtractPropTypes<{
                disabled: BooleanConstructor;
                error: BooleanConstructor;
                errorMessages: {
                    type: PropType<string | string[]>;
                    default: () => never[];
                };
                maxErrors: {
                    type: (StringConstructor | NumberConstructor)[];
                    default: number;
                };
                readonly: BooleanConstructor;
                rules: {
                    type: PropType<ValidationRule[]>;
                    default: () => never[];
                };
                modelValue: null;
                density: {
                    type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                    default: string;
                    validator: (v: any) => boolean;
                };
                size: {
                    type: PropType<Size | undefined>;
                    default: string;
                };
                height: (StringConstructor | NumberConstructor)[];
                maxHeight: (StringConstructor | NumberConstructor)[];
                maxWidth: (StringConstructor | NumberConstructor)[];
                minHeight: (StringConstructor | NumberConstructor)[];
                minWidth: (StringConstructor | NumberConstructor)[];
                width: (StringConstructor | NumberConstructor)[];
                appendIcon: (StringConstructor | ObjectConstructor)[];
                direction: {
                    type: PropType<"vertical" | "horizontal">; /**
                     * @zh 输入框 name
                     */
                    default: string;
                    validator: (v: any) => boolean;
                };
                focused: BooleanConstructor;
                hideDetails: PropType<boolean | "auto">;
                hint: StringConstructor;
                inline: BooleanConstructor;
                label: (BooleanConstructor | StringConstructor)[];
                labelId: StringConstructor;
                labelWidth: (StringConstructor | NumberConstructor)[];
                messages: {
                    type: (StringConstructor | ArrayConstructor)[];
                    default: () => never[];
                };
                name: StringConstructor;
                prependIcon: StringConstructor;
                persistentHint: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
            } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "readonly" | "direction" | "errorMessages" | "focused" | "persistentHint" | "messages" | "maxErrors" | "rules">;
            $attrs: {
                [x: string]: unknown;
            };
            $refs: {
                [x: string]: unknown;
            };
            $slots: Readonly<{
                [name: string]: vue.Slot | undefined;
            }>;
            $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
            $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
            $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void);
            $el: any;
            $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
                disabled: BooleanConstructor;
                error: BooleanConstructor;
                errorMessages: {
                    type: PropType<string | string[]>;
                    default: () => never[];
                };
                maxErrors: {
                    type: (StringConstructor | NumberConstructor)[];
                    default: number;
                };
                readonly: BooleanConstructor;
                rules: {
                    type: PropType<ValidationRule[]>;
                    default: () => never[];
                };
                modelValue: null;
                density: {
                    type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                    default: string;
                    validator: (v: any) => boolean;
                };
                size: {
                    type: PropType<Size | undefined>;
                    default: string;
                };
                height: (StringConstructor | NumberConstructor)[];
                maxHeight: (StringConstructor | NumberConstructor)[];
                maxWidth: (StringConstructor | NumberConstructor)[];
                minHeight: (StringConstructor | NumberConstructor)[];
                minWidth: (StringConstructor | NumberConstructor)[];
                width: (StringConstructor | NumberConstructor)[];
                appendIcon: (StringConstructor | ObjectConstructor)[];
                direction: {
                    type: PropType<"vertical" | "horizontal">; /**
                     * @zh 输入框 name
                     */
                    default: string;
                    validator: (v: any) => boolean;
                };
                focused: BooleanConstructor;
                hideDetails: PropType<boolean | "auto">;
                hint: StringConstructor;
                inline: BooleanConstructor;
                label: (BooleanConstructor | StringConstructor)[];
                labelId: StringConstructor;
                labelWidth: (StringConstructor | NumberConstructor)[];
                messages: {
                    type: (StringConstructor | ArrayConstructor)[];
                    default: () => never[];
                };
                name: StringConstructor;
                prependIcon: StringConstructor;
                persistentHint: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: FormControlSlot & {
                        props: Record<string, unknown>;
                    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
            }, {
                isDisabled: vue.ComputedRef<boolean>;
                isReadonly: vue.ComputedRef<boolean>;
                isPristine: vue.Ref<boolean>;
                isValid: vue.ComputedRef<boolean | null>;
                isValidating: vue.Ref<boolean>;
                reset: () => void;
                resetValidation: () => void;
                validate: () => Promise<string[]>;
            }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
                'click:prepend': (_event: MouseEvent) => boolean;
                'click:label': (_event: MouseEvent) => boolean;
                'click:append': (_event: MouseEvent) => boolean;
                'update:modelValue': (_modelValue: any) => boolean;
            }, string, {
                error: boolean;
                disabled: boolean;
                size: Size | undefined;
                density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
                inline: boolean;
                readonly: boolean;
                direction: "vertical" | "horizontal";
                errorMessages: string | string[];
                focused: boolean;
                persistentHint: boolean;
                messages: string | unknown[];
                maxErrors: string | number;
                rules: ValidationRule[];
            }, {}, string> & {
                beforeCreate?: ((() => void) | (() => void)[]) | undefined;
                created?: ((() => void) | (() => void)[]) | undefined;
                beforeMount?: ((() => void) | (() => void)[]) | undefined;
                mounted?: ((() => void) | (() => void)[]) | undefined;
                beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
                updated?: ((() => void) | (() => void)[]) | undefined;
                activated?: ((() => void) | (() => void)[]) | undefined;
                deactivated?: ((() => void) | (() => void)[]) | undefined;
                beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
                beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
                destroyed?: ((() => void) | (() => void)[]) | undefined;
                unmounted?: ((() => void) | (() => void)[]) | undefined;
                renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
            };
            $forceUpdate: () => void;
            $nextTick: typeof nextTick;
            $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
        } & Readonly<vue.ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            appendIcon: (StringConstructor | ObjectConstructor)[];
            direction: {
                type: PropType<"vertical" | "horizontal">; /**
                 * @zh 输入框 name
                 */
                default: string;
                validator: (v: any) => boolean;
            };
            focused: BooleanConstructor;
            hideDetails: PropType<boolean | "auto">;
            hint: StringConstructor;
            inline: BooleanConstructor;
            label: (BooleanConstructor | StringConstructor)[];
            labelId: StringConstructor;
            labelWidth: (StringConstructor | NumberConstructor)[];
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            name: StringConstructor;
            prependIcon: StringConstructor;
            persistentHint: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        } & vue.ShallowUnwrapRef<{
            isDisabled: vue.ComputedRef<boolean>;
            isReadonly: vue.ComputedRef<boolean>;
            isPristine: vue.Ref<boolean>;
            isValid: vue.ComputedRef<boolean | null>;
            isValidating: vue.Ref<boolean>;
            reset: () => void;
            resetValidation: () => void;
            validate: () => Promise<string[]>;
        }> & {} & vue.ComponentCustomProperties & {} & {
            $slots: MakeSlots<{
                prepend: [FormControlSlot];
                label: [FormControlSlot];
                default: [FormControlSlot & {
                    props: Record<string, unknown>;
                }];
                append: [FormControlSlot];
                details: [FormControlSlot];
            }>;
        }) | undefined>;
        inputControlRef: vue.Ref<({
            $: vue.ComponentInternalInstance;
            $data: {};
            $props: Partial<{
                disabled: boolean;
                variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                active: boolean;
                clearable: boolean;
                clearIcon: string | Record<string, any>;
                dirty: boolean;
            }> & Omit<Readonly<vue.ExtractPropTypes<{
                shape: Omit<{
                    type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    default: string;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                    default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                };
                color: StringConstructor;
                textColor: StringConstructor;
                variant: Omit<{
                    type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    default: string;
                    validator: (v: any) => boolean;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                    default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                };
                appendInnerIcon: (StringConstructor | ObjectConstructor)[];
                clearable: BooleanConstructor;
                clearIcon: {
                    type: (StringConstructor | ObjectConstructor)[];
                    default: string;
                };
                disabled: BooleanConstructor;
                prependInnerIcon: (StringConstructor | ObjectConstructor)[];
                prefix: StringConstructor;
                prefixIcon: (StringConstructor | ObjectConstructor)[];
                suffix: StringConstructor;
                suffixIcon: (StringConstructor | ObjectConstructor)[];
                active: BooleanConstructor;
                dirty: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
                "onUpdate:active"?: ((_active: boolean) => any) | undefined;
            } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "disabled" | "variant" | "shape" | "active" | "clearable" | "clearIcon" | "dirty">;
            $attrs: {
                [x: string]: unknown;
            };
            $refs: {
                [x: string]: unknown;
            };
            $slots: Readonly<{
                [name: string]: vue.Slot | undefined;
            }>;
            $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
            $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
            $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
            $el: any;
            $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
                shape: Omit<{
                    type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                    default: string;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                    default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                };
                color: StringConstructor;
                textColor: StringConstructor;
                variant: Omit<{
                    type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                    default: string;
                    validator: (v: any) => boolean;
                }, "default" | "type"> & {
                    type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                    default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                };
                appendInnerIcon: (StringConstructor | ObjectConstructor)[];
                clearable: BooleanConstructor;
                clearIcon: {
                    type: (StringConstructor | ObjectConstructor)[];
                    default: string;
                };
                disabled: BooleanConstructor;
                prependInnerIcon: (StringConstructor | ObjectConstructor)[];
                prefix: StringConstructor;
                prefixIcon: (StringConstructor | ObjectConstructor)[];
                suffix: StringConstructor;
                suffixIcon: (StringConstructor | ObjectConstructor)[];
                active: BooleanConstructor;
                dirty: BooleanConstructor;
            } & {
                $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | {
                    'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                    clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]);
                };
                'v-slots': new () => {
                    'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                    clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>[]) | undefined;
                };
            }>> & {
                "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
                "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
                "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
                "onUpdate:active"?: ((_active: boolean) => any) | undefined;
            }, {
                inputRef: vue.Ref<HTMLInputElement | undefined>;
                controlRef: vue.Ref<HTMLElement | undefined>;
            }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
                'click:clear': (_event: MouseEvent) => boolean;
                'click:prepend-inner': (_event: MouseEvent) => boolean;
                'click:prefix': (_event: MouseEvent) => boolean;
                'click:suffix': (_event: MouseEvent) => boolean; /**
                 * @zh 持续显示的计数器
                 */
                'click:append-inner': (_event: MouseEvent) => boolean;
                'click:control': (_event: MouseEvent) => boolean;
                'update:active': (_active: boolean) => boolean;
                'update:modelValue': (_modelValue: any) => boolean;
            }, string, {
                disabled: boolean;
                variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                active: boolean;
                clearable: boolean;
                clearIcon: string | Record<string, any>;
                dirty: boolean;
            }, {}, string> & {
                beforeCreate?: ((() => void) | (() => void)[]) | undefined;
                created?: ((() => void) | (() => void)[]) | undefined;
                beforeMount?: ((() => void) | (() => void)[]) | undefined;
                mounted?: ((() => void) | (() => void)[]) | undefined;
                beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
                updated?: ((() => void) | (() => void)[]) | undefined;
                activated?: ((() => void) | (() => void)[]) | undefined;
                deactivated?: ((() => void) | (() => void)[]) | undefined;
                beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
                beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
                destroyed?: ((() => void) | (() => void)[]) | undefined;
                unmounted?: ((() => void) | (() => void)[]) | undefined;
                renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
                errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
            };
            $forceUpdate: () => void;
            $nextTick: typeof nextTick;
            $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
        } & Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        } & vue.ShallowUnwrapRef<{
            inputRef: vue.Ref<HTMLInputElement | undefined>;
            controlRef: vue.Ref<HTMLElement | undefined>;
        }> & {} & vue.ComponentCustomProperties & {} & {
            $slots: MakeSlots<{
                'prepend-inner': [InputControlSlot];
                prefix: [InputControlSlot];
                default: [InputControlDefaultSlot];
                suffix: [InputControlSlot];
                'append-inner': [InputControlSlot];
                clear: [InputControlSlot];
            }>;
        }) | undefined>;
        blur: () => void;
        focus: () => void;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    shape: Omit<{
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
    clearable: BooleanConstructor;
    clearIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    disabled: BooleanConstructor;
    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
    prefix: StringConstructor;
    prefixIcon: (StringConstructor | ObjectConstructor)[];
    suffix: StringConstructor;
    suffixIcon: (StringConstructor | ObjectConstructor)[];
    autofocus: BooleanConstructor;
    autoResize: BooleanConstructor;
    counter: PropType<string | number | true>;
    counterValue: PropType<(value: any) => number>;
    id: StringConstructor;
    inputAttach: PropType<string | boolean | Element>;
    maxRows: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (v: any) => boolean;
    };
    controlValue: null;
    modelValue: null;
    name: StringConstructor;
    noResize: BooleanConstructor;
    persistentCounter: BooleanConstructor;
    placeholder: StringConstructor;
    rows: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (v: any) => boolean;
    };
    type: {
        type: StringConstructor;
        default: string;
    };
    width: (StringConstructor | NumberConstructor)[];
} & {
    $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[])) | {
        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]));
        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | undefined;
        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_: string) => any) | undefined;
    "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
    "onUpdate:controlValue"?: ((_: string) => any) | undefined;
    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
    "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
    "onUpdate:active"?: ((_active: boolean) => any) | undefined;
}, {
    formControlRef: vue.Ref<({
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            appendIcon: (StringConstructor | ObjectConstructor)[];
            direction: {
                type: PropType<"vertical" | "horizontal">; /**
                 * @zh 输入框 name
                 */
                default: string;
                validator: (v: any) => boolean;
            };
            focused: BooleanConstructor;
            hideDetails: PropType<boolean | "auto">;
            hint: StringConstructor;
            inline: BooleanConstructor;
            label: (BooleanConstructor | StringConstructor)[];
            labelId: StringConstructor;
            labelWidth: (StringConstructor | NumberConstructor)[];
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            name: StringConstructor;
            prependIcon: StringConstructor;
            persistentHint: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "readonly" | "direction" | "errorMessages" | "focused" | "persistentHint" | "messages" | "maxErrors" | "rules">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:prepend", _event: MouseEvent) => void) & ((event: "click:label", _event: MouseEvent) => void) & ((event: "click:append", _event: MouseEvent) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            errorMessages: {
                type: PropType<string | string[]>;
                default: () => never[];
            };
            maxErrors: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
            };
            readonly: BooleanConstructor;
            rules: {
                type: PropType<ValidationRule[]>;
                default: () => never[];
            };
            modelValue: null;
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            appendIcon: (StringConstructor | ObjectConstructor)[];
            direction: {
                type: PropType<"vertical" | "horizontal">; /**
                 * @zh 输入框 name
                 */
                default: string;
                validator: (v: any) => boolean;
            };
            focused: BooleanConstructor;
            hideDetails: PropType<boolean | "auto">;
            hint: StringConstructor;
            inline: BooleanConstructor;
            label: (BooleanConstructor | StringConstructor)[];
            labelId: StringConstructor;
            labelWidth: (StringConstructor | NumberConstructor)[];
            messages: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            name: StringConstructor;
            prependIcon: StringConstructor;
            persistentHint: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
        }, {
            isDisabled: vue.ComputedRef<boolean>;
            isReadonly: vue.ComputedRef<boolean>;
            isPristine: vue.Ref<boolean>;
            isValid: vue.ComputedRef<boolean | null>;
            isValidating: vue.Ref<boolean>;
            reset: () => void;
            resetValidation: () => void;
            validate: () => Promise<string[]>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:prepend': (_event: MouseEvent) => boolean;
            'click:label': (_event: MouseEvent) => boolean;
            'click:append': (_event: MouseEvent) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            readonly: boolean;
            direction: "vertical" | "horizontal";
            errorMessages: string | string[];
            focused: boolean;
            persistentHint: boolean;
            messages: string | unknown[];
            maxErrors: string | number;
            rules: ValidationRule[];
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        disabled: BooleanConstructor;
        error: BooleanConstructor;
        errorMessages: {
            type: PropType<string | string[]>;
            default: () => never[];
        };
        maxErrors: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
        };
        readonly: BooleanConstructor;
        rules: {
            type: PropType<ValidationRule[]>;
            default: () => never[];
        };
        modelValue: null;
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: PropType<Size | undefined>;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        appendIcon: (StringConstructor | ObjectConstructor)[];
        direction: {
            type: PropType<"vertical" | "horizontal">; /**
             * @zh 输入框 name
             */
            default: string;
            validator: (v: any) => boolean;
        };
        focused: BooleanConstructor;
        hideDetails: PropType<boolean | "auto">;
        hint: StringConstructor;
        inline: BooleanConstructor;
        label: (BooleanConstructor | StringConstructor)[];
        labelId: StringConstructor;
        labelWidth: (StringConstructor | NumberConstructor)[];
        messages: {
            type: (StringConstructor | ArrayConstructor)[];
            default: () => never[];
        };
        name: StringConstructor;
        prependIcon: StringConstructor;
        persistentHint: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:prepend"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:label"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append"?: ((_event: MouseEvent) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        isDisabled: vue.ComputedRef<boolean>;
        isReadonly: vue.ComputedRef<boolean>;
        isPristine: vue.Ref<boolean>;
        isValid: vue.ComputedRef<boolean | null>;
        isValidating: vue.Ref<boolean>;
        reset: () => void;
        resetValidation: () => void;
        validate: () => Promise<string[]>;
    }> & {} & vue.ComponentCustomProperties & {} & {
        $slots: MakeSlots<{
            prepend: [FormControlSlot];
            label: [FormControlSlot];
            default: [FormControlSlot & {
                props: Record<string, unknown>;
            }];
            append: [FormControlSlot];
            details: [FormControlSlot];
        }>;
    }) | undefined>;
    inputControlRef: vue.Ref<({
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "disabled" | "variant" | "shape" | "active" | "clearable" | "clearIcon" | "dirty">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "click:prepend-inner", _event: MouseEvent) => void) & ((event: "click:prefix", _event: MouseEvent) => void) & ((event: "click:suffix", _event: MouseEvent) => void) & ((event: "click:append-inner", _event: MouseEvent) => void) & ((event: "click:control", _event: MouseEvent) => void) & ((event: "update:active", _active: boolean) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            active: BooleanConstructor;
            dirty: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
            "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:active"?: ((_active: boolean) => any) | undefined;
        }, {
            inputRef: vue.Ref<HTMLInputElement | undefined>;
            controlRef: vue.Ref<HTMLElement | undefined>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:clear': (_event: MouseEvent) => boolean;
            'click:prepend-inner': (_event: MouseEvent) => boolean;
            'click:prefix': (_event: MouseEvent) => boolean;
            'click:suffix': (_event: MouseEvent) => boolean; /**
             * @zh 持续显示的计数器
             */
            'click:append-inner': (_event: MouseEvent) => boolean;
            'click:control': (_event: MouseEvent) => boolean;
            'update:active': (_active: boolean) => boolean;
            'update:modelValue': (_modelValue: any) => boolean;
        }, string, {
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            active: boolean;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
            dirty: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        shape: Omit<{
            type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        };
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        };
        appendInnerIcon: (StringConstructor | ObjectConstructor)[];
        clearable: BooleanConstructor;
        clearIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        disabled: BooleanConstructor;
        prependInnerIcon: (StringConstructor | ObjectConstructor)[];
        prefix: StringConstructor;
        prefixIcon: (StringConstructor | ObjectConstructor)[];
        suffix: StringConstructor;
        suffixIcon: (StringConstructor | ObjectConstructor)[];
        active: BooleanConstructor;
        dirty: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prepend-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:prefix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:suffix"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:append-inner"?: ((_event: MouseEvent) => any) | undefined;
        "onClick:control"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:active"?: ((_active: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        inputRef: vue.Ref<HTMLInputElement | undefined>;
        controlRef: vue.Ref<HTMLElement | undefined>;
    }> & {} & vue.ComponentCustomProperties & {} & {
        $slots: MakeSlots<{
            'prepend-inner': [InputControlSlot];
            prefix: [InputControlSlot];
            default: [InputControlDefaultSlot];
            suffix: [InputControlSlot];
            'append-inner': [InputControlSlot];
            clear: [InputControlSlot];
        }>;
    }) | undefined>;
    blur: () => void;
    focus: () => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_: string) => boolean;
    'update:controlValue': (_: string) => boolean;
    'click:clear': (_event: MouseEvent) => boolean;
    'click:prepend-inner': (_event: MouseEvent) => boolean;
    'click:prefix': (_event: MouseEvent) => boolean;
    'click:suffix': (_event: MouseEvent) => boolean; /**
     * @zh 持续显示的计数器
     */
    'click:append-inner': (_event: MouseEvent) => boolean;
    'click:control': (_event: MouseEvent) => boolean;
    'update:active': (_active: boolean) => boolean;
    'click:prepend': (_event: MouseEvent) => boolean;
    'click:label': (_event: MouseEvent) => boolean;
    'click:append': (_event: MouseEvent) => boolean;
}, string, {
    type: string;
    disabled: boolean;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    autofocus: boolean;
    autoResize: boolean;
    noResize: boolean;
    persistentCounter: boolean;
    rows: string | number;
    clearable: boolean;
    clearIcon: string | Record<string, any>;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: InputSlots;
});
type Input = InstanceType<typeof Input>;

type DatePickerSlots = InputSlots;
declare const DatePicker: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: string | unknown[];
            readonly: boolean;
            openOnClear: boolean;
            range: boolean;
            appendInnerIcon: string;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            /**
             * @zh 输入框后追加的图标
             */
            appendInnerIcon: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 时间格式化
             */
            format: (StringConstructor | FunctionConstructor | ArrayConstructor)[];
            /**
             * @zh 输入框ID
             */
            id: StringConstructor;
            /**
             * @zh 绑定值
             */
            modelValue: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 点击清除后是否展开菜单面板
             */
            openOnClear: BooleanConstructor;
            /**
             * @zh 面板的属性
             */
            panelProps: ObjectConstructor;
            /**
             * @zh 只读
             */
            readonly: BooleanConstructor;
            /**
             * @zh 开启范围时间选择
             */
            range: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            onChange?: ((_modelValue: any) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "readonly" | "openOnClear" | "range" | "appendInnerIcon">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "change", _modelValue: any) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            /**
             * @zh 输入框后追加的图标
             */
            appendInnerIcon: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 时间格式化
             */
            format: (StringConstructor | FunctionConstructor | ArrayConstructor)[];
            /**
             * @zh 输入框ID
             */
            id: StringConstructor;
            /**
             * @zh 绑定值
             */
            modelValue: {
                type: (StringConstructor | ArrayConstructor)[];
                default: () => never[];
            };
            /**
             * @zh 点击清除后是否展开菜单面板
             */
            openOnClear: BooleanConstructor;
            /**
             * @zh 面板的属性
             */
            panelProps: ObjectConstructor;
            /**
             * @zh 只读
             */
            readonly: BooleanConstructor;
            /**
             * @zh 开启范围时间选择
             */
            range: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            onChange?: ((_modelValue: any) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_modelValue: any) => true;
            change: (_modelValue: any) => true;
        }, string, {
            modelValue: string | unknown[];
            readonly: boolean;
            openOnClear: boolean;
            range: boolean;
            appendInnerIcon: string;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        /**
         * @zh 输入框后追加的图标
         */
        appendInnerIcon: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 时间格式化
         */
        format: (StringConstructor | FunctionConstructor | ArrayConstructor)[];
        /**
         * @zh 输入框ID
         */
        id: StringConstructor;
        /**
         * @zh 绑定值
         */
        modelValue: {
            type: (StringConstructor | ArrayConstructor)[];
            default: () => never[];
        };
        /**
         * @zh 点击清除后是否展开菜单面板
         */
        openOnClear: BooleanConstructor;
        /**
         * @zh 面板的属性
         */
        panelProps: ObjectConstructor;
        /**
         * @zh 只读
         */
        readonly: BooleanConstructor;
        /**
         * @zh 开启范围时间选择
         */
        range: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]));
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        onChange?: ((_modelValue: any) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    /**
     * @zh 输入框后追加的图标
     */
    appendInnerIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 时间格式化
     */
    format: (StringConstructor | FunctionConstructor | ArrayConstructor)[];
    /**
     * @zh 输入框ID
     */
    id: StringConstructor;
    /**
     * @zh 绑定值
     */
    modelValue: {
        type: (StringConstructor | ArrayConstructor)[];
        default: () => never[];
    };
    /**
     * @zh 点击清除后是否展开菜单面板
     */
    openOnClear: BooleanConstructor;
    /**
     * @zh 面板的属性
     */
    panelProps: ObjectConstructor;
    /**
     * @zh 只读
     */
    readonly: BooleanConstructor;
    /**
     * @zh 开启范围时间选择
     */
    range: BooleanConstructor;
} & {
    $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[])) | {
        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]));
        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | undefined;
        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    onChange?: ((_modelValue: any) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => true;
    change: (_modelValue: any) => true;
}, string, {
    modelValue: string | unknown[];
    readonly: boolean;
    openOnClear: boolean;
    range: boolean;
    appendInnerIcon: string;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: DatePickerSlots;
});
type DatePicker = InstanceType<typeof DatePicker>;

declare const MAP: {
    readonly year: {
        readonly alias: "Y";
        readonly get: "getFullYear";
        readonly set: "setFullYear";
        readonly startOf: "YYYY-01-01 00:00:00";
        readonly endOf: "YYYY-12-$1 23:59:59.999";
    };
    readonly month: {
        readonly alias: "M";
        readonly get: "getMonth";
        readonly set: "setMonth";
        readonly startOf: "YYYY-MM-01 00:00:00";
        readonly endOf: "YYYY-MM-31 23:59:59.999";
    };
    readonly day: {
        readonly alias: "D";
        readonly get: "getDate";
        readonly set: "setDate";
        readonly startOf: "YYYY-MM-DD 00:00:00";
        readonly endOf: "YYYY-MM-DD 23:59:59.999";
    };
    readonly hour: {
        readonly alias: "H";
        readonly get: "getHours";
        readonly set: "setHours";
        readonly startOf: "YYYY-MM-DD HH:00:00";
        readonly endOf: "YYYY-MM-DD HH:59:59.999";
    };
    readonly minute: {
        readonly alias: "m";
        readonly get: "getMinutes";
        readonly set: "setMinutes";
        readonly startOf: "YYYY-MM-DD HH:mm:00";
        readonly endOf: "YYYY-MM-DD HH:mm:59.999";
    };
    readonly second: {
        readonly alias: "s";
        readonly get: "getSeconds";
        readonly set: "setSeconds";
        readonly startOf: "YYYY-MM-DD HH:mm:ss.000";
        readonly endOf: "YYYY-MM-DD HH:mm:ss.999";
    };
    readonly millisecond: {
        readonly alias: "ms";
        readonly get: "getMilliseconds";
        readonly set: "setMilliseconds";
        readonly startOf: "YYYY-MM-DD HH:mm:ss.000";
        readonly endOf: "YYYY-MM-DD HH:mm:ss.999";
    };
};

interface DateInstance extends Date, InternalDateInstance {
}
type DateManipulateType = keyof typeof MAP;
type DateOptions = number | string | Date;
interface InternalDateInstance {
    add(value: number, unit: DateManipulateType): DateInstance;
    subtract(value: number, unit: DateManipulateType): DateInstance;
    startOf(unit: DateManipulateType): DateInstance;
    endOf(unit: DateManipulateType): DateInstance;
    format(value?: string): string;
    clone(): DateInstance;
    unix(): number;
    valueOf(): number;
    toDate(): Date;
    toObject(): Record<string, any>;
}

declare const defaultDateFormat = "YYYY-MM-DD HH:mm:ss";
declare function createDate(options?: DateOptions): DateInstance;

declare const DatePickerPanel: vue.DefineComponent<{
    /**
     * @zh 激活的日期的按钮颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 每周的第一天是周几（0 - 周日、1 - 周一）。
     */
    firstDayOfWeek: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: string | number) => boolean;
    };
    /**
     * @zh 时间格式化
     */
    format: {
        type: PropType<string | ((date: DateInstance) => string)>;
        default: string;
    };
    /**
     * @zh 最大时间值
     */
    max: PropType<DateOptions>;
    /**
     * @zh 最小时间值
     */
    min: PropType<DateOptions>;
    /**
     * @zh 时间值
     */
    modelValue: PropType<DateOptions>;
    /**
     * @zh 双箭头往前翻页图标
     */
    prevDoubleIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 单箭头往前翻页图标
     */
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 单箭头往后翻页图标
     */
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 双箭头往后翻页图标
     */
    nextDoubleIcon: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: string) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    /**
     * @zh 激活的日期的按钮颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 每周的第一天是周几（0 - 周日、1 - 周一）。
     */
    firstDayOfWeek: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: string | number) => boolean;
    };
    /**
     * @zh 时间格式化
     */
    format: {
        type: PropType<string | ((date: DateInstance) => string)>;
        default: string;
    };
    /**
     * @zh 最大时间值
     */
    max: PropType<DateOptions>;
    /**
     * @zh 最小时间值
     */
    min: PropType<DateOptions>;
    /**
     * @zh 时间值
     */
    modelValue: PropType<DateOptions>;
    /**
     * @zh 双箭头往前翻页图标
     */
    prevDoubleIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 单箭头往前翻页图标
     */
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 单箭头往后翻页图标
     */
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 双箭头往后翻页图标
     */
    nextDoubleIcon: {
        type: StringConstructor;
        default: string;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: string) => any) | undefined;
}, {
    activeColor: string;
    format: string | ((date: DateInstance) => string);
    firstDayOfWeek: string | number;
    prevDoubleIcon: string;
    prevIcon: string;
    nextIcon: string;
    nextDoubleIcon: string;
}>;

declare const DateRangePickerPanel: vue.DefineComponent<{
    /**
     * @zh 时间格式化
     */
    format: {
        type: PropType<string[] | ((dates: DateInstance[]) => string[])>;
        default: () => string[];
    };
    /**
     * @zh 时间值
     */
    modelValue: {
        type: PropType<string[]>;
        default: () => never[];
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_value: string[]) => true;
    preview: (_value: boolean) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    /**
     * @zh 时间格式化
     */
    format: {
        type: PropType<string[] | ((dates: DateInstance[]) => string[])>;
        default: () => string[];
    };
    /**
     * @zh 时间值
     */
    modelValue: {
        type: PropType<string[]>;
        default: () => never[];
    };
}>> & {
    "onUpdate:modelValue"?: ((_value: string[]) => any) | undefined;
    onPreview?: ((_value: boolean) => any) | undefined;
}, {
    modelValue: string[];
    format: string[] | ((dates: DateInstance[]) => string[]);
}>;

interface DefaultsInstance {
    [key: string]: undefined | Record<string, unknown>;
    global?: Record<string, unknown>;
}
type DefaultsOptions = Partial<DefaultsInstance>;

declare const DefaultsProvider: vue.DefineComponent<{
    defaults: PropType<Partial<DefaultsInstance>>;
    reset: (StringConstructor | NumberConstructor)[];
    root: BooleanConstructor;
    scoped: BooleanConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>[] | undefined, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    defaults: PropType<Partial<DefaultsInstance>>;
    reset: (StringConstructor | NumberConstructor)[];
    root: BooleanConstructor;
    scoped: BooleanConstructor;
}>>, {
    root: boolean;
    scoped: boolean;
}>;

declare const Device: vue.DefineComponent<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    model: StringConstructor;
    autoHeight: BooleanConstructor;
    battery: {
        type: NumberConstructor;
        default: number;
    };
    operator: {
        type: StringConstructor;
        default: string;
    };
    headerColor: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    model: StringConstructor;
    autoHeight: BooleanConstructor;
    battery: {
        type: NumberConstructor;
        default: number;
    };
    operator: {
        type: StringConstructor;
        default: string;
    };
    headerColor: StringConstructor;
}>>, {
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    autoHeight: boolean;
    battery: number;
    operator: string;
}>;
type Device = InstanceType<typeof Device>;

type DeviceStatusBar = InstanceType<typeof DeviceStatusBar>;
declare const DeviceStatusBar: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            tag: string;
            height: number;
            battery: number;
            operator: string;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            color: StringConstructor;
            textColor: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            height: {
                type: NumberConstructor;
                default: number;
            };
            battery: {
                type: NumberConstructor;
                default: number;
            };
            operator: {
                type: StringConstructor;
                default: string;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "tag" | "height" | "battery" | "operator">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            color: StringConstructor;
            textColor: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            height: {
                type: NumberConstructor;
                default: number;
            };
            battery: {
                type: NumberConstructor;
                default: number;
            };
            operator: {
                type: StringConstructor;
                default: string;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            tag: string;
            height: number;
            battery: number;
            operator: string;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        color: StringConstructor;
        textColor: StringConstructor;
        tag: {
            type: StringConstructor;
            default: string;
        };
        height: {
            type: NumberConstructor;
            default: number;
        };
        battery: {
            type: NumberConstructor;
            default: number;
        };
        operator: {
            type: StringConstructor;
            default: string;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    color: StringConstructor;
    textColor: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    height: {
        type: NumberConstructor;
        default: number;
    };
    battery: {
        type: NumberConstructor;
        default: number;
    };
    operator: {
        type: StringConstructor;
        default: string;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    tag: string;
    height: number;
    battery: number;
    operator: string;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots?: Record<string, (...args: any[]) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]> | undefined;
});

declare const VeDividerTextAligns: readonly ["left", "center", "right"];
type VeDividerTextAlign = typeof VeDividerTextAligns[number];
type Divider = InstanceType<typeof Divider>;
declare const Divider: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            tag: string;
            dashed: boolean;
            vertical: boolean;
            textAlign: "left" | "right" | "center";
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: PropType<string>;
                default: string;
            };
            textAlign: {
                type: PropType<"left" | "right" | "center">;
                default: string;
                validator: (val: VeDividerTextAlign) => boolean;
            };
            length: (StringConstructor | NumberConstructor)[];
            dashed: BooleanConstructor;
            vertical: BooleanConstructor;
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "tag" | "dashed" | "vertical" | "textAlign">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            tag: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: PropType<string>;
                default: string;
            };
            textAlign: {
                type: PropType<"left" | "right" | "center">;
                default: string;
                validator: (val: VeDividerTextAlign) => boolean;
            };
            length: (StringConstructor | NumberConstructor)[];
            dashed: BooleanConstructor;
            vertical: BooleanConstructor;
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            tag: string;
            dashed: boolean;
            vertical: boolean;
            textAlign: "left" | "right" | "center";
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        tag: Omit<{
            type: StringConstructor;
            default: string;
        }, "default" | "type"> & {
            type: PropType<string>;
            default: string;
        };
        textAlign: {
            type: PropType<"left" | "right" | "center">;
            default: string;
            validator: (val: VeDividerTextAlign) => boolean;
        };
        length: (StringConstructor | NumberConstructor)[];
        dashed: BooleanConstructor;
        vertical: BooleanConstructor;
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: PropType<string>;
        default: string;
    };
    textAlign: {
        type: PropType<"left" | "right" | "center">;
        default: string;
        validator: (val: VeDividerTextAlign) => boolean;
    };
    length: (StringConstructor | NumberConstructor)[];
    dashed: BooleanConstructor;
    vertical: BooleanConstructor;
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    tag: string;
    dashed: boolean;
    vertical: boolean;
    textAlign: "left" | "right" | "center";
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots?: Record<string, (...args: any[]) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]> | undefined;
});

declare function staticPositionStrategy(): void;

/**
 * 连接的定位策略
 *
 * @param data
 * @param props
 * @param contentStyles
 * @param anchorClasses
 */
declare function connectedPositionStrategy(data: PositionStrategyData, props: PositionStrategyProps, contentStyles: Ref<Record<string, string>>, anchorClasses: Ref<string[]>): {
    updatePosition: () => void;
} | undefined;

declare function pointerPositionStrategy(data: PositionStrategyData, props: PositionStrategyProps, contentStyles: Ref<Record<string, string>>, _anchorClasses: Ref<string[]>): {
    updatePosition: undefined;
};

declare const POSITION_STRATEGIES: {
    static: typeof staticPositionStrategy;
    connected: typeof connectedPositionStrategy;
    pointer: typeof pointerPositionStrategy;
};
interface PositionStrategyData {
    contentEl: Ref<HTMLElement | undefined>;
    activatorEl: Ref<HTMLElement | undefined>;
    isActive: Ref<boolean>;
    activatedPosition?: Ref<{
        left: number;
        top: number;
    } | undefined>;
}
type PositionStrategy = keyof typeof POSITION_STRATEGIES | ((data: PositionStrategyData, props: PositionStrategyProps, contentStyles: Ref<Record<string, string>>, anchorClasses: Ref<string[]>) => undefined | {
    updatePosition: (e: Event) => void;
});
type Origin = Anchor$1 | 'auto' | 'overlap';
type PositionStrategyProps = ExtractPropTypes<ReturnType<typeof makePositionStrategyProps>> & {
    maxHeight?: number | string;
    maxWidth?: number | string;
    minHeight?: number | string;
    minWidth?: number | string;
};
declare const makePositionStrategyProps: <Defaults extends {
    positionStrategy?: unknown;
    anchor?: unknown;
    origin?: unknown;
    offset?: unknown;
} = {}>(defaults?: Defaults | undefined) => {
    positionStrategy: unknown extends Defaults["positionStrategy"] ? {
        type: PropType<PositionStrategy>;
        default: string;
        validator: (val: any) => boolean;
    } : Omit<{
        type: PropType<PositionStrategy>;
        default: string;
        validator: (val: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<unknown extends Defaults["positionStrategy"] ? PositionStrategy : NonNullable<PositionStrategy> | Defaults["positionStrategy"]>;
        default: unknown extends Defaults["positionStrategy"] ? PositionStrategy : NonNullable<PositionStrategy> | Defaults["positionStrategy"];
    };
    anchor: unknown extends Defaults["anchor"] ? {
        type: PropType<Anchor$1>;
        default: string;
    } : Omit<{
        type: PropType<Anchor$1>;
        default: string;
    }, "default" | "type"> & {
        type: PropType<unknown extends Defaults["anchor"] ? Anchor$1 : NonNullable<Anchor$1> | Defaults["anchor"]>;
        default: unknown extends Defaults["anchor"] ? Anchor$1 : NonNullable<Anchor$1> | Defaults["anchor"];
    };
    origin: unknown extends Defaults["origin"] ? {
        type: PropType<Origin>;
        default: string;
    } : Omit<{
        type: PropType<Origin>;
        default: string;
    }, "default" | "type"> & {
        type: PropType<unknown extends Defaults["origin"] ? Origin : NonNullable<Origin> | Defaults["origin"]>;
        default: unknown extends Defaults["origin"] ? Origin : NonNullable<Origin> | Defaults["origin"];
    };
    offset: unknown extends Defaults["offset"] ? (StringConstructor | NumberConstructor)[] : {
        type: PropType<unknown extends Defaults["offset"] ? string | number : NonNullable<string | number> | Defaults["offset"]>;
        default: unknown extends Defaults["offset"] ? string | number : NonNullable<string | number> | Defaults["offset"];
    };
};

interface ScrollStrategyData {
    root: Ref<HTMLElement | undefined>;
    contentEl: Ref<HTMLElement | undefined>;
    activatorEl: Ref<HTMLElement | undefined>;
    isActive: Ref<boolean>;
    updatePosition: Ref<((e: Event) => void) | undefined>;
}

type OverlaySlots = MakeSlots<{
    default: [
        {
            close: () => void;
            isActive: Ref<boolean>;
        }
    ];
    activator: [
        {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }
    ];
}>;
declare const Overlay: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            anchor: _veno_ui_utils.Anchor;
            contained: boolean;
            absolute: boolean;
            origin: Origin;
            eager: boolean;
            noClickAnimation: boolean;
            persistent: boolean;
            scrim: string | boolean;
            activatorProps: Record<string, any>;
            openOnClick: boolean;
            openOnHover: boolean;
            openOnFocus: boolean;
            positionStrategy: PositionStrategy;
            scrollStrategy: boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void);
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            eager: BooleanConstructor;
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            theme: StringConstructor;
            scrollStrategy: {
                type: PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
                default: string;
                validator: (val: any) => boolean;
            };
            positionStrategy: {
                type: PropType<PositionStrategy>;
                default: string;
                validator: (val: any) => boolean;
            };
            anchor: {
                type: PropType<_veno_ui_utils.Anchor>;
                default: string;
            };
            origin: {
                type: PropType<Origin>;
                default: string;
            };
            offset: (StringConstructor | NumberConstructor)[];
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            closeDelay: (StringConstructor | NumberConstructor)[];
            openDelay: (StringConstructor | NumberConstructor)[];
            activator: PropType<_veno_ui_utils.Selector>;
            activatorProps: {
                type: PropType<Record<string, any>>;
                default: () => {};
            };
            openOnClick: {
                type: BooleanConstructor;
                default: undefined;
            };
            openOnHover: BooleanConstructor;
            openOnFocus: {
                type: BooleanConstructor;
                default: undefined;
            };
            modelValue: BooleanConstructor;
            absolute: BooleanConstructor;
            attach: PropType<string | boolean | Element>;
            contained: BooleanConstructor;
            contentStyle: null;
            contentClass: null;
            noClickAnimation: BooleanConstructor;
            persistent: BooleanConstructor;
            scrim: {
                type: (BooleanConstructor | StringConstructor)[];
                default: boolean;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
            "onClick:outside"?: ((_event: MouseEvent) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "transition" | "anchor" | "contained" | "absolute" | "origin" | "eager" | "noClickAnimation" | "persistent" | "scrim" | "activatorProps" | "openOnClick" | "openOnHover" | "openOnFocus" | "positionStrategy" | "scrollStrategy">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: boolean) => void) & ((event: "click:outside", _event: MouseEvent) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            eager: BooleanConstructor;
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            theme: StringConstructor;
            scrollStrategy: {
                type: PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
                default: string;
                validator: (val: any) => boolean;
            };
            positionStrategy: {
                type: PropType<PositionStrategy>;
                default: string;
                validator: (val: any) => boolean;
            };
            anchor: {
                type: PropType<_veno_ui_utils.Anchor>;
                default: string;
            };
            origin: {
                type: PropType<Origin>;
                default: string;
            };
            offset: (StringConstructor | NumberConstructor)[];
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            closeDelay: (StringConstructor | NumberConstructor)[];
            openDelay: (StringConstructor | NumberConstructor)[];
            activator: PropType<_veno_ui_utils.Selector>;
            activatorProps: {
                type: PropType<Record<string, any>>;
                default: () => {};
            };
            openOnClick: {
                type: BooleanConstructor;
                default: undefined;
            };
            openOnHover: BooleanConstructor;
            openOnFocus: {
                type: BooleanConstructor;
                default: undefined;
            };
            modelValue: BooleanConstructor;
            absolute: BooleanConstructor;
            attach: PropType<string | boolean | Element>;
            contained: BooleanConstructor;
            contentStyle: null;
            contentClass: null;
            noClickAnimation: BooleanConstructor;
            persistent: BooleanConstructor;
            scrim: {
                type: (BooleanConstructor | StringConstructor)[];
                default: boolean;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
            "onClick:outside"?: ((_event: MouseEvent) => any) | undefined;
        }, {
            animateClick: () => void;
            close: () => void;
            contentEl: Ref<HTMLElement | undefined>;
            activatorEl: Ref<HTMLElement | undefined>;
            updatePosition: Ref<((e: Event) => void) | undefined>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:outside': (_event: MouseEvent) => true;
            'update:modelValue': (_modelValue: boolean) => true;
        }, string, {
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            anchor: _veno_ui_utils.Anchor;
            contained: boolean;
            absolute: boolean;
            origin: Origin;
            eager: boolean;
            noClickAnimation: boolean;
            persistent: boolean;
            scrim: string | boolean;
            activatorProps: Record<string, any>;
            openOnClick: boolean;
            openOnHover: boolean;
            openOnFocus: boolean;
            positionStrategy: PositionStrategy;
            scrollStrategy: boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void);
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        eager: BooleanConstructor;
        transition: Omit<{
            type: PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        };
        theme: StringConstructor;
        scrollStrategy: {
            type: PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            default: string;
            validator: (val: any) => boolean;
        };
        positionStrategy: {
            type: PropType<PositionStrategy>;
            default: string;
            validator: (val: any) => boolean;
        };
        anchor: {
            type: PropType<_veno_ui_utils.Anchor>;
            default: string;
        };
        origin: {
            type: PropType<Origin>;
            default: string;
        };
        offset: (StringConstructor | NumberConstructor)[];
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        closeDelay: (StringConstructor | NumberConstructor)[];
        openDelay: (StringConstructor | NumberConstructor)[];
        activator: PropType<_veno_ui_utils.Selector>;
        activatorProps: {
            type: PropType<Record<string, any>>;
            default: () => {};
        };
        openOnClick: {
            type: BooleanConstructor;
            default: undefined;
        };
        openOnHover: BooleanConstructor;
        openOnFocus: {
            type: BooleanConstructor;
            default: undefined;
        };
        modelValue: BooleanConstructor;
        absolute: BooleanConstructor;
        attach: PropType<string | boolean | Element>;
        contained: BooleanConstructor;
        contentStyle: null;
        contentClass: null;
        noClickAnimation: BooleanConstructor;
        persistent: BooleanConstructor;
        scrim: {
            type: (BooleanConstructor | StringConstructor)[];
            default: boolean;
        };
    } & {
        $children: () => vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            default?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            activator?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            default?: false | ((args_0: {
                close: () => void;
                isActive: Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            activator?: false | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        "onClick:outside"?: ((_event: MouseEvent) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        animateClick: () => void;
        close: () => void;
        contentEl: Ref<HTMLElement | undefined>;
        activatorEl: Ref<HTMLElement | undefined>;
        updatePosition: Ref<((e: Event) => void) | undefined>;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    eager: BooleanConstructor;
    transition: Omit<{
        type: PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    theme: StringConstructor;
    scrollStrategy: {
        type: PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
        default: string;
        validator: (val: any) => boolean;
    };
    positionStrategy: {
        type: PropType<PositionStrategy>;
        default: string;
        validator: (val: any) => boolean;
    };
    anchor: {
        type: PropType<_veno_ui_utils.Anchor>;
        default: string;
    };
    origin: {
        type: PropType<Origin>;
        default: string;
    };
    offset: (StringConstructor | NumberConstructor)[];
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    closeDelay: (StringConstructor | NumberConstructor)[];
    openDelay: (StringConstructor | NumberConstructor)[];
    activator: PropType<_veno_ui_utils.Selector>;
    activatorProps: {
        type: PropType<Record<string, any>>;
        default: () => {};
    };
    openOnClick: {
        type: BooleanConstructor;
        default: undefined;
    };
    openOnHover: BooleanConstructor;
    openOnFocus: {
        type: BooleanConstructor;
        default: undefined;
    };
    modelValue: BooleanConstructor;
    absolute: BooleanConstructor;
    attach: PropType<string | boolean | Element>;
    contained: BooleanConstructor;
    contentStyle: null;
    contentClass: null;
    noClickAnimation: BooleanConstructor;
    persistent: BooleanConstructor;
    scrim: {
        type: (BooleanConstructor | StringConstructor)[];
        default: boolean;
    };
} & {
    $children: () => vue.VNodeChild | ((args_0: {
        close: () => void;
        isActive: Ref<boolean>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        default?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        activator?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        default?: false | ((args_0: {
            close: () => void;
            isActive: Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        activator?: false | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
    "onClick:outside"?: ((_event: MouseEvent) => any) | undefined;
}, {
    animateClick: () => void;
    close: () => void;
    contentEl: Ref<HTMLElement | undefined>;
    activatorEl: Ref<HTMLElement | undefined>;
    updatePosition: Ref<((e: Event) => void) | undefined>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'click:outside': (_event: MouseEvent) => true;
    'update:modelValue': (_modelValue: boolean) => true;
}, string, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
    anchor: _veno_ui_utils.Anchor;
    contained: boolean;
    absolute: boolean;
    origin: Origin;
    eager: boolean;
    noClickAnimation: boolean;
    persistent: boolean;
    scrim: string | boolean;
    activatorProps: Record<string, any>;
    openOnClick: boolean;
    openOnHover: boolean;
    openOnFocus: boolean;
    positionStrategy: PositionStrategy;
    scrollStrategy: boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void);
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: OverlaySlots;
});
type Overlay = InstanceType<typeof Overlay>;

declare const Dialog: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    target: vue.PropType<HTMLElement>;
                }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    target: vue.PropType<HTMLElement>;
                }>>, {}>;
            };
            fullscreen: boolean;
            scrollable: boolean;
            draggable: boolean;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        target: vue.PropType<HTMLElement>;
                    }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        target: vue.PropType<HTMLElement>;
                    }>>, {}>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        target: vue.PropType<HTMLElement>;
                    }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        target: vue.PropType<HTMLElement>;
                    }>>, {}>;
                };
            };
            /**
             * @zh 全屏
             */
            fullscreen: BooleanConstructor;
            /**
             * @zh ID
             */
            id: StringConstructor;
            /**
             * @zh 是否显示
             */
            modelValue: BooleanConstructor;
            /**
             * @zh 是否可以滚动
             */
            scrollable: BooleanConstructor;
            /**
             * @zh 可以拖拽的
             */
            draggable: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "transition" | "fullscreen" | "scrollable" | "draggable">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _: boolean) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        target: vue.PropType<HTMLElement>;
                    }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        target: vue.PropType<HTMLElement>;
                    }>>, {}>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        target: vue.PropType<HTMLElement>;
                    }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        target: vue.PropType<HTMLElement>;
                    }>>, {}>;
                };
            };
            /**
             * @zh 全屏
             */
            fullscreen: BooleanConstructor;
            /**
             * @zh ID
             */
            id: StringConstructor;
            /**
             * @zh 是否显示
             */
            modelValue: BooleanConstructor;
            /**
             * @zh 是否可以滚动
             */
            scrollable: BooleanConstructor;
            /**
             * @zh 可以拖拽的
             */
            draggable: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_: boolean) => boolean;
        }, string, {
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    target: vue.PropType<HTMLElement>;
                }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    target: vue.PropType<HTMLElement>;
                }>>, {}>;
            };
            fullscreen: boolean;
            scrollable: boolean;
            draggable: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        transition: Omit<{
            type: vue.PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    target: vue.PropType<HTMLElement>;
                }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    target: vue.PropType<HTMLElement>;
                }>>, {}>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    target: vue.PropType<HTMLElement>;
                }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    target: vue.PropType<HTMLElement>;
                }>>, {}>;
            };
        };
        /**
         * @zh 全屏
         */
        fullscreen: BooleanConstructor;
        /**
         * @zh ID
         */
        id: StringConstructor;
        /**
         * @zh 是否显示
         */
        modelValue: BooleanConstructor;
        /**
         * @zh 是否可以滚动
         */
        scrollable: BooleanConstructor;
        /**
         * @zh 可以拖拽的
         */
        draggable: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            default?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            activator?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            default?: false | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            activator?: false | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                target: vue.PropType<HTMLElement>;
            }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                target: vue.PropType<HTMLElement>;
            }>>, {}>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                target: vue.PropType<HTMLElement>;
            }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                target: vue.PropType<HTMLElement>;
            }>>, {}>;
        };
    };
    /**
     * @zh 全屏
     */
    fullscreen: BooleanConstructor;
    /**
     * @zh ID
     */
    id: StringConstructor;
    /**
     * @zh 是否显示
     */
    modelValue: BooleanConstructor;
    /**
     * @zh 是否可以滚动
     */
    scrollable: BooleanConstructor;
    /**
     * @zh 可以拖拽的
     */
    draggable: BooleanConstructor;
} & {
    $children: () => vue.VNodeChild | ((args_0: {
        close: () => void;
        isActive: vue.Ref<boolean>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        default?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        activator?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        default?: false | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        activator?: false | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_: boolean) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_: boolean) => boolean;
}, string, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            target: vue.PropType<HTMLElement>;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            target: vue.PropType<HTMLElement>;
        }>>, {}>;
    };
    fullscreen: boolean;
    scrollable: boolean;
    draggable: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: OverlaySlots;
});
type Dialog = InstanceType<typeof Dialog>;

declare const Drawer: vue.DefineComponent<{
    modelValue: Omit<{
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<boolean | undefined> | null>;
        default: NonNullable<boolean | undefined> | null;
    };
    name: StringConstructor;
    position: Omit<{
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"fixed" | "absolute">>;
        default: NonNullable<"fixed" | "absolute">;
    };
    anchor: Omit<{
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"bottom" | "left" | "right" | "top">>;
        default: NonNullable<"bottom" | "left" | "right" | "top">;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    theme: StringConstructor;
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    /**
     * @zh 禁用大小调整监听
     */
    disableResizeWatcher: BooleanConstructor;
    /**
     * @zh 禁用路由监听
     */
    disableRouteWatcher: BooleanConstructor;
    /**
     * @zh 背景颜色
     */
    color: StringConstructor;
    /**
     * @zh 悬停时展开
     */
    expandOnHover: BooleanConstructor;
    /**
     * @zh 持续激活
     */
    permanent: BooleanConstructor;
    /**
     * @zh 最小化
     */
    rail: BooleanConstructor;
    /**
     * @zh 最小化宽度
     */
    railWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 显示激活/隐藏按钮
     */
    showToggler: BooleanConstructor;
    /**
     * @zh 临时抽屉
     */
    temporary: BooleanConstructor;
    /**
     * @zh 可触摸
     */
    touchless: BooleanConstructor;
    /**
     * @zh 宽度
     */
    width: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: boolean) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    modelValue: Omit<{
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<boolean | undefined> | null>;
        default: NonNullable<boolean | undefined> | null;
    };
    name: StringConstructor;
    position: Omit<{
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"fixed" | "absolute">>;
        default: NonNullable<"fixed" | "absolute">;
    };
    anchor: Omit<{
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"bottom" | "left" | "right" | "top">>;
        default: NonNullable<"bottom" | "left" | "right" | "top">;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    theme: StringConstructor;
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    /**
     * @zh 禁用大小调整监听
     */
    disableResizeWatcher: BooleanConstructor;
    /**
     * @zh 禁用路由监听
     */
    disableRouteWatcher: BooleanConstructor;
    /**
     * @zh 背景颜色
     */
    color: StringConstructor;
    /**
     * @zh 悬停时展开
     */
    expandOnHover: BooleanConstructor;
    /**
     * @zh 持续激活
     */
    permanent: BooleanConstructor;
    /**
     * @zh 最小化
     */
    rail: BooleanConstructor;
    /**
     * @zh 最小化宽度
     */
    railWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 显示激活/隐藏按钮
     */
    showToggler: BooleanConstructor;
    /**
     * @zh 临时抽屉
     */
    temporary: BooleanConstructor;
    /**
     * @zh 可触摸
     */
    touchless: BooleanConstructor;
    /**
     * @zh 宽度
     */
    width: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
}, {
    modelValue: NonNullable<boolean | undefined> | null;
    anchor: NonNullable<"bottom" | "left" | "right" | "top">;
    tag: string;
    position: NonNullable<"fixed" | "absolute">;
    width: string | number;
    priority: string | number;
    beautifyScrollbar: boolean;
    disableResizeWatcher: boolean;
    disableRouteWatcher: boolean;
    expandOnHover: boolean;
    permanent: boolean;
    rail: boolean;
    railWidth: string | number;
    showToggler: boolean;
    temporary: boolean;
    touchless: boolean;
}>;
type Drawer = InstanceType<typeof Drawer>;

declare const DraggableSortable: vue.DefineComponent<{
    clone: vue.PropType<(v: any) => any>;
    itemKey: {
        type: (StringConstructor | FunctionConstructor)[];
        default: () => (v: any) => any;
    };
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    put: {
        type: BooleanConstructor;
        default: boolean;
    };
    group: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any[]) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    clone: vue.PropType<(v: any) => any>;
    itemKey: {
        type: (StringConstructor | FunctionConstructor)[];
        default: () => (v: any) => any;
    };
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    put: {
        type: BooleanConstructor;
        default: boolean;
    };
    group: StringConstructor;
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any[]) => any) | undefined;
}, {
    modelValue: any[];
    itemKey: string | Function;
    put: boolean;
}>;

interface FormField {
    name: Ref<string | undefined>;
    modelValue: Ref;
    validate?: () => Promise<string[]>;
    reset?: () => void;
    resetValidation?: () => void;
}

type FormItemProps = {
    [key: string]: any;
    $type?: 'input' | 'textarea' | 'select' | 'switch' | 'date-picker' | 'checkbox' | 'radio';
};
declare const FormChildren: vue.DefineComponent<{
    /**
     * @zh 数据驱动的表单列表项
     */
    items: PropType<FormItemProps[]>;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>[], unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    /**
     * @zh 数据驱动的表单列表项
     */
    items: PropType<FormItemProps[]>;
}>>, {}>;
type FormChildren = InstanceType<typeof FormChildren>;

declare const Form: vue.DefineComponent<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    disabled: BooleanConstructor;
    fastFail: BooleanConstructor;
    lazyValidation: BooleanConstructor;
    readonly: BooleanConstructor;
    valid: {
        type: PropType<boolean | null>;
        default: null;
    };
    modelValue: PropType<Record<string, any>>;
    defaultValue: PropType<Record<string, any>>;
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    /**
     * @zh 布局方向
     */
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
        validator: (v: any) => boolean;
    };
    /**
     * @zh 隐藏详情
     */
    hideDetails: PropType<boolean | "auto">;
    /**
     * @zh 内联
     */
    inline: BooleanConstructor;
    /**
     * @zh 数据驱动的表单列表项
     */
    items: PropType<FormItemProps[]>;
    /**
     * @zh 标签宽度
     */
    labelWidth: (StringConstructor | NumberConstructor)[];
}, {
    errorMessages: vue.Ref<{
        id: string | number;
        errorMessages: string[];
    }[]>;
    isDisabled: vue.ComputedRef<boolean>;
    isReadonly: vue.ComputedRef<boolean>;
    isValidating: vue.Ref<boolean>;
    items: Map<string | number, FormField>;
    submit: (e: Event) => Promise<void>;
    reset: (e: Event) => Promise<void>;
    resetValidation: () => Promise<void>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:valid': (_valid: boolean | null) => boolean;
    'update:modelValue': (_modelValue: Record<string, any>) => boolean;
    resetValidation: () => boolean;
    reset: (_event: Event) => boolean;
    submit: (_value: Record<string, any>, _event: Event) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    disabled: BooleanConstructor;
    fastFail: BooleanConstructor;
    lazyValidation: BooleanConstructor;
    readonly: BooleanConstructor;
    valid: {
        type: PropType<boolean | null>;
        default: null;
    };
    modelValue: PropType<Record<string, any>>;
    defaultValue: PropType<Record<string, any>>;
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    /**
     * @zh 布局方向
     */
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
        validator: (v: any) => boolean;
    };
    /**
     * @zh 隐藏详情
     */
    hideDetails: PropType<boolean | "auto">;
    /**
     * @zh 内联
     */
    inline: BooleanConstructor;
    /**
     * @zh 数据驱动的表单列表项
     */
    items: PropType<FormItemProps[]>;
    /**
     * @zh 标签宽度
     */
    labelWidth: (StringConstructor | NumberConstructor)[];
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: Record<string, any>) => any) | undefined;
    onReset?: ((_event: Event) => any) | undefined;
    "onUpdate:valid"?: ((_valid: boolean | null) => any) | undefined;
    onResetValidation?: (() => any) | undefined;
    onSubmit?: ((_value: Record<string, any>, _event: Event) => any) | undefined;
}, {
    disabled: boolean;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    readonly: boolean;
    fastFail: boolean;
    lazyValidation: boolean;
    valid: boolean | null;
    direction: "vertical" | "horizontal";
}>;
type Form = InstanceType<typeof Form>;

type Container = InstanceType<typeof Container>;
declare const Container: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    fluid: {
        type: BooleanConstructor;
        default: boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    fluid: {
        type: BooleanConstructor;
        default: boolean;
    };
}>>, {
    tag: string;
    fluid: boolean;
}>;

type Col = InstanceType<typeof Col>;
declare const Col: vue.DefineComponent<{
    alignSelf: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    order: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    cols: {
        type: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        default: boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    alignSelf: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    order: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    cols: {
        type: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        default: boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    tag: string;
    offset: string | number;
    cols: string | number | boolean;
    order: string | number;
    alignSelf: string;
}>;

type Row = InstanceType<typeof Row>;
declare const Row: vue.DefineComponent<{
    alignContent: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    justify: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    gutter: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    align: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    alignContent: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    justify: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    gutter: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    align: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    tag: string;
    gutter: string | number;
    align: string;
    justify: string;
    alignContent: string;
}>;

type Header = InstanceType<typeof Header>;
declare const Header: vue.DefineComponent<{
    modelValue: {
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    };
    name: StringConstructor;
    position: Omit<{
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"fixed" | "absolute">>;
        default: NonNullable<"fixed" | "absolute">;
    };
    anchor: Omit<{
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"bottom" | "left" | "right" | "top">>;
        default: NonNullable<"bottom" | "left" | "right" | "top">;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    title: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    modelValue: {
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    };
    name: StringConstructor;
    position: Omit<{
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"fixed" | "absolute">>;
        default: NonNullable<"fixed" | "absolute">;
    };
    anchor: Omit<{
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"bottom" | "left" | "right" | "top">>;
        default: NonNullable<"bottom" | "left" | "right" | "top">;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    title: StringConstructor;
}>>, {
    modelValue: boolean | undefined;
    anchor: NonNullable<"bottom" | "left" | "right" | "top">;
    fixed: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    position: NonNullable<"fixed" | "absolute">;
    height: NonNullable<string | number>;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    priority: string | number;
}>;

declare const HeaderNavIcon: vue.DefineComponent<{
    icon: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    icon: string;
}>;

declare const HeaderTitle: vue.DefineComponent<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    text: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    text: StringConstructor;
}>>, {
    tag: string;
}>;

type Hover = InstanceType<typeof Hover>;
declare const Hover: vue.DefineComponent<{
    closeDelay: (StringConstructor | NumberConstructor)[];
    openDelay: (StringConstructor | NumberConstructor)[];
    disabled: BooleanConstructor;
    modelValue: {
        type: BooleanConstructor;
        default: undefined;
    };
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>[] | undefined, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: boolean) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    closeDelay: (StringConstructor | NumberConstructor)[];
    openDelay: (StringConstructor | NumberConstructor)[];
    disabled: BooleanConstructor;
    modelValue: {
        type: BooleanConstructor;
        default: undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
}, {
    modelValue: boolean;
    disabled: boolean;
}>;

declare const Icon: vue.DefineComponent<{
    icon: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    /**
     * @zh 图标颜色
     */
    color: StringConstructor;
    /**
     * @zh 是否在左侧
     */
    start: BooleanConstructor;
    /**
     * @zh 是否在右侧
     */
    end: BooleanConstructor;
}, () => JSX.Element | undefined, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: (StringConstructor | ObjectConstructor | FunctionConstructor)[];
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    /**
     * @zh 图标颜色
     */
    color: StringConstructor;
    /**
     * @zh 是否在左侧
     */
    start: BooleanConstructor;
    /**
     * @zh 是否在右侧
     */
    end: BooleanConstructor;
}>>, {
    tag: string;
    size: Size | undefined;
    start: boolean;
    end: boolean;
}>;
type Icon = InstanceType<typeof Icon>;

type JSXComponent<Props = any> = {
    new (): ComponentPublicInstance<Props>;
} | FunctionalComponent<Props>;
type IconValue = string | JSXComponent;
interface IconsAliases {
    checkboxIndeterminate: IconValue;
    checkboxOn: IconValue;
    checkboxOff: IconValue;
    close: IconValue;
    clear: IconValue;
    collapse: IconValue;
    calendar: IconValue;
    dropdown: IconValue;
    error: IconValue;
    expand: IconValue;
    filter: IconValue;
    first: IconValue;
    info: IconValue;
    last: IconValue;
    link: IconValue;
    menu: IconValue;
    next: IconValue;
    nextDouble: IconValue;
    nodata: IconValue;
    prev: IconValue;
    prevDouble: IconValue;
    radioOn: IconValue;
    radioOff: IconValue;
    separator: IconValue;
    sort: IconValue;
    success: IconValue;
    toggler: IconValue;
    warning: IconValue;
    [name: string]: IconValue;
}
type IconSetComponent = JSXComponent<{
    icon: IconValue;
    tag: string;
}>;
interface IconsOptions {
    /**
     * @zh 所有图标的别名
     */
    aliases?: Partial<IconsAliases>;
    /**
     * @zh 默认图标集合名
     */
    defaultSet?: string;
    /**
     * @zh 所有图标集合
     */
    sets?: Record<string, IconSetComponent>;
}

declare const IconClass: vue.DefineComponent<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}>>, {}>;

declare const IconComponent: vue.DefineComponent<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}>>, {}>;

declare const IconLigature: vue.DefineComponent<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
}>>, {}>;

declare const IconSvg: vue.DefineComponent<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
    viewBox: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    icon: {
        type: vue.PropType<IconValue>;
        required: true;
    };
    tag: {
        type: StringConstructor;
        required: true;
    };
    viewBox: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    viewBox: string;
}>;

declare const Image: vue.DefineComponent<{
    transition: {
        type: PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    };
    /**
     * @zh 纵横比
     */
    aspectRatio: (StringConstructor | NumberConstructor)[];
    /**
     * @zh alt
     */
    alt: StringConstructor;
    /**
     * @zh object-fit: cover
     */
    cover: BooleanConstructor;
    /**
     * @zh 立即加载
     */
    eager: BooleanConstructor;
    /**
     * @zh 渐变
     */
    gradient: StringConstructor;
    /**
     * @zh 懒加载 src
     */
    lazySrc: StringConstructor;
    /**
     * @zh IntersectionObserverInit
     */
    options: {
        type: PropType<IntersectionObserverInit>;
        default: () => {
            root: undefined;
            rootMargin: undefined;
            threshold: undefined;
        };
    };
    /**
     * @zh sizes
     */
    sizes: StringConstructor;
    /**
     * @zh src
     */
    src: StringConstructor;
    /**
     * @zh srcset
     */
    srcset: StringConstructor;
    /**
     * @zh 宽度
     */
    width: (StringConstructor | NumberConstructor)[];
}, {
    currentSrc: vue.Ref<string>;
    image: vue.Ref<HTMLImageElement | undefined>;
    state: vue.Ref<"error" | "loading" | "idle" | "loaded">;
    naturalWidth: vue.Ref<number | undefined>;
    naturalHeight: vue.Ref<number | undefined>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    loadstart: (_src: string | undefined, _image: HTMLImageElement | undefined) => true;
    load: (_src: string | undefined, _image: HTMLImageElement | undefined) => true;
    error: (_src: string | undefined, _image: HTMLImageElement | undefined) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    transition: {
        type: PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    };
    /**
     * @zh 纵横比
     */
    aspectRatio: (StringConstructor | NumberConstructor)[];
    /**
     * @zh alt
     */
    alt: StringConstructor;
    /**
     * @zh object-fit: cover
     */
    cover: BooleanConstructor;
    /**
     * @zh 立即加载
     */
    eager: BooleanConstructor;
    /**
     * @zh 渐变
     */
    gradient: StringConstructor;
    /**
     * @zh 懒加载 src
     */
    lazySrc: StringConstructor;
    /**
     * @zh IntersectionObserverInit
     */
    options: {
        type: PropType<IntersectionObserverInit>;
        default: () => {
            root: undefined;
            rootMargin: undefined;
            threshold: undefined;
        };
    };
    /**
     * @zh sizes
     */
    sizes: StringConstructor;
    /**
     * @zh src
     */
    src: StringConstructor;
    /**
     * @zh srcset
     */
    srcset: StringConstructor;
    /**
     * @zh 宽度
     */
    width: (StringConstructor | NumberConstructor)[];
}>> & {
    onError?: ((_src: string | undefined, _image: HTMLImageElement | undefined) => any) | undefined;
    onLoadstart?: ((_src: string | undefined, _image: HTMLImageElement | undefined) => any) | undefined;
    onLoad?: ((_src: string | undefined, _image: HTMLImageElement | undefined) => any) | undefined;
}, {
    transition: string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    });
    cover: boolean;
    eager: boolean;
    options: IntersectionObserverInit;
}>;
type Image = InstanceType<typeof Image>;

type Label = InstanceType<typeof Label>;
declare const Label: vue.DefineComponent<{
    theme: StringConstructor;
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    text: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    theme: StringConstructor;
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    text: StringConstructor;
}>>, {
    error: boolean;
    disabled: boolean;
}>;

type Layout = InstanceType<typeof Layout>;
declare const Layout: vue.DefineComponent<{
    overlaps: vue.Prop<string[], string[]>;
    fullHeight: BooleanConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}, {
    getLayoutItem: (id: string) => LayoutItem$1 | undefined;
    items: vue.ComputedRef<LayoutItem$1[]>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    overlaps: vue.Prop<string[], string[]>;
    fullHeight: BooleanConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    tag: string;
    fullHeight: boolean;
}>;

type LayoutItem = InstanceType<typeof LayoutItem>;
declare const LayoutItem: vue.DefineComponent<{
    modelValue: {
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    };
    name: StringConstructor;
    position: {
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    };
    anchor: {
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    modelValue: {
        type: vue.PropType<boolean | undefined>;
        default: boolean;
    };
    name: StringConstructor;
    position: {
        type: vue.PropType<"fixed" | "absolute">;
        default: string;
    };
    anchor: {
        type: vue.PropType<"bottom" | "left" | "right" | "top">;
        default: string;
    };
    priority: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}>>, {
    modelValue: boolean | undefined;
    anchor: "bottom" | "left" | "right" | "top";
    tag: string;
    position: "fixed" | "absolute";
    size: string | number;
    priority: string | number;
}>;

type Lazy = InstanceType<typeof Lazy>;
declare const Lazy: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            tag: string;
            options: IntersectionObserverInit;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            tag: {
                type: StringConstructor;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            modelValue: BooleanConstructor;
            options: {
                type: PropType<IntersectionObserverInit>;
                default: () => {
                    root: undefined;
                    rootMargin: undefined;
                    threshold: undefined;
                };
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "transition" | "tag" | "options">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _modelValue: boolean) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            tag: {
                type: StringConstructor;
                default: string;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            modelValue: BooleanConstructor;
            options: {
                type: PropType<IntersectionObserverInit>;
                default: () => {
                    root: undefined;
                    rootMargin: undefined;
                    threshold: undefined;
                };
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_modelValue: boolean) => boolean;
        }, string, {
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
            tag: string;
            options: IntersectionObserverInit;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        transition: Omit<{
            type: PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        };
        tag: {
            type: StringConstructor;
            default: string;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        modelValue: BooleanConstructor;
        options: {
            type: PropType<IntersectionObserverInit>;
            default: () => {
                root: undefined;
                rootMargin: undefined;
                threshold: undefined;
            };
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    modelValue: BooleanConstructor;
    options: {
        type: PropType<IntersectionObserverInit>;
        default: () => {
            root: undefined;
            rootMargin: undefined;
            threshold: undefined;
        };
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: boolean) => boolean;
}, string, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
    tag: string;
    options: IntersectionObserverInit;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots?: Record<string, (...args: any[]) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]> | undefined;
});

declare const Link: vue.DefineComponent<{
    underline: {
        type: PropType<boolean | "hover">;
        default: string;
    };
    linkIcon: {
        type: StringConstructor;
        default: string;
    };
    prependIcon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
    appendIcon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    underline: {
        type: PropType<boolean | "hover">;
        default: string;
    };
    linkIcon: {
        type: StringConstructor;
        default: string;
    };
    prependIcon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
    appendIcon: (BooleanConstructor | StringConstructor | ObjectConstructor)[];
}>>, {
    underline: boolean | "hover";
    linkIcon: string;
}>;
type Link = InstanceType<typeof Link>;

type ListItemSlot = {
    isActive: boolean;
    activate: (value: boolean) => void;
    isSelected: boolean;
    select: (value: boolean) => void;
};
type ListItemTitleSlot = {
    title?: string;
};
type ListItemSubtitleSlot = {
    subtitle?: string;
};
declare const ListItem: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            link: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            absolute: boolean;
            size: NonNullable<Size | undefined> | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            active: boolean;
            activeColor: string;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            href: StringConstructor;
            replace: BooleanConstructor;
            to: vue.PropType<vue_router.RouteLocationRaw>;
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: vue.PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Size | undefined> | undefined>;
                default: NonNullable<Size | undefined> | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否激活
             */
            active: BooleanConstructor;
            /**
             * @zh 激活时的颜色
             */
            activeColor: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 激活时的 class
             */
            activeClass: StringConstructor;
            /**
             * @zh 后置头像
             */
            appendAvatar: StringConstructor;
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 是否是一个链接
             */
            link: BooleanConstructor;
            /**
             * @zh 前置头像
             */
            prependAvatar: StringConstructor;
            /**
             * @zh 前置图标
             */
            prependIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 点击时是否有波纹
             */
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 副标题
             */
            subtitle: StringConstructor;
            /**
             * @zh 文本内容
             */
            text: StringConstructor;
            /**
             * @zh 标题
             */
            title: StringConstructor;
            /**
             * @zh 列表项的值
             */
            value: null;
        } & {
            $children: () => vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "link" | "ripple" | "replace" | "fixed" | "disabled" | "tag" | "variant" | "absolute" | "size" | "density" | "shape" | "active" | "activeColor">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            href: StringConstructor;
            replace: BooleanConstructor;
            to: vue.PropType<vue_router.RouteLocationRaw>;
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: vue.PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Size | undefined> | undefined>;
                default: NonNullable<Size | undefined> | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否激活
             */
            active: BooleanConstructor;
            /**
             * @zh 激活时的颜色
             */
            activeColor: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 激活时的 class
             */
            activeClass: StringConstructor;
            /**
             * @zh 后置头像
             */
            appendAvatar: StringConstructor;
            /**
             * @zh 后置图标
             */
            appendIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 是否是一个链接
             */
            link: BooleanConstructor;
            /**
             * @zh 前置头像
             */
            prependAvatar: StringConstructor;
            /**
             * @zh 前置图标
             */
            prependIcon: (StringConstructor | ObjectConstructor)[];
            /**
             * @zh 点击时是否有波纹
             */
            ripple: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 副标题
             */
            subtitle: StringConstructor;
            /**
             * @zh 文本内容
             */
            text: StringConstructor;
            /**
             * @zh 标题
             */
            title: StringConstructor;
            /**
             * @zh 列表项的值
             */
            value: null;
        } & {
            $children: () => vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                prepend?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                append?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            link: boolean;
            ripple: boolean;
            replace: boolean;
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            absolute: boolean;
            size: NonNullable<Size | undefined> | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            active: boolean;
            activeColor: string;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        href: StringConstructor;
        replace: BooleanConstructor;
        to: vue.PropType<vue_router.RouteLocationRaw>;
        disabled: BooleanConstructor;
        elevation: {
            type: (StringConstructor | NumberConstructor)[];
            validator(v: any): boolean;
        };
        shape: {
            type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        };
        border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        density: {
            type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: Omit<{
            type: vue.PropType<Size | undefined>;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<Size | undefined> | undefined>;
            default: NonNullable<Size | undefined> | undefined;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        absolute: BooleanConstructor;
        bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        fixed: BooleanConstructor;
        left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        position: {
            type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
            validator: (v: any) => boolean;
        };
        right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        };
        theme: StringConstructor;
        tag: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 是否激活
         */
        active: BooleanConstructor;
        /**
         * @zh 激活时的颜色
         */
        activeColor: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 激活时的 class
         */
        activeClass: StringConstructor;
        /**
         * @zh 后置头像
         */
        appendAvatar: StringConstructor;
        /**
         * @zh 后置图标
         */
        appendIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 是否是一个链接
         */
        link: BooleanConstructor;
        /**
         * @zh 前置头像
         */
        prependAvatar: StringConstructor;
        /**
         * @zh 前置图标
         */
        prependIcon: (StringConstructor | ObjectConstructor)[];
        /**
         * @zh 点击时是否有波纹
         */
        ripple: {
            type: BooleanConstructor;
            default: boolean;
        };
        /**
         * @zh 副标题
         */
        subtitle: StringConstructor;
        /**
         * @zh 文本内容
         */
        text: StringConstructor;
        /**
         * @zh 标题
         */
        title: StringConstructor;
        /**
         * @zh 列表项的值
         */
        value: null;
    } & {
        $children: () => vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            prepend?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            append?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    disabled: BooleanConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: Omit<{
        type: vue.PropType<Size | undefined>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Size | undefined> | undefined>;
        default: NonNullable<Size | undefined> | undefined;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 是否激活
     */
    active: BooleanConstructor;
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 激活时的 class
     */
    activeClass: StringConstructor;
    /**
     * @zh 后置头像
     */
    appendAvatar: StringConstructor;
    /**
     * @zh 后置图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 是否是一个链接
     */
    link: BooleanConstructor;
    /**
     * @zh 前置头像
     */
    prependAvatar: StringConstructor;
    /**
     * @zh 前置图标
     */
    prependIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 点击时是否有波纹
     */
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 副标题
     */
    subtitle: StringConstructor;
    /**
     * @zh 文本内容
     */
    text: StringConstructor;
    /**
     * @zh 标题
     */
    title: StringConstructor;
    /**
     * @zh 列表项的值
     */
    value: null;
} & {
    $children: () => vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        prepend?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        append?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: ListItemSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    link: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: NonNullable<Size | undefined> | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    active: boolean;
    activeColor: string;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: MakeSlots<{
        prepend: [ListItemSlot];
        append: [ListItemSlot];
        default: [ListItemSlot];
        title: [ListItemTitleSlot];
        subtitle: [ListItemSubtitleSlot];
    }>;
});
type ListItem = InstanceType<typeof ListItem>;

type ListGroupActivatorSlot = {
    props: {
        onClick: (e: Event) => void;
        appendIcon: string;
        class: string;
        value?: string;
    };
};
declare const ListGroup: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            tag: string;
            collapseIcon: string | Record<string, any>;
            expandIcon: string | Record<string, any>;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 列表组收起时的图标
             */
            collapseIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            /**
             * @zh 列表组展开时的图标
             */
            expandIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            /**
             * @zh 列表组的值
             */
            value: null;
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                activator?: vue.VNodeChild | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                activator?: false | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "tag" | "collapseIcon" | "expandIcon">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            tag: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 列表组收起时的图标
             */
            collapseIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            /**
             * @zh 列表组展开时的图标
             */
            expandIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            /**
             * @zh 列表组的值
             */
            value: null;
        } & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                activator?: vue.VNodeChild | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                activator?: false | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            tag: string;
            collapseIcon: string | Record<string, any>;
            expandIcon: string | Record<string, any>;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        tag: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 列表组收起时的图标
         */
        collapseIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        /**
         * @zh 列表组展开时的图标
         */
        expandIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        /**
         * @zh 列表组的值
         */
        value: null;
    } & {
        $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild | {
            activator?: vue.VNodeChild | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            activator?: false | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 列表组收起时的图标
     */
    collapseIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    /**
     * @zh 列表组展开时的图标
     */
    expandIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    /**
     * @zh 列表组的值
     */
    value: null;
} & {
    $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | vue.VNodeChild | {
        activator?: vue.VNodeChild | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        activator?: false | ((args_0: ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    tag: string;
    collapseIcon: string | Record<string, any>;
    expandIcon: string | Record<string, any>;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: MakeSlots<{
        activator: [ListGroupActivatorSlot];
        default: [
        ];
    }>;
});
type ListGroup = InstanceType<typeof ListGroup>;

type SelectStrategyFn = (data: {
    id: string;
    value: boolean;
    selected: Map<string, 'on' | 'off' | 'indeterminate'>;
    children: Map<string, string[]>;
    parents: Map<string, string>;
    event?: Event;
}) => Map<string, 'on' | 'off' | 'indeterminate'>;
type SelectStrategyTransformInFn = (v: string[] | undefined, children: Map<string, string[]>, parents: Map<string, string>) => Map<string, 'on' | 'off' | 'indeterminate'>;
type SelectStrategyTransformOutFn = (v: Map<string, 'on' | 'off' | 'indeterminate'>, children: Map<string, string[]>, parents: Map<string, string>) => any[];
type SelectStrategy$1 = {
    select: SelectStrategyFn;
    in: SelectStrategyTransformInFn;
    out: SelectStrategyTransformOutFn;
};

type OpenStrategyFn = (data: {
    id: string;
    value: boolean;
    opened: Set<string>;
    children: Map<string, string[]>;
    parents: Map<string, string>;
    event?: Event;
}) => Set<string>;

type ActiveStrategyFn = (data: {
    id: string;
    value: boolean;
    active: Set<string>;
    children: Map<string, string[]>;
    parents: Map<string, string>;
    event?: Event;
}) => Set<string>;

type SelectStrategy = 'single-leaf' | 'leaf' | 'independent' | 'classic' | SelectStrategy$1;
type OpenStrategy = 'single' | 'multiple' | OpenStrategyFn;
type ActiveStrategy = 'single' | 'multiple' | ActiveStrategyFn;

type ListChildrenSlots<T> = MakeSlots<{
    default: [];
    header: [{
        item: T;
        index: number;
    } & ListGroupActivatorSlot];
    item: [{
        item: T;
        index: number;
    }];
    title: [ListItemTitleSlot];
    subtitle: [ListItemSubtitleSlot];
}>;

type ListItemProps = {
    [key: string]: any;
    $type?: 'item' | 'subheader' | 'divider';
    $children?: (string | ListItemProps)[];
};
type ListSlots<T> = ListChildrenSlots<T> & MakeSlots<{
    prepend: [];
    append: [];
}>;
declare const List: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            absolute: boolean;
            size: NonNullable<Size | undefined> | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            nav: boolean;
            opened: boolean | string[];
            deleteAfterUnmount: boolean;
            selectStrategy: NonNullable<SelectStrategy>;
            openStrategy: NonNullable<OpenStrategy>;
            activeStrategy: NonNullable<ActiveStrategy>;
        }> & Omit<Readonly<vue.ExtractPropTypes<Omit<{
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: vue.PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Size | undefined> | undefined>;
                default: NonNullable<Size | undefined> | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: {
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            selectStrategy: {
                type: vue.PropType<NonNullable<SelectStrategy>>;
                default: NonNullable<SelectStrategy>;
            };
            openStrategy: {
                type: vue.PropType<NonNullable<OpenStrategy>>;
                default: NonNullable<OpenStrategy>;
            };
            activeStrategy: {
                type: vue.PropType<NonNullable<ActiveStrategy>>;
                default: NonNullable<ActiveStrategy>;
            };
            opened: {
                type: vue.PropType<boolean | string[]>;
                default: () => never[];
            };
            selected: vue.PropType<string[]>;
            active: vue.PropType<string[]>;
            deleteAfterUnmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 是否为导航列表
             */
            nav: BooleanConstructor;
            /**
             * @zh 数据驱动时列表项数据
             */
            items: Prop<(string | ListItemProps)[], (string | ListItemProps)[]>;
        }, "items"> & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                header?: vue.VNodeChild | ((args_0: {
                    item: unknown;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                item?: vue.VNodeChild | ((args_0: {
                    item: unknown;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                header?: false | ((args_0: {
                    item: unknown;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                item?: false | ((args_0: {
                    item: unknown;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:active"?: ((_active: string[]) => any) | undefined;
            "onUpdate:selected"?: ((_selected: string[]) => any) | undefined;
            "onUpdate:opened"?: ((_opened: string[]) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "fixed" | "disabled" | "tag" | "variant" | "absolute" | "size" | "density" | "shape" | "nav" | "opened" | "deleteAfterUnmount" | "selectStrategy" | "openStrategy" | "activeStrategy">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:active", _active: string[]) => void) & ((event: "update:selected", _selected: string[]) => void) & ((event: "update:opened", _opened: string[]) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<Omit<{
            disabled: BooleanConstructor;
            elevation: {
                type: (StringConstructor | NumberConstructor)[];
                validator(v: any): boolean;
            };
            shape: {
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            };
            border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            density: {
                type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: Omit<{
                type: vue.PropType<Size | undefined>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Size | undefined> | undefined>;
                default: NonNullable<Size | undefined> | undefined;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            absolute: BooleanConstructor;
            bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            fixed: BooleanConstructor;
            left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            position: {
                type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
                validator: (v: any) => boolean;
            };
            right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
            color: StringConstructor;
            textColor: StringConstructor;
            variant: {
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            };
            theme: StringConstructor;
            tag: {
                type: StringConstructor;
                default: string;
            };
            selectStrategy: {
                type: vue.PropType<NonNullable<SelectStrategy>>;
                default: NonNullable<SelectStrategy>;
            };
            openStrategy: {
                type: vue.PropType<NonNullable<OpenStrategy>>;
                default: NonNullable<OpenStrategy>;
            };
            activeStrategy: {
                type: vue.PropType<NonNullable<ActiveStrategy>>;
                default: NonNullable<ActiveStrategy>;
            };
            opened: {
                type: vue.PropType<boolean | string[]>;
                default: () => never[];
            };
            selected: vue.PropType<string[]>;
            active: vue.PropType<string[]>;
            deleteAfterUnmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 是否为导航列表
             */
            nav: BooleanConstructor;
            /**
             * @zh 数据驱动时列表项数据
             */
            items: Prop<(string | ListItemProps)[], (string | ListItemProps)[]>;
        }, "items"> & {
            $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild | {
                default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                header?: vue.VNodeChild | ((args_0: {
                    item: unknown;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                item?: vue.VNodeChild | ((args_0: {
                    item: unknown;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
                append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                header?: false | ((args_0: {
                    item: unknown;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                item?: false | ((args_0: {
                    item: unknown;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:active"?: ((_active: string[]) => any) | undefined;
            "onUpdate:selected"?: ((_selected: string[]) => any) | undefined;
            "onUpdate:opened"?: ((_opened: string[]) => any) | undefined;
        }, {
            open: (id: string, value: boolean, event?: Event | undefined) => void;
            select: (id: string, value: boolean, event?: Event | undefined) => void;
            activate: (id: string, value: boolean, event?: Event | undefined) => void;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Omit<{
            'update:selected': (_selected: string[]) => boolean;
            'update:opened': (_opened: string[]) => boolean;
            'update:active': (_active: string[]) => boolean;
        }, "items">, string, {
            fixed: boolean;
            disabled: boolean;
            tag: string;
            variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
            absolute: boolean;
            size: NonNullable<Size | undefined> | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
            nav: boolean;
            opened: boolean | string[];
            deleteAfterUnmount: boolean;
            selectStrategy: NonNullable<SelectStrategy>;
            openStrategy: NonNullable<OpenStrategy>;
            activeStrategy: NonNullable<ActiveStrategy>;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<Omit<{
        disabled: BooleanConstructor;
        elevation: {
            type: (StringConstructor | NumberConstructor)[];
            validator(v: any): boolean;
        };
        shape: {
            type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        };
        border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        density: {
            type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: Omit<{
            type: vue.PropType<Size | undefined>;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<Size | undefined> | undefined>;
            default: NonNullable<Size | undefined> | undefined;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        absolute: BooleanConstructor;
        bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        fixed: BooleanConstructor;
        left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        position: {
            type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
            validator: (v: any) => boolean;
        };
        right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        color: StringConstructor;
        textColor: StringConstructor;
        variant: {
            type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        };
        theme: StringConstructor;
        tag: {
            type: StringConstructor;
            default: string;
        };
        selectStrategy: {
            type: vue.PropType<NonNullable<SelectStrategy>>;
            default: NonNullable<SelectStrategy>;
        };
        openStrategy: {
            type: vue.PropType<NonNullable<OpenStrategy>>;
            default: NonNullable<OpenStrategy>;
        };
        activeStrategy: {
            type: vue.PropType<NonNullable<ActiveStrategy>>;
            default: NonNullable<ActiveStrategy>;
        };
        opened: {
            type: vue.PropType<boolean | string[]>;
            default: () => never[];
        };
        selected: vue.PropType<string[]>;
        active: vue.PropType<string[]>;
        deleteAfterUnmount: {
            type: BooleanConstructor;
            default: boolean;
        };
        /**
         * @zh 是否为导航列表
         */
        nav: BooleanConstructor;
        /**
         * @zh 数据驱动时列表项数据
         */
        items: Prop<(string | ListItemProps)[], (string | ListItemProps)[]>;
    }, "items"> & {
        $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild | {
            default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            header?: vue.VNodeChild | ((args_0: {
                item: unknown;
                index: number;
            } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            item?: vue.VNodeChild | ((args_0: {
                item: unknown;
                index: number;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
            append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            header?: false | ((args_0: {
                item: unknown;
                index: number;
            } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            item?: false | ((args_0: {
                item: unknown;
                index: number;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:active"?: ((_active: string[]) => any) | undefined;
        "onUpdate:selected"?: ((_selected: string[]) => any) | undefined;
        "onUpdate:opened"?: ((_opened: string[]) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        open: (id: string, value: boolean, event?: Event | undefined) => void;
        select: (id: string, value: boolean, event?: Event | undefined) => void;
        activate: (id: string, value: boolean, event?: Event | undefined) => void;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<Omit<{
    disabled: BooleanConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: Omit<{
        type: vue.PropType<Size | undefined>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Size | undefined> | undefined>;
        default: NonNullable<Size | undefined> | undefined;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    selectStrategy: {
        type: vue.PropType<NonNullable<SelectStrategy>>;
        default: NonNullable<SelectStrategy>;
    };
    openStrategy: {
        type: vue.PropType<NonNullable<OpenStrategy>>;
        default: NonNullable<OpenStrategy>;
    };
    activeStrategy: {
        type: vue.PropType<NonNullable<ActiveStrategy>>;
        default: NonNullable<ActiveStrategy>;
    };
    opened: {
        type: vue.PropType<boolean | string[]>;
        default: () => never[];
    };
    selected: vue.PropType<string[]>;
    active: vue.PropType<string[]>;
    deleteAfterUnmount: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 是否为导航列表
     */
    nav: BooleanConstructor;
    /**
     * @zh 数据驱动时列表项数据
     */
    items: Prop<(string | ListItemProps)[], (string | ListItemProps)[]>;
}, "items"> & {
    $children: () => (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | vue.VNodeChild | {
        default?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        header?: vue.VNodeChild | ((args_0: {
            item: unknown;
            index: number;
        } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        item?: vue.VNodeChild | ((args_0: {
            item: unknown;
            index: number;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prepend?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
        append?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        default?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        header?: false | ((args_0: {
            item: unknown;
            index: number;
        } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        item?: false | ((args_0: {
            item: unknown;
            index: number;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prepend?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        append?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:active"?: ((_active: string[]) => any) | undefined;
    "onUpdate:selected"?: ((_selected: string[]) => any) | undefined;
    "onUpdate:opened"?: ((_opened: string[]) => any) | undefined;
}, {
    open: (id: string, value: boolean, event?: Event | undefined) => void;
    select: (id: string, value: boolean, event?: Event | undefined) => void;
    activate: (id: string, value: boolean, event?: Event | undefined) => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Omit<{
    'update:selected': (_selected: string[]) => boolean;
    'update:opened': (_opened: string[]) => boolean;
    'update:active': (_active: string[]) => boolean;
}, "items">, string, {
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: NonNullable<Size | undefined> | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    nav: boolean;
    opened: boolean | string[];
    deleteAfterUnmount: boolean;
    selectStrategy: NonNullable<SelectStrategy>;
    openStrategy: NonNullable<OpenStrategy>;
    activeStrategy: NonNullable<ActiveStrategy>;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new <T_1>() => {
    $props: {
        items?: T_1[] | undefined;
    };
    $slots: ListSlots<T_1>;
});
type List = InstanceType<typeof List>;

declare const ListSubheader: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 副标题颜色
     */
    color: StringConstructor;
    inset: BooleanConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 副标题颜色
     */
    color: StringConstructor;
    inset: BooleanConstructor;
}>>, {
    tag: string;
    inset: boolean;
}>;

declare const ListItemAvatar: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    start: BooleanConstructor;
    end: BooleanConstructor;
    image: StringConstructor;
    icon: (StringConstructor | ObjectConstructor)[];
    text: StringConstructor;
    link: BooleanConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    start: BooleanConstructor;
    end: BooleanConstructor;
    image: StringConstructor;
    icon: (StringConstructor | ObjectConstructor)[];
    text: StringConstructor;
    link: BooleanConstructor;
}>>, {
    link: boolean;
    fixed: boolean;
    tag: string;
    color: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    start: boolean;
    end: boolean;
}>;
type ListItemAvatar = InstanceType<typeof ListItemAvatar>;

declare const ListItemHeader: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const ListItemTitle: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const ListItemSubtitle: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

type Main = InstanceType<typeof Main>;
declare const Main: vue.DefineComponent<{
    color: StringConstructor;
    textColor: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    color: StringConstructor;
    textColor: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
}>>, {
    tag: string;
}>;

declare const Menu: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            modelValue: BooleanConstructor;
            id: StringConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "transition">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _modelValue: boolean) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            transition: Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            };
            modelValue: BooleanConstructor;
            id: StringConstructor;
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        }, {
            overlayRef: vue.Ref<any>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_modelValue: boolean) => boolean;
        }, string, {
            modelValue: boolean;
            transition: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        transition: Omit<{
            type: vue.PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        };
        modelValue: BooleanConstructor;
        id: StringConstructor;
    } & {
        $children: () => vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            default?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            activator?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            default?: false | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            activator?: false | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<{
        overlayRef: vue.Ref<any>;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    modelValue: BooleanConstructor;
    id: StringConstructor;
} & {
    $children: () => vue.VNodeChild | ((args_0: {
        close: () => void;
        isActive: vue.Ref<boolean>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        default?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        activator?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        default?: false | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        activator?: false | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
}, {
    overlayRef: vue.Ref<any>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: boolean) => boolean;
}, string, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: OverlaySlots;
});
type Menu = InstanceType<typeof Menu>;

declare const Messages: vue.DefineComponent<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
            group: boolean;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
            group: boolean;
        };
    };
    active: BooleanConstructor;
    value: {
        type: (StringConstructor | ArrayConstructor)[];
        default: () => never[];
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
            group: boolean;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
            group: boolean;
        };
    };
    active: BooleanConstructor;
    value: {
        type: (StringConstructor | ArrayConstructor)[];
        default: () => never[];
    };
}>>, {
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
        group: boolean;
    };
    active: boolean;
    value: string | unknown[];
}>;

declare const MessageProvider: vue.DefineComponent<{
    registered: BooleanConstructor;
}, {
    items: vue.Ref<{
        id: string;
        modelValue: boolean;
        text: string;
        duration: number;
        close: () => void;
    }[]>;
    open: (props?: Record<string, any> | undefined) => (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    info: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    success: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    warning: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    error: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    loading: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    close: (id: string) => void;
    remove: (id: string) => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    registered: BooleanConstructor;
}>>, {
    registered: boolean;
}>;

declare const NotificationProvider: vue.DefineComponent<{
    registered: BooleanConstructor;
}, {
    items: vue.Ref<{
        id: string;
        modelValue: boolean;
        text: string;
        duration: number;
        close: () => void;
    }[]>;
    open: (props?: Record<string, any> | undefined) => (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    info: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    success: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    warning: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    error: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    loading: (text: string, rest?: Record<string, any> | undefined) => Promise<unknown> | (() => void);
    close: (id: string) => void;
    remove: (id: string) => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    registered: BooleanConstructor;
}>>, {
    registered: boolean;
}>;

declare const Pagination: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string; /**
         * @zh 是否禁用
         */
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 导航的无障碍标签值
     */
    ariaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 当前页的无障碍标签值
     */
    currentPageAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 是否禁用
     */
    disabled: BooleanConstructor;
    /**
     * @zh 省略值
     */
    ellipsis: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 第一页的无障碍标签值
     */
    firstAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 第一页初始值
     */
    firstPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 第一页的按钮图标
     */
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 最后一页的无障碍标签值
     */
    lastAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 最后一页的按钮图标
     */
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 当前页
     */
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: (props: any) => any;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 下一页的无障碍标签值
     */
    nextAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 下一页的按钮图标
     */
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 上一页的按钮图标
     */
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 页面的无障碍标签值
     */
    pageAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 每页条数
     */
    perPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 每页条数可选项
     */
    perPageOptions: {
        type: ArrayConstructor;
        default: () => number[];
    };
    /**
     * @zh 上一页的无障碍标签值
     */
    previousAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 显示首页和最后一页
     */
    showFirstLastPage: BooleanConstructor;
    /**
     * @zh 显示快速跳跃
     */
    showQuickJumper: BooleanConstructor;
    /**
     * @zh 显示每页条数选择器
     */
    showPerPageSelect: BooleanConstructor;
    /**
     * @zh 总条数
     */
    total: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 总显示页数
     */
    totalVisible: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (val: number) => boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: number) => true;
    'update:perPage': (_perPage: number) => true;
    first: (_value: number) => true;
    prev: (_value: number) => true;
    next: (_value: number) => true;
    last: (_value: number) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string; /**
         * @zh 是否禁用
         */
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 导航的无障碍标签值
     */
    ariaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 当前页的无障碍标签值
     */
    currentPageAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 是否禁用
     */
    disabled: BooleanConstructor;
    /**
     * @zh 省略值
     */
    ellipsis: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 第一页的无障碍标签值
     */
    firstAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 第一页初始值
     */
    firstPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 第一页的按钮图标
     */
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 最后一页的无障碍标签值
     */
    lastAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 最后一页的按钮图标
     */
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 当前页
     */
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: (props: any) => any;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 下一页的无障碍标签值
     */
    nextAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 下一页的按钮图标
     */
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 上一页的按钮图标
     */
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 页面的无障碍标签值
     */
    pageAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 每页条数
     */
    perPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 每页条数可选项
     */
    perPageOptions: {
        type: ArrayConstructor;
        default: () => number[];
    };
    /**
     * @zh 上一页的无障碍标签值
     */
    previousAriaLabel: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 显示首页和最后一页
     */
    showFirstLastPage: BooleanConstructor;
    /**
     * @zh 显示快速跳跃
     */
    showQuickJumper: BooleanConstructor;
    /**
     * @zh 显示每页条数选择器
     */
    showPerPageSelect: BooleanConstructor;
    /**
     * @zh 总条数
     */
    total: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (val: number) => boolean;
    };
    /**
     * @zh 总显示页数
     */
    totalVisible: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (val: number) => boolean;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: number) => any) | undefined;
    onNext?: ((_value: number) => any) | undefined;
    onPrev?: ((_value: number) => any) | undefined;
    "onUpdate:perPage"?: ((_perPage: number) => any) | undefined;
    onFirst?: ((_value: number) => any) | undefined;
    onLast?: ((_value: number) => any) | undefined;
}, {
    modelValue: string | number;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    activeColor: string;
    prevIcon: string;
    nextIcon: string;
    ariaLabel: string;
    currentPageAriaLabel: string;
    ellipsis: string;
    firstAriaLabel: string;
    firstPage: string | number;
    firstIcon: string;
    lastAriaLabel: string;
    lastIcon: string;
    nextAriaLabel: string;
    pageAriaLabel: string;
    perPage: string | number;
    perPageOptions: unknown[];
    previousAriaLabel: string;
    showFirstLastPage: boolean;
    showQuickJumper: boolean;
    showPerPageSelect: boolean;
    total: string | number;
}>;
type Pagination = InstanceType<typeof Pagination>;

type Paper = InstanceType<typeof Paper>;
declare const Paper: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    fixed: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
}>;

declare const Progress: vue.DefineComponent<{
    variant: {
        type: PropType<"linear" | "circular">;
        default: string;
        validator: (v: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
    rotate: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 进度条颜色
     */
    color: {
        type: PropType<string | false | null>;
        default: string;
    };
    /**
     * @zh 是否在左侧
     */
    start: BooleanConstructor;
    /**
     * @zh 是否在右侧
     */
    end: BooleanConstructor;
}, {
    start: () => void;
    finish: () => Promise<unknown>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: number) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    variant: {
        type: PropType<"linear" | "circular">;
        default: string;
        validator: (v: any) => boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
    rotate: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * @zh 进度条颜色
     */
    color: {
        type: PropType<string | false | null>;
        default: string;
    };
    /**
     * @zh 是否在左侧
     */
    start: BooleanConstructor;
    /**
     * @zh 是否在右侧
     */
    end: BooleanConstructor;
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: number) => any) | undefined;
}, {
    modelValue: string | number;
    tag: string;
    color: string | false | null;
    variant: "linear" | "circular";
    size: Size | undefined;
    active: boolean;
    start: boolean;
    end: boolean;
    indeterminate: boolean;
    rotate: string | number;
    strokeWidth: string | number;
    underlay: boolean;
}>;
type Progress = InstanceType<typeof Progress>;

declare const ProgressLinear: vue.DefineComponent<{
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
}>>, {
    modelValue: string | number;
    active: boolean;
    indeterminate: boolean;
    strokeWidth: string | number;
    underlay: boolean;
}>;

declare const ProgressCircular: vue.DefineComponent<{
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
    size: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    rotate: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    active: {
        type: BooleanConstructor;
        default: boolean;
    };
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    strokeWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    indeterminate: BooleanConstructor;
    underlay: {
        type: BooleanConstructor;
        default: boolean;
    };
    size: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    rotate: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}>>, {
    modelValue: string | number;
    size: string | number;
    active: boolean;
    indeterminate: boolean;
    rotate: string | number;
    strokeWidth: string | number;
    underlay: boolean;
}>;

declare const Radio: vue.DefineComponent<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    trueIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    trueIcon: {
        type: vue.PropType<string>;
        default: string;
    };
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    type: string;
    error: boolean;
    disabled: boolean;
    color: string;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: boolean | null;
    falseIcon: string;
    trueIcon: string;
    readonly: boolean;
    valueComparator: typeof _veno_ui_utils.deepEqual;
}>;
type Radio = InstanceType<typeof Radio>;

interface RadioGroupItemProps {
    value: any;
    [key: string]: any;
}
declare const RadioGroup: vue.DefineComponent<{
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: {
        type: PropType<string>;
        default: string;
    };
    trueIcon: {
        type: PropType<string>;
        default: string;
    };
    multiple: {
        type: PropType<boolean | null>;
        default: null;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: {
        type: PropType<string>;
        default: string;
    };
    modelValue: null;
    /**
     * @zh 单选组的所有可选项
     */
    items: PropType<(string | RadioGroupItemProps)[]>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: {
        type: PropType<string>;
        default: string;
    };
    trueIcon: {
        type: PropType<string>;
        default: string;
    };
    multiple: {
        type: PropType<boolean | null>;
        default: null;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: {
        type: PropType<string>;
        default: string;
    };
    modelValue: null;
    /**
     * @zh 单选组的所有可选项
     */
    items: PropType<(string | RadioGroupItemProps)[]>;
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    type: string;
    disabled: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: boolean | null;
    falseIcon: string;
    trueIcon: string;
    readonly: boolean;
}>;

type Responsive = InstanceType<typeof Responsive>;
declare const Responsive: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{}> & Omit<Readonly<vue.ExtractPropTypes<{
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            aspectRatio: (StringConstructor | NumberConstructor)[];
            contentClass: StringConstructor;
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, never>;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: (StringConstructor | NumberConstructor)[];
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: (StringConstructor | NumberConstructor)[];
            width: (StringConstructor | NumberConstructor)[];
            aspectRatio: (StringConstructor | NumberConstructor)[];
            contentClass: StringConstructor;
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {}, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: (StringConstructor | NumberConstructor)[];
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: (StringConstructor | NumberConstructor)[];
        width: (StringConstructor | NumberConstructor)[];
        aspectRatio: (StringConstructor | NumberConstructor)[];
        contentClass: StringConstructor;
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    aspectRatio: (StringConstructor | NumberConstructor)[];
    contentClass: StringConstructor;
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots?: Record<string, (...args: any[]) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]> | undefined;
});

declare const Scrim: vue.DefineComponent<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    modelValue: BooleanConstructor;
    color: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    };
    modelValue: BooleanConstructor;
    color: StringConstructor;
}>>, {
    modelValue: boolean;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    };
}>;

declare const Scrollbar: vue.DefineComponent<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    tag: string;
    beautifyScrollbar: boolean;
}>;

type SelectionControlSlot = {
    label: string | undefined;
    model: WritableComputedRef<any>;
    isReadonly: ComputedRef<boolean>;
    isDisabled: ComputedRef<boolean>;
    textColorClasses: Ref<string[]>;
    textColorStyles: Ref<string[]>;
    props: {
        onBlur: (e: Event) => void;
        onFocus: (e: FocusEvent) => void;
        id: string;
    };
};
declare const SelectionControl: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            multiple: boolean | null;
            readonly: boolean;
            valueComparator: typeof deepEqual;
        }> & Omit<Readonly<ExtractPropTypes<Omit<{
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            theme: StringConstructor;
            color: StringConstructor;
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            id: StringConstructor;
            inline: BooleanConstructor;
            label: StringConstructor;
            falseIcon: StringConstructor;
            trueIcon: StringConstructor;
            multiple: {
                type: PropType<boolean | null>;
                default: null;
            };
            name: StringConstructor;
            readonly: BooleanConstructor;
            trueValue: null;
            falseValue: null;
            modelValue: null;
            type: StringConstructor;
            value: null;
            valueComparator: {
                type: PropType<typeof deepEqual>;
                default: typeof deepEqual;
            };
        }, "modelValue" | "onUpdate:modelValue"> & {
            $children: () => vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                label?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                input?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                label?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                input?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "error" | "disabled" | "size" | "density" | "inline" | "multiple" | "readonly" | "valueComparator">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<ExtractPropTypes<Omit<{
            density: {
                type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
                default: string;
                validator: (v: any) => boolean;
            };
            size: {
                type: PropType<Size | undefined>;
                default: string;
            };
            theme: StringConstructor;
            color: StringConstructor;
            disabled: BooleanConstructor;
            error: BooleanConstructor;
            id: StringConstructor;
            inline: BooleanConstructor;
            label: StringConstructor;
            falseIcon: StringConstructor;
            trueIcon: StringConstructor;
            multiple: {
                type: PropType<boolean | null>;
                default: null;
            };
            name: StringConstructor;
            readonly: BooleanConstructor;
            trueValue: null;
            falseValue: null;
            modelValue: null;
            type: StringConstructor;
            value: null;
            valueComparator: {
                type: PropType<typeof deepEqual>;
                default: typeof deepEqual;
            };
        }, "modelValue" | "onUpdate:modelValue"> & {
            $children: () => vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                label?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                input?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                label?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                input?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, {
            isFocused: Ref<boolean>;
            inputRef: Ref<HTMLInputElement | undefined>;
        }, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Omit<{
            'update:modelValue': (_modelValue: any) => boolean;
        }, "modelValue" | "update:modelValue">, string, {
            error: boolean;
            disabled: boolean;
            size: Size | undefined;
            density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
            inline: boolean;
            multiple: boolean | null;
            readonly: boolean;
            valueComparator: typeof deepEqual;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<ExtractPropTypes<Omit<{
        density: {
            type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
            default: string;
            validator: (v: any) => boolean;
        };
        size: {
            type: PropType<Size | undefined>;
            default: string;
        };
        theme: StringConstructor;
        color: StringConstructor;
        disabled: BooleanConstructor;
        error: BooleanConstructor;
        id: StringConstructor;
        inline: BooleanConstructor;
        label: StringConstructor;
        falseIcon: StringConstructor;
        trueIcon: StringConstructor;
        multiple: {
            type: PropType<boolean | null>;
            default: null;
        };
        name: StringConstructor;
        readonly: BooleanConstructor;
        trueValue: null;
        falseValue: null;
        modelValue: null;
        type: StringConstructor;
        value: null;
        valueComparator: {
            type: PropType<typeof deepEqual>;
            default: typeof deepEqual;
        };
    }, "modelValue" | "onUpdate:modelValue"> & {
        $children: () => vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            label?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            input?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            label?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            input?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<{
        isFocused: Ref<boolean>;
        inputRef: Ref<HTMLInputElement | undefined>;
    }> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<ExtractPropTypes<Omit<{
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: StringConstructor;
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: StringConstructor;
    trueIcon: StringConstructor;
    multiple: {
        type: PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: StringConstructor;
    value: null;
    valueComparator: {
        type: PropType<typeof deepEqual>;
        default: typeof deepEqual;
    };
}, "modelValue" | "onUpdate:modelValue"> & {
    $children: () => vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        label?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        input?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        label?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        input?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | ((args_0: SelectionControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, {
    isFocused: Ref<boolean>;
    inputRef: Ref<HTMLInputElement | undefined>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Omit<{
    'update:modelValue': (_modelValue: any) => boolean;
}, "modelValue" | "update:modelValue">, string, {
    error: boolean;
    disabled: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: boolean | null;
    readonly: boolean;
    valueComparator: typeof deepEqual;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new <T_1>() => {
    $props: {
        modelValue?: T_1 | undefined;
        'onUpdate:modelValue'?: ((val: T_1) => any) | undefined;
    };
    $slots: MakeSlots<{
        label: [SelectionControlSlot];
        input: [SelectionControlSlot];
        default: [SelectionControlSlot];
    }>;
});
type SelectionControl = InstanceType<typeof SelectionControl>;

declare const SelectionGroupControl: vue.DefineComponent<{
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: StringConstructor;
    trueIcon: StringConstructor;
    multiple: {
        type: PropType<boolean | null>;
        default: null;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: StringConstructor;
    modelValue: null;
}, {
    disabled: Ref<boolean>;
    inline: Ref<boolean>;
    modelValue: vue.WritableComputedRef<any>;
    multiple: vue.ComputedRef<boolean>;
    id: vue.ComputedRef<string>;
    name: Ref<string | undefined>;
    falseIcon: Ref<string | undefined>;
    trueIcon: Ref<string | undefined>;
    readonly: Ref<boolean>;
    type: Ref<string | undefined>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    id: StringConstructor;
    inline: BooleanConstructor;
    name: StringConstructor;
    falseIcon: StringConstructor;
    trueIcon: StringConstructor;
    multiple: {
        type: PropType<boolean | null>;
        default: null;
    };
    disabled: BooleanConstructor;
    readonly: BooleanConstructor;
    type: StringConstructor;
    modelValue: null;
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    disabled: boolean;
    inline: boolean;
    multiple: boolean | null;
    readonly: boolean;
}>;
type SelectionGroupControl = InstanceType<typeof SelectionGroupControl>;

interface GroupItem {
    id: string;
    value: Ref<unknown>;
    disabled: Ref<boolean | undefined>;
}
interface GroupInstance {
    vm: ComponentInternalInstance | null;
    register: (item: GroupItem, cmp: ComponentInternalInstance) => void;
    unregister: (id: string) => void;
    select: (id: string, value: boolean) => void;
    selected: Ref<any[]>;
    isSelected: (id: string) => boolean;
    prev: () => void;
    next: () => void;
    selectedClass: Ref<string | undefined>;
    items: Ref<{
        id: string;
        value: unknown;
        disabled: boolean | undefined;
    }[]>;
    disabled: Ref<boolean | undefined>;
}

declare const SlideGroup: vue.DefineComponent<{
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: vue.PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: StringConstructor;
    disabled: BooleanConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    activeClass: {
        type: StringConstructor;
        default: string;
    };
    centerActive: BooleanConstructor;
    direction: {
        type: StringConstructor;
        default: string;
    };
    symbol: {
        type: null;
        default: InjectionKey<GroupInstance>;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    showArrows: {
        type: (BooleanConstructor | StringConstructor)[];
        validator: (v: any) => boolean;
    };
}, {
    selected: vue.WritableComputedRef<string[]>;
    scrollTo: (location: 'prev' | 'next') => void;
    scrollOffset: vue.Ref<number>;
    focus: (location?: 'next' | 'prev' | 'first' | 'last') => void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: vue.PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: StringConstructor;
    disabled: BooleanConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    activeClass: {
        type: StringConstructor;
        default: string;
    };
    centerActive: BooleanConstructor;
    direction: {
        type: StringConstructor;
        default: string;
    };
    symbol: {
        type: null;
        default: InjectionKey<GroupInstance>;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    showArrows: {
        type: (BooleanConstructor | StringConstructor)[];
        validator: (v: any) => boolean;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    symbol: any;
    modelValue: string | number | boolean | Record<string, any> | unknown[];
    disabled: boolean;
    tag: string;
    multiple: boolean;
    prevIcon: string;
    nextIcon: string;
    direction: string;
    activeClass: string;
    centerActive: boolean;
}>;
type SlideGroup = InstanceType<typeof SlideGroup>;

declare const SlideGroupItem: vue.DefineComponent<{
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>[] | undefined, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
}>>, {
    disabled: boolean;
}>;

type SelectItemProps = string | Record<string, any>;
type InternalSelectItemProps = ListItemProps & {
    text: string;
    value: string | number;
    filtered?: boolean;
};
type SelectSlots = InputSlots & ListChildrenSlots<InternalSelectItemProps> & MakeSlots<{
    'tag': [
        {
            item: InternalSelectItemProps;
            close: () => void;
        }
    ];
    'no-data': [];
}>;
declare const Select: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: any;
            loading: boolean;
            multiple: boolean;
            readonly: boolean;
            beautifyScrollbar: boolean;
            openOnClear: boolean;
            appendInnerIcon: string;
            deleteAfterUnmount: boolean;
            filterable: boolean;
            tags: boolean;
            returnObject: boolean;
            itemText: string;
            itemValue: string;
            noDataText: string;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            beautifyScrollbar: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 追加的内联图标
             */
            appendInnerIcon: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 可选项卸载后是否从已选项中移除
             */
            deleteAfterUnmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 可过滤的
             */
            filterable: BooleanConstructor;
            /**
             * @zh ID
             */
            id: StringConstructor;
            /**
             * @zh 选择框可选项
             */
            items: PropType<SelectItemProps[]>;
            /**
             * @zh 可选项文本字段
             */
            itemText: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 可选项值字段
             */
            itemValue: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 加载中
             */
            loading: BooleanConstructor;
            /**
             * @zh 当前值
             */
            modelValue: {
                type: null;
                default: () => never[];
            };
            /**
             * @zh 是否多选
             */
            multiple: BooleanConstructor;
            /**
             * @zh 无数据时显示的文本
             */
            noDataText: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否在清除时打开可选菜单
             */
            openOnClear: BooleanConstructor;
            /**
             * @zh 输入框占位符
             */
            placeholder: StringConstructor;
            /**
             * @zh 查询字符串
             */
            query: StringConstructor;
            /**
             * @zh 标签
             */
            tags: BooleanConstructor;
            /**
             * @zh 只读
             */
            readonly: BooleanConstructor;
            /**
             * @zh 返回对象值
             */
            returnObject: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                header?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                item?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                tag?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    close: () => void;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'no-data'?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                header?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                item?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                tag?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    close: () => void;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'no-data'?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:query"?: ((_query: string) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "loading" | "multiple" | "readonly" | "beautifyScrollbar" | "openOnClear" | "appendInnerIcon" | "deleteAfterUnmount" | "filterable" | "tags" | "returnObject" | "itemText" | "itemValue" | "noDataText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", _modelValue: any) => void) & ((event: "click:clear", _event: MouseEvent) => void) & ((event: "update:query", _query: string) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            beautifyScrollbar: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 追加的内联图标
             */
            appendInnerIcon: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 可选项卸载后是否从已选项中移除
             */
            deleteAfterUnmount: {
                type: BooleanConstructor;
                default: boolean;
            };
            /**
             * @zh 可过滤的
             */
            filterable: BooleanConstructor;
            /**
             * @zh ID
             */
            id: StringConstructor;
            /**
             * @zh 选择框可选项
             */
            items: PropType<SelectItemProps[]>;
            /**
             * @zh 可选项文本字段
             */
            itemText: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 可选项值字段
             */
            itemValue: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 加载中
             */
            loading: BooleanConstructor;
            /**
             * @zh 当前值
             */
            modelValue: {
                type: null;
                default: () => never[];
            };
            /**
             * @zh 是否多选
             */
            multiple: BooleanConstructor;
            /**
             * @zh 无数据时显示的文本
             */
            noDataText: {
                type: StringConstructor;
                default: string;
            };
            /**
             * @zh 是否在清除时打开可选菜单
             */
            openOnClear: BooleanConstructor;
            /**
             * @zh 输入框占位符
             */
            placeholder: StringConstructor;
            /**
             * @zh 查询字符串
             */
            query: StringConstructor;
            /**
             * @zh 标签
             */
            tags: BooleanConstructor;
            /**
             * @zh 只读
             */
            readonly: BooleanConstructor;
            /**
             * @zh 返回对象值
             */
            returnObject: BooleanConstructor;
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                header?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                item?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                tag?: vue.VNodeChild | ((args_0: {
                    item: InternalSelectItemProps;
                    close: () => void;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'no-data'?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | vue.VNodeChild;
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                header?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                item?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    index: number;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                tag?: false | ((args_0: {
                    item: InternalSelectItemProps;
                    close: () => void;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'no-data'?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
            "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
            "onUpdate:query"?: ((_query: string) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'click:clear': (_event: MouseEvent) => true;
            'update:modelValue': (_modelValue: any) => true;
            'update:query': (_query: string) => true;
        }, string, {
            modelValue: any;
            loading: boolean;
            multiple: boolean;
            readonly: boolean;
            beautifyScrollbar: boolean;
            openOnClear: boolean;
            appendInnerIcon: string;
            deleteAfterUnmount: boolean;
            filterable: boolean;
            tags: boolean;
            returnObject: boolean;
            itemText: string;
            itemValue: string;
            noDataText: string;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        beautifyScrollbar: {
            type: BooleanConstructor;
            default: boolean;
        };
        /**
         * @zh 追加的内联图标
         */
        appendInnerIcon: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 可选项卸载后是否从已选项中移除
         */
        deleteAfterUnmount: {
            type: BooleanConstructor;
            default: boolean;
        };
        /**
         * @zh 可过滤的
         */
        filterable: BooleanConstructor;
        /**
         * @zh ID
         */
        id: StringConstructor;
        /**
         * @zh 选择框可选项
         */
        items: PropType<SelectItemProps[]>;
        /**
         * @zh 可选项文本字段
         */
        itemText: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 可选项值字段
         */
        itemValue: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 加载中
         */
        loading: BooleanConstructor;
        /**
         * @zh 当前值
         */
        modelValue: {
            type: null;
            default: () => never[];
        };
        /**
         * @zh 是否多选
         */
        multiple: BooleanConstructor;
        /**
         * @zh 无数据时显示的文本
         */
        noDataText: {
            type: StringConstructor;
            default: string;
        };
        /**
         * @zh 是否在清除时打开可选菜单
         */
        openOnClear: BooleanConstructor;
        /**
         * @zh 输入框占位符
         */
        placeholder: StringConstructor;
        /**
         * @zh 查询字符串
         */
        query: StringConstructor;
        /**
         * @zh 标签
         */
        tags: BooleanConstructor;
        /**
         * @zh 只读
         */
        readonly: BooleanConstructor;
        /**
         * @zh 返回对象值
         */
        returnObject: BooleanConstructor;
    } & {
        $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]));
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            header?: vue.VNodeChild | ((args_0: {
                item: InternalSelectItemProps;
                index: number;
            } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            item?: vue.VNodeChild | ((args_0: {
                item: InternalSelectItemProps;
                index: number;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            tag?: vue.VNodeChild | ((args_0: {
                item: InternalSelectItemProps;
                close: () => void;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'no-data'?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | vue.VNodeChild;
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            header?: false | ((args_0: {
                item: InternalSelectItemProps;
                index: number;
            } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            item?: false | ((args_0: {
                item: InternalSelectItemProps;
                index: number;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            tag?: false | ((args_0: {
                item: InternalSelectItemProps;
                close: () => void;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'no-data'?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
        "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
        "onUpdate:query"?: ((_query: string) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 追加的内联图标
     */
    appendInnerIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 可选项卸载后是否从已选项中移除
     */
    deleteAfterUnmount: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 可过滤的
     */
    filterable: BooleanConstructor;
    /**
     * @zh ID
     */
    id: StringConstructor;
    /**
     * @zh 选择框可选项
     */
    items: PropType<SelectItemProps[]>;
    /**
     * @zh 可选项文本字段
     */
    itemText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 可选项值字段
     */
    itemValue: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 加载中
     */
    loading: BooleanConstructor;
    /**
     * @zh 当前值
     */
    modelValue: {
        type: null;
        default: () => never[];
    };
    /**
     * @zh 是否多选
     */
    multiple: BooleanConstructor;
    /**
     * @zh 无数据时显示的文本
     */
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 是否在清除时打开可选菜单
     */
    openOnClear: BooleanConstructor;
    /**
     * @zh 输入框占位符
     */
    placeholder: StringConstructor;
    /**
     * @zh 查询字符串
     */
    query: StringConstructor;
    /**
     * @zh 标签
     */
    tags: BooleanConstructor;
    /**
     * @zh 只读
     */
    readonly: BooleanConstructor;
    /**
     * @zh 返回对象值
     */
    returnObject: BooleanConstructor;
} & {
    $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[])) | {
        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]));
        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        header?: vue.VNodeChild | ((args_0: {
            item: InternalSelectItemProps;
            index: number;
        } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        item?: vue.VNodeChild | ((args_0: {
            item: InternalSelectItemProps;
            index: number;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        title?: vue.VNodeChild | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        subtitle?: vue.VNodeChild | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        tag?: vue.VNodeChild | ((args_0: {
            item: InternalSelectItemProps;
            close: () => void;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'no-data'?: (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | vue.VNodeChild;
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | undefined;
        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        header?: false | ((args_0: {
            item: InternalSelectItemProps;
            index: number;
        } & ListGroupActivatorSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        item?: false | ((args_0: {
            item: InternalSelectItemProps;
            index: number;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        title?: false | ((args_0: ListItemTitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        subtitle?: false | ((args_0: ListItemSubtitleSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        tag?: false | ((args_0: {
            item: InternalSelectItemProps;
            close: () => void;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'no-data'?: false | (() => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
    "onClick:clear"?: ((_event: MouseEvent) => any) | undefined;
    "onUpdate:query"?: ((_query: string) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'click:clear': (_event: MouseEvent) => true;
    'update:modelValue': (_modelValue: any) => true;
    'update:query': (_query: string) => true;
}, string, {
    modelValue: any;
    loading: boolean;
    multiple: boolean;
    readonly: boolean;
    beautifyScrollbar: boolean;
    openOnClear: boolean;
    appendInnerIcon: string;
    deleteAfterUnmount: boolean;
    filterable: boolean;
    tags: boolean;
    returnObject: boolean;
    itemText: string;
    itemValue: string;
    noDataText: string;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: SelectSlots;
});
type Select = InstanceType<typeof Select>;

declare const Spacer: vue.DefineComponent<{
    alignSelf: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    order: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    cols: Omit<{
        type: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        default: boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | number | boolean>>;
        default: NonNullable<string | number | boolean>;
    };
    alignContent: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    justify: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    gutter: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    align: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    alignSelf: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    order: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    offset: {
        type: (StringConstructor | NumberConstructor)[];
        default: null;
    };
    cols: Omit<{
        type: (BooleanConstructor | StringConstructor | NumberConstructor)[];
        default: boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | number | boolean>>;
        default: NonNullable<string | number | boolean>;
    };
    alignContent: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    justify: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
    gutter: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    align: {
        type: StringConstructor;
        default: null;
        validator: (str: any) => boolean;
    };
}>>, {
    offset: string | number;
    cols: NonNullable<string | number | boolean>;
    order: string | number;
    alignSelf: string;
    gutter: string | number;
    align: string;
    justify: string;
    alignContent: string;
}>;
type Spacer = InstanceType<typeof Spacer>;

type Switch = InstanceType<typeof Switch>;
declare const Switch: vue.DefineComponent<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: StringConstructor;
    trueIcon: StringConstructor;
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    theme: StringConstructor;
    color: {
        type: vue.PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    error: BooleanConstructor;
    id: StringConstructor;
    inline: BooleanConstructor;
    label: StringConstructor;
    falseIcon: StringConstructor;
    trueIcon: StringConstructor;
    multiple: {
        type: vue.PropType<boolean | null>;
        default: null;
    };
    name: StringConstructor;
    readonly: BooleanConstructor;
    trueValue: null;
    falseValue: null;
    modelValue: null;
    type: {
        type: vue.PropType<string>;
        default: string;
    };
    value: null;
    valueComparator: {
        type: vue.PropType<typeof _veno_ui_utils.deepEqual>;
        default: typeof _veno_ui_utils.deepEqual;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    type: string;
    error: boolean;
    disabled: boolean;
    color: string;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    inline: boolean;
    multiple: boolean | null;
    readonly: boolean;
    valueComparator: typeof _veno_ui_utils.deepEqual;
}>;

type DataIteratorSortFunction = <T, K extends keyof T>(items: T[], sortBy: string[], sortDesc: boolean[], locale: string, customSorters?: Record<K, (a: T[K], b: T[K]) => number>) => T[];
type PaginationProps = Partial<typeof defaultPagination>;
declare const defaultPagination: {
    page: number;
    perPage: number;
    perPageOptions: number[];
    total: number;
    totalVisible: number;
    showQuickJumper: boolean;
    showPerPageSelect: boolean;
};

interface TableHeaderProps {
    $type?: 'selection';
    value: string;
    text?: string;
    align?: 'start' | 'center' | 'end';
    sortable?: boolean;
    fixed?: boolean | 'start' | 'end';
    width?: string | number;
    minWidth?: string | number;
    maxWidth?: string | number;
    [key: string]: any;
}
declare const Table: vue.DefineComponent<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: {
        type: PropType<NonNullable<string | number | boolean>>;
        default: NonNullable<string | number | boolean>;
    };
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    remote: BooleanConstructor;
    items: {
        type: PropType<Record<string, any>[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortBy: {
        type: PropType<string | string[]>;
        default: () => never[];
    };
    sortDesc: {
        type: PropType<boolean | boolean[]>;
        default: () => never[];
    };
    customSort: {
        type: PropType<DataIteratorSortFunction>;
        default: typeof _veno_ui_utils.sortItems;
    };
    locale: {
        type: StringConstructor;
        default: string;
    };
    pagination: {
        type: PropType<Partial<{
            page: number;
            perPage: number;
            perPageOptions: number[];
            total: number;
            totalVisible: number;
            showQuickJumper: boolean;
            showPerPageSelect: boolean;
        }>>;
        defualt: () => {
            page: number;
            perPage: number;
            perPageOptions: number[];
            total: number;
            totalVisible: number;
            showQuickJumper: boolean;
            showPerPageSelect: boolean;
        };
    };
    /**
     * @zh 隐藏边框
     */
    hideBorder: BooleanConstructor;
    /**
     * @zh 隐藏表头
     */
    hideHeader: BooleanConstructor;
    /**
     * @zh 固定表头
     */
    fixedHeader: BooleanConstructor;
    /**
     * @zh 表头
     */
    headers: {
        type: PropType<TableHeaderProps[]>;
        default: () => never[];
    };
    /**
     * @zh 已选择的
     */
    selected: {
        type: PropType<Record<string, any>[]>;
        default: () => never[];
    };
    /**
     * @zh 排序的图标
     */
    sortIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 排序激活时的颜色
     */
    sortActiveColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 加载中
     */
    loading: BooleanConstructor;
    /**
     * @zh 唯一键
     */
    itemKey: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 隐藏分页
     */
    hidePagination: BooleanConstructor;
}, {
    exportCSV(name: string): void;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:pagination': (_: PaginationProps) => boolean;
    'update:sortBy': (_: string | string[]) => boolean;
    'update:sortDesc': (_: boolean | boolean[]) => boolean;
    'update:options': (_: Record<string, any>) => boolean;
    'update:selected': (_: Record<string, any>[]) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    beautifyScrollbar: {
        type: BooleanConstructor;
        default: boolean;
    };
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: {
        type: PropType<NonNullable<string | number | boolean>>;
        default: NonNullable<string | number | boolean>;
    };
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    remote: BooleanConstructor;
    items: {
        type: PropType<Record<string, any>[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortBy: {
        type: PropType<string | string[]>;
        default: () => never[];
    };
    sortDesc: {
        type: PropType<boolean | boolean[]>;
        default: () => never[];
    };
    customSort: {
        type: PropType<DataIteratorSortFunction>;
        default: typeof _veno_ui_utils.sortItems;
    };
    locale: {
        type: StringConstructor;
        default: string;
    };
    pagination: {
        type: PropType<Partial<{
            page: number;
            perPage: number;
            perPageOptions: number[];
            total: number;
            totalVisible: number;
            showQuickJumper: boolean;
            showPerPageSelect: boolean;
        }>>;
        defualt: () => {
            page: number;
            perPage: number;
            perPageOptions: number[];
            total: number;
            totalVisible: number;
            showQuickJumper: boolean;
            showPerPageSelect: boolean;
        };
    };
    /**
     * @zh 隐藏边框
     */
    hideBorder: BooleanConstructor;
    /**
     * @zh 隐藏表头
     */
    hideHeader: BooleanConstructor;
    /**
     * @zh 固定表头
     */
    fixedHeader: BooleanConstructor;
    /**
     * @zh 表头
     */
    headers: {
        type: PropType<TableHeaderProps[]>;
        default: () => never[];
    };
    /**
     * @zh 已选择的
     */
    selected: {
        type: PropType<Record<string, any>[]>;
        default: () => never[];
    };
    /**
     * @zh 排序的图标
     */
    sortIcon: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 排序激活时的颜色
     */
    sortActiveColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 加载中
     */
    loading: BooleanConstructor;
    /**
     * @zh 唯一键
     */
    itemKey: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 隐藏分页
     */
    hidePagination: BooleanConstructor;
}>> & {
    "onUpdate:selected"?: ((_: Record<string, any>[]) => any) | undefined;
    "onUpdate:pagination"?: ((_: Partial<{
        page: number;
        perPage: number;
        perPageOptions: number[];
        total: number;
        totalVisible: number;
        showQuickJumper: boolean;
        showPerPageSelect: boolean;
    }>) => any) | undefined;
    "onUpdate:sortBy"?: ((_: string | string[]) => any) | undefined;
    "onUpdate:sortDesc"?: ((_: boolean | boolean[]) => any) | undefined;
    "onUpdate:options"?: ((_: Record<string, any>) => any) | undefined;
}, {
    loading: boolean;
    fixed: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    border: NonNullable<string | number | boolean>;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    items: Record<string, any>[];
    beautifyScrollbar: boolean;
    itemKey: string;
    selected: Record<string, any>[];
    remote: boolean;
    mustSort: boolean;
    multiSort: boolean;
    sortBy: string | string[];
    sortDesc: boolean | boolean[];
    customSort: DataIteratorSortFunction;
    locale: string;
    hideBorder: boolean;
    hideHeader: boolean;
    fixedHeader: boolean;
    headers: TableHeaderProps[];
    sortIcon: string;
    sortActiveColor: string;
    hidePagination: boolean;
}>;

type TabItem = string | Record<string, any>;
declare const Tabs: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    alignWithTitle: BooleanConstructor;
    color: StringConstructor;
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
    };
    fixedTabs: BooleanConstructor;
    items: {
        type: PropType<TabItem[]>;
        default: () => never[];
    };
    stacked: BooleanConstructor;
    backgroundColor: StringConstructor;
    centered: BooleanConstructor;
    grow: BooleanConstructor;
    height: {
        type: (StringConstructor | NumberConstructor)[];
        default: undefined;
    };
    hideSlider: BooleanConstructor;
    optional: BooleanConstructor;
    right: BooleanConstructor;
    sliderColor: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    alignWithTitle: BooleanConstructor;
    color: StringConstructor;
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
    };
    fixedTabs: BooleanConstructor;
    items: {
        type: PropType<TabItem[]>;
        default: () => never[];
    };
    stacked: BooleanConstructor;
    backgroundColor: StringConstructor;
    centered: BooleanConstructor;
    grow: BooleanConstructor;
    height: {
        type: (StringConstructor | NumberConstructor)[];
        default: undefined;
    };
    hideSlider: BooleanConstructor;
    optional: BooleanConstructor;
    right: BooleanConstructor;
    sliderColor: StringConstructor;
}>>, {
    tag: string;
    right: boolean;
    height: string | number;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    items: TabItem[];
    stacked: boolean;
    direction: "vertical" | "horizontal";
    alignWithTitle: boolean;
    fixedTabs: boolean;
    centered: boolean;
    grow: boolean;
    hideSlider: boolean;
    optional: boolean;
}>;
type Tabs = InstanceType<typeof Tabs>;

declare const Tab: vue.DefineComponent<{
    theme: StringConstructor;
    value: null;
    disabled: BooleanConstructor;
    selectedClass: {
        type: PropType<string>;
        default: string;
    };
    href: StringConstructor;
    replace: BooleanConstructor;
    to: PropType<vue_router.RouteLocationRaw>;
    tag: {
        type: StringConstructor;
        default: string;
    };
    fixed: BooleanConstructor;
    icon: (BooleanConstructor | StringConstructor)[];
    prependIcon: StringConstructor;
    appendIcon: StringConstructor;
    stacked: BooleanConstructor;
    title: StringConstructor;
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    color: StringConstructor;
    sliderColor: StringConstructor;
    hideSlider: BooleanConstructor;
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
    };
}, {
    isSelected: vue.Ref<boolean>;
}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    theme: StringConstructor;
    value: null;
    disabled: BooleanConstructor;
    selectedClass: {
        type: PropType<string>;
        default: string;
    };
    href: StringConstructor;
    replace: BooleanConstructor;
    to: PropType<vue_router.RouteLocationRaw>;
    tag: {
        type: StringConstructor;
        default: string;
    };
    fixed: BooleanConstructor;
    icon: (BooleanConstructor | StringConstructor)[];
    prependIcon: StringConstructor;
    appendIcon: StringConstructor;
    stacked: BooleanConstructor;
    title: StringConstructor;
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    color: StringConstructor;
    sliderColor: StringConstructor;
    hideSlider: BooleanConstructor;
    direction: {
        type: PropType<"vertical" | "horizontal">;
        default: string;
    };
}>>, {
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    stacked: boolean;
    selectedClass: string;
    direction: "vertical" | "horizontal";
    hideSlider: boolean;
}>;
type Tab = InstanceType<typeof Tab>;

declare const Tag: vue.DefineComponent<{
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean; /**
         * @zh 可关闭
         */
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        };
    };
    loading: BooleanConstructor;
    /**
     * @zh 激活时的 class
     */
    activeClass: StringConstructor;
    /**
     * @zh 追加的头像图片
     */
    appendAvatar: StringConstructor;
    /**
     * @zh 追加的图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 可关闭
     */
    closable: BooleanConstructor;
    /**
     * @zh 关闭图标
     */
    closeIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    /**
     * @zh 是否显示
     */
    modelValue: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 前置的头像图片
     */
    prependAvatar: StringConstructor;
    /**
     * @zh 前置的图标
     */
    prependIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 涟漪动画
     */
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标签文字
     */
    text: StringConstructor;
    /**
     * @zh 是否为链接
     */
    link: BooleanConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'click:close': (_event: MouseEvent) => true;
    'update:modelValue': (_modelValue: boolean) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    href: StringConstructor;
    replace: BooleanConstructor;
    to: vue.PropType<vue_router.RouteLocationRaw>;
    value: null;
    disabled: BooleanConstructor;
    selectedClass: StringConstructor;
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean; /**
         * @zh 可关闭
         */
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    transition: Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
            }>;
        };
    };
    loading: BooleanConstructor;
    /**
     * @zh 激活时的 class
     */
    activeClass: StringConstructor;
    /**
     * @zh 追加的头像图片
     */
    appendAvatar: StringConstructor;
    /**
     * @zh 追加的图标
     */
    appendIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 可关闭
     */
    closable: BooleanConstructor;
    /**
     * @zh 关闭图标
     */
    closeIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    /**
     * @zh 是否显示
     */
    modelValue: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 前置的头像图片
     */
    prependAvatar: StringConstructor;
    /**
     * @zh 前置的图标
     */
    prependIcon: (StringConstructor | ObjectConstructor)[];
    /**
     * @zh 涟漪动画
     */
    ripple: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 标签文字
     */
    text: StringConstructor;
    /**
     * @zh 是否为链接
     */
    link: BooleanConstructor;
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
    "onClick:close"?: ((_event: MouseEvent) => any) | undefined;
}, {
    modelValue: boolean;
    closable: boolean;
    closeIcon: string | Record<string, any>;
    transition: NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
        }>;
    };
    loading: boolean;
    link: boolean;
    ripple: boolean;
    replace: boolean;
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
}>;
type Tag = InstanceType<typeof Tag>;

declare const TagGroup: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: {
        type: PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    column: BooleanConstructor;
    valueComparator: {
        type: PropType<typeof deepEqual>;
        default: typeof deepEqual;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => boolean;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: PropType<Size | undefined>;
        default: string;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    modelValue: {
        type: (BooleanConstructor | StringConstructor | ObjectConstructor | NumberConstructor | ArrayConstructor)[];
        default: undefined;
    };
    multiple: BooleanConstructor;
    mandatory: PropType<boolean | "force">;
    max: NumberConstructor;
    selectedClass: {
        type: PropType<string>;
        default: string;
    };
    disabled: BooleanConstructor;
    column: BooleanConstructor;
    valueComparator: {
        type: PropType<typeof deepEqual>;
        default: typeof deepEqual;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    modelValue: string | number | boolean | Record<string, any> | unknown[];
    fixed: boolean;
    disabled: boolean;
    tag: string;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    absolute: boolean;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
    selectedClass: string;
    multiple: boolean;
    valueComparator: typeof deepEqual;
    column: boolean;
}>;
type TagGroup = InstanceType<typeof TagGroup>;

declare const Textarea: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            type: string;
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            autofocus: boolean;
            autoResize: boolean;
            noResize: boolean;
            persistentCounter: boolean;
            rows: string | number;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            autofocus: BooleanConstructor;
            autoResize: BooleanConstructor;
            counter: vue.PropType<string | number | true>;
            counterValue: vue.PropType<(value: any) => number>;
            id: StringConstructor;
            inputAttach: vue.PropType<string | boolean | Element>;
            maxRows: {
                type: (StringConstructor | NumberConstructor)[];
                validator: (v: any) => boolean;
            };
            controlValue: null;
            modelValue: null;
            name: StringConstructor;
            noResize: BooleanConstructor;
            persistentCounter: BooleanConstructor;
            placeholder: StringConstructor;
            rows: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
                validator: (v: any) => boolean;
            };
            type: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
            width: (StringConstructor | NumberConstructor)[];
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "type" | "disabled" | "variant" | "shape" | "autofocus" | "autoResize" | "noResize" | "persistentCounter" | "rows" | "clearable" | "clearIcon">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            shape: Omit<{
                type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
                default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            };
            color: StringConstructor;
            textColor: StringConstructor;
            variant: Omit<{
                type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
                default: string;
                validator: (v: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
                default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            };
            appendInnerIcon: (StringConstructor | ObjectConstructor)[];
            clearable: BooleanConstructor;
            clearIcon: {
                type: (StringConstructor | ObjectConstructor)[];
                default: string;
            };
            disabled: BooleanConstructor;
            prependInnerIcon: (StringConstructor | ObjectConstructor)[];
            prefix: StringConstructor;
            prefixIcon: (StringConstructor | ObjectConstructor)[];
            suffix: StringConstructor;
            suffixIcon: (StringConstructor | ObjectConstructor)[];
            autofocus: BooleanConstructor;
            autoResize: BooleanConstructor;
            counter: vue.PropType<string | number | true>;
            counterValue: vue.PropType<(value: any) => number>;
            id: StringConstructor;
            inputAttach: vue.PropType<string | boolean | Element>;
            maxRows: {
                type: (StringConstructor | NumberConstructor)[];
                validator: (v: any) => boolean;
            };
            controlValue: null;
            modelValue: null;
            name: StringConstructor;
            noResize: BooleanConstructor;
            persistentCounter: BooleanConstructor;
            placeholder: StringConstructor;
            rows: {
                type: (StringConstructor | NumberConstructor)[];
                default: number;
                validator: (v: any) => boolean;
            };
            type: Omit<{
                type: StringConstructor;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<string>;
                default: string;
            };
            width: (StringConstructor | NumberConstructor)[];
        } & {
            $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | {
                prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]));
                append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                default?: false | (((args_0: FormControlSlot & {
                    props: Record<string, unknown>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[])) | undefined;
                append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            type: string;
            disabled: boolean;
            variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            autofocus: boolean;
            autoResize: boolean;
            noResize: boolean;
            persistentCounter: boolean;
            rows: string | number;
            clearable: boolean;
            clearIcon: string | Record<string, any>;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        shape: Omit<{
            type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
            default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        };
        color: StringConstructor;
        textColor: StringConstructor;
        variant: Omit<{
            type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
            default: string;
            validator: (v: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
            default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        };
        appendInnerIcon: (StringConstructor | ObjectConstructor)[];
        clearable: BooleanConstructor;
        clearIcon: {
            type: (StringConstructor | ObjectConstructor)[];
            default: string;
        };
        disabled: BooleanConstructor;
        prependInnerIcon: (StringConstructor | ObjectConstructor)[];
        prefix: StringConstructor;
        prefixIcon: (StringConstructor | ObjectConstructor)[];
        suffix: StringConstructor;
        suffixIcon: (StringConstructor | ObjectConstructor)[];
        autofocus: BooleanConstructor;
        autoResize: BooleanConstructor;
        counter: vue.PropType<string | number | true>;
        counterValue: vue.PropType<(value: any) => number>;
        id: StringConstructor;
        inputAttach: vue.PropType<string | boolean | Element>;
        maxRows: {
            type: (StringConstructor | NumberConstructor)[];
            validator: (v: any) => boolean;
        };
        controlValue: null;
        modelValue: null;
        name: StringConstructor;
        noResize: BooleanConstructor;
        persistentCounter: BooleanConstructor;
        placeholder: StringConstructor;
        rows: {
            type: (StringConstructor | NumberConstructor)[];
            default: number;
            validator: (v: any) => boolean;
        };
        type: Omit<{
            type: StringConstructor;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<string>;
            default: string;
        };
        width: (StringConstructor | NumberConstructor)[];
    } & {
        $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | {
            prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            default?: vue.VNodeChild | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]));
            append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            default?: false | (((args_0: FormControlSlot & {
                props: Record<string, unknown>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[])) | undefined;
            append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    shape: Omit<{
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">>;
        default: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    };
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
    appendInnerIcon: (StringConstructor | ObjectConstructor)[];
    clearable: BooleanConstructor;
    clearIcon: {
        type: (StringConstructor | ObjectConstructor)[];
        default: string;
    };
    disabled: BooleanConstructor;
    prependInnerIcon: (StringConstructor | ObjectConstructor)[];
    prefix: StringConstructor;
    prefixIcon: (StringConstructor | ObjectConstructor)[];
    suffix: StringConstructor;
    suffixIcon: (StringConstructor | ObjectConstructor)[];
    autofocus: BooleanConstructor;
    autoResize: BooleanConstructor;
    counter: vue.PropType<string | number | true>;
    counterValue: vue.PropType<(value: any) => number>;
    id: StringConstructor;
    inputAttach: vue.PropType<string | boolean | Element>;
    maxRows: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (v: any) => boolean;
    };
    controlValue: null;
    modelValue: null;
    name: StringConstructor;
    noResize: BooleanConstructor;
    persistentCounter: BooleanConstructor;
    placeholder: StringConstructor;
    rows: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
        validator: (v: any) => boolean;
    };
    type: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    width: (StringConstructor | NumberConstructor)[];
} & {
    $children: () => vue.VNodeChild | (((args_0: FormControlSlot & {
        props: Record<string, unknown>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[])) | {
        prepend?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        label?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        default?: vue.VNodeChild | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]));
        append?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        details?: vue.VNodeChild | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'prepend-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        prefix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        suffix?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        'append-inner'?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        clear?: vue.VNodeChild | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        counter?: vue.VNodeChild | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        prepend?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        label?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        default?: false | (((args_0: FormControlSlot & {
            props: Record<string, unknown>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) & ((args_0: InputControlDefaultSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[])) | undefined;
        append?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        details?: false | ((args_0: FormControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'prepend-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        prefix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        suffix?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        'append-inner'?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        clear?: false | ((args_0: InputControlSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        counter?: false | ((args_0: CounterSlot) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>>, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    type: string;
    disabled: boolean;
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    shape: NonNullable<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
    autofocus: boolean;
    autoResize: boolean;
    noResize: boolean;
    persistentCounter: boolean;
    rows: string | number;
    clearable: boolean;
    clearIcon: string | Record<string, any>;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: InputSlots;
});

declare const ThemeProvider: vue.DefineComponent<{
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
}>>, {
    tag: string;
}>;

type Toolbar = InstanceType<typeof Toolbar>;
declare const Toolbar: vue.DefineComponent<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    title: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    elevation: {
        type: (StringConstructor | NumberConstructor)[];
        validator(v: any): boolean;
    };
    shape: {
        type: vue.PropType<"tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle">;
        default: string;
    };
    border: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    density: {
        type: vue.PropType<"medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined>;
        default: string;
        validator: (v: any) => boolean;
    };
    size: {
        type: vue.PropType<Size | undefined>;
        default: string;
    };
    height: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: (StringConstructor | NumberConstructor)[];
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: (StringConstructor | NumberConstructor)[];
    width: (StringConstructor | NumberConstructor)[];
    absolute: BooleanConstructor;
    bottom: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    fixed: BooleanConstructor;
    left: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    position: {
        type: vue.PropType<"fixed" | "absolute" | "static" | "relative" | "sticky">;
        validator: (v: any) => boolean;
    };
    right: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    top: (BooleanConstructor | StringConstructor | NumberConstructor)[];
    color: StringConstructor;
    textColor: StringConstructor;
    variant: {
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    };
    theme: StringConstructor;
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<string>;
        default: string;
    };
    title: StringConstructor;
}>>, {
    fixed: boolean;
    tag: string;
    variant: "text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined";
    absolute: boolean;
    height: NonNullable<string | number>;
    size: Size | undefined;
    density: "medium" | "ultra-low" | "low" | "high" | "ultra-high" | undefined;
    shape: "tile" | "rounded-sm" | "rounded" | "rounded-lg" | "pill" | "circle";
}>;

type ToolbarItems = InstanceType<typeof ToolbarItems>;
declare const ToolbarItems: vue.DefineComponent<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>[] | undefined, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    color: StringConstructor;
    textColor: StringConstructor;
    variant: Omit<{
        type: vue.PropType<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
        default: string;
        validator: (v: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">>;
        default: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
    };
}>>, {
    variant: NonNullable<"text" | "contained" | "outlined" | "plain" | "contained-text" | "contained-outlined">;
}>;

type ToolbarTitle = InstanceType<typeof ToolbarTitle>;
declare const ToolbarTitle: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    text: StringConstructor;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    text: StringConstructor;
}>>, {
    tag: string;
}>;

declare const Tooltip: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            modelValue: boolean;
            transition: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            anchor: NonNullable<Anchor$1>;
            contained: boolean;
            absolute: boolean;
            maxWidth: NonNullable<string | number>;
            minWidth: NonNullable<string | number>;
            offset: NonNullable<string | number>;
            origin: NonNullable<Origin>;
            eager: boolean;
            noClickAnimation: boolean;
            persistent: boolean;
            scrim: string | boolean;
            activatorProps: Record<string, any>;
            openOnClick: boolean;
            openOnHover: boolean;
            openOnFocus: boolean;
            positionStrategy: NonNullable<PositionStrategy>;
            scrollStrategy: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            arrow: boolean;
        }> & Omit<Readonly<vue.ExtractPropTypes<{
            eager: BooleanConstructor;
            transition: Omit<Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            }, "default" | "type"> & {
                type: vue.PropType<{
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>>;
                default: {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
            };
            theme: StringConstructor;
            scrollStrategy: Omit<{
                type: vue.PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
                default: string;
                validator: (val: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>>;
                default: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            };
            positionStrategy: Omit<{
                type: vue.PropType<PositionStrategy>;
                default: string;
                validator: (val: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<PositionStrategy>>;
                default: NonNullable<PositionStrategy>;
            };
            anchor: Omit<{
                type: vue.PropType<Anchor$1>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Anchor$1>>;
                default: NonNullable<Anchor$1>;
            };
            origin: Omit<{
                type: vue.PropType<Origin>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Origin>>;
                default: NonNullable<Origin>;
            };
            offset: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            width: (StringConstructor | NumberConstructor)[];
            closeDelay: (StringConstructor | NumberConstructor)[];
            openDelay: (StringConstructor | NumberConstructor)[];
            activator: vue.PropType<_veno_ui_utils.Selector>;
            activatorProps: {
                type: vue.PropType<Record<string, any>>;
                /**
                 * @zh DOM ID
                 */
                default: () => {};
            };
            openOnClick: Omit<{
                type: BooleanConstructor;
                default: undefined;
            }, "default" | "type"> & {
                type: vue.PropType<boolean>;
                default: boolean;
            };
            openOnHover: {
                type: vue.PropType<boolean>;
                default: boolean;
            };
            openOnFocus: {
                type: BooleanConstructor;
                default: undefined;
            };
            modelValue: BooleanConstructor;
            absolute: BooleanConstructor;
            attach: vue.PropType<string | boolean | Element>;
            contained: BooleanConstructor;
            contentStyle: null;
            contentClass: null;
            noClickAnimation: BooleanConstructor;
            persistent: BooleanConstructor;
            scrim: {
                type: (BooleanConstructor | StringConstructor)[];
                default: boolean;
            };
            /**
             * @zh DOM ID
             */
            id: StringConstructor;
            /**
             * @zh 工具提示内容
             */
            text: StringConstructor;
            /**
             * @zh 是否显示箭头
             */
            arrow: {
                type: BooleanConstructor;
                default: boolean;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "modelValue" | "transition" | "anchor" | "contained" | "absolute" | "maxWidth" | "minWidth" | "offset" | "origin" | "eager" | "noClickAnimation" | "persistent" | "scrim" | "activatorProps" | "openOnClick" | "openOnHover" | "openOnFocus" | "positionStrategy" | "scrollStrategy" | "arrow">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: "update:modelValue", _modelValue: boolean) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            eager: BooleanConstructor;
            transition: Omit<Omit<{
                type: vue.PropType<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })>;
                default: string;
                validator: (val: unknown) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
                default: NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                };
            }, "default" | "type"> & {
                type: vue.PropType<{
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>>;
                default: {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                    component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
                })> | {
                    readonly component: vue.DefineComponent<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                        [key: string]: any;
                    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                        group: BooleanConstructor;
                        hideOnLeave: BooleanConstructor;
                        leaveAbsolute: BooleanConstructor;
                        mode: {
                            type: StringConstructor;
                            default: string | undefined;
                        };
                        origin: {
                            type: StringConstructor;
                            default: string;
                        };
                        onBeforeEnter: FunctionConstructor;
                        onLeave: FunctionConstructor;
                        onAfterLeave: FunctionConstructor;
                    }>>, {
                        group: boolean;
                        mode: string;
                        hideOnLeave: boolean;
                        leaveAbsolute: boolean;
                        origin: string;
                    }>;
                }>;
            };
            theme: StringConstructor;
            scrollStrategy: Omit<{
                type: vue.PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
                default: string;
                validator: (val: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>>;
                default: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            };
            positionStrategy: Omit<{
                type: vue.PropType<PositionStrategy>;
                default: string;
                validator: (val: any) => boolean;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<PositionStrategy>>;
                default: NonNullable<PositionStrategy>;
            };
            anchor: Omit<{
                type: vue.PropType<Anchor$1>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Anchor$1>>;
                default: NonNullable<Anchor$1>;
            };
            origin: Omit<{
                type: vue.PropType<Origin>;
                default: string;
            }, "default" | "type"> & {
                type: vue.PropType<NonNullable<Origin>>;
                default: NonNullable<Origin>;
            };
            offset: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            height: (StringConstructor | NumberConstructor)[];
            maxHeight: (StringConstructor | NumberConstructor)[];
            maxWidth: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            minHeight: (StringConstructor | NumberConstructor)[];
            minWidth: {
                type: vue.PropType<NonNullable<string | number>>;
                default: NonNullable<string | number>;
            };
            width: (StringConstructor | NumberConstructor)[];
            closeDelay: (StringConstructor | NumberConstructor)[];
            openDelay: (StringConstructor | NumberConstructor)[];
            activator: vue.PropType<_veno_ui_utils.Selector>;
            activatorProps: {
                type: vue.PropType<Record<string, any>>;
                /**
                 * @zh DOM ID
                 */
                default: () => {};
            };
            openOnClick: Omit<{
                type: BooleanConstructor;
                default: undefined;
            }, "default" | "type"> & {
                type: vue.PropType<boolean>;
                default: boolean;
            };
            openOnHover: {
                type: vue.PropType<boolean>;
                default: boolean;
            };
            openOnFocus: {
                type: BooleanConstructor;
                default: undefined;
            };
            modelValue: BooleanConstructor;
            absolute: BooleanConstructor;
            attach: vue.PropType<string | boolean | Element>;
            contained: BooleanConstructor;
            contentStyle: null;
            contentClass: null;
            noClickAnimation: BooleanConstructor;
            persistent: BooleanConstructor;
            scrim: {
                type: (BooleanConstructor | StringConstructor)[];
                default: boolean;
            };
            /**
             * @zh DOM ID
             */
            id: StringConstructor;
            /**
             * @zh 工具提示内容
             */
            text: StringConstructor;
            /**
             * @zh 是否显示箭头
             */
            arrow: {
                type: BooleanConstructor;
                default: boolean;
            };
        } & {
            $children: () => vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | {
                default?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
                activator?: vue.VNodeChild | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]);
            };
            'v-slots': new () => {
                default?: false | ((args_0: {
                    close: () => void;
                    isActive: vue.Ref<boolean>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
                activator?: false | ((args_0: {
                    close: () => void;
                    isActive: boolean;
                    props: Record<string, any>;
                    on: Record<string, any>;
                }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>[]) | undefined;
            };
        }>> & {
            "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (_modelValue: boolean) => boolean;
        }, string, {
            modelValue: boolean;
            transition: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            anchor: NonNullable<Anchor$1>;
            contained: boolean;
            absolute: boolean;
            maxWidth: NonNullable<string | number>;
            minWidth: NonNullable<string | number>;
            offset: NonNullable<string | number>;
            origin: NonNullable<Origin>;
            eager: boolean;
            noClickAnimation: boolean;
            persistent: boolean;
            scrim: string | boolean;
            activatorProps: Record<string, any>;
            openOnClick: boolean;
            openOnHover: boolean;
            openOnFocus: boolean;
            positionStrategy: NonNullable<PositionStrategy>;
            scrollStrategy: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            arrow: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        eager: BooleanConstructor;
        transition: Omit<Omit<{
            type: vue.PropType<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })>;
            default: string;
            validator: (val: unknown) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
            default: NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            };
        }, "default" | "type"> & {
            type: vue.PropType<{
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>>;
            default: {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
                component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
            })> | {
                readonly component: vue.DefineComponent<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                    [key: string]: any;
                }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                    group: BooleanConstructor;
                    hideOnLeave: BooleanConstructor;
                    leaveAbsolute: BooleanConstructor;
                    mode: {
                        type: StringConstructor;
                        default: string | undefined;
                    };
                    origin: {
                        type: StringConstructor;
                        default: string;
                    };
                    onBeforeEnter: FunctionConstructor;
                    onLeave: FunctionConstructor;
                    onAfterLeave: FunctionConstructor;
                }>>, {
                    group: boolean;
                    mode: string;
                    hideOnLeave: boolean;
                    leaveAbsolute: boolean;
                    origin: string;
                }>;
            }>;
        };
        theme: StringConstructor;
        scrollStrategy: Omit<{
            type: vue.PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
            default: string;
            validator: (val: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>>;
            default: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
        };
        positionStrategy: Omit<{
            type: vue.PropType<PositionStrategy>;
            default: string;
            validator: (val: any) => boolean;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<PositionStrategy>>;
            default: NonNullable<PositionStrategy>;
        };
        anchor: Omit<{
            type: vue.PropType<Anchor$1>;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<Anchor$1>>;
            default: NonNullable<Anchor$1>;
        };
        origin: Omit<{
            type: vue.PropType<Origin>;
            default: string;
        }, "default" | "type"> & {
            type: vue.PropType<NonNullable<Origin>>;
            default: NonNullable<Origin>;
        };
        offset: {
            type: vue.PropType<NonNullable<string | number>>;
            default: NonNullable<string | number>;
        };
        height: (StringConstructor | NumberConstructor)[];
        maxHeight: (StringConstructor | NumberConstructor)[];
        maxWidth: {
            type: vue.PropType<NonNullable<string | number>>;
            default: NonNullable<string | number>;
        };
        minHeight: (StringConstructor | NumberConstructor)[];
        minWidth: {
            type: vue.PropType<NonNullable<string | number>>;
            default: NonNullable<string | number>;
        };
        width: (StringConstructor | NumberConstructor)[];
        closeDelay: (StringConstructor | NumberConstructor)[];
        openDelay: (StringConstructor | NumberConstructor)[];
        activator: vue.PropType<_veno_ui_utils.Selector>;
        activatorProps: {
            type: vue.PropType<Record<string, any>>;
            /**
             * @zh DOM ID
             */
            default: () => {};
        };
        openOnClick: Omit<{
            type: BooleanConstructor;
            default: undefined;
        }, "default" | "type"> & {
            type: vue.PropType<boolean>;
            default: boolean;
        };
        openOnHover: {
            type: vue.PropType<boolean>;
            default: boolean;
        };
        openOnFocus: {
            type: BooleanConstructor;
            default: undefined;
        };
        modelValue: BooleanConstructor;
        absolute: BooleanConstructor;
        attach: vue.PropType<string | boolean | Element>;
        contained: BooleanConstructor;
        contentStyle: null;
        contentClass: null;
        noClickAnimation: BooleanConstructor;
        persistent: BooleanConstructor;
        scrim: {
            type: (BooleanConstructor | StringConstructor)[];
            default: boolean;
        };
        /**
         * @zh DOM ID
         */
        id: StringConstructor;
        /**
         * @zh 工具提示内容
         */
        text: StringConstructor;
        /**
         * @zh 是否显示箭头
         */
        arrow: {
            type: BooleanConstructor;
            default: boolean;
        };
    } & {
        $children: () => vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | {
            default?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
            activator?: vue.VNodeChild | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]);
        };
        'v-slots': new () => {
            default?: false | ((args_0: {
                close: () => void;
                isActive: vue.Ref<boolean>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
            activator?: false | ((args_0: {
                close: () => void;
                isActive: boolean;
                props: Record<string, any>;
                on: Record<string, any>;
            }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>[]) | undefined;
        };
    }>> & {
        "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    eager: BooleanConstructor;
    transition: Omit<Omit<{
        type: vue.PropType<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })>;
        default: string;
        validator: (val: unknown) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
        default: NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        };
    }, "default" | "type"> & {
        type: vue.PropType<{
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>>;
        default: {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
            component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
        })> | {
            readonly component: vue.DefineComponent<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
                [key: string]: any;
            }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
                group: BooleanConstructor;
                hideOnLeave: BooleanConstructor;
                leaveAbsolute: BooleanConstructor;
                mode: {
                    type: StringConstructor;
                    default: string | undefined;
                };
                origin: {
                    type: StringConstructor;
                    default: string;
                };
                onBeforeEnter: FunctionConstructor;
                onLeave: FunctionConstructor;
                onAfterLeave: FunctionConstructor;
            }>>, {
                group: boolean;
                mode: string;
                hideOnLeave: boolean;
                leaveAbsolute: boolean;
                origin: string;
            }>;
        }>;
    };
    theme: StringConstructor;
    scrollStrategy: Omit<{
        type: vue.PropType<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
        default: string;
        validator: (val: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>>;
        default: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
    };
    positionStrategy: Omit<{
        type: vue.PropType<PositionStrategy>;
        default: string;
        validator: (val: any) => boolean;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<PositionStrategy>>;
        default: NonNullable<PositionStrategy>;
    };
    anchor: Omit<{
        type: vue.PropType<Anchor$1>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Anchor$1>>;
        default: NonNullable<Anchor$1>;
    };
    origin: Omit<{
        type: vue.PropType<Origin>;
        default: string;
    }, "default" | "type"> & {
        type: vue.PropType<NonNullable<Origin>>;
        default: NonNullable<Origin>;
    };
    offset: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    height: (StringConstructor | NumberConstructor)[];
    maxHeight: (StringConstructor | NumberConstructor)[];
    maxWidth: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    minHeight: (StringConstructor | NumberConstructor)[];
    minWidth: {
        type: vue.PropType<NonNullable<string | number>>;
        default: NonNullable<string | number>;
    };
    width: (StringConstructor | NumberConstructor)[];
    closeDelay: (StringConstructor | NumberConstructor)[];
    openDelay: (StringConstructor | NumberConstructor)[];
    activator: vue.PropType<_veno_ui_utils.Selector>;
    activatorProps: {
        type: vue.PropType<Record<string, any>>;
        /**
         * @zh DOM ID
         */
        default: () => {};
    };
    openOnClick: Omit<{
        type: BooleanConstructor;
        default: undefined;
    }, "default" | "type"> & {
        type: vue.PropType<boolean>;
        default: boolean;
    };
    openOnHover: {
        type: vue.PropType<boolean>;
        default: boolean;
    };
    openOnFocus: {
        type: BooleanConstructor;
        default: undefined;
    };
    modelValue: BooleanConstructor;
    absolute: BooleanConstructor;
    attach: vue.PropType<string | boolean | Element>;
    contained: BooleanConstructor;
    contentStyle: null;
    contentClass: null;
    noClickAnimation: BooleanConstructor;
    persistent: BooleanConstructor;
    scrim: {
        type: (BooleanConstructor | StringConstructor)[];
        default: boolean;
    };
    /**
     * @zh DOM ID
     */
    id: StringConstructor;
    /**
     * @zh 工具提示内容
     */
    text: StringConstructor;
    /**
     * @zh 是否显示箭头
     */
    arrow: {
        type: BooleanConstructor;
        default: boolean;
    };
} & {
    $children: () => vue.VNodeChild | ((args_0: {
        close: () => void;
        isActive: vue.Ref<boolean>;
    }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>[]) | {
        default?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
        activator?: vue.VNodeChild | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]);
    };
    'v-slots': new () => {
        default?: false | ((args_0: {
            close: () => void;
            isActive: vue.Ref<boolean>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
        activator?: false | ((args_0: {
            close: () => void;
            isActive: boolean;
            props: Record<string, any>;
            on: Record<string, any>;
        }) => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }> | vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>[]) | undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: boolean) => any) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: boolean) => boolean;
}, string, {
    modelValue: boolean;
    transition: {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    } | NonNullable<NonNullable<string | false | (vue.TransitionProps & {
        component?: vue.Component<any, any, any, vue.ComputedOptions, vue.MethodOptions> | undefined;
    })> | {
        readonly component: vue.DefineComponent<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
            group: BooleanConstructor;
            hideOnLeave: BooleanConstructor;
            leaveAbsolute: BooleanConstructor;
            mode: {
                type: StringConstructor;
                default: string | undefined;
            };
            origin: {
                type: StringConstructor;
                default: string;
            };
            onBeforeEnter: FunctionConstructor;
            onLeave: FunctionConstructor;
            onAfterLeave: FunctionConstructor;
        }>>, {
            group: boolean;
            mode: string;
            hideOnLeave: boolean;
            leaveAbsolute: boolean;
            origin: string;
        }>;
    }>;
    anchor: NonNullable<Anchor$1>;
    contained: boolean;
    absolute: boolean;
    maxWidth: NonNullable<string | number>;
    minWidth: NonNullable<string | number>;
    offset: NonNullable<string | number>;
    origin: NonNullable<Origin>;
    eager: boolean;
    noClickAnimation: boolean;
    persistent: boolean;
    scrim: string | boolean;
    activatorProps: Record<string, any>;
    openOnClick: boolean;
    openOnHover: boolean;
    openOnFocus: boolean;
    positionStrategy: NonNullable<PositionStrategy>;
    scrollStrategy: NonNullable<boolean | "block" | "close" | "none" | "reposition" | ((data: ScrollStrategyData, name: string) => void)>;
    arrow: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & (new () => {
    $slots: OverlaySlots;
});
type Tooltip = InstanceType<typeof Tooltip>;

declare const Transformable: vue.DefineComponent<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: PropType<string>;
        default: string;
    };
    /**
     * @zh 位置大小及旋转
     */
    modelValue: {
        type: PropType<{
            top: number;
            left: number;
            width: number;
            height: number;
            rotation: number;
        }>;
        default: () => {
            top: number;
            left: number;
            width: number;
            height: number;
            rotation: number;
        };
    };
    /**
     * @zh 可以移动
     */
    moveable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 可以旋转
     */
    rotatable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 可以调整尺寸
     */
    resizable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 颜色
     */
    color: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 定位模式
     */
    position: {
        type: PropType<"fixed" | "absolute">;
        default: string;
    };
    /**
     * @zh 隐藏显示可拖拽的锚点
     */
    hideAnchors: {
        type: BooleanConstructor;
        default: boolean;
    };
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (_modelValue: any) => true;
}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    tag: Omit<{
        type: StringConstructor;
        default: string;
    }, "default" | "type"> & {
        type: PropType<string>;
        default: string;
    };
    /**
     * @zh 位置大小及旋转
     */
    modelValue: {
        type: PropType<{
            top: number;
            left: number;
            width: number;
            height: number;
            rotation: number;
        }>;
        default: () => {
            top: number;
            left: number;
            width: number;
            height: number;
            rotation: number;
        };
    };
    /**
     * @zh 可以移动
     */
    moveable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 可以旋转
     */
    rotatable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 可以调整尺寸
     */
    resizable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @zh 颜色
     */
    color: {
        type: StringConstructor;
        default: string;
    };
    /**
     * @zh 定位模式
     */
    position: {
        type: PropType<"fixed" | "absolute">;
        default: string;
    };
    /**
     * @zh 隐藏显示可拖拽的锚点
     */
    hideAnchors: {
        type: BooleanConstructor;
        default: boolean;
    };
}>> & {
    "onUpdate:modelValue"?: ((_modelValue: any) => any) | undefined;
}, {
    modelValue: {
        top: number;
        left: number;
        width: number;
        height: number;
        rotation: number;
    };
    tag: string;
    color: string;
    position: "fixed" | "absolute";
    moveable: boolean;
    rotatable: boolean;
    resizable: boolean;
    hideAnchors: boolean;
}>;
type Transformable = InstanceType<typeof Transformable>;

declare const FadeTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
    mode: string;
    hideOnLeave: boolean;
    leaveAbsolute: boolean;
    origin: string;
}>;

declare const ScaleTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
    mode: string;
    hideOnLeave: boolean;
    leaveAbsolute: boolean;
    origin: string;
}>;

declare const ExpandTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
}>;
declare const ExpandXTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
}>;

declare const DialogTransition: vue.DefineComponent<{
    target: PropType<HTMLElement>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    target: PropType<HTMLElement>;
}>>, {}>;

declare const MenuTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    hideOnLeave: BooleanConstructor;
    leaveAbsolute: BooleanConstructor;
    mode: {
        type: StringConstructor;
        default: string | undefined;
    };
    origin: {
        type: StringConstructor;
        default: string;
    };
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
    mode: string;
    hideOnLeave: boolean;
    leaveAbsolute: boolean;
    origin: string;
}>;

declare const FadeInExpandTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
}>;

declare const SlideRightFadeInExpandTransition: vue.DefineComponent<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    group: BooleanConstructor;
    mode: vue.Prop<"default" | "in-out" | "out-in", "default" | "in-out" | "out-in">;
    onBeforeEnter: FunctionConstructor;
    onLeave: FunctionConstructor;
    onAfterLeave: FunctionConstructor;
}>>, {
    group: boolean;
}>;

declare const H1: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;
declare const H2: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;
declare const H3: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;
declare const H4: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;
declare const H5: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;
declare const H6: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const P: vue.DefineComponent<{}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

type index$2_Alert = Alert;
type index$2_Anchor = Anchor;
type index$2_AnchorItem = AnchorItem;
declare const index$2_App: typeof App;
type index$2_Avatar = Avatar;
declare const index$2_Badge: typeof Badge;
declare const index$2_Breadcrumb: typeof Breadcrumb;
declare const index$2_BreadcrumbItem: typeof BreadcrumbItem;
type index$2_Button = Button;
declare const index$2_ButtonGroup: typeof ButtonGroup;
declare const index$2_ButtonToggle: typeof ButtonToggle;
declare const index$2_Card: typeof Card;
declare const index$2_CardActions: typeof CardActions;
declare const index$2_CardAvatar: typeof CardAvatar;
declare const index$2_CardHeader: typeof CardHeader;
declare const index$2_CardHeaderText: typeof CardHeaderText;
declare const index$2_CardImage: typeof CardImage;
declare const index$2_CardSubtitle: typeof CardSubtitle;
declare const index$2_CardText: typeof CardText;
declare const index$2_CardTitle: typeof CardTitle;
type index$2_Carousel = Carousel;
type index$2_CarouselItem = CarouselItem;
declare const index$2_Checkbox: typeof Checkbox;
declare const index$2_CheckboxGroup: typeof CheckboxGroup;
declare const index$2_Code: typeof Code;
declare const index$2_Col: typeof Col;
declare const index$2_Container: typeof Container;
declare const index$2_Counter: typeof Counter;
type index$2_DatePicker = DatePicker;
declare const index$2_DatePickerPanel: typeof DatePickerPanel;
declare const index$2_DateRangePickerPanel: typeof DateRangePickerPanel;
declare const index$2_DefaultsProvider: typeof DefaultsProvider;
type index$2_Device = Device;
declare const index$2_DeviceStatusBar: typeof DeviceStatusBar;
type index$2_Dialog = Dialog;
declare const index$2_DialogTransition: typeof DialogTransition;
declare const index$2_Divider: typeof Divider;
declare const index$2_DraggableSortable: typeof DraggableSortable;
type index$2_Drawer = Drawer;
declare const index$2_ExpandTransition: typeof ExpandTransition;
declare const index$2_ExpandXTransition: typeof ExpandXTransition;
declare const index$2_FadeInExpandTransition: typeof FadeInExpandTransition;
declare const index$2_FadeTransition: typeof FadeTransition;
type index$2_Form = Form;
type index$2_FormChildren = FormChildren;
type index$2_FormControl = FormControl;
declare const index$2_H1: typeof H1;
declare const index$2_H2: typeof H2;
declare const index$2_H3: typeof H3;
declare const index$2_H4: typeof H4;
declare const index$2_H5: typeof H5;
declare const index$2_H6: typeof H6;
declare const index$2_Header: typeof Header;
declare const index$2_HeaderNavIcon: typeof HeaderNavIcon;
declare const index$2_HeaderTitle: typeof HeaderTitle;
declare const index$2_Hover: typeof Hover;
type index$2_Icon = Icon;
declare const index$2_IconClass: typeof IconClass;
declare const index$2_IconComponent: typeof IconComponent;
declare const index$2_IconLigature: typeof IconLigature;
declare const index$2_IconSvg: typeof IconSvg;
type index$2_Image = Image;
type index$2_Input = Input;
type index$2_InputControl = InputControl;
declare const index$2_Label: typeof Label;
declare const index$2_Layout: typeof Layout;
declare const index$2_LayoutItem: typeof LayoutItem;
declare const index$2_Lazy: typeof Lazy;
type index$2_Link = Link;
type index$2_List = List;
type index$2_ListGroup = ListGroup;
type index$2_ListItem = ListItem;
type index$2_ListItemAvatar = ListItemAvatar;
declare const index$2_ListItemHeader: typeof ListItemHeader;
declare const index$2_ListItemSubtitle: typeof ListItemSubtitle;
declare const index$2_ListItemTitle: typeof ListItemTitle;
declare const index$2_ListSubheader: typeof ListSubheader;
declare const index$2_Main: typeof Main;
type index$2_Menu = Menu;
declare const index$2_MenuTransition: typeof MenuTransition;
declare const index$2_MessageProvider: typeof MessageProvider;
declare const index$2_Messages: typeof Messages;
declare const index$2_NotificationProvider: typeof NotificationProvider;
type index$2_Overlay = Overlay;
declare const index$2_P: typeof P;
type index$2_Pagination = Pagination;
declare const index$2_Paper: typeof Paper;
type index$2_Progress = Progress;
declare const index$2_ProgressCircular: typeof ProgressCircular;
declare const index$2_ProgressLinear: typeof ProgressLinear;
type index$2_Radio = Radio;
declare const index$2_RadioGroup: typeof RadioGroup;
declare const index$2_Responsive: typeof Responsive;
declare const index$2_Row: typeof Row;
declare const index$2_ScaleTransition: typeof ScaleTransition;
declare const index$2_Scrim: typeof Scrim;
declare const index$2_Scrollbar: typeof Scrollbar;
type index$2_Select = Select;
type index$2_SelectionControl = SelectionControl;
type index$2_SelectionGroupControl = SelectionGroupControl;
type index$2_SlideGroup = SlideGroup;
declare const index$2_SlideGroupItem: typeof SlideGroupItem;
declare const index$2_SlideRightFadeInExpandTransition: typeof SlideRightFadeInExpandTransition;
type index$2_Spacer = Spacer;
declare const index$2_Switch: typeof Switch;
type index$2_Tab = Tab;
declare const index$2_Table: typeof Table;
type index$2_Tabs = Tabs;
type index$2_Tag = Tag;
type index$2_TagGroup = TagGroup;
declare const index$2_Textarea: typeof Textarea;
declare const index$2_ThemeProvider: typeof ThemeProvider;
declare const index$2_Toolbar: typeof Toolbar;
declare const index$2_ToolbarItems: typeof ToolbarItems;
declare const index$2_ToolbarTitle: typeof ToolbarTitle;
type index$2_Tooltip = Tooltip;
type index$2_Transformable = Transformable;
declare namespace index$2 {
  export {
    index$2_Alert as Alert,
    index$2_Anchor as Anchor,
    index$2_AnchorItem as AnchorItem,
    index$2_App as App,
    index$2_Avatar as Avatar,
    index$2_Badge as Badge,
    index$2_Breadcrumb as Breadcrumb,
    index$2_BreadcrumbItem as BreadcrumbItem,
    index$2_Button as Button,
    index$2_ButtonGroup as ButtonGroup,
    index$2_ButtonToggle as ButtonToggle,
    index$2_Card as Card,
    index$2_CardActions as CardActions,
    index$2_CardAvatar as CardAvatar,
    index$2_CardHeader as CardHeader,
    index$2_CardHeaderText as CardHeaderText,
    index$2_CardImage as CardImage,
    index$2_CardSubtitle as CardSubtitle,
    index$2_CardText as CardText,
    index$2_CardTitle as CardTitle,
    index$2_Carousel as Carousel,
    index$2_CarouselItem as CarouselItem,
    index$2_Checkbox as Checkbox,
    index$2_CheckboxGroup as CheckboxGroup,
    index$2_Code as Code,
    index$2_Col as Col,
    index$2_Container as Container,
    index$2_Counter as Counter,
    index$2_DatePicker as DatePicker,
    index$2_DatePickerPanel as DatePickerPanel,
    index$2_DateRangePickerPanel as DateRangePickerPanel,
    index$2_DefaultsProvider as DefaultsProvider,
    index$2_Device as Device,
    index$2_DeviceStatusBar as DeviceStatusBar,
    index$2_Dialog as Dialog,
    index$2_DialogTransition as DialogTransition,
    index$2_Divider as Divider,
    index$2_DraggableSortable as DraggableSortable,
    index$2_Drawer as Drawer,
    index$2_ExpandTransition as ExpandTransition,
    index$2_ExpandXTransition as ExpandXTransition,
    index$2_FadeInExpandTransition as FadeInExpandTransition,
    index$2_FadeTransition as FadeTransition,
    index$2_Form as Form,
    index$2_FormChildren as FormChildren,
    index$2_FormControl as FormControl,
    index$2_H1 as H1,
    index$2_H2 as H2,
    index$2_H3 as H3,
    index$2_H4 as H4,
    index$2_H5 as H5,
    index$2_H6 as H6,
    index$2_Header as Header,
    index$2_HeaderNavIcon as HeaderNavIcon,
    index$2_HeaderTitle as HeaderTitle,
    index$2_Hover as Hover,
    index$2_Icon as Icon,
    index$2_IconClass as IconClass,
    index$2_IconComponent as IconComponent,
    index$2_IconLigature as IconLigature,
    index$2_IconSvg as IconSvg,
    index$2_Image as Image,
    index$2_Input as Input,
    index$2_InputControl as InputControl,
    index$2_Label as Label,
    index$2_Layout as Layout,
    index$2_LayoutItem as LayoutItem,
    index$2_Lazy as Lazy,
    index$2_Link as Link,
    index$2_List as List,
    index$2_ListGroup as ListGroup,
    index$2_ListItem as ListItem,
    index$2_ListItemAvatar as ListItemAvatar,
    index$2_ListItemHeader as ListItemHeader,
    index$2_ListItemSubtitle as ListItemSubtitle,
    index$2_ListItemTitle as ListItemTitle,
    index$2_ListSubheader as ListSubheader,
    index$2_Main as Main,
    index$2_Menu as Menu,
    index$2_MenuTransition as MenuTransition,
    index$2_MessageProvider as MessageProvider,
    index$2_Messages as Messages,
    index$2_NotificationProvider as NotificationProvider,
    index$2_Overlay as Overlay,
    index$2_P as P,
    index$2_Pagination as Pagination,
    index$2_Paper as Paper,
    index$2_Progress as Progress,
    index$2_ProgressCircular as ProgressCircular,
    index$2_ProgressLinear as ProgressLinear,
    index$2_Radio as Radio,
    index$2_RadioGroup as RadioGroup,
    index$2_Responsive as Responsive,
    index$2_Row as Row,
    index$2_ScaleTransition as ScaleTransition,
    index$2_Scrim as Scrim,
    index$2_Scrollbar as Scrollbar,
    index$2_Select as Select,
    index$2_SelectionControl as SelectionControl,
    index$2_SelectionGroupControl as SelectionGroupControl,
    index$2_SlideGroup as SlideGroup,
    index$2_SlideGroupItem as SlideGroupItem,
    index$2_SlideRightFadeInExpandTransition as SlideRightFadeInExpandTransition,
    index$2_Spacer as Spacer,
    index$2_Switch as Switch,
    index$2_Tab as Tab,
    index$2_Table as Table,
    index$2_Tabs as Tabs,
    index$2_Tag as Tag,
    index$2_TagGroup as TagGroup,
    index$2_Textarea as Textarea,
    index$2_ThemeProvider as ThemeProvider,
    index$2_Toolbar as Toolbar,
    index$2_ToolbarItems as ToolbarItems,
    index$2_ToolbarTitle as ToolbarTitle,
    index$2_Tooltip as Tooltip,
    index$2_Transformable as Transformable,
  };
}

declare const Intersect: ObjectDirective<HTMLElement>;

interface ClickOutsideBindingArgs {
    handler: (e: MouseEvent) => void;
    closeConditional?: (e: Event) => boolean;
    include?: () => HTMLElement[];
}
interface ClickOutsideDirectiveBinding extends DirectiveBinding {
    value: ((e: MouseEvent) => void) | ClickOutsideBindingArgs;
}
declare const ClickOutside: {
    mounted(el: HTMLElement, binding: ClickOutsideDirectiveBinding): void;
    unmounted(el: HTMLElement): void;
};

interface ResizeDirectiveBinding extends Omit<DirectiveBinding, 'modifiers'> {
    value: () => void;
    modifiers?: {
        active?: boolean;
        quiet?: boolean;
    };
}
declare function mounted(el: HTMLElement, binding: ResizeDirectiveBinding): void;
declare function unmounted(el: HTMLElement): void;
declare const Resize: {
    mounted: typeof mounted;
    unmounted: typeof unmounted;
};

declare const Ripple: ObjectDirective;

declare const index$1_ClickOutside: typeof ClickOutside;
declare const index$1_Intersect: typeof Intersect;
declare const index$1_Resize: typeof Resize;
declare const index$1_Ripple: typeof Ripple;
declare namespace index$1 {
  export {
    index$1_ClickOutside as ClickOutside,
    index$1_Intersect as Intersect,
    index$1_Resize as Resize,
    index$1_Ripple as Ripple,
  };
}

declare const index_MessageProvider: typeof MessageProvider;
declare const index_NotificationProvider: typeof NotificationProvider;
declare namespace index {
  export {
    index_MessageProvider as MessageProvider,
    index_NotificationProvider as NotificationProvider,
  };
}

interface Prismjs {
    languages: Record<string, any>;
    highlight(code: string, grammar: any, language: string): string;
}

type Shiki = Highlighter | Promise<Highlighter>;

interface HighlighterOptions {
    type?: 'prismjs' | 'shiki';
    prismjs?: Prismjs;
    shiki?: Shiki;
}

type DisplayBreakpoint = keyof DisplayThresholds;
interface DisplayThresholds {
    xs: number;
    sm: number;
    md: number;
    lg: number;
    xl: number;
    xxl: number;
}
interface DisplayOptions {
    mobileBreakpoint?: number | DisplayBreakpoint;
    thresholds?: Partial<DisplayThresholds>;
}
interface DisplayPlatform {
    android: boolean;
    ios: boolean;
    cordova: boolean;
    electron: boolean;
    chrome: boolean;
    edge: boolean;
    firefox: boolean;
    opera: boolean;
    win: boolean;
    mac: boolean;
    linux: boolean;
    touch: boolean;
    ssr: boolean;
}
interface DisplayInstance {
    xs: boolean;
    sm: boolean;
    md: boolean;
    lg: boolean;
    xl: boolean;
    xxl: boolean;
    smAndUp: boolean;
    mdAndUp: boolean;
    lgAndUp: boolean;
    xlAndUp: boolean;
    smAndDown: boolean;
    mdAndDown: boolean;
    lgAndDown: boolean;
    xlAndDown: boolean;
    name: DisplayBreakpoint;
    height: number;
    width: number;
    mobile: boolean;
    mobileBreakpoint: number | DisplayBreakpoint;
    platform: DisplayPlatform;
    thresholds: DisplayThresholds;
}
declare function useDisplay(): ToRefs<DisplayInstance>;

declare function useLayout(): LayoutInstance;

type closeMessage = () => void;
interface MessageItem {
    id: string;
    modelValue: boolean;
    text: string;
    duration: number;
    close: closeMessage;
}
type OpenMessage = (text: string, rest?: Record<string, any>) => Promise<MessageItem> | closeMessage;
interface MessageInstance {
    items: Ref<MessageItem[]>;
    open: (props?: Record<string, any>) => OpenMessage;
    info: OpenMessage;
    success: OpenMessage;
    warning: OpenMessage;
    error: OpenMessage;
    loading: OpenMessage;
    close: (id: string) => void;
    remove: (id: string) => void;
}
declare const message: {
    items: Ref<{
        id: string;
        modelValue: boolean;
        text: string;
        duration: number;
        close: closeMessage;
    }[]>;
    open: (props?: Record<string, any>) => (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    info: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    success: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    warning: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    error: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    loading: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    close: (id: string) => void;
    remove: (id: string) => void;
};
declare const notification: {
    items: Ref<{
        id: string;
        modelValue: boolean;
        text: string;
        duration: number;
        close: closeMessage;
    }[]>;
    open: (props?: Record<string, any>) => (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    info: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    success: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    warning: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    error: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    loading: (text: string, rest?: Record<string, any>) => Promise<unknown> | (() => void);
    close: (id: string) => void;
    remove: (id: string) => void;
};
declare function useMessage(): MessageInstance;
declare function useNotification(): MessageInstance;

interface VenoUiResolverOptions {
    prefix?: string;
}
/**
 * Resolver for unplugin-vue-components and unplugin-auto-import
 *
 * @param options
 */
declare function VenoUiResolver(options?: VenoUiResolverOptions): {
    type: "component";
    resolve: (name: string) => {
        name: string;
        from: string;
    } | undefined;
}[];

interface VenoOptions {
    componentPrefix?: string;
    components?: Record<string, any>;
    directives?: Record<string, any>;
    providers?: Record<string, Component>;
    highlighter?: HighlighterOptions;
    defaults?: DefaultsOptions;
    theme?: ThemeOptions;
    icons?: IconsOptions;
    display?: DisplayOptions;
}

declare const createVeno: (options?: VenoOptions) => {
    install: (app: vue.App<any>) => void;
    version: string;
};

export { DateInstance, DateManipulateType, DateOptions, DefaultsInstance, DisplayBreakpoint, DisplayInstance, DisplayThresholds, IconsAliases, IconsOptions, InternalDateInstance, MessageInstance, ThemeDefinition, ThemeInstance, VenoUiResolver, index$2 as components, createDate, createVeno, defaultDateFormat, index$1 as directives, message, notification, index as providers, useDisplay, useLayout, useMessage, useNotification, useTheme, index$3 as utils };
