/*!
* veno-ui • v0.6.0
* MIT License
* https://venojs.com
*/

import { Fragment, defineComponent as defineComponent$1, h, getCurrentInstance as getCurrentInstance$1, effectScope, onScopeDispose, ref, computed, unref, provide, inject, shallowReactive, toRaw, watchEffect, mergeProps, Transition, resolveDynamicComponent, toRef, onMounted, onBeforeUnmount, watch, isRef, createVNode, onBeforeMount, nextTick, withDirectives, vShow, isVNode, resolveDirective, TransitionGroup, camelize, readonly, reactive, onDeactivated, onActivated, shallowRef, vModelDynamic, Teleport, vModelText, warn, toHandlers, toRefs, createTextVNode, cloneVNode, capitalize, onBeforeUpdate } from 'vue';

function wrapInArray(val) {
  return val == null ? [] : Array.isArray(val) ? val : [val];
}
function createRange(length, start = 0) {
  return Array.from({ length }, (v, k) => start + k);
}

function parseAnchor(anchor) {
  let [side, align] = anchor.split(" ");
  if (!align) {
    align = side === "top" || side === "bottom" ? "start" : side === "start" || side === "end" ? "top" : "center";
  }
  return {
    side,
    align
  };
}
function oppositeAnchor(anchor) {
  return {
    side: {
      center: "center",
      top: "bottom",
      bottom: "top",
      start: "end",
      end: "start"
    }[anchor.side],
    align: anchor.align
  };
}
function physicalAnchor(anchor, el) {
  const { side, align } = anchor;
  const { direction } = window.getComputedStyle(el);
  const map = direction === "ltr" ? { start: "left", end: "right" } : { start: "right", end: "left" };
  return `${map[side] ?? side} ${map[align] ?? align}`;
}

class Box {
  x;
  y;
  width;
  height;
  constructor({ x, y, width, height }) {
    this.x = x;
    this.y = y;
    this.width = width;
    this.height = height;
  }
  get top() {
    return this.y;
  }
  get bottom() {
    return this.y + this.height;
  }
  get left() {
    return this.x;
  }
  get right() {
    return this.x + this.width;
  }
}

function nullifyTransforms(el) {
  const rect = el.getBoundingClientRect();
  const style = getComputedStyle(el);
  const tx = style.transform;
  if (tx) {
    let ta, sx, sy, dx, dy;
    if (tx.startsWith("matrix3d(")) {
      ta = tx.slice(9, -1).split(/, /);
      sx = +ta[0];
      sy = +ta[5];
      dx = +ta[12];
      dy = +ta[13];
    } else if (tx.startsWith("matrix(")) {
      ta = tx.slice(7, -1).split(/, /);
      sx = +ta[0];
      sy = +ta[3];
      dx = +ta[4];
      dy = +ta[5];
    } else {
      return new Box(rect);
    }
    const to = style.transformOrigin;
    const x = rect.x - dx - (1 - sx) * parseFloat(to);
    const y = rect.y - dy - (1 - sy) * parseFloat(to.slice(to.indexOf(" ") + 1));
    const w = sx ? rect.width / sx : el.offsetWidth;
    const h = sy ? rect.height / sy : el.offsetHeight;
    return new Box({ x, y, width: w, height: h });
  } else {
    return new Box(rect);
  }
}

function isObject(objectable) {
  return objectable !== null && typeof objectable === "object" && !Array.isArray(objectable);
}
function getNestedValue(obj, path, fallback) {
  const last = path.length - 1;
  if (last < 0)
    return obj === void 0 ? fallback : obj;
  for (let i = 0; i < last; i++) {
    if (obj == null) {
      return fallback;
    }
    obj = obj[path[i]];
  }
  if (obj == null)
    return fallback;
  return obj[path[last]] === void 0 ? fallback : obj[path[last]];
}
function setNestedValue(obj, path, value) {
  const last = path.length - 1;
  for (let i = 0; i < last; i++) {
    if (typeof obj[path[i]] !== "object")
      obj[path[i]] = {};
    obj = obj[path[i]];
  }
  obj[path[last]] = value;
}
function getObjectValueByPath(obj, path, fallback) {
  if (obj == null || !path || typeof path !== "string")
    return fallback;
  if (obj[path] !== void 0)
    return obj[path];
  path = path.replace(/\[(\w+)\]/g, ".$1");
  path = path.replace(/^\./, "");
  return getNestedValue(obj, path.split("."), fallback);
}
function setObjectValueByPath(obj, path, value) {
  if (typeof obj !== "object" || !path)
    return;
  path = path.replace(/\[(\w+)\]/g, ".$1");
  path = path.replace(/^\./, "");
  return setNestedValue(obj, path.split("."), value);
}
function deepMerge(source = {}, target = {}, out = {}) {
  for (const key in source) {
    out[key] = source[key];
  }
  for (const key in target) {
    const sourceProperty = source[key];
    const targetProperty = target[key];
    if (isObject(sourceProperty) && isObject(targetProperty)) {
      out[key] = deepMerge(sourceProperty, targetProperty);
      continue;
    }
    out[key] = targetProperty;
  }
  return out;
}

function deepEqual(a, b) {
  if (a === b)
    return true;
  if (a instanceof Date && b instanceof Date && a.getTime() !== b.getTime()) {
    return false;
  }
  if (a !== Object(a) || b !== Object(b)) {
    return false;
  }
  const props = Object.keys(a);
  if (props.length !== Object.keys(b).length) {
    return false;
  }
  return props.every((p) => deepEqual(a[p], b[p]));
}
function convertToUnit(str, unit = "px") {
  if (str == null || str === "") {
    return void 0;
  } else if (isNaN(+str)) {
    return String(str);
  } else if (!isFinite(+str)) {
    return void 0;
  } else {
    return `${Number(str)}${unit}`;
  }
}
function isComponentInstance(obj) {
  return obj?.$el;
}
function sortItems(items, sortBy, sortDesc, locale, customSorters) {
  if (sortBy === null || !sortBy.length)
    return items;
  const stringCollator = new Intl.Collator(locale, { sensitivity: "accent", usage: "sort" });
  return items.sort((a, b) => {
    for (let i = 0; i < sortBy.length; i++) {
      const sortKey = sortBy[i];
      let sortA = getObjectValueByPath(a, sortKey);
      let sortB = getObjectValueByPath(b, sortKey);
      if (sortDesc[i]) {
        [sortA, sortB] = [sortB, sortA];
      }
      if (customSorters?.[sortKey]) {
        const customResult = customSorters[sortKey](sortA, sortB);
        if (!customResult)
          continue;
        return customResult;
      }
      if (sortA === null && sortB === null) {
        continue;
      }
      if (sortA instanceof Date && sortB instanceof Date) {
        return sortA.getTime() - sortB.getTime();
      }
      [sortA, sortB] = [sortA, sortB].map((s) => (s || "").toString().toLocaleLowerCase());
      if (sortA !== sortB) {
        if (!isNaN(sortA) && !isNaN(sortB))
          return Number(sortA) - Number(sortB);
        return stringCollator.compare(sortA, sortB);
      }
    }
    return 0;
  });
}
function debounce(fn, delay) {
  let timeoutId = 0;
  return (...args) => {
    clearTimeout(timeoutId);
    timeoutId = setTimeout(() => fn(...args), delay);
  };
}
function throttle(fn, limit) {
  let throttling = false;
  return (...args) => {
    if (!throttling) {
      throttling = true;
      setTimeout(() => throttling = false, limit);
      return fn(...args);
    }
  };
}
function clamp(value, min = 0, max = 1) {
  return Math.max(min, Math.min(max, value));
}
function padEnd(str, length, char = "0") {
  return str + char.repeat(Math.max(0, length - str.length));
}
function chunk(str, size = 1) {
  const chunked = [];
  let index = 0;
  while (index < str.length) {
    chunked.push(str.substr(index, size));
    index += size;
  }
  return chunked;
}
function getUid() {
  return getUid._uid++;
}
getUid._uid = 0;
function flattenFragments(nodes) {
  return nodes.map((node) => {
    if (node.type === Fragment) {
      return flattenFragments(node.children);
    } else {
      return node;
    }
  }).flat();
}
class CircularBuffer {
  constructor(size) {
    this.size = size;
  }
  #arr = [];
  #pointer = 0;
  push(val) {
    this.#arr[this.#pointer] = val;
    this.#pointer = (this.#pointer + 1) % this.size;
  }
  values() {
    return this.#arr.slice(this.#pointer).concat(this.#arr.slice(0, this.#pointer));
  }
}
function padNumber(x, length) {
  let padded = String(x);
  if (padded.length > length) {
    padded.substring(padded.length - length);
  }
  while (padded.length < length) {
    padded = `0${padded}`;
  }
  return padded;
}

const mainTRC = 2.4;
const Rco = 0.2126729;
const Gco = 0.7151522;
const Bco = 0.072175;
const normBG = 0.55;
const normTXT = 0.58;
const revTXT = 0.57;
const revBG = 0.62;
const blkThrs = 0.03;
const blkClmp = 1.45;
const deltaYmin = 5e-4;
const scaleBoW = 1.25;
const scaleWoB = 1.25;
const loConThresh = 0.078;
const loConFactor = 12.82051282051282;
const loConOffset = 0.06;
const loClip = 1e-3;
function APCAcontrast(text, background) {
  const Rtxt = ((text >> 16 & 255) / 255) ** mainTRC;
  const Gtxt = ((text >> 8 & 255) / 255) ** mainTRC;
  const Btxt = ((text >> 0 & 255) / 255) ** mainTRC;
  const Rbg = ((background >> 16 & 255) / 255) ** mainTRC;
  const Gbg = ((background >> 8 & 255) / 255) ** mainTRC;
  const Bbg = ((background >> 0 & 255) / 255) ** mainTRC;
  let Ytxt = Rtxt * Rco + Gtxt * Gco + Btxt * Bco;
  let Ybg = Rbg * Rco + Gbg * Gco + Bbg * Bco;
  if (Ytxt <= blkThrs)
    Ytxt += (blkThrs - Ytxt) ** blkClmp;
  if (Ybg <= blkThrs)
    Ybg += (blkThrs - Ybg) ** blkClmp;
  if (Math.abs(Ybg - Ytxt) < deltaYmin)
    return 0;
  let outputContrast;
  if (Ybg > Ytxt) {
    const SAPC = (Ybg ** normBG - Ytxt ** normTXT) * scaleBoW;
    outputContrast = SAPC < loClip ? 0 : SAPC < loConThresh ? SAPC - SAPC * loConFactor * loConOffset : SAPC - loConOffset;
  } else {
    const SAPC = (Ybg ** revBG - Ytxt ** revTXT) * scaleWoB;
    outputContrast = SAPC > -loClip ? 0 : SAPC > -loConThresh ? SAPC - SAPC * loConFactor * loConOffset : SAPC + loConOffset;
  }
  return outputContrast * 100;
}
const srgbReverseMatrix = [
  [0.4124, 0.3576, 0.1805],
  [0.2126, 0.7152, 0.0722],
  [0.0193, 0.1192, 0.9505]
];
const srgbReverseTransform = (C) => C <= 0.04045 ? C / 12.92 : ((C + 0.055) / 1.055) ** 2.4;
function toXYZ$1(rgb) {
  const xyz = [0, 0, 0];
  const transform = srgbReverseTransform;
  const matrix = srgbReverseMatrix;
  const r = transform((rgb >> 16 & 255) / 255);
  const g = transform((rgb >> 8 & 255) / 255);
  const b = transform((rgb >> 0 & 255) / 255);
  for (let i = 0; i < 3; ++i) {
    xyz[i] = matrix[i][0] * r + matrix[i][1] * g + matrix[i][2] * b;
  }
  return xyz;
}

function isDarkColor(int) {
  const blackContrast = Math.abs(APCAcontrast(0, int));
  const whiteContrast = Math.abs(APCAcontrast(16777215, int));
  return whiteContrast > Math.min(blackContrast, 50);
}
function colorToOnColorHex(color) {
  return isDarkColor(colorToInt(color)) ? "#FFF" : "#000";
}
function isCssColor(color) {
  return !!color && /^(#|inherit|var\(--|(rgb|hsl)a?\()/.test(color);
}
function colorToInt(color) {
  let rgb;
  if (typeof color === "number") {
    rgb = color;
  } else if (typeof color === "string") {
    let c = color.startsWith("#") ? color.substring(1) : color;
    if (c.length === 3) {
      c = c.split("").map((char) => char + char).join("");
    }
    if (c.length !== 6) {
      console.warn(`'${color}' is not a valid rgb color`);
    }
    rgb = parseInt(c, 16);
  } else {
    throw new TypeError(`Colors can only be numbers or strings, recieved ${color} instead`);
  }
  if (rgb < 0) {
    console.warn(`Colors cannot be negative: '${color}'`);
    rgb = 0;
  } else if (rgb > 16777215 || isNaN(rgb)) {
    console.warn(`'${color}' is not a valid rgb color`);
    rgb = 16777215;
  }
  return rgb;
}
function HexToRGBA(hex) {
  const rgba = chunk(hex.slice(1), 2).map((c) => parseInt(c, 16));
  return {
    r: rgba[0],
    g: rgba[1],
    b: rgba[2],
    a: rgba[3] === void 0 ? 1 : Math.round(rgba[3] / 255 * 100) / 100
  };
}
function parseHex(hex) {
  if (hex.startsWith("#")) {
    hex = hex.slice(1);
  }
  hex = hex.replace(/([^0-9a-f])/gi, "F");
  if (hex.length === 3 || hex.length === 4) {
    hex = hex.split("").map((x) => x + x).join("");
  }
  if (hex.length === 6) {
    hex = padEnd(hex, 8, "F");
  } else {
    hex = padEnd(padEnd(hex, 6), 8, "F");
  }
  return `#${hex}`.toUpperCase().substr(0, 9);
}
function colorIntToRGB(int) {
  return {
    r: (int & 16711680) >> 16,
    g: (int & 65280) >> 8,
    b: int & 255
  };
}
function colorToRGB(color) {
  return colorIntToRGB(colorToInt(color));
}
function getLuma(color) {
  const rgb = colorToInt(color);
  return toXYZ$1(rgb)[1];
}

function createSharedComposable(composable) {
  let subscribers = 0;
  let scope;
  let state;
  return () => {
    subscribers++;
    if (state === void 0) {
      scope = effectScope(true);
      state = scope.run(composable);
    }
    onScopeDispose(() => {
      if (scope && --subscribers <= 0) {
        scope?.stop();
        state = scope = void 0;
      }
    });
    return state;
  };
}

function toKebabCase(str) {
  return str.replace(/[^a-z0-9]/gi, "-").replace(/\B([A-Z])/g, "-$1").toLowerCase();
}
function toCameCase(str) {
  return str.replace(/-(\w)/g, (match, part) => part.toLocaleUpperCase());
}
function toPascalCase(str) {
  return toCameCase(
    str.replace(/^[a-z]/, (match) => match.toLocaleUpperCase())
  );
}

function createSimpleFunctional(klass, tag = "div", name) {
  return defineComponent$1({
    name: name ?? toKebabCase(klass.replace(/__/g, "-")),
    props: {
      tag: {
        type: String,
        default: tag
      }
    },
    setup(props, { slots }) {
      return () => h(props.tag, { class: klass }, slots.default?.());
    }
  });
}

function downloadCSV(name, headers, rows, charset = "utf-8") {
  const csv = [
    headers.map((header) => typeof header === "object" ? header.text ?? header.value : header).join(","),
    ...rows.map((row) => {
      return headers.map((header) => typeof header === "object" ? row[header.value] : row[header]).join(",");
    })
  ];
  const blob = new Blob([
    `\uFEFF${csv.join("\n")}`
  ], {
    type: `text/csv;charset=${charset}`
  });
  const link = document.createElement("a");
  link.setAttribute("href", window.URL.createObjectURL(blob));
  link.setAttribute("download", `${name}.csv`);
  link.click();
}

const classifyRE = /(?:^|[-_])(\w)/g;
const classify = (str) => str.replace(classifyRE, (c) => c.toUpperCase()).replace(/[-_]/g, "");
function formatComponentName(vm, includeFile) {
  if (vm.$root === vm) {
    return "<Root>";
  }
  const options = typeof vm === "function" && vm.cid != null ? vm.options : vm._isVue ? vm.$options || vm.constructor.options : vm || {};
  let name = options.name || options._componentTag;
  const file = options.__file;
  if (!name && file) {
    const match = file.match(/([^/\\]+)\.vue$/);
    name = match?.[1];
  }
  return (name ? `<${classify(name)}>` : "<Anonymous>") + (file && includeFile !== false ? ` at ${file}` : "");
}
function generateComponentTrace(vm) {
  if (vm._isVue && vm.$parent) {
    const tree = [];
    let currentRecursiveSequence = 0;
    while (vm) {
      if (tree.length > 0) {
        const last = tree[tree.length - 1];
        if (last.constructor === vm.constructor) {
          currentRecursiveSequence++;
          vm = vm.$parent;
          continue;
        } else if (currentRecursiveSequence > 0) {
          tree[tree.length - 1] = [last, currentRecursiveSequence];
          currentRecursiveSequence = 0;
        }
      }
      tree.push(vm);
      vm = vm.$parent;
    }
    return `

found in

${tree.map((vm2, i) => `${i === 0 ? "---> " : " ".repeat(5 + i * 2)}${Array.isArray(vm2) ? `${formatComponentName(vm2[0])}... (${vm2[1]} recursive calls)` : formatComponentName(vm2)}`).join("\n")}`;
  } else {
    return `

(found in ${formatComponentName(vm)})`;
  }
}

function attachedRoot(node) {
  if (typeof node.getRootNode !== "function") {
    while (node.parentNode)
      node = node.parentNode;
    if (node !== document)
      return null;
    return document;
  }
  const root = node.getRootNode();
  if (root !== document && root.getRootNode({ composed: true }) !== document)
    return null;
  return root;
}

const standardEasing = "cubic-bezier(0.4, 0, 0.2, 1)";
const deceleratedEasing = "cubic-bezier(0.0, 0, 0.2, 1)";
const acceleratedEasing = "cubic-bezier(0.4, 0, 1, 1)";
function pick(obj, paths) {
  const found = /* @__PURE__ */ Object.create({});
  const rest = /* @__PURE__ */ Object.create({});
  for (const key in obj) {
    if (paths.some(
      (path) => path instanceof RegExp ? path.test(key) : path === key
    )) {
      found[key] = obj[key];
    } else {
      rest[key] = obj[key];
    }
  }
  return [found, rest];
}
function filterInputAttrs(attrs) {
  return pick(attrs, ["class", "style", "id", /^data-/]);
}

function getCurrentInstance(errorName, errorMessage) {
  const vm = getCurrentInstance$1();
  if (!vm) {
    throw new Error(
      `${errorName} ${errorMessage || "must be called from inside a setup function"}`
    );
  }
  return vm;
}
function getCurrentInstanceName(errorName = "getCurrentInstanceName") {
  return toKebabCase(getCurrentInstance(errorName).type?.name ?? "");
}

const IS_NODE = typeof process !== "undefined";
const IN_BROWSER = typeof window !== "undefined";
IS_NODE && process.env.DEBUG === "true";
IS_NODE && process.env.NODE_ENV === "production";
const SUPPORTS_INTERSECTION_OBSERVER = IN_BROWSER && "IntersectionObserver" in window;
const SUPPORTS_RESIZE_OBSERVER = IN_BROWSER && "ResizeObserver" in window;
const SUPPORTS_TOUCH = IN_BROWSER && ("ontouchstart" in window || window.navigator.maxTouchPoints > 0);
const SUPPORTS_FOCUS_VISIBLE = IN_BROWSER && CSS.supports("selector(:focus-visible)");
const keyCodes = Object.freeze({
  enter: 13,
  tab: 9,
  delete: 46,
  esc: 27,
  space: 32,
  up: 38,
  down: 40,
  left: 37,
  right: 39,
  end: 35,
  home: 36,
  del: 46,
  backspace: 8,
  insert: 45,
  pageup: 33,
  pagedown: 34,
  shift: 16
});
const keyValues = Object.freeze({
  enter: "Enter",
  tab: "Tab",
  delete: "Delete",
  esc: "Escape",
  space: "Space",
  up: "ArrowUp",
  down: "ArrowDown",
  left: "ArrowLeft",
  right: "ArrowRight",
  end: "End",
  home: "Home",
  del: "Delete",
  backspace: "Backspace",
  insert: "Insert",
  pageup: "PageUp",
  pagedown: "PageDown",
  shift: "Shift"
});

function isFixedPosition(el) {
  while (el) {
    if (window.getComputedStyle(el).position === "fixed") {
      return true;
    }
    el = el.offsetParent;
  }
  return false;
}

function elementToViewport(point, offset) {
  return {
    x: point.x + offset.x,
    y: point.y + offset.y
  };
}
function getOffset(a, b) {
  return {
    x: a.x - b.x,
    y: a.y - b.y
  };
}
function anchorToPoint(anchor, box) {
  const { side, align } = anchor;
  let x;
  let y = 0;
  if (side === "top" || side === "bottom") {
    switch (side) {
      case "top":
        y = 0;
        break;
      case "bottom":
        y = box.height;
        break;
    }
    switch (align) {
      case "start":
        x = 0;
        break;
      case "center":
        x = box.width / 2;
        break;
      case "end":
        x = box.width;
        break;
    }
  } else if (side === "start" || side === "end") {
    switch (side) {
      case "start":
        x = 0;
        break;
      case "end":
        x = box.width;
        break;
    }
    switch (align) {
      case "top":
        y = 0;
        break;
      case "center":
        y = box.height / 2;
        break;
      case "bottom":
        y = box.height;
        break;
    }
  } else {
    x = box.width / 2;
    y = box.height / 2;
  }
  return elementToViewport({ x, y }, box);
}

function propsFactory(props, source) {
  return (defaults) => {
    return Object.keys(props).reduce((obj, prop) => {
      const isObjectDefinition = typeof props[prop] === "object" && props[prop] != null && !Array.isArray(props[prop]);
      const definition = isObjectDefinition ? props[prop] : { type: props[prop] };
      if (defaults && prop in defaults) {
        obj[prop] = {
          ...definition,
          default: defaults[prop]
        };
      } else {
        obj[prop] = definition;
      }
      if (source) {
        obj[prop].source = source;
      }
      return obj;
    }, {});
  };
}

function querySelector(selector, vm) {
  let el;
  if (selector === "parent") {
    el = vm?.proxy?.$el?.parentNode;
  } else if (typeof selector === "string") {
    el = document.querySelector(selector);
  } else if ("$el" in selector) {
    el = selector.$el;
  } else if (selector) {
    el = selector;
  }
  return el?.nodeType === Node.ELEMENT_NODE ? el : void 0;
}

let clean = true;
const frames = [];
function requestNewFrame(cb) {
  if (!clean || frames.length) {
    frames.push(cb);
    run();
  } else {
    clean = false;
    cb();
    run();
  }
}
let raf = -1;
function run() {
  cancelAnimationFrame(raf);
  raf = requestAnimationFrame(() => {
    const frame = frames.shift();
    if (frame)
      frame();
    if (frames.length)
      run();
    else
      clean = true;
  });
}

function getScrollParent(el) {
  while (el) {
    if (hasScrollbar(el))
      return el;
    el = el.parentElement;
  }
  return document.scrollingElement;
}
function getScrollParents(el) {
  const elements = [];
  while (el) {
    if (hasScrollbar(el))
      elements.push(el);
    el = el.parentElement;
  }
  return elements;
}
function hasScrollbar(el) {
  if (!el || el.nodeType !== Node.ELEMENT_NODE)
    return false;
  const style = window.getComputedStyle(el);
  return style.overflowY === "scroll" || (style.overflowY === "auto" || style.overflowY === "overlay") && el.scrollHeight > el.clientHeight;
}
function getScrollbarWidth(el) {
  if (!el || el.nodeType !== Node.ELEMENT_NODE)
    return 0;
  if (el.tagName === "HTML") {
    return window.innerWidth - document.documentElement.offsetWidth;
  }
  const style = window.getComputedStyle(el);
  return el.offsetWidth - el.clientWidth - parseFloat(style.borderLeftWidth) - parseFloat(style.borderRightWidth);
}

function useRender(render) {
  const vm = getCurrentInstance("useRender");
  vm.render = render;
}

function classToHex(color, colors, currentTheme) {
  const [colorName, colorModifier] = color.toString().trim().replace("-", "").split(" ", 2);
  let hexColor = "";
  if (colorName && colorName in colors) {
    if (colorModifier && colorModifier in colors[colorName]) {
      hexColor = colors[colorName][colorModifier];
    } else if ("base" in colors[colorName]) {
      hexColor = colors[colorName].base;
    }
  } else if (colorName && colorName in currentTheme) {
    hexColor = currentTheme[colorName];
  }
  return hexColor;
}
function parseGradient(gradient, colors, currentTheme) {
  return gradient.replace(/([a-z]+(\s[a-z]+-[1-5])?)(?=$|,)/gi, (x) => {
    return classToHex(x, colors, currentTheme) || x;
  }).replace(/(rgba\()#[0-9a-f]+(?=,)/gi, (x) => {
    return `rgba(${Object.values(HexToRGBA(parseHex(x.replace(/rgba\(/, "")))).slice(0, 3).join(",")}`;
  });
}

const UI_NAME = "veno-ui";
const UI_VERSION = "0.6.0";

function createMessage$1(message, vm, parent) {
  if (parent) {
    vm = {
      _isVue: true,
      $parent: parent,
      $options: vm
    };
  }
  if (vm) {
    vm.$_alreadyWarned = vm.$_alreadyWarned || [];
    if (vm.$_alreadyWarned.includes(message))
      return;
    vm.$_alreadyWarned.push(message);
  }
  return `[${UI_NAME}] ${message}${vm ? generateComponentTrace(vm) : ""}`;
}
function consoleInfo(message, vm, parent) {
  const newMessage = createMessage$1(message, vm, parent);
  newMessage != null && console.info(newMessage);
}
function consoleWarn(message, vm, parent) {
  const newMessage = createMessage$1(message, vm, parent);
  newMessage != null && console.warn(newMessage);
}
function consoleError(message, vm, parent) {
  const newMessage = createMessage$1(message, vm, parent);
  newMessage != null && console.error(newMessage);
}

const DefaultsKey = Symbol.for("veno-ui:defaults");
function createDefaults(options) {
  return ref(options != null ? options : {});
}
function useDefaults() {
  const defaults = inject(DefaultsKey);
  if (!defaults)
    throw new Error("[VenoUi] Could not find defaults instance");
  return defaults;
}
function provideDefaults(defaults, options) {
  const injectedDefaults = useDefaults();
  const providedDefaults = ref(defaults);
  const newDefaults = computed(() => {
    const scoped = unref(options == null ? void 0 : options.scoped);
    const reset = unref(options == null ? void 0 : options.reset);
    const root = unref(options == null ? void 0 : options.root);
    let properties = deepMerge(providedDefaults.value, {
      prev: injectedDefaults.value
    });
    if (scoped)
      return properties;
    if (reset || root) {
      const len = Number(reset || Infinity);
      for (let i = 0; i <= len; i++) {
        if (!properties.prev)
          break;
        properties = properties.prev;
      }
      return properties;
    }
    return deepMerge(properties.prev, properties);
  });
  provide(DefaultsKey, newDefaults);
  return newDefaults;
}

var __defProp$1s = Object.defineProperty;
var __getOwnPropSymbols$1u = Object.getOwnPropertySymbols;
var __hasOwnProp$1u = Object.prototype.hasOwnProperty;
var __propIsEnum$1u = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1s = (obj, key, value) => key in obj ? __defProp$1s(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1s = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1u.call(b, prop))
      __defNormalProp$1s(a, prop, b[prop]);
  if (__getOwnPropSymbols$1u)
    for (var prop of __getOwnPropSymbols$1u(b)) {
      if (__propIsEnum$1u.call(b, prop))
        __defNormalProp$1s(a, prop, b[prop]);
    }
  return a;
};
function propIsDefined(vnode, prop) {
  var _a, _b;
  return ((_a = vnode.props) == null ? void 0 : _a.hasOwnProperty(prop)) || ((_b = vnode.props) == null ? void 0 : _b.hasOwnProperty(toKebabCase(prop)));
}
const defineComponent = function defineComponent2(options) {
  var _a;
  options._setup = (_a = options._setup) != null ? _a : options.setup;
  if (!options.name) {
    consoleWarn("The component is missing an explicit name, unable to generate default prop value");
    return options;
  }
  if (options._setup) {
    options.setup = function setup(props, ctx) {
      const vm = getCurrentInstance$1();
      const defaults = useDefaults();
      const _props = shallowReactive(__spreadValues$1s({}, toRaw(props)));
      watchEffect(() => {
        var _a2, _b;
        const globalDefaults = defaults.value.global;
        const componentDefaults = defaults.value[options.name];
        for (const prop of Object.keys(props)) {
          let newVal;
          if (propIsDefined(vm.vnode, prop)) {
            newVal = props[prop];
          } else {
            newVal = (_b = (_a2 = componentDefaults == null ? void 0 : componentDefaults[prop]) != null ? _a2 : globalDefaults == null ? void 0 : globalDefaults[prop]) != null ? _b : props[prop];
          }
          if (_props[prop] !== newVal) {
            _props[prop] = newVal;
          }
        }
      });
      return options._setup(_props, ctx);
    };
  }
  return options;
};
function genericComponent(exposeDefaults = true) {
  return (options) => (exposeDefaults ? defineComponent : defineComponent$1)(options);
}

function findChildren(vnode) {
  var _a;
  if (!vnode || typeof vnode !== "object") {
    return [];
  }
  if (Array.isArray(vnode)) {
    return vnode.map((child) => findChildren(child)).filter((v) => v).flat(1);
  } else if (Array.isArray(vnode.children)) {
    return vnode.children.map((child) => findChildren(child)).filter((v) => v).flat(1);
  } else if (vnode.component) {
    return [vnode.component, ...findChildren((_a = vnode.component) == null ? void 0 : _a.subTree)].filter((v) => v).flat(1);
  }
  return [];
}
function findChildrenWithProvide(provide, vnode) {
  return findChildren(vnode).slice(1).filter((cmp) => !!cmp.provides[provide]);
}

function createSymbol(key) {
  return Symbol.for(`${UI_NAME}:${key}`);
}

var index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  UI_NAME: UI_NAME,
  UI_VERSION: UI_VERSION,
  classToHex: classToHex,
  consoleError: consoleError,
  consoleInfo: consoleInfo,
  consoleWarn: consoleWarn,
  createSymbol: createSymbol,
  defineComponent: defineComponent,
  findChildren: findChildren,
  findChildrenWithProvide: findChildrenWithProvide,
  genericComponent: genericComponent,
  parseGradient: parseGradient,
  propIsDefined: propIsDefined
});

function useProxiedModel(props, prop, defaultValue, transformIn = (v) => v, transformOut = (v) => v) {
  const vm = getCurrentInstance("useProxiedModel");
  const propIsDefined$1 = computed(() => {
    return typeof props[prop] !== "undefined" && vm.vnode && propIsDefined(vm.vnode, prop);
  });
  const internal = ref(
    typeof props[prop] === "undefined" ? defaultValue : props[prop]
  );
  return computed({
    get() {
      if (propIsDefined$1.value) {
        return transformIn(props[prop]);
      } else {
        return transformIn(internal.value);
      }
    },
    set(newValue) {
      internal.value = transformOut(newValue);
      vm.emit(`update:${prop}`, internal.value);
    }
  });
}

var __getOwnPropSymbols$1t = Object.getOwnPropertySymbols;
var __hasOwnProp$1t = Object.prototype.hasOwnProperty;
var __propIsEnum$1t = Object.prototype.propertyIsEnumerable;
var __objRest$4 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$1t.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$1t)
    for (var prop of __getOwnPropSymbols$1t(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$1t.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
const makeTransitionProps = propsFactory({
  /**
   * @zh 过渡动画
   */
  transition: {
    type: [Boolean, String, Object],
    default: "ve-fade-transition",
    validator: (val) => val !== true
  }
}, "transition");
const MaybeTransition = (props, { slots }) => {
  var _b;
  const _a = props, { transition } = _a, rest = __objRest$4(_a, ["transition"]);
  if (!transition || typeof transition === "boolean")
    return (_b = slots.default) == null ? void 0 : _b.call(slots);
  const _c = typeof transition === "object" ? transition : {}, { component = Transition } = _c, customProps = __objRest$4(_c, ["component"]);
  return h(
    component,
    mergeProps(
      typeof transition === "string" ? { name: transition } : customProps,
      rest
    ),
    slots
  );
};

const makeLoadingProps = propsFactory({
  loading: Boolean
}, "loading");
function useLoading(props, name = getCurrentInstanceName()) {
  return {
    loadingClasses: computed(() => ({
      [`${name}--loading`]: props.loading
    }))
  };
}

var __defProp$1r = Object.defineProperty;
var __defProps$u = Object.defineProperties;
var __getOwnPropDescs$u = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1s = Object.getOwnPropertySymbols;
var __hasOwnProp$1s = Object.prototype.hasOwnProperty;
var __propIsEnum$1s = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1r = (obj, key, value) => key in obj ? __defProp$1r(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1r = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1s.call(b, prop))
      __defNormalProp$1r(a, prop, b[prop]);
  if (__getOwnPropSymbols$1s)
    for (var prop of __getOwnPropSymbols$1s(b)) {
      if (__propIsEnum$1s.call(b, prop))
        __defNormalProp$1r(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$u = (a, b) => __defProps$u(a, __getOwnPropDescs$u(b));
function useRoute() {
  const vm = getCurrentInstance$1();
  return computed(() => {
    var _a;
    return (_a = vm == null ? void 0 : vm.proxy) == null ? void 0 : _a.$route;
  });
}
function useRouter() {
  var _a, _b;
  return (_b = (_a = getCurrentInstance$1()) == null ? void 0 : _a.proxy) == null ? void 0 : _b.$router;
}
function useRouterHistory() {
  const router = useRouter();
  const isWebHashHistory = computed(() => router && router.options.history.base.includes("#"));
  return {
    isWebHashHistory
  };
}
function useLink(props, attrs) {
  const RouterLink = resolveDynamicComponent("RouterLink");
  const isLink = computed(() => !!(props.href || props.to));
  const isClickable = computed(() => {
    return (isLink == null ? void 0 : isLink.value) || !!(attrs.onClick || attrs.onClickOnce);
  });
  if (typeof RouterLink === "string") {
    return {
      isLink,
      isClickable,
      href: toRef(props, "href")
    };
  }
  const link = props.to ? RouterLink.useLink(props) : void 0;
  return __spreadProps$u(__spreadValues$1r({}, link), {
    isLink,
    isClickable,
    href: computed(() => props.to ? link == null ? void 0 : link.route.value.href : props.href)
  });
}
const makeRouterProps = propsFactory({
  href: String,
  replace: Boolean,
  to: [String, Object]
}, "router");
function useBackButton(cb) {
  const router = useRouter();
  let popped = false;
  let removeGuard;
  onMounted(() => {
    window.addEventListener("popstate", onPopstate);
    removeGuard = router == null ? void 0 : router.beforeEach((to, from, next) => {
      setTimeout(() => popped ? cb(next) : next());
    });
  });
  onBeforeUnmount(() => {
    window.removeEventListener("popstate", onPopstate);
    removeGuard == null ? void 0 : removeGuard();
  });
  function onPopstate(e) {
    var _a;
    if ((_a = e.state) == null ? void 0 : _a.replaced)
      return;
    popped = true;
    setTimeout(() => popped = false);
  }
}

const makeDisabledProps = propsFactory({
  disabled: Boolean
}, "disabled");
function useDisabled(props, name = getCurrentInstanceName()) {
  return {
    disabledClasses: computed(() => {
      const { disabled } = unref(props);
      return {
        [`${name}--disabled`]: disabled
      };
    })
  };
}

const makeTagProps = propsFactory({
  /**
   * @zh 指定在根元素上使用的自定义标签
   */
  tag: {
    type: String,
    default: "div"
  }
}, "tag");

var defaultOptions = {
  defaultTheme: "light",
  themes: {
    light: {
      dark: false,
      colors: {
        "background": "#FFF",
        "on-background": "#333333",
        "surface": "#FFF",
        "on-surface": "#333333",
        "surface-variant": "#424242",
        "on-surface-variant": "#EEE",
        "primary": "#0969DA",
        "secondary": "#F2F3F5",
        "on-secondary": "#1D2129",
        "error": "#F53F3F",
        "info": "#2080F0",
        "success": "#00B42A",
        "warning": "#FF7D00"
      },
      variables: {
        "border-color": "#000",
        "border-opacity": 0.12,
        "high-emphasis-opacity": 0.87,
        "medium-emphasis-opacity": 0.6,
        "disabled-opacity": 0.38,
        "idle-opacity": 0.04,
        "hover-opacity": 0.04,
        "focus-opacity": 0.12,
        "selected-opacity": 0.08,
        "activated-opacity": 0.12,
        "pressed-opacity": 0.12,
        "dragged-opacity": 0.08
      }
    },
    dark: {
      dark: true,
      colors: {
        "background": "#22272E",
        "surface": "#2D333B",
        "surface-variant": "#BDBDBD",
        "on-surface-variant": "#424242",
        "primary": "#539BF5",
        "secondary": "#444C56",
        "on-secondary": "#F2F3F5",
        "error": "#F53F3F",
        "info": "#2080F0",
        "success": "#00B42A",
        "warning": "#FF7D00"
      },
      variables: {
        "border-color": "#FFF",
        "border-opacity": 0.08,
        "high-emphasis-opacity": 0.87,
        "medium-emphasis-opacity": 0.6,
        "disabled-opacity": 0.38,
        "idle-opacity": 0.1,
        "hover-opacity": 0.04,
        "focus-opacity": 0.12,
        "selected-opacity": 0.08,
        "activated-opacity": 0.12,
        "pressed-opacity": 0.16,
        "dragged-opacity": 0.08
      }
    }
  }
};

var __defProp$1q = Object.defineProperty;
var __defProps$t = Object.defineProperties;
var __getOwnPropDescs$t = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1r = Object.getOwnPropertySymbols;
var __hasOwnProp$1r = Object.prototype.hasOwnProperty;
var __propIsEnum$1r = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1q = (obj, key, value) => key in obj ? __defProp$1q(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1q = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1r.call(b, prop))
      __defNormalProp$1q(a, prop, b[prop]);
  if (__getOwnPropSymbols$1r)
    for (var prop of __getOwnPropSymbols$1r(b)) {
      if (__propIsEnum$1r.call(b, prop))
        __defNormalProp$1q(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$t = (a, b) => __defProps$t(a, __getOwnPropDescs$t(b));
const ThemeKey = Symbol.for("veno-ui:theme");
const makeThemeProps = propsFactory({
  /**
   * @zh 设置主题
   */
  theme: String
}, "theme");
const parseThemeOptions = (options = defaultOptions) => {
  if (!options) {
    return __spreadProps$t(__spreadValues$1q({}, defaultOptions), { isDisabled: true });
  }
  return deepMerge(defaultOptions, options);
};
function createCssClass(selector, content) {
  return [
    `${selector} {
`,
    ...content.map((line) => `  ${line};
`),
    "}\n"
  ];
}
function createTheme(app, options) {
  const head = app._context.provides.usehead;
  const parsedOptions = parseThemeOptions(options);
  const styleEl = ref();
  const current = ref(parsedOptions.defaultTheme);
  const themes = ref(parsedOptions.themes);
  const computedThemes = computed(() => {
    return Object.keys(themes.value).reduce((obj, key) => {
      const theme = themes.value[key];
      for (const color of Object.keys(theme.colors)) {
        if (/on-[a-z]/.test(color) || theme.colors[`on-${color}`])
          continue;
        theme.colors[`on-${color}`] = colorToOnColorHex(theme.colors[color]);
      }
      obj[key] = theme;
      return obj;
    }, {});
  });
  const styles = computed(() => {
    const lines = [];
    for (const themeName of Object.keys(computedThemes.value)) {
      const theme = computedThemes.value[themeName];
      lines.push(
        ...createCssClass(`.ve-theme--${themeName}`, [
          ...genCssVariables(themeName),
          ...Object.keys(theme.variables).map((key) => {
            const value = theme.variables[key];
            const color = typeof value === "string" && value.startsWith("#") ? colorToRGB(value) : void 0;
            const rgb = color ? `${color.r}, ${color.g}, ${color.b}` : void 0;
            return `--ve-${key}: ${rgb != null ? rgb : value}`;
          })
        ])
      );
      if (theme.dark) {
        for (const key of Object.keys(theme.colors)) {
          if (/on-[a-z]/.test(key)) {
            lines.push(
              ...createCssClass(`.${key}`, [
                `color: rgb(var(--ve-theme-${key})) !important`
              ])
            );
          } else {
            lines.push(
              ...createCssClass(`.bg-${key}`, [
                `--ve-theme-overlay-multiplier: var(--ve-theme-${key}-overlay-multiplier)`,
                `background: rgb(var(--ve-theme-${key})) !important`,
                `color: rgb(var(--ve-theme-on-${key})) !important`
              ]),
              ...createCssClass(`.text-${key}`, [
                `color: rgb(var(--ve-theme-${key})) !important`
              ]),
              ...createCssClass(`.border-${key}`, [
                `--ve-border-color: var(--ve-theme-${key})`
              ])
            );
          }
        }
      }
    }
    return lines.map((str, i) => i === 0 ? str : `    ${str}`).join("");
  });
  function genCssVariables(name) {
    const theme = computedThemes.value[name];
    if (!theme)
      throw new Error(`Could not find theme ${name}`);
    const lightOverlay = theme.dark ? 2 : 1;
    const darkOverlay = theme.dark ? 1 : 2;
    const variables = [];
    for (const [key, value] of Object.entries(theme.colors)) {
      const rgb = colorToRGB(value);
      variables.push(`--ve-theme-${key}: ${rgb.r},${rgb.g},${rgb.b}`);
      if (!key.startsWith("on-")) {
        variables.push(`--ve-theme-${key}-overlay-multiplier: ${getLuma(value) > 0.18 ? lightOverlay : darkOverlay}`);
      }
    }
    return variables;
  }
  if (head) {
    head.addHeadObjs(computed(() => ({
      style: [{
        children: styles.value,
        type: "text/css",
        id: "veno-ui-theme-stylesheet"
      }]
    })));
    if (IN_BROWSER) {
      watchEffect(() => head.updateDOM());
    }
  } else {
    let updateStyles = function() {
      if (parsedOptions.isDisabled)
        return;
      genStyleElement();
      if (styleEl.value)
        styleEl.value.innerHTML = styles.value;
    }, genStyleElement = function() {
      if (typeof document === "undefined" || styleEl.value)
        return;
      const el = document.createElement("style");
      el.type = "text/css";
      el.id = "veno-ui-theme-stylesheet";
      styleEl.value = el;
      document.head.appendChild(styleEl.value);
    };
    watch(themes, updateStyles, { deep: true, immediate: true });
  }
  return {
    isDisabled: parsedOptions.isDisabled,
    themes: computedThemes,
    setTheme: (key, theme) => themes.value[key] = theme,
    getTheme: (key) => computedThemes.value[key],
    current,
    themeClasses: computed(() => {
      return parsedOptions.isDisabled ? void 0 : `ve-theme--${current.value}`;
    })
  };
}
function provideTheme(props) {
  getCurrentInstance("provideTheme");
  const theme = inject(ThemeKey, null);
  if (!theme)
    throw new Error("Could not find theme injection");
  const current = computed(() => {
    const { theme: propTheme } = unref(props);
    if (propTheme && propTheme.includes(":")) {
      const [theme1, theme2] = propTheme.split(":");
      return (theme == null ? void 0 : theme.current.value) === theme1 ? theme2 : theme1;
    }
    return propTheme != null ? propTheme : theme == null ? void 0 : theme.current.value;
  });
  const themeClasses = computed(() => {
    return theme.isDisabled ? void 0 : `ve-theme--${current.value}`;
  });
  const newTheme = __spreadProps$t(__spreadValues$1q({}, theme), {
    current,
    themeClasses
  });
  provide(ThemeKey, newTheme);
  return newTheme;
}
function useTheme() {
  getCurrentInstance("useTheme");
  const provider = inject(ThemeKey, null);
  if (!provider)
    throw new Error("Could not find theme injection");
  return provider;
}

const makeColorProps = propsFactory({
  color: String,
  textColor: String
}, "color");
function useColor(colors) {
  const backgroundIsCssColor = computed(() => isCssColor(colors.value.background));
  const textIsCssColor = computed(() => isCssColor(colors.value.text));
  const colorClasses = computed(() => {
    const classes = [];
    if (colors.value.background && !backgroundIsCssColor.value) {
      classes.push(`bg-${colors.value.background}`);
    }
    if (colors.value.text && !textIsCssColor.value) {
      classes.push(`text-${colors.value.text}`);
    }
    return classes;
  });
  const colorStyles = computed(() => {
    const styles = {};
    if (colors.value.background && backgroundIsCssColor.value) {
      styles.backgroundColor = colors.value.background;
      styles.color = colorToOnColorHex(styles.backgroundColor);
    }
    if (colors.value.text && textIsCssColor.value) {
      styles.color = colors.value.text;
      styles.caretColor = colors.value.text;
    }
    return styles;
  });
  return { colorClasses, colorStyles };
}
function useTextColor(props, name) {
  const colors = computed(() => ({
    text: isRef(props) ? props.value : name ? props[name] : null
  }));
  const {
    colorClasses: textColorClasses,
    colorStyles: textColorStyles
  } = useColor(colors);
  return { textColorClasses, textColorStyles };
}
function useBackgroundColor(props, name) {
  const colors = computed(() => ({
    background: isRef(props) ? props.value : name ? props[name] : null
  }));
  const {
    colorClasses: backgroundColorClasses,
    colorStyles: backgroundColorStyles
  } = useColor(colors);
  return { backgroundColorClasses, backgroundColorStyles };
}

const VARIANTS = ["contained", "outlined", "plain", "text", "contained-text", "contained-outlined"];
function genOverlays(isClickable, name) {
  return createVNode(Fragment, null, [isClickable && createVNode("div", {
    "aria-hidden": "true",
    "class": `${name}__overlay`
  }, null), createVNode("div", {
    "aria-hidden": "true",
    "class": `${name}__underlay`
  }, null), createVNode("div", {
    "aria-hidden": "true",
    "class": `${name}__border`
  }, null)]);
}
const makeVariantProps = propsFactory({
  /**
   * @zh 颜色
   */
  color: String,
  /**
   * @zh 文本颜色
   */
  textColor: String,
  /**
   * @zh 变体
   */
  variant: {
    type: String,
    default: "contained",
    validator: (v) => VARIANTS.includes(v)
  }
}, "variant");
function useVariant(props, name = getCurrentInstanceName()) {
  const variant = computed(() => {
    const {
      variant: variant2
    } = unref(props);
    return variant2;
  });
  const colors = computed(() => {
    const {
      textColor,
      color,
      variant: variant2
    } = unref(props);
    if (variant2 === "contained") {
      return {
        text: textColor,
        background: color
      };
    }
    return {
      text: color != null ? color : textColor
    };
  });
  const variantClasses = computed(() => {
    return [`${name}--variant-${variant.value}`];
  });
  const {
    colorClasses,
    colorStyles
  } = useColor(colors);
  return {
    colorClasses,
    colorStyles,
    variantClasses
  };
}

const POSITIONS = ["static", "relative", "fixed", "absolute", "sticky"];
const makePositionProps = propsFactory({
  /**
   * @zh 采用绝对定位
   */
  absolute: Boolean,
  /**
   * @zh 底部位置
   */
  bottom: [Boolean, Number, String],
  /**
   * @zh 采用固定定位
   */
  fixed: Boolean,
  /**
   * @zh 左侧位置
   */
  left: [Boolean, Number, String],
  /**
   * @zh 采用的定位模式
   */
  position: {
    type: String,
    validator: (
      /* istanbul ignore next */
      (v) => POSITIONS.includes(v)
    )
  },
  /**
   * @zh 右侧位置
   */
  right: [Boolean, Number, String],
  /**
   * @zh 顶部位置
   */
  top: [Boolean, Number, String]
}, "position");
function usePosition(props, name = getCurrentInstanceName()) {
  const targets = ["top", "right", "bottom", "left"];
  const positionClasses = computed(() => {
    const { fixed, absolute, position } = unref(props);
    if (fixed) {
      return `${name}--fixed`;
    } else if (absolute) {
      return `${name}--absolute`;
    } else if (position) {
      return `position-${position}`;
    }
    return null;
  });
  const positionStyles = computed(() => {
    const unrefedProps = unref(props);
    const styles = {};
    for (const target of targets) {
      const prop = unrefedProps[target];
      if (prop == null || prop === false)
        continue;
      styles[target] = convertToUnit(prop === true ? "0" : String(prop));
    }
    return styles;
  });
  return {
    positionClasses,
    positionStyles
  };
}

const makeDimensionProps = propsFactory({
  /**
   * @zh 高度
   */
  height: [Number, String],
  /**
   * @zh 最大高度
   */
  maxHeight: [Number, String],
  /**
   * @zh 最大宽度
   */
  maxWidth: [Number, String],
  /**
   * @zh 最小高度
   */
  minHeight: [Number, String],
  /**
   * @zh 最小宽度
   */
  minWidth: [Number, String],
  /**
   * @zh 宽度
   */
  width: [Number, String]
}, "dimension");
function useDimension(props) {
  return {
    dimensionStyles: computed(() => {
      const { height, maxHeight, maxWidth, minHeight, minWidth, width } = unref(props);
      return {
        height: convertToUnit(height),
        maxHeight: convertToUnit(maxHeight),
        maxWidth: convertToUnit(maxWidth),
        minHeight: convertToUnit(minHeight),
        minWidth: convertToUnit(minWidth),
        width: convertToUnit(width)
      };
    })
  };
}

const aliases$3 = {
  xs: "x-small",
  sm: "small",
  md: "medium",
  lg: "large",
  xl: "x-large"
};
const SIZES = [
  ...Object.keys(aliases$3),
  ...new Set(Object.values(aliases$3))
];
const makeSizeProps = propsFactory({
  /**
   * @zh 大小
   */
  size: {
    type: [String, Number],
    default: "medium"
  }
}, "size");
function useSize(props, name = getCurrentInstanceName()) {
  const sizeClasses = computed(() => {
    let { size } = unref(props);
    if (!name || !size || !SIZES.includes(size))
      return null;
    if (size in aliases$3)
      size = aliases$3[size];
    return `${name}--size-${size}`;
  });
  const sizeStyles = computed(() => {
    const { size } = unref(props);
    if (!size || SIZES.includes(size))
      return {};
    return {
      width: convertToUnit(size),
      height: convertToUnit(size)
    };
  });
  return {
    sizeClasses,
    sizeStyles
  };
}

const DENSITIES = ["ultra-low", "low", "medium", "high", "ultra-high"];
const makeDensityProps = propsFactory({
  density: {
    type: String,
    default: "medium",
    validator: (v) => DENSITIES.includes(v)
  }
}, "density");
function useDensity(props, name = getCurrentInstanceName()) {
  const densityClasses = computed(() => {
    const { density } = unref(props);
    if (!name || !density || !DENSITIES.includes(density))
      return null;
    return `${name}--density-${density}`;
  });
  return {
    densityClasses
  };
}

const makeBorderProps = propsFactory({
  border: [Boolean, Number, String]
}, "border");
function useBorder(props, name = getCurrentInstanceName()) {
  const borderClasses = computed(() => {
    const { border } = unref(props);
    const classes = [];
    if (border === true) {
      classes.push(`${name}--border`);
    } else if (typeof border === "string" && border !== "" || border === 0) {
      for (const value of String(border).split(" ")) {
        classes.push(`border-${value}`);
      }
    }
    return classes;
  });
  return {
    borderClasses
  };
}

const SHAPES = [
  "tile",
  "rounded-sm",
  "rounded",
  "rounded-lg",
  "pill",
  "circle"
];
const makeShapeProps = propsFactory({
  shape: {
    type: String,
    default: "tile"
  }
}, "shape");
function useShape(props, name = getCurrentInstanceName()) {
  const shapeClasses = computed(() => {
    const { shape } = unref(props);
    if (!shape || !SHAPES.includes(shape))
      return null;
    return `${name}--shape-${shape}`;
  });
  return {
    shapeClasses
  };
}

const makeElevationProps = propsFactory({
  elevation: {
    type: [Number, String],
    validator(v) {
      const value = parseInt(v);
      return !isNaN(value) && value >= 0 && value <= 24;
    }
  }
}, "elevation");
function useElevation(props, name = getCurrentInstanceName()) {
  const elevationClasses = computed(() => {
    const { elevation } = unref(props);
    const classes = [];
    if (elevation == null)
      return classes;
    classes.push(`${name}--elevation-${elevation}`);
    return classes;
  });
  return { elevationClasses };
}

var __defProp$1p = Object.defineProperty;
var __getOwnPropSymbols$1q = Object.getOwnPropertySymbols;
var __hasOwnProp$1q = Object.prototype.hasOwnProperty;
var __propIsEnum$1q = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1p = (obj, key, value) => key in obj ? __defProp$1p(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1p = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1q.call(b, prop))
      __defNormalProp$1p(a, prop, b[prop]);
  if (__getOwnPropSymbols$1q)
    for (var prop of __getOwnPropSymbols$1q(b)) {
      if (__propIsEnum$1q.call(b, prop))
        __defNormalProp$1p(a, prop, b[prop]);
    }
  return a;
};
const makePaperProps = propsFactory(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p(__spreadValues$1p({}, makeTagProps()), makeThemeProps()), makeVariantProps()), makePositionProps()), makeDimensionProps()), makeSizeProps()), makeDensityProps()), makeBorderProps()), makeShapeProps()), makeElevationProps()), "paper");
function usePaper(props, name = getCurrentInstanceName()) {
  const { themeClasses } = provideTheme(props);
  const { colorClasses, variantClasses, colorStyles } = useVariant(props, name);
  const { positionClasses, positionStyles } = usePosition(props, name);
  const { dimensionStyles } = useDimension(props);
  const { sizeClasses, sizeStyles } = useSize(props, name);
  const { densityClasses } = useDensity(props, name);
  const { borderClasses } = useBorder(props, name);
  const { shapeClasses } = useShape(props, name);
  const { elevationClasses } = useElevation(props, name);
  const paperClasses = computed(() => [
    themeClasses.value,
    colorClasses.value,
    variantClasses.value,
    positionClasses.value,
    sizeClasses.value,
    densityClasses.value,
    borderClasses.value,
    shapeClasses.value,
    elevationClasses.value
  ]);
  const paperStyles = computed(() => [
    colorStyles.value,
    positionStyles.value,
    dimensionStyles.value,
    sizeStyles.value
  ]);
  return {
    paperClasses,
    paperStyles
  };
}

function mounted$2(el, binding) {
  if (!SUPPORTS_INTERSECTION_OBSERVER)
    return;
  const modifiers = binding.modifiers || {};
  const value = binding.value;
  const { handler, options } = typeof value === "object" ? value : { handler: value, options: {} };
  const observer = new IntersectionObserver((entries = [], observer2) => {
    if (!el._intersect)
      return;
    const isIntersecting = entries.some((entry) => entry.isIntersecting);
    if (handler && (!modifiers.quiet || el._intersect.init) && (!modifiers.once || isIntersecting || !el._intersect.init)) {
      handler(isIntersecting, entries, observer2);
    }
    if (isIntersecting && modifiers.once) {
      unmounted$2(el);
    } else {
      el._intersect.init = true;
    }
  }, options);
  el._intersect = { init: false, observer };
  observer.observe(el);
}
function unmounted$2(el) {
  if (!el._intersect)
    return;
  el._intersect.observer.unobserve(el);
  delete el._intersect;
}
const Intersect = {
  mounted: mounted$2,
  unmounted: unmounted$2
};

function defaultConditional() {
  return true;
}
function checkEvent(e, el, binding) {
  if (!e || checkIsActive(e, binding) === false)
    return false;
  const root = attachedRoot(el);
  if (root instanceof ShadowRoot && root.host === e.target)
    return false;
  const elements = (typeof binding.value === "object" && binding.value.include || (() => []))();
  elements.push(el);
  return !elements.some((el2) => el2 == null ? void 0 : el2.contains(e.target));
}
function checkIsActive(e, binding) {
  const isActive = typeof binding.value === "object" && binding.value.closeConditional || defaultConditional;
  return isActive(e);
}
function directive(e, el, binding) {
  const handler = typeof binding.value === "function" ? binding.value : binding.value.handler;
  el._clickOutside.lastMousedownWasOutside && checkEvent(e, el, binding) && setTimeout(() => {
    checkIsActive(e, binding) && handler && handler(e);
  }, 0);
}
function handleShadow(el, callback) {
  const root = attachedRoot(el);
  callback(document.body);
  if (root instanceof ShadowRoot) {
    callback(root);
  }
}
const ClickOutside = {
  // [data-app] may not be found
  // if using bind, inserted makes
  // sure that the root element is
  // available, iOS does not support
  // clicks on body
  mounted(el, binding) {
    const onClick = (e) => directive(e, el, binding);
    const onMousedown = (e) => {
      el._clickOutside.lastMousedownWasOutside = checkEvent(e, el, binding);
    };
    handleShadow(el, (app) => {
      app.addEventListener("click", onClick, true);
      app.addEventListener("mousedown", onMousedown, true);
    });
    el._clickOutside = {
      lastMousedownWasOutside: true,
      onClick,
      onMousedown
    };
  },
  unmounted(el) {
    if (!el._clickOutside)
      return;
    handleShadow(el, (app) => {
      if (!app || !el._clickOutside)
        return;
      app.removeEventListener("click", el._clickOutside.onClick, true);
      app.removeEventListener("mousedown", el._clickOutside.onMousedown, true);
    });
    delete el._clickOutside;
  }
};

function mounted$1(el, binding) {
  var _a, _b;
  const handler = binding.value;
  const options = {
    passive: !((_a = binding.modifiers) == null ? void 0 : _a.active)
  };
  window.addEventListener("resize", handler, options);
  el._onResize = {
    handler,
    options
  };
  if (!((_b = binding.modifiers) == null ? void 0 : _b.quiet)) {
    handler();
  }
}
function unmounted$1(el) {
  if (!el._onResize)
    return;
  const { handler, options } = el._onResize;
  window.removeEventListener("resize", handler, options);
  delete el._onResize;
}
const Resize = {
  mounted: mounted$1,
  unmounted: unmounted$1
};

const rippleStop = Symbol("rippleStop");
const DELAY_RIPPLE = 80;
function transform(el, value) {
  el.style.transform = value;
  el.style.webkitTransform = value;
}
function opacity(el, value) {
  el.style.opacity = `calc(${value} * var(--ve-theme-overlay-multiplier, 1))`;
}
function isTouchEvent(e) {
  return e.constructor.name === "TouchEvent";
}
function isKeyboardEvent(e) {
  return e.constructor.name === "KeyboardEvent";
}
const calculate = (e, el, value = {}) => {
  var _a;
  let localX = 0;
  let localY = 0;
  if (!isKeyboardEvent(e)) {
    const offset = el.getBoundingClientRect();
    const target = isTouchEvent(e) ? e.touches[e.touches.length - 1] : e;
    localX = target.clientX - offset.left;
    localY = target.clientY - offset.top;
  }
  let radius = 0;
  let scale = 0.3;
  if ((_a = el._ripple) == null ? void 0 : _a.circle) {
    scale = 0.15;
    radius = el.clientWidth / 2;
    radius = value.center ? radius : radius + Math.sqrt((localX - radius) ** 2 + (localY - radius) ** 2) / 4;
  } else {
    radius = Math.sqrt(el.clientWidth ** 2 + el.clientHeight ** 2) / 2;
  }
  const centerX = `${(el.clientWidth - radius * 2) / 2}px`;
  const centerY = `${(el.clientHeight - radius * 2) / 2}px`;
  const x = value.center ? centerX : `${localX - radius}px`;
  const y = value.center ? centerY : `${localY - radius}px`;
  return { radius, scale, x, y, centerX, centerY };
};
const ripples = {
  /* eslint-disable max-statements */
  show(e, el, value = {}) {
    var _a;
    if (!((_a = el == null ? void 0 : el._ripple) == null ? void 0 : _a.enabled)) {
      return;
    }
    const container = document.createElement("span");
    const animation = document.createElement("span");
    container.appendChild(animation);
    container.className = "ve-ripple__container";
    if (value.class) {
      container.className += ` ${value.class}`;
    }
    const { radius, scale, x, y, centerX, centerY } = calculate(e, el, value);
    const size = `${radius * 2}px`;
    animation.className = "ve-ripple__animation";
    animation.style.width = size;
    animation.style.height = size;
    el.appendChild(container);
    const computed = window.getComputedStyle(el);
    if (computed && computed.position === "static") {
      el.style.position = "relative";
      el.dataset.previousPosition = "static";
    }
    animation.classList.add("ve-ripple__animation--enter");
    animation.classList.add("ve-ripple__animation--visible");
    transform(animation, `translate(${x}, ${y}) scale3d(${scale},${scale},${scale})`);
    opacity(animation, 0);
    animation.dataset.activated = String(performance.now());
    setTimeout(() => {
      animation.classList.remove("ve-ripple__animation--enter");
      animation.classList.add("ve-ripple__animation--in");
      transform(animation, `translate(${centerX}, ${centerY}) scale3d(1,1,1)`);
      opacity(animation, 0.08);
    }, 0);
  },
  hide(el) {
    var _a;
    if (!((_a = el == null ? void 0 : el._ripple) == null ? void 0 : _a.enabled))
      return;
    const ripples2 = el.getElementsByClassName("ve-ripple__animation");
    if (ripples2.length === 0)
      return;
    const animation = ripples2[ripples2.length - 1];
    if (animation.dataset.isHiding)
      return;
    else
      animation.dataset.isHiding = "true";
    const diff = performance.now() - Number(animation.dataset.activated);
    const delay = Math.max(250 - diff, 0);
    setTimeout(() => {
      animation.classList.remove("ve-ripple__animation--in");
      animation.classList.add("ve-ripple__animation--out");
      opacity(animation, 0);
      setTimeout(() => {
        const ripples3 = el.getElementsByClassName("ve-ripple__animation");
        if (ripples3.length === 1 && el.dataset.previousPosition) {
          el.style.position = el.dataset.previousPosition;
          delete el.dataset.previousPosition;
        }
        animation.parentNode && el.removeChild(animation.parentNode);
      }, 300);
    }, delay);
  }
};
function isRippleEnabled(value) {
  return typeof value === "undefined" || !!value;
}
function rippleShow(e) {
  const value = {};
  const element = e.currentTarget;
  if (!(element == null ? void 0 : element._ripple) || element._ripple.touched || e[rippleStop])
    return;
  e[rippleStop] = true;
  if (isTouchEvent(e)) {
    element._ripple.touched = true;
    element._ripple.isTouch = true;
  } else {
    if (element._ripple.isTouch)
      return;
  }
  value.center = element._ripple.centered || isKeyboardEvent(e);
  if (element._ripple.class) {
    value.class = element._ripple.class;
  }
  if (isTouchEvent(e)) {
    if (element._ripple.showTimerCommit)
      return;
    element._ripple.showTimerCommit = () => {
      ripples.show(e, element, value);
    };
    element._ripple.showTimer = window.setTimeout(() => {
      var _a;
      if ((_a = element == null ? void 0 : element._ripple) == null ? void 0 : _a.showTimerCommit) {
        element._ripple.showTimerCommit();
        element._ripple.showTimerCommit = null;
      }
    }, DELAY_RIPPLE);
  } else {
    ripples.show(e, element, value);
  }
}
function rippleHide(e) {
  const element = e.currentTarget;
  if (!element || !element._ripple)
    return;
  window.clearTimeout(element._ripple.showTimer);
  if (e.type === "touchend" && element._ripple.showTimerCommit) {
    element._ripple.showTimerCommit();
    element._ripple.showTimerCommit = null;
    element._ripple.showTimer = window.setTimeout(() => {
      rippleHide(e);
    });
    return;
  }
  window.setTimeout(() => {
    if (element._ripple) {
      element._ripple.touched = false;
    }
  });
  ripples.hide(element);
}
function rippleCancelShow(e) {
  const element = e.currentTarget;
  if (!element || !element._ripple)
    return;
  if (element._ripple.showTimerCommit) {
    element._ripple.showTimerCommit = null;
  }
  window.clearTimeout(element._ripple.showTimer);
}
let keyboardRipple = false;
function keyboardRippleShow(e) {
  if (!keyboardRipple && (e.keyCode === keyCodes.enter || e.keyCode === keyCodes.space)) {
    keyboardRipple = true;
    rippleShow(e);
  }
}
function keyboardRippleHide(e) {
  keyboardRipple = false;
  rippleHide(e);
}
function focusRippleHide(e) {
  if (keyboardRipple) {
    keyboardRipple = false;
    rippleHide(e);
  }
}
function updateRipple(el, binding, wasEnabled) {
  var _a;
  const { value, modifiers } = binding;
  const enabled = isRippleEnabled(value);
  if (!enabled) {
    ripples.hide(el);
  }
  el._ripple = (_a = el._ripple) != null ? _a : {};
  el._ripple.enabled = enabled;
  el._ripple.centered = modifiers.center;
  el._ripple.circle = modifiers.circle;
  if (isObject(value) && value.class) {
    el._ripple.class = value.class;
  }
  if (enabled && !wasEnabled) {
    el.addEventListener("touchstart", rippleShow, { passive: true });
    el.addEventListener("touchend", rippleHide, { passive: true });
    el.addEventListener("touchmove", rippleCancelShow, { passive: true });
    el.addEventListener("touchcancel", rippleHide);
    el.addEventListener("mousedown", rippleShow);
    el.addEventListener("mouseup", rippleHide);
    el.addEventListener("mouseleave", rippleHide);
    el.addEventListener("keydown", keyboardRippleShow);
    el.addEventListener("keyup", keyboardRippleHide);
    el.addEventListener("blur", focusRippleHide);
    el.addEventListener("dragstart", rippleHide, { passive: true });
  } else if (!enabled && wasEnabled) {
    removeListeners(el);
  }
}
function removeListeners(el) {
  el.removeEventListener("mousedown", rippleShow);
  el.removeEventListener("touchstart", rippleShow);
  el.removeEventListener("touchend", rippleHide);
  el.removeEventListener("touchmove", rippleCancelShow);
  el.removeEventListener("touchcancel", rippleHide);
  el.removeEventListener("mouseup", rippleHide);
  el.removeEventListener("mouseleave", rippleHide);
  el.removeEventListener("keydown", keyboardRippleShow);
  el.removeEventListener("keyup", keyboardRippleHide);
  el.removeEventListener("dragstart", rippleHide);
  el.removeEventListener("blur", focusRippleHide);
}
function mounted(el, binding) {
  updateRipple(el, binding, false);
}
function unmounted(el) {
  delete el._ripple;
  removeListeners(el);
}
function updated(el, binding) {
  if (binding.value === binding.oldValue) {
    return;
  }
  const wasEnabled = isRippleEnabled(binding.oldValue);
  updateRipple(el, binding, wasEnabled);
}
const Ripple = {
  mounted,
  unmounted,
  updated
};

var directives = /*#__PURE__*/Object.freeze({
  __proto__: null,
  ClickOutside: ClickOutside,
  Intersect: Intersect,
  Resize: Resize,
  Ripple: Ripple
});

var __defProp$1o = Object.defineProperty;
var __getOwnPropSymbols$1p = Object.getOwnPropertySymbols;
var __hasOwnProp$1p = Object.prototype.hasOwnProperty;
var __propIsEnum$1p = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1o = (obj, key, value) => key in obj ? __defProp$1o(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1o = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1p.call(b, prop))
      __defNormalProp$1o(a, prop, b[prop]);
  if (__getOwnPropSymbols$1p)
    for (var prop of __getOwnPropSymbols$1p(b)) {
      if (__propIsEnum$1p.call(b, prop))
        __defNormalProp$1o(a, prop, b[prop]);
    }
  return a;
};
function useAspectStyles(props) {
  return {
    aspectStyles: computed(() => {
      const ratio = Number(props.aspectRatio);
      return ratio ? {
        paddingBottom: `${String(1 / ratio * 100)}%`
      } : void 0;
    })
  };
}
const Responsive = genericComponent()({
  name: "VeResponsive",
  props: __spreadValues$1o({
    aspectRatio: [String, Number],
    contentClass: String
  }, makeDimensionProps()),
  setup(props, {
    slots
  }) {
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      aspectStyles
    } = useAspectStyles(props);
    return () => {
      var _a;
      return createVNode("div", {
        "class": "ve-responsive",
        "style": dimensionStyles.value
      }, [createVNode("div", {
        "class": "ve-responsive__sizer",
        "style": aspectStyles.value
      }, null), (_a = slots.additional) == null ? void 0 : _a.call(slots), slots.default && createVNode("div", {
        "class": ["ve-responsive__content", props.contentClass]
      }, [slots.default()])]);
    };
  }
});

var __defProp$1n = Object.defineProperty;
var __getOwnPropSymbols$1o = Object.getOwnPropertySymbols;
var __hasOwnProp$1o = Object.prototype.hasOwnProperty;
var __propIsEnum$1o = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1n = (obj, key, value) => key in obj ? __defProp$1n(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1n = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1o.call(b, prop))
      __defNormalProp$1n(a, prop, b[prop]);
  if (__getOwnPropSymbols$1o)
    for (var prop of __getOwnPropSymbols$1o(b)) {
      if (__propIsEnum$1o.call(b, prop))
        __defNormalProp$1n(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$c(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Image = /* @__PURE__ */ defineComponent$1({
  name: "VeImage",
  props: __spreadValues$1n({
    /**
     * @zh 纵横比
     */
    aspectRatio: [String, Number],
    /**
     * @zh alt
     */
    alt: String,
    /**
     * @zh object-fit: cover
     */
    cover: Boolean,
    /**
     * @zh 立即加载
     */
    eager: Boolean,
    /**
     * @zh 渐变
     */
    gradient: String,
    /**
     * @zh 懒加载 src
     */
    lazySrc: String,
    /**
     * @zh IntersectionObserverInit
     */
    options: {
      type: Object,
      // For more information on types, navigate to:
      // https://developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API
      default: () => ({
        root: void 0,
        rootMargin: void 0,
        threshold: void 0
      })
    },
    /**
     * @zh sizes
     */
    sizes: String,
    /**
     * @zh src
     */
    src: String,
    /**
     * @zh srcset
     */
    srcset: String,
    /**
     * @zh 宽度
     */
    width: [String, Number]
  }, makeTransitionProps()),
  emits: {
    loadstart: (_src, _image) => true,
    load: (_src, _image) => true,
    error: (_src, _image) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    const currentSrc = ref("");
    const image = ref();
    const state = ref(props.eager ? "loading" : "idle");
    const naturalWidth = ref();
    const naturalHeight = ref();
    const aspectRatio = computed(() => {
      return Number(props.aspectRatio || 0) || naturalWidth.value / naturalHeight.value || 0;
    });
    watch(() => props.src, () => {
      init(state.value !== "idle");
    });
    onBeforeMount(() => init());
    function init(isIntersecting) {
      if (props.eager && isIntersecting)
        return;
      if (SUPPORTS_INTERSECTION_OBSERVER && !isIntersecting && !props.eager)
        return;
      state.value = "loading";
      if (props.lazySrc && IN_BROWSER) {
        const lazyImg = new window.Image();
        lazyImg.src = props.lazySrc;
        pollForSize(lazyImg, null);
      }
      if (!props.src)
        return;
      nextTick(() => {
        var _a, _b;
        emit("loadstart", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
        if ((_b = image.value) == null ? void 0 : _b.complete) {
          if (!image.value.naturalWidth)
            onError();
          if (state.value === "error")
            return;
          if (!aspectRatio.value)
            pollForSize(image.value, null);
          onLoad();
        } else {
          if (!aspectRatio.value)
            pollForSize(image.value);
          getSrc();
        }
      });
    }
    function onLoad() {
      var _a;
      getSrc();
      state.value = "loaded";
      emit("load", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
    }
    function onError() {
      var _a;
      state.value = "error";
      emit("error", ((_a = image.value) == null ? void 0 : _a.currentSrc) || props.src, image.value);
    }
    function getSrc() {
      const img = image.value;
      if (img)
        currentSrc.value = img.currentSrc || img.src;
    }
    function pollForSize(img, timeout = 100) {
      const poll = () => {
        const {
          naturalHeight: imgHeight,
          naturalWidth: imgWidth
        } = img;
        if (imgHeight || imgWidth) {
          naturalWidth.value = imgWidth;
          naturalHeight.value = imgHeight;
        } else if (!img.complete && state.value === "loading" && timeout != null) {
          setTimeout(poll, timeout);
        } else if (img.currentSrc.endsWith(".svg") || img.currentSrc.startsWith("data:image/svg+xml")) {
          naturalWidth.value = 1;
          naturalHeight.value = 1;
        }
      };
      poll();
    }
    const containClasses = computed(() => ({
      "ve-image__img--cover": props.cover,
      "ve-image__img--contain": !props.cover
    }));
    const __image = computed(() => {
      var _a;
      let _slot;
      if (!props.src || state.value === "idle")
        return;
      const img = h("img", {
        class: ["ve-image__img", containClasses.value],
        src: props.src,
        srcset: props.srcset,
        sizes: props.sizes,
        ref: image,
        onLoad,
        onError
      });
      const sources = (_a = slots.sources) == null ? void 0 : _a.call(slots);
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, _isSlot$c(_slot = withDirectives(sources ? createVNode("picture", {
        "class": "ve-image__picture"
      }, [sources, img]) : img, [[vShow, state.value === "loaded"]])) ? _slot : {
        default: () => [_slot]
      });
    });
    const __preloadImage = computed(() => createVNode(MaybeTransition, {
      "transition": props.transition
    }, {
      default: () => [props.lazySrc && state.value !== "loaded" && createVNode("img", {
        "class": ["ve-image__img", "ve-image__img--preload", containClasses.value],
        "src": props.lazySrc,
        "alt": ""
      }, null)]
    }));
    const __placeholder = computed(() => {
      if (!slots.placeholder)
        return;
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, {
        default: () => [(state.value === "loading" || state.value === "error" && !slots.error) && createVNode("div", {
          "class": "ve-image__placeholder"
        }, [slots.placeholder()])]
      });
    });
    const __error = computed(() => {
      if (!slots.error)
        return;
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, {
        default: () => [state.value === "error" && createVNode("div", {
          "class": "ve-image__error"
        }, [slots.error()])]
      });
    });
    const __gradient = computed(() => {
      if (!props.gradient)
        return;
      return createVNode("div", {
        "class": "ve-image__gradient",
        "style": {
          backgroundImage: `linear-gradient(${props.gradient})`
        }
      }, null);
    });
    const isBooted = ref(false);
    {
      const stop = watch(aspectRatio, (val) => {
        if (val) {
          requestAnimationFrame(() => {
            requestAnimationFrame(() => {
              isBooted.value = true;
            });
          });
          stop();
        }
      });
    }
    useRender(() => withDirectives(createVNode(Responsive, {
      "class": ["ve-image", {
        "ve-image--booting": !isBooted.value
      }],
      "style": {
        width: convertToUnit(props.width === "auto" ? naturalWidth.value : props.width)
      },
      "aspectRatio": aspectRatio.value,
      "aria-label": props.alt,
      "role": props.alt ? "img" : void 0
    }, {
      additional: () => [__image.value, __preloadImage.value, __gradient.value, __placeholder.value, __error.value],
      default: slots.default
    }), [[resolveDirective("intersect"), {
      handler: init,
      options: props.options
    }, null, {
      once: true
    }]]));
    return {
      currentSrc,
      image,
      state,
      naturalWidth,
      naturalHeight
    };
  }
});

const makeIconProps = propsFactory({
  /**
   * @zh 图标值
   */
  icon: [String, Object, Function],
  /**
   * @zh 指定在根元素上使用的自定义标签
   */
  tag: {
    type: String,
    default: "i"
  }
}, "icon");
const makeIconSetProps = propsFactory({
  /**
   * @zh 图标值
   */
  icon: {
    type: [String, Object, Function],
    required: true
  },
  /**
   * @zh 指定在根元素上使用的自定义标签
   */
  tag: {
    type: String,
    required: true
  }
}, "icon-set");

const IconClass = /* @__PURE__ */ defineComponent({
  name: "VeIconClass",
  props: makeIconSetProps(),
  setup(props) {
    return () => {
      return createVNode(props.tag, {
        "class": props.icon
      }, null);
    };
  }
});

var __defProp$1m = Object.defineProperty;
var __defProps$s = Object.defineProperties;
var __getOwnPropDescs$s = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1n = Object.getOwnPropertySymbols;
var __hasOwnProp$1n = Object.prototype.hasOwnProperty;
var __propIsEnum$1n = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1m = (obj, key, value) => key in obj ? __defProp$1m(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1m = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1n.call(b, prop))
      __defNormalProp$1m(a, prop, b[prop]);
  if (__getOwnPropSymbols$1n)
    for (var prop of __getOwnPropSymbols$1n(b)) {
      if (__propIsEnum$1n.call(b, prop))
        __defNormalProp$1m(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$s = (a, b) => __defProps$s(a, __getOwnPropDescs$s(b));
const mdi = (props) => h(IconClass, __spreadProps$s(__spreadValues$1m({}, props), { class: "mdi" }));
const aliases$2 = {
  checkboxIndeterminate: "svg:M17,13H7V11H17M19,3H5C3.89,3 3,3.89 3,5V19C3,20.1 3.9,21 5,21H19C20.1,21 21,20.1 21,19V5C21,3.89 20.1,3 19,3Z",
  checkboxOn: "svg:M10,17L5,12L6.41,10.58L10,14.17L17.59,6.58L19,8M19,3H5C3.89,3 3,3.89 3,5V19C3,20.1 3.9,21 5,21H19C20.1,21 21,20.1 21,19V5C21,3.89 20.1,3 19,3Z",
  checkboxOff: "svg:M19,3H5C3.89,3 3,3.89 3,5V19C3,20.1 3.9,21 5,21H19C20.1,21 21,20.1 21,19V5C21,3.89 20.1,3 19,3M19,5V19H5V5H19Z",
  close: "svg:M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z",
  clear: "svg:M12,2C17.53,2 22,6.47 22,12C22,17.53 17.53,22 12,22C6.47,22 2,17.53 2,12C2,6.47 6.47,2 12,2M15.59,7L12,10.59L8.41,7L7,8.41L10.59,12L7,15.59L8.41,17L12,13.41L15.59,17L17,15.59L13.41,12L17,8.41L15.59,7Z",
  collapse: "svg:M7.41,15.41L12,10.83L16.59,15.41L18,14L12,8L6,14L7.41,15.41Z",
  calendar: "svg:M19,4H18V2H16V4H8V2H6V4H5C3.89,4 3,4.9 3,6V20A2,2 0 0,0 5,22H19A2,2 0 0,0 21,20V6A2,2 0 0,0 19,4M19,20H5V10H19V20M19,8H5V6H19V8Z",
  dropdown: "svg:M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58Z",
  error: "svg:M12 2c5.53 0 10 4.47 10 10s-4.47 10-10 10S2 17.53 2 12S6.47 2 12 2m3.59 5L12 10.59L8.41 7L7 8.41L10.59 12L7 15.59L8.41 17L12 13.41L15.59 17L17 15.59L13.41 12L17 8.41L15.59 7Z",
  expand: "svg:M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58Z",
  filter: "svg:M6,13H18V11H6M3,6V8H21V6M10,18H14V16H10V18Z",
  first: "svg:M18.41,16.59L13.82,12L18.41,7.41L17,6L11,12L17,18L18.41,16.59M6,6H8V18H6V6Z",
  info: "svg:M13,9H11V7H13M13,17H11V11H13M12,2C6.48,2 2,6.48 2,12C2,17.52 6.48,22 12,22C17.52,22 22,17.52 22,12C22,6.48 17.52,2 12,2Z",
  last: "svg:M5.59,7.41L10.18,12L5.59,16.59L7,18L13,12L7,6L5.59,7.41M16,6H18V18H16V6Z",
  link: "svg:M3.9,12C3.9,10.29 5.29,8.9 7,8.9H11V7H7A5,5 0 0,0 2,12A5,5 0 0,0 7,17H11V15.1H7C5.29,15.1 3.9,13.71 3.9,12M8,13H16V11H8V13M17,7H13V8.9H17C18.71,8.9 20.1,10.29 20.1,12C20.1,13.71 18.71,15.1 17,15.1H13V17H17A5,5 0 0,0 22,12A5,5 0 0,0 17,7Z",
  menu: "svg:M3,6H21V8H3V6M3,11H21V13H3V11M3,16H21V18H3V16Z",
  next: "svg:M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z",
  nextDouble: "svg:M5.59,7.41L7,6L13,12L7,18L5.59,16.59L10.17,12L5.59,7.41M11.59,7.41L13,6L19,12L13,18L11.59,16.59L16.17,12L11.59,7.41Z",
  nodata: "svg:M2.39 1.73L1.11 3L4.21 6.1C4.08 6.39 4 6.69 4 7V17C4 19.21 7.59 21 12 21C14.3 21 16.38 20.5 17.84 19.73L20.84 22.73L22.11 21.46L2.39 1.73M6 9.64C6.76 10.07 7.7 10.42 8.76 10.65L12.11 14C12.07 14 12.04 14 12 14C9.58 14 7.3 13.4 6 12.45V9.64M12 19C8.13 19 6 17.5 6 17V14.77C7.61 15.55 9.72 16 12 16C12.68 16 13.34 15.95 14 15.87L16.34 18.23C15.33 18.65 13.87 19 12 19M8.64 5.44L7.06 3.86C8.42 3.33 10.13 3 12 3C16.42 3 20 4.79 20 7V16.8L18 14.8V14.77L18 14.78L16.45 13.25C17.05 13.03 17.58 12.76 18 12.45V9.64C16.97 10.22 15.61 10.65 14.06 10.86L12.19 9C15.94 8.94 18 7.5 18 7C18 6.5 15.87 5 12 5C10.66 5 9.54 5.18 8.64 5.44Z",
  prev: "svg:M15.41,16.58L10.83,12L15.41,7.41L14,6L8,12L14,18L15.41,16.58Z",
  prevDouble: "svg:M18.41,7.41L17,6L11,12L17,18L18.41,16.59L13.83,12L18.41,7.41M12.41,7.41L11,6L5,12L11,18L12.41,16.59L7.83,12L12.41,7.41Z",
  radioOn: "svg:M12,20C7.58,20 4,16.42 4,12C4,7.58 7.58,4 12,4C16.42,4 20,7.58 20,12C20,16.42 16.42,20 12,20M12,2C6.48,2 2,6.48 2,12C2,17.52 6.48,22 12,22C17.52,22 22,17.52 22,12C22,6.48 17.52,2 12,2M12,7C9.24,7 7,9.24 7,12C7,14.76 9.24,17 12,17C14.76,17 17,14.76 17,12C17,9.24 14.76,7 12,7Z",
  radioOff: "svg:M12,20C7.58,20 4,16.42 4,12C4,7.58 7.58,4 12,4C16.42,4 20,7.58 20,12C20,16.42 16.42,20 12,20M12,2C6.48,2 2,6.48 2,12C2,17.52 6.48,22 12,22C17.52,22 22,17.52 22,12C22,6.48 17.52,2 12,2Z",
  separator: "svg:M7 21L14.9 3H17L9.1 21H7Z",
  sort: "svg:M13,20H11V8L5.5,13.5L4.08,12.08L12,4.16L19.92,12.08L18.5,13.5L13,8V20Z",
  success: "svg:M12,2C17.52,2 22,6.48 22,12C22,17.52 17.52,22 12,22C6.48,22 2,17.52 2,12C2,6.48 6.48,2 12,2M11,16.5L18,9.5L16.59,8.09L11,13.67L7.91,10.59L6.5,12L11,16.5Z",
  toggler: "svg:M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z",
  warning: "svg:M13 13h-2V7h2m0 10h-2v-2h2M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10a10 10 0 0 0 10-10A10 10 0 0 0 12 2Z"
};

var __defProp$1l = Object.defineProperty;
var __getOwnPropSymbols$1m = Object.getOwnPropertySymbols;
var __hasOwnProp$1m = Object.prototype.hasOwnProperty;
var __propIsEnum$1m = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1l = (obj, key, value) => key in obj ? __defProp$1l(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1l = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1m.call(b, prop))
      __defNormalProp$1l(a, prop, b[prop]);
  if (__getOwnPropSymbols$1m)
    for (var prop of __getOwnPropSymbols$1m(b)) {
      if (__propIsEnum$1m.call(b, prop))
        __defNormalProp$1l(a, prop, b[prop]);
    }
  return a;
};
const IconSvg = /* @__PURE__ */ defineComponent({
  name: "VeIconSvg",
  props: __spreadValues$1l({
    viewBox: {
      type: String,
      default: "0 0 24 24"
    }
  }, makeIconSetProps()),
  setup(props) {
    return () => {
      const isString = typeof props.icon === "string";
      return createVNode(props.tag, null, {
        default: () => [isString ? createVNode("svg", {
          "xmlns": "http://www.w3.org/2000/svg",
          "viewBox": props.viewBox,
          "role": "img",
          "aria-hidden": "true"
        }, [createVNode("path", {
          "d": props.icon
        }, null)]) : createVNode(props.icon, {
          "role": "img",
          "aria-hidden": "true"
        }, null)]
      });
    };
  }
});

const IconLigature = /* @__PURE__ */ defineComponent({
  name: "VeIconLigature",
  props: makeIconSetProps(),
  setup(props) {
    return () => {
      return createVNode(props.tag, null, {
        default: () => [props.icon]
      });
    };
  }
});

const IconsKey = createSymbol("icons");
function useIcons() {
  const icons = inject(IconsKey);
  if (!icons)
    throw new Error("[VenoUi] Could not find icons instance");
  return icons;
}
function createIcons(options) {
  return deepMerge({
    defaultSet: "mdi",
    sets: {
      mdi,
      svg: IconSvg,
      class: IconClass,
      ligature: IconLigature
    },
    aliases: aliases$2
  }, options || {});
}

const IconComponent = /* @__PURE__ */ defineComponent({
  name: "VeIconComponent",
  props: makeIconSetProps(),
  setup(props) {
    return () => {
      return createVNode(props.tag, null, {
        default: () => [createVNode(props.icon, {
          "role": "img",
          "aria-hidden": "true"
        }, null)]
      });
    };
  }
});

const useIcon = (props) => {
  const icons = useIcons();
  const iconData = computed(() => {
    var _a;
    const { icon: value } = unref(props);
    if (!value) {
      consoleError("Icon value is undefined or null");
      return;
    }
    const icon = typeof value === "string" && value.includes("$") ? (_a = icons.aliases) == null ? void 0 : _a[value.slice(value.indexOf("$") + 1)] : value;
    if (!icon) {
      consoleError(`Could not find aliased icon "${value}"`);
      return;
    }
    if (typeof icon !== "string")
      return { component: IconComponent, icon };
    const setName = Object.keys(icons.sets).find((v) => icon.startsWith(`${v}:`));
    return {
      component: icons.sets[setName != null ? setName : icons.defaultSet],
      icon: setName ? icon.slice(setName.length + 1) : icon
    };
  });
  return { iconData };
};

var __defProp$1k = Object.defineProperty;
var __getOwnPropSymbols$1l = Object.getOwnPropertySymbols;
var __hasOwnProp$1l = Object.prototype.hasOwnProperty;
var __propIsEnum$1l = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1k = (obj, key, value) => key in obj ? __defProp$1k(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1k = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1l.call(b, prop))
      __defNormalProp$1k(a, prop, b[prop]);
  if (__getOwnPropSymbols$1l)
    for (var prop of __getOwnPropSymbols$1l(b)) {
      if (__propIsEnum$1l.call(b, prop))
        __defNormalProp$1k(a, prop, b[prop]);
    }
  return a;
};
const Icon = /* @__PURE__ */ defineComponent$1({
  name: "VeIcon",
  props: __spreadValues$1k(__spreadValues$1k({
    /**
     * @zh 图标颜色
     */
    color: String,
    /**
     * @zh 是否在左侧
     */
    start: Boolean,
    /**
     * @zh 是否在右侧
     */
    end: Boolean
  }, makeSizeProps()), makeIconProps()),
  setup(props, {
    slots
  }) {
    const {
      iconData
    } = useIcon(computed(() => {
      var _a, _b;
      if (!slots.default)
        return props;
      const slot = (_a = slots.default) == null ? void 0 : _a.call(slots);
      if (!slot)
        return props;
      const nodes = flattenFragments(slot);
      if (typeof ((_b = nodes == null ? void 0 : nodes[0]) == null ? void 0 : _b.children) === "string") {
        return {
          tag: props.tag,
          icon: nodes[0].children
        };
      }
      return {
        tag: props.tag,
        icon: () => slot
      };
    }));
    const {
      sizeClasses
    } = useSize(props);
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(toRef(props, "color"));
    return () => {
      if (!iconData.value)
        return;
      return createVNode(iconData.value.component, {
        "tag": props.tag,
        "icon": iconData.value.icon,
        "class": ["ve-icon", "notranslate", sizeClasses.value, textColorClasses.value, {
          "ve-icon--start": props.start,
          "ve-icon--end": props.end
        }],
        "style": [!sizeClasses.value ? {
          fontSize: convertToUnit(props.size),
          width: convertToUnit(props.size),
          height: convertToUnit(props.size)
        } : void 0, textColorStyles.value],
        "aria-hidden": "true"
      }, null);
    };
  }
});

var __defProp$1j = Object.defineProperty;
var __getOwnPropSymbols$1k = Object.getOwnPropertySymbols;
var __hasOwnProp$1k = Object.prototype.hasOwnProperty;
var __propIsEnum$1k = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1j = (obj, key, value) => key in obj ? __defProp$1j(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1j = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1k.call(b, prop))
      __defNormalProp$1j(a, prop, b[prop]);
  if (__getOwnPropSymbols$1k)
    for (var prop of __getOwnPropSymbols$1k(b)) {
      if (__propIsEnum$1k.call(b, prop))
        __defNormalProp$1j(a, prop, b[prop]);
    }
  return a;
};
const RADIX = 0.8;
const makeAvatarProps = propsFactory(__spreadValues$1j({
  /**
   * @zh 是否在左侧
   */
  start: Boolean,
  /**
   * @zh 是否在右侧
   */
  end: Boolean,
  /**
   * @zh 图像
   */
  image: String,
  /**
   * @zh 图标
   */
  icon: [String, Object],
  /**
   * @zh 文本
   */
  text: String,
  /**
   * @zh 可点击
   */
  link: Boolean
}, makePaperProps({
  color: "secondary",
  shape: "circle"
})), "avatar");
const Avatar = /* @__PURE__ */ defineComponent({
  name: "VeAvatar",
  directives: {
    Resize
  },
  props: makeAvatarProps(),
  setup(props, {
    slots,
    attrs
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const rootRef = ref();
    const contentRef = ref();
    function onResize() {
      nextTick(() => {
        if (!rootRef.value || !contentRef.value)
          return;
        const ratio = Math.min(rootRef.value.offsetWidth / contentRef.value.offsetWidth * RADIX, rootRef.value.offsetHeight / contentRef.value.offsetHeight * RADIX, 1);
        contentRef.value.style.transform = `translateX(-50%) translateY(-50%) scale(${ratio})`;
      });
    }
    watch(toRef(props, "text"), onResize);
    return () => {
      const hasImage = !!props.image;
      const hasIcon = !!props.icon;
      const hasText = !!props.text;
      const isClickable = props.link || !!(attrs.onClick || attrs.onClickOnce);
      return withDirectives(createVNode(props.tag, {
        "class": ["ve-avatar", {
          "ve-avatar--start": props.start,
          "ve-avatar--end": props.end,
          "ve-avatar--icon": props.icon,
          "ve-avatar--link": isClickable
        }, paperClasses.value],
        "style": paperStyles.value,
        "ref": rootRef
      }, {
        default: () => {
          var _a;
          return [hasImage && createVNode(Image, {
            "src": props.image,
            "alt": ""
          }, null), hasIcon && !hasImage && createVNode(Icon, {
            "icon": props.icon,
            "size": props.size
          }, null), hasText && !hasIcon && !hasImage && createVNode("span", {
            "class": "ve-avatar__wrapper",
            "ref": contentRef
          }, [props.text]), (_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      }), [[resolveDirective("resize"), onResize]]);
    };
  }
});

var __defProp$1i = Object.defineProperty;
var __getOwnPropSymbols$1j = Object.getOwnPropertySymbols;
var __hasOwnProp$1j = Object.prototype.hasOwnProperty;
var __propIsEnum$1j = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1i = (obj, key, value) => key in obj ? __defProp$1i(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1i = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1j.call(b, prop))
      __defNormalProp$1i(a, prop, b[prop]);
  if (__getOwnPropSymbols$1j)
    for (var prop of __getOwnPropSymbols$1j(b)) {
      if (__propIsEnum$1j.call(b, prop))
        __defNormalProp$1i(a, prop, b[prop]);
    }
  return a;
};
const VeDividerTextAligns = ["left", "center", "right"];
const Divider = genericComponent()({
  name: "VeDivider",
  props: __spreadValues$1i({
    textAlign: {
      type: String,
      default: "center",
      validator: (val) => VeDividerTextAligns.includes(val)
    },
    length: [Number, String],
    dashed: Boolean,
    vertical: Boolean
  }, makeTagProps({
    tag: "hr"
  })),
  setup(props, {
    attrs,
    slots
  }) {
    const dividerStyles = computed(() => {
      const styles = {};
      if (props.length) {
        styles[props.vertical ? "maxHeight" : "maxWidth"] = convertToUnit(props.length);
      }
      return styles;
    });
    return () => {
      var _a;
      const hasDefaultSlot = !!slots.default;
      const Tag = hasDefaultSlot ? "div" : props.tag;
      const role = (_a = attrs.role) != null ? _a : "separator";
      return createVNode(Tag, {
        "class": ["ve-divider", {
          "ve-divider--dashed": props.dashed,
          "ve-divider--vertical": props.vertical,
          "ve-divider--text": hasDefaultSlot,
          "ve-divider--text-left": props.textAlign === "left",
          "ve-divider--text-right": props.textAlign === "right"
        }],
        "style": [dividerStyles.value],
        "aria-orientation": role === "separator" ? props.vertical ? "vertical" : "horizontal" : void 0,
        "role": role
      }, {
        default: hasDefaultSlot ? () => {
          var _a2;
          return [createVNode(Fragment, null, [createVNode("div", {
            "class": "ve-divider__line"
          }, null), createVNode("div", {
            "class": "ve-divider__wrap"
          }, [(_a2 = slots.default) == null ? void 0 : _a2.call(slots)]), createVNode("div", {
            "class": "ve-divider__line"
          }, null)])];
        } : void 0
      });
    };
  }
});

const CardImage = createSimpleFunctional("ve-card-image");

const CardAvatar = createSimpleFunctional("ve-card-avatar");

const CardHeader = createSimpleFunctional("ve-card-header");

const CardHeaderText = createSimpleFunctional("ve-card-header-text");

const CardTitle = createSimpleFunctional("ve-card-title");

const CardSubtitle = createSimpleFunctional("ve-card-subtitle");

const CardText = createSimpleFunctional("ve-card-text");

const CardActions = createSimpleFunctional("ve-card-actions");

var __defProp$1h = Object.defineProperty;
var __getOwnPropSymbols$1i = Object.getOwnPropertySymbols;
var __hasOwnProp$1i = Object.prototype.hasOwnProperty;
var __propIsEnum$1i = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1h = (obj, key, value) => key in obj ? __defProp$1h(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1h = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1i.call(b, prop))
      __defNormalProp$1h(a, prop, b[prop]);
  if (__getOwnPropSymbols$1i)
    for (var prop of __getOwnPropSymbols$1i(b)) {
      if (__propIsEnum$1i.call(b, prop))
        __defNormalProp$1h(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$b(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const makeCardProps = propsFactory(__spreadValues$1h(__spreadValues$1h(__spreadValues$1h(__spreadValues$1h({
  link: Boolean,
  hover: Boolean,
  image: String,
  prependAvatar: String,
  prependIcon: String,
  appendAvatar: String,
  appendIcon: String,
  title: String,
  subtitle: String,
  divided: Boolean,
  text: String,
  ripple: {
    type: Boolean,
    default: true
  }
}, makeRouterProps()), makeLoadingProps()), makeDisabledProps()), makePaperProps({
  shape: "rounded-sm",
  variant: "contained"
})), "card");
const Card = /* @__PURE__ */ defineComponent({
  name: "VeCard",
  directives: {
    Ripple
  },
  props: makeCardProps(),
  setup(props, {
    attrs,
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const link = useLink(props, attrs);
    const {
      loadingClasses
    } = useLoading(props);
    const {
      disabledClasses
    } = useDisabled(props);
    return () => {
      let _slot;
      const Tag = link.isLink.value ? "a" : props.tag;
      const hasImage = !!(slots.image || props.image);
      const hasTitle = !!(slots.title || props.title);
      const hasSubtitle = !!(slots.subtitle || props.subtitle);
      const hasHeaderText = !!slots.headerText || hasTitle || hasSubtitle;
      const hasPrepend = !!(slots.prepend || props.prependAvatar || props.prependIcon);
      const hasAppend = !!(slots.append || props.appendAvatar || props.appendIcon);
      const hasHeader = !!slots.header || hasHeaderText || hasPrepend || hasAppend;
      const hasText = !!(slots.text || props.text);
      const isClickable = !props.disabled && (link.isClickable.value || props.link);
      return withDirectives(createVNode(Tag, {
        "class": ["ve-card", {
          "ve-card--hover": props.hover && !props.disabled,
          "ve-card--link": isClickable
        }, paperClasses.value, loadingClasses.value, disabledClasses.value],
        "style": paperStyles.value,
        "href": link.href.value,
        "onClick": isClickable && link.navigate
      }, {
        default: () => {
          var _a, _b;
          return [genOverlays(isClickable, "ve-card"), hasImage && createVNode(CardImage, null, {
            default: () => {
              var _a2, _b2;
              return [(_b2 = (_a2 = slots.image) == null ? void 0 : _a2.call(slots, {
                src: props.image
              })) != null ? _b2 : createVNode(Image, {
                "src": props.image,
                "cover": true
              }, null)];
            }
          }), (_a = slots.media) == null ? void 0 : _a.call(slots), hasHeader && createVNode(CardHeader, null, {
            default: () => {
              var _a2, _b2;
              return [(_b2 = (_a2 = slots.header) == null ? void 0 : _a2.call(slots)) != null ? _b2 : createVNode(Fragment, null, [hasPrepend && createVNode(CardAvatar, null, {
                default: () => {
                  var _a3, _b3;
                  return [(_b3 = (_a3 = slots.prepend) == null ? void 0 : _a3.call(slots)) != null ? _b3 : createVNode(Avatar, {
                    "density": props.density,
                    "icon": props.prependIcon,
                    "image": props.prependAvatar
                  }, null)];
                }
              }), hasHeaderText && createVNode(CardHeaderText, null, {
                default: () => {
                  var _a3, _b3;
                  return [(_b3 = (_a3 = slots.headerText) == null ? void 0 : _a3.call(slots)) != null ? _b3 : createVNode(Fragment, null, [hasTitle && createVNode(CardTitle, null, {
                    default: () => {
                      var _a4, _b4;
                      return [(_b4 = (_a4 = slots.title) == null ? void 0 : _a4.call(slots)) != null ? _b4 : props.title];
                    }
                  }), hasSubtitle && createVNode(CardSubtitle, null, {
                    default: () => {
                      var _a4, _b4;
                      return [(_b4 = (_a4 = slots.subtitle) == null ? void 0 : _a4.call(slots)) != null ? _b4 : props.subtitle];
                    }
                  })])];
                }
              }), hasAppend && createVNode(CardAvatar, null, {
                default: () => {
                  var _a3, _b3;
                  return [(_b3 = (_a3 = slots.append) == null ? void 0 : _a3.call(slots)) != null ? _b3 : createVNode(Avatar, {
                    "density": props.density,
                    "icon": props.appendIcon,
                    "image": props.appendAvatar
                  }, null)];
                }
              })])];
            }
          }), props.divided && createVNode(Divider, null, null), hasText && createVNode(CardText, null, {
            default: () => {
              var _a2, _b2;
              return [(_b2 = (_a2 = slots.text) == null ? void 0 : _a2.call(slots)) != null ? _b2 : props.text];
            }
          }), (_b = slots.default) == null ? void 0 : _b.call(slots), slots.actions && props.divided && createVNode(Divider, null, null), slots.actions && createVNode(CardActions, null, _isSlot$b(_slot = slots.actions()) ? _slot : {
            default: () => [_slot]
          })];
        }
      }), [[resolveDirective("ripple"), isClickable && props.ripple]]);
    };
  }
});
function filterCardProps(props) {
  return pick(props, Object.keys(Card.props));
}

const makeGroupProps = propsFactory({
  /**
   * @zh 选择的值
   */
  modelValue: {
    type: [Number, Boolean, String, Array, Object],
    default: void 0
  },
  /**
   * @zh 支持多选
   */
  multiple: Boolean,
  /**
   * @zh 是否强制选择
   */
  mandatory: [Boolean, String],
  /**
   * @zh 最大值
   */
  max: Number,
  /**
   * @zh 选中后的 class
   */
  selectedClass: String,
  /**
   * @zh 是否禁用
   */
  disabled: Boolean
}, "group");
const makeGroupItemProps = propsFactory({
  /**
   * @zh 选中后的值
   */
  value: null,
  /**
   * @zh 是否禁用
   */
  disabled: Boolean,
  /**
   * @zh 选中后的 class
   */
  selectedClass: String
}, "group-item");
function useGroupItem(props, injectKey, required = true) {
  const vm = getCurrentInstance$1();
  if (!vm) {
    throw new Error(
      "[VenoUi] useGroupItem composable must be used inside a component setup function"
    );
  }
  const group = inject(injectKey, null);
  if (!group) {
    if (!required)
      return group;
    throw new Error(`[VenoUi] Could not find useGroup injection with symbol ${injectKey.description}`);
  }
  const id = `ve-group-item-${getUid()}`;
  const value = toRef(props, "value");
  const disabled = computed(() => group.disabled.value || props.disabled);
  group.register({
    id,
    value,
    disabled
  }, vm);
  onBeforeUnmount(() => group.unregister(id));
  const isSelected = computed(() => group.isSelected(id));
  const selectedClass = computed(() => {
    var _a;
    return isSelected.value && ((_a = group.selectedClass.value) != null ? _a : props.selectedClass);
  });
  return {
    id,
    isSelected,
    toggle: () => group.select(id, !isSelected.value),
    select: (value2) => group.select(id, value2),
    selectedClass,
    value,
    disabled,
    group
  };
}
function useGroup(props, injectKey) {
  let isUnmounted = false;
  const items = ref([]);
  const selected = useProxiedModel(
    props,
    "modelValue",
    [],
    (v) => {
      if (v == null)
        return [];
      return getIds(items.value, wrapInArray(v));
    },
    (v) => {
      const arr = getValues(items.value, v);
      return props.multiple ? arr : arr[0];
    }
  );
  const groupVm = getCurrentInstance$1();
  function register(item, vm) {
    const unwrapped = item;
    const index = findChildren(groupVm == null ? void 0 : groupVm.vnode).slice(1).filter((cmp) => !!cmp.provides[injectKey]).indexOf(vm);
    if (index > -1)
      items.value.splice(index, 0, unwrapped);
    else
      items.value.push(unwrapped);
  }
  function unregister(id) {
    if (isUnmounted)
      return;
    selected.value = selected.value.filter((v) => v !== id);
    forceMandatoryValue();
    const index = items.value.findIndex((item) => item.id === id);
    items.value.splice(index, 1);
  }
  function forceMandatoryValue() {
    const item = items.value.find((item2) => !item2.disabled);
    if (item && props.mandatory === "force" && !selected.value.length) {
      selected.value = [item.id];
    }
  }
  onMounted(() => {
    forceMandatoryValue();
  });
  onBeforeUnmount(() => {
    isUnmounted = true;
  });
  function select(id, isSelected) {
    const item = items.value.find((item2) => item2.id === id);
    if (isSelected && (item == null ? void 0 : item.disabled))
      return;
    if (props.multiple) {
      const internalValue = selected.value.slice();
      const index = internalValue.findIndex((v) => v === id);
      if (props.mandatory && index > -1 && internalValue.length <= 1)
        return;
      if (props.max != null && index < 0 && internalValue.length + 1 > props.max)
        return;
      if (index < 0 && isSelected)
        internalValue.push(id);
      else if (index >= 0 && !isSelected)
        internalValue.splice(index, 1);
      selected.value = internalValue;
    } else {
      if (props.mandatory && selected.value.includes(id))
        return;
      selected.value = isSelected ? [id] : [];
    }
  }
  function step(offset) {
    if (props.multiple)
      consoleWarn('This method is not supported when using "multiple" prop');
    if (!selected.value.length) {
      const item = items.value.find((item2) => !item2.disabled);
      item && (selected.value = [item.id]);
    } else {
      const currentId = selected.value[0];
      const currentIndex = items.value.findIndex((i) => i.id === currentId);
      let newIndex = (currentIndex + offset) % items.value.length;
      let newItem = items.value[newIndex];
      while (newItem.disabled && newIndex !== currentIndex) {
        newIndex = (newIndex + offset) % items.value.length;
        newItem = items.value[newIndex];
      }
      if (newItem.disabled)
        return;
      selected.value = [items.value[newIndex].id];
    }
  }
  const state = {
    vm: groupVm,
    register,
    unregister,
    selected,
    select,
    disabled: toRef(props, "disabled"),
    prev: () => step(items.value.length - 1),
    next: () => step(1),
    isSelected: (id) => selected.value.includes(id),
    selectedClass: computed(() => props.selectedClass),
    items
  };
  provide(injectKey, state);
  return state;
}
function getIds(items, modelValue) {
  const ids = [];
  for (const item of items) {
    if (item.value != null) {
      if (modelValue.find((value) => deepEqual(value, item.value)) != null) {
        ids.push(item.id);
      }
    } else if (modelValue.includes(item.id)) {
      ids.push(item.id);
    }
  }
  return ids;
}
function getValues(items, ids) {
  const values = [];
  for (const item of items) {
    if (ids.includes(item.id)) {
      values.push(item.value != null ? item.value : item.id);
    }
  }
  return values;
}

const makeProgressLinearProps = propsFactory({
  /**
   * @zh 是否激活
   */
  active: {
    type: Boolean,
    default: true
  },
  /**
   * @zh 当前进度比
   */
  modelValue: {
    type: [Number, String],
    default: 0
  },
  /**
   * @zh 描线宽
   */
  strokeWidth: {
    type: [Number, String],
    default: 2
  },
  /**
   * @zh 不确定的进度条
   */
  indeterminate: Boolean,
  /**
   * @zh 是否显示底部衬底
   */
  underlay: {
    type: Boolean,
    default: true
  }
}, "progress-linear");
const ProgressLinear = /* @__PURE__ */ defineComponent({
  name: "VeProgressLinear",
  props: makeProgressLinearProps(),
  setup(props) {
    const model = computed(() => Math.max(0, Math.min(100, parseFloat(props.modelValue))));
    const height = computed(() => Number(props.strokeWidth));
    return () => createVNode("div", {
      "class": ["ve-progress-linear", {
        "ve-progress-linear--active": props.active,
        "ve-progress-linear--indeterminate": props.indeterminate
      }],
      "style": {
        height: props.active ? convertToUnit(height.value) : 0
      }
    }, [props.underlay && createVNode("div", {
      "class": "ve-progress-linear__underlay"
    }, null), createVNode("div", {
      "class": "ve-progress-linear__overlay",
      "style": {
        width: convertToUnit(model.value, "%")
      }
    }, null)]);
  }
});
function filterProgressLinearProps(attrs) {
  return pick(attrs, Object.keys(ProgressLinear.props));
}

var __defProp$1g = Object.defineProperty;
var __getOwnPropSymbols$1h = Object.getOwnPropertySymbols;
var __hasOwnProp$1h = Object.prototype.hasOwnProperty;
var __propIsEnum$1h = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1g = (obj, key, value) => key in obj ? __defProp$1g(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1g = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1h.call(b, prop))
      __defNormalProp$1g(a, prop, b[prop]);
  if (__getOwnPropSymbols$1h)
    for (var prop of __getOwnPropSymbols$1h(b)) {
      if (__propIsEnum$1h.call(b, prop))
        __defNormalProp$1g(a, prop, b[prop]);
    }
  return a;
};
const diameter = 24;
const makeProgressCircularProps = propsFactory(__spreadValues$1g({
  /**
   * @zh 进度条大小
   */
  size: {
    type: [String, Number],
    default: diameter
  },
  /**
   * @zh 进度条初始化角度
   */
  rotate: {
    type: [Number, String],
    default: 0
  }
}, makeProgressLinearProps()), "progress-circular");
const ProgressCircular = /* @__PURE__ */ defineComponent({
  name: "VeProgressCircular",
  props: makeProgressCircularProps(),
  setup(props) {
    const model = computed(() => Math.max(0, Math.min(100, parseFloat(props.modelValue))));
    const radius = computed(() => {
      const rate = Math.max(Number(props.strokeWidth) && Number(props.size) ? 1 - Number(props.strokeWidth) / Number(props.size) : 0.5, 0.5);
      return diameter * rate / 2;
    });
    const strokeWidth = computed(() => diameter - radius.value * 2);
    const circumference = computed(() => 2 * Math.PI * radius.value);
    const offset = computed(() => convertToUnit((100 - model.value) / 100 * circumference.value));
    return () => createVNode("svg", {
      "class": ["ve-progress-circular", {
        "ve-progress-circular--active": props.active,
        "ve-progress-circular--indeterminate": props.indeterminate
      }],
      "style": {
        transform: `rotate(calc(-90deg + ${Number(props.rotate)}deg))`
      },
      "xmlns": "http://www.w3.org/2000/svg",
      "viewBox": `0 0 ${diameter} ${diameter}`
    }, [props.underlay && createVNode("circle", {
      "class": "ve-progress-circular__underlay",
      "fill": "transparent",
      "cx": "50%",
      "cy": "50%",
      "r": radius.value,
      "stroke-width": strokeWidth.value,
      "stroke-dasharray": circumference.value,
      "stroke-dashoffset": 0
    }, null), createVNode("circle", {
      "class": "ve-progress-circular__overlay",
      "fill": "transparent",
      "cx": "50%",
      "cy": "50%",
      "r": radius.value,
      "stroke-width": strokeWidth.value,
      "stroke-dasharray": circumference.value,
      "stroke-dashoffset": offset.value
    }, null)]);
  }
});
function filterProgressCircularProps(attrs) {
  return pick(attrs, Object.keys(ProgressCircular.props));
}

var __defProp$1f = Object.defineProperty;
var __defProps$r = Object.defineProperties;
var __getOwnPropDescs$r = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1g = Object.getOwnPropertySymbols;
var __hasOwnProp$1g = Object.prototype.hasOwnProperty;
var __propIsEnum$1g = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1f = (obj, key, value) => key in obj ? __defProp$1f(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1f = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1g.call(b, prop))
      __defNormalProp$1f(a, prop, b[prop]);
  if (__getOwnPropSymbols$1g)
    for (var prop of __getOwnPropSymbols$1g(b)) {
      if (__propIsEnum$1g.call(b, prop))
        __defNormalProp$1f(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$r = (a, b) => __defProps$r(a, __getOwnPropDescs$r(b));
function createCssTransition(name, origin = "top center 0", mode) {
  return defineComponent$1({
    name,
    props: {
      group: Boolean,
      hideOnLeave: Boolean,
      leaveAbsolute: Boolean,
      mode: {
        type: String,
        default: mode
      },
      origin: {
        type: String,
        default: origin
      },
      onBeforeEnter: Function,
      onLeave: Function,
      onAfterLeave: Function
    },
    setup(props, { slots, attrs }) {
      return () => {
        const tag = props.group ? TransitionGroup : Transition;
        return h(tag, __spreadValues$1f({
          name,
          mode: props.mode,
          onBeforeEnter(el) {
            var _a;
            el.style.transformOrigin = props.origin;
            (_a = props.onBeforeEnter) == null ? void 0 : _a.call(props, el);
          },
          onLeave(el) {
            var _a;
            if (props.leaveAbsolute) {
              const { offsetTop, offsetLeft, offsetWidth, offsetHeight } = el;
              el._transitionInitialStyles = {
                position: el.style.position,
                top: el.style.top,
                left: el.style.left,
                width: el.style.width,
                height: el.style.height
              };
              el.style.position = "absolute";
              el.style.top = `${offsetTop}px`;
              el.style.left = `${offsetLeft}px`;
              el.style.width = `${offsetWidth}px`;
              el.style.height = `${offsetHeight}px`;
            }
            if (props.hideOnLeave) {
              el._initialDisplay = el.style.display;
              el.style.display = "none";
            }
            (_a = props.onLeave) == null ? void 0 : _a.call(props, el);
          },
          onAfterLeave(el) {
            var _a;
            if (props.leaveAbsolute && (el == null ? void 0 : el._transitionInitialStyles)) {
              const { position, top, left, width, height } = el._transitionInitialStyles;
              delete el._transitionInitialStyles;
              el.style.position = position || "";
              el.style.top = top || "";
              el.style.left = left || "";
              el.style.width = width || "";
              el.style.height = height || "";
            }
            if (props.hideOnLeave && el) {
              el.style.display = el._initialDisplay || "";
            }
            (_a = props.onAfterLeave) == null ? void 0 : _a.call(props, el);
          }
        }, attrs), slots.default);
      };
    }
  });
}
function createJavascriptTransition(name, functions, mode = "in-out") {
  return defineComponent$1({
    name,
    props: {
      group: Boolean,
      mode: {
        type: String,
        default: mode
      },
      onBeforeEnter: Function,
      onLeave: Function,
      onAfterLeave: Function
    },
    setup(props, { slots }) {
      return () => {
        const tag = props.group ? TransitionGroup : Transition;
        return h(tag, __spreadProps$r(__spreadValues$1f({
          name
        }, functions), {
          onBeforeEnter(el) {
            var _a, _b;
            (_a = functions.onBeforeEnter) == null ? void 0 : _a.call(functions, el);
            (_b = props.onBeforeEnter) == null ? void 0 : _b.call(props, el);
          },
          onLeave(el) {
            var _a, _b;
            (_a = functions.onLeave) == null ? void 0 : _a.call(functions, el);
            (_b = props.onLeave) == null ? void 0 : _b.call(props, el);
          },
          onAfterLeave(el) {
            var _a, _b;
            (_a = functions.onAfterLeave) == null ? void 0 : _a.call(functions, el);
            (_b = props.onAfterLeave) == null ? void 0 : _b.call(props, el);
          }
        }), slots.default);
      };
    }
  });
}

const FadeTransition = createCssTransition("ve-fade-transition");

const ScaleTransition = createCssTransition("ve-scale-transition");

function expandTransitionGenerator(expandedParentClass = "", x = false) {
  const sizeProperty = x ? "width" : "height";
  const offsetProperty = camelize(`offset-${sizeProperty}`);
  return {
    onBeforeEnter(el) {
      el._parent = el.parentNode;
      el._initialStyle = {
        transition: el.style.transition,
        overflow: el.style.overflow,
        [sizeProperty]: el.style[sizeProperty]
      };
    },
    onEnter(el) {
      const initialStyle = el._initialStyle;
      el.style.setProperty("transition", "none", "important");
      el.style.overflow = "hidden";
      const offset = `${el[offsetProperty]}px`;
      el.style[sizeProperty] = "0";
      void el.offsetHeight;
      el.style.transition = initialStyle.transition;
      if (expandedParentClass && el._parent) {
        el._parent.classList.add(expandedParentClass);
      }
      requestAnimationFrame(() => {
        el.style[sizeProperty] = offset;
      });
    },
    onAfterEnter: resetStyles,
    onEnterCancelled: resetStyles,
    onLeave(el) {
      el._initialStyle = {
        transition: "",
        overflow: el.style.overflow,
        [sizeProperty]: el.style[sizeProperty]
      };
      el.style.overflow = "hidden";
      el.style[sizeProperty] = `${el[offsetProperty]}px`;
      void el.offsetHeight;
      requestAnimationFrame(() => el.style[sizeProperty] = "0");
    },
    onAfterLeave,
    onLeaveCancelled: onAfterLeave
  };
  function onAfterLeave(el) {
    if (expandedParentClass && el._parent) {
      el._parent.classList.remove(expandedParentClass);
    }
    resetStyles(el);
  }
  function resetStyles(el) {
    const size = el._initialStyle[sizeProperty];
    el.style.overflow = el._initialStyle.overflow;
    if (size != null)
      el.style[sizeProperty] = size;
    delete el._initialStyle;
  }
}
function fadeInExpandTransitionGenerator(x = false, reverse = false) {
  return {
    onBeforeLeave: (el) => {
      if (x) {
        el.style.maxWidth = `${el.offsetWidth}px`;
      } else {
        el.style.maxHeight = `${el.offsetHeight}px`;
      }
      void el.offsetWidth;
    },
    onLeave: (el) => {
      if (x) {
        el.style.maxWidth = "0";
      } else {
        el.style.maxHeight = "0";
      }
      void el.offsetWidth;
    },
    onAfterLeave: (el) => {
      if (x) {
        el.style.maxWidth = "";
      } else {
        el.style.maxHeight = "";
      }
    },
    onEnter: (el) => {
      el.style.transition = "none";
      if (x) {
        const memorizedWidth = el.offsetWidth;
        el.style.maxWidth = "0";
        void el.offsetWidth;
        el.style.transition = "";
        el.style.maxWidth = `${memorizedWidth}px`;
      } else {
        if (reverse) {
          el.style.maxHeight = `${el.offsetHeight}px`;
          void el.offsetHeight;
          el.style.transition = "";
          el.style.maxHeight = "0";
        } else {
          const memorizedHeight = el.offsetHeight;
          el.style.maxHeight = "0";
          void el.offsetWidth;
          el.style.transition = "";
          el.style.maxHeight = `${memorizedHeight}px`;
        }
      }
      void el.offsetWidth;
    },
    onAfterEnter: (el) => {
      if (x) {
        el.style.maxWidth = "";
      } else {
        if (!reverse) {
          el.style.maxHeight = "";
        }
      }
    }
  };
}

const ExpandTransition = createJavascriptTransition(
  "ve-expand-transition",
  expandTransitionGenerator()
);
const ExpandXTransition = createJavascriptTransition(
  "ve-expand-x-transition",
  expandTransitionGenerator("", true)
);

const useSharedClick = createSharedComposable(() => {
  const clickedEl = ref();
  const clickedPosition = ref();
  const onClick = (e) => {
    clickedEl.value = e.target;
    clickedPosition.value = { left: e.clientX, top: e.clientY };
  };
  document.addEventListener("click", onClick);
  onScopeDispose(() => {
    document.removeEventListener("click", onClick);
  });
  return {
    clickedEl,
    clickedPosition: readonly(clickedPosition)
  };
});

const DialogTransition = /* @__PURE__ */ defineComponent({
  name: "VeDialogTransition",
  props: {
    target: Object
  },
  setup(props, {
    slots
  }) {
    const {
      clickedEl
    } = useSharedClick();
    const targetEl = ref();
    const getTransformOrigin = (el) => {
      if (targetEl.value && document.documentElement.contains(targetEl.value)) {
        const {
          x,
          y
        } = getDimensions(targetEl.value, el);
        return `${x}px ${y}px`;
      }
      return "center";
    };
    const functions = {
      onBeforeEnter(el) {
        el.style.pointerEvents = "none";
      },
      async onEnter(el, done) {
        var _a;
        await new Promise((resolve) => requestAnimationFrame(resolve));
        targetEl.value = (_a = props.target) != null ? _a : clickedEl.value;
        el.style.transformOrigin = getTransformOrigin(el);
        el.animate([{
          transform: "scale(0.5)",
          opacity: 0
        }, {
          transform: ""
        }], {
          duration: 225,
          easing: deceleratedEasing
        }).finished.then(() => done());
      },
      onAfterEnter(el) {
        el.style.removeProperty("pointer-events");
        el.style.removeProperty("transform-origin");
      },
      onBeforeLeave(el) {
        el.style.pointerEvents = "none";
      },
      async onLeave(el, done) {
        await new Promise((resolve) => requestAnimationFrame(resolve));
        el.style.transformOrigin = getTransformOrigin(el);
        el.animate([{
          transform: ""
        }, {
          transform: "scale(0.5)",
          opacity: 0
        }], {
          duration: 125,
          easing: acceleratedEasing
        }).finished.then(() => done());
      },
      onAfterLeave(el) {
        el.style.removeProperty("pointer-events");
        el.style.removeProperty("transform-origin");
      }
    };
    return () => {
      return createVNode(Transition, mergeProps({
        "name": "dialog-transition"
      }, functions, {
        "css": false
      }), slots);
    };
  }
});
function getDimensions(target, el) {
  const targetBox = target.getBoundingClientRect();
  const elBox = nullifyTransforms(el);
  const [anchorSide, anchorOffset] = getComputedStyle(el).getPropertyValue("--ve-overlay-anchor-origin").split(" ");
  let offsetX = targetBox.left + targetBox.width / 2;
  if (anchorSide === "left" || anchorOffset === "left") {
    offsetX -= targetBox.width / 2;
  } else if (anchorSide === "right" || anchorOffset === "right") {
    offsetX += targetBox.width / 2;
  }
  let offsetY = targetBox.top + targetBox.height / 2;
  if (anchorSide === "top" || anchorOffset === "top") {
    offsetY -= targetBox.height / 2;
  } else if (anchorSide === "bottom" || anchorOffset === "bottom") {
    offsetY += targetBox.height / 2;
  }
  return {
    x: offsetX - elBox.left,
    y: offsetY - elBox.top
  };
}

const MenuTransition = createCssTransition("ve-menu-transition");

const FadeInExpandTransition = createJavascriptTransition(
  "ve-fade-in-expand-transition",
  fadeInExpandTransitionGenerator()
);

const SlideRightFadeInExpandTransition = createJavascriptTransition(
  "ve-slide-right-fade-in-expand-transition",
  fadeInExpandTransitionGenerator()
);

var __defProp$1e = Object.defineProperty;
var __getOwnPropSymbols$1f = Object.getOwnPropertySymbols;
var __hasOwnProp$1f = Object.prototype.hasOwnProperty;
var __propIsEnum$1f = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1e = (obj, key, value) => key in obj ? __defProp$1e(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1e = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1f.call(b, prop))
      __defNormalProp$1e(a, prop, b[prop]);
  if (__getOwnPropSymbols$1f)
    for (var prop of __getOwnPropSymbols$1f(b)) {
      if (__propIsEnum$1f.call(b, prop))
        __defNormalProp$1e(a, prop, b[prop]);
    }
  return a;
};
const ButtonGroup = /* @__PURE__ */ defineComponent({
  name: "VeButtonGroup",
  props: __spreadValues$1e(__spreadValues$1e({
    /**
     * @zh 是否有分割线
     */
    divided: Boolean
  }, makeDisabledProps()), makePaperProps({
    shape: "rounded-sm"
  })),
  setup(props, {
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    provideDefaults(reactive({
      VeButton: {
        disabled: toRef(props, "disabled"),
        height: "auto",
        color: toRef(props, "color"),
        variant: toRef(props, "variant")
      }
    }));
    return () => {
      return createVNode(props.tag, {
        "class": ["ve-button-group", {
          "ve-button-group--divided": props.divided
        }, paperClasses.value],
        "style": [paperStyles.value]
      }, slots);
    };
  }
});

var __defProp$1d = Object.defineProperty;
var __getOwnPropSymbols$1e = Object.getOwnPropertySymbols;
var __hasOwnProp$1e = Object.prototype.hasOwnProperty;
var __propIsEnum$1e = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1d = (obj, key, value) => key in obj ? __defProp$1d(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1d = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1e.call(b, prop))
      __defNormalProp$1d(a, prop, b[prop]);
  if (__getOwnPropSymbols$1e)
    for (var prop of __getOwnPropSymbols$1e(b)) {
      if (__propIsEnum$1e.call(b, prop))
        __defNormalProp$1d(a, prop, b[prop]);
    }
  return a;
};
const ButtonToggleKey = Symbol.for("veno-ui:button-toggle");
const ButtonToggle = /* @__PURE__ */ defineComponent({
  name: "VeButtonToggle",
  props: __spreadValues$1d({}, makeGroupProps({
    selectedClass: "ve-button--selected"
  })),
  emits: {
    "update:modelValue": (_value) => true
  },
  setup(props, {
    slots
  }) {
    const {
      isSelected,
      next,
      prev,
      select,
      selected
    } = useGroup(props, ButtonToggleKey);
    useRender(() => {
      return createVNode(ButtonGroup, {
        "class": "ve-button-toggle"
      }, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots, {
            isSelected,
            next,
            prev,
            select,
            selected
          })];
        }
      });
    });
    return {
      next,
      prev,
      select
    };
  }
});

var __defProp$1c = Object.defineProperty;
var __getOwnPropSymbols$1d = Object.getOwnPropertySymbols;
var __hasOwnProp$1d = Object.prototype.hasOwnProperty;
var __propIsEnum$1d = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1c = (obj, key, value) => key in obj ? __defProp$1c(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1c = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1d.call(b, prop))
      __defNormalProp$1c(a, prop, b[prop]);
  if (__getOwnPropSymbols$1d)
    for (var prop of __getOwnPropSymbols$1d(b)) {
      if (__propIsEnum$1d.call(b, prop))
        __defNormalProp$1c(a, prop, b[prop]);
    }
  return a;
};
const makeButtonProps = propsFactory(__spreadValues$1c(__spreadValues$1c(__spreadValues$1c(__spreadValues$1c(__spreadValues$1c({
  /**
   * @zh 按钮的类型
   */
  type: {
    type: String,
    default: "button"
  },
  /**
   * @zh 图标按钮
   */
  icon: [Boolean, String, Object],
  /**
   * @zh 前置图标
   */
  prependIcon: [String, Object],
  /**
   * @zh 后置图标
   */
  appendIcon: [String, Object],
  stacked: Boolean,
  /**
   * @zh 按钮是否显示为块级
   */
  block: Boolean,
  /**
   * @zh 按钮文字内容
   */
  text: [String, Number],
  /**
   * @zh 按钮是否在点击时出现波纹
   */
  ripple: {
    type: Boolean,
    default: true
  },
  overlay: {
    type: Boolean,
    default: true
  }
}, makeDisabledProps()), makeLoadingProps()), makeRouterProps()), makeGroupItemProps()), makePaperProps({
  tag: "button",
  shape: "rounded-sm",
  variant: "contained"
})), "button");
const Button = /* @__PURE__ */ defineComponent({
  name: "VeButton",
  directives: {
    Ripple
  },
  props: makeButtonProps(),
  emits: {
    click: (_event) => true
  },
  setup(props, {
    attrs,
    slots,
    emit
  }) {
    const group = useGroupItem(props, ButtonToggleKey, false);
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const isDisabled = computed(() => (group == null ? void 0 : group.disabled.value) || props.disabled || props.loading);
    const {
      loadingClasses
    } = useLoading(props);
    const {
      disabledClasses
    } = useDisabled(computed(() => ({
      disabled: (group == null ? void 0 : group.disabled.value) || props.disabled
    })));
    const link = useLink(props, attrs);
    const handleClick = (e) => {
      if (isDisabled.value) {
        e.preventDefault();
        return;
      }
      link.navigate ? link.navigate() : group == null ? void 0 : group.toggle();
      emit("click", e);
    };
    return () => {
      var _a;
      const Tag = link.isLink.value ? "a" : props.tag;
      const hasPrependIcon = !props.icon && (props.prependIcon || slots["prepend-icon"]);
      const hasPrependLoading = !hasPrependIcon && props.loading && (slots.default || props.text);
      const hasIconOnly = props.icon && typeof props.icon !== "boolean" || Boolean(slots.icon);
      const hasDefault = !hasIconOnly && (slots.default || props.text);
      const hasAppendIcon = !props.icon && (props.appendIcon || slots["append-icon"]);
      return withDirectives(createVNode(Tag, {
        "role": link.isLink.value ? void 0 : "button",
        "aria-disabled": props.disabled || void 0,
        "type": link.isLink.value ? void 0 : props.type,
        "class": ["ve-button", group == null ? void 0 : group.selectedClass.value, paperClasses.value, disabledClasses.value, loadingClasses.value, {
          "ve-button--active": (_a = link.isExactActive) == null ? void 0 : _a.value,
          "ve-button--block": props.block,
          "ve-button--stacked": props.stacked,
          "ve-button--icon": !hasIconOnly && !!props.icon,
          "ve-button--icon-only": hasIconOnly
        }],
        "style": paperStyles.value,
        "disabled": props.disabled || void 0,
        "href": link.href.value,
        "onClick": handleClick
      }, {
        default: () => {
          var _a2, _b, _c, _d, _e;
          return [genOverlays(props.overlay, "ve-button"), createVNode(ExpandXTransition, null, {
            default: () => [hasPrependLoading && createVNode(Icon, {
              "class": "ve-button__icon",
              "icon": createVNode(ProgressCircular, {
                "color": "currentColor",
                "indeterminate": true
              }, null),
              "size": props.size,
              "start": true
            }, null)]
          }), hasPrependIcon && createVNode(Icon, {
            "class": "ve-button__icon",
            "icon": props.loading ? createVNode(ProgressCircular, {
              "color": "currentColor",
              "indeterminate": true
            }, null) : (_a2 = slots["prepend-icon"]) != null ? _a2 : props.prependIcon,
            "size": props.size,
            "start": true
          }, null), hasDefault && createVNode("span", {
            "class": "ve-button__wrapper"
          }, [(_c = (_b = slots.default) == null ? void 0 : _b.call(slots)) != null ? _c : props.text]), hasIconOnly && createVNode(Icon, {
            "class": "ve-button__icon",
            "icon": props.loading ? createVNode(ProgressCircular, {
              "color": "currentColor",
              "indeterminate": true
            }, null) : (_d = slots.icon) != null ? _d : props.icon,
            "size": props.size
          }, null), hasAppendIcon && createVNode(Icon, {
            "class": "ve-button__icon",
            "icon": (_e = slots["append-icon"]) != null ? _e : props.appendIcon,
            "size": props.size,
            "end": true
          }, null)];
        }
      }), [[resolveDirective("ripple"), !isDisabled.value && props.ripple, null]]);
    };
  }
});

function useIntersectionObserver(callback) {
  const intersectionRef = ref();
  const isIntersecting = ref(false);
  if (SUPPORTS_INTERSECTION_OBSERVER) {
    const observer = new IntersectionObserver((entries) => {
      callback == null ? void 0 : callback(entries, observer);
      isIntersecting.value = !!entries.find((entry) => entry.isIntersecting);
    });
    onBeforeUnmount(() => {
      observer.disconnect();
    });
    watch(intersectionRef, (newValue, oldValue) => {
      if (oldValue) {
        observer.unobserve(oldValue);
        isIntersecting.value = false;
      }
      if (newValue)
        observer.observe(newValue);
    }, {
      flush: "post"
    });
  } else {
    isIntersecting.value = true;
  }
  return { intersectionRef, isIntersecting };
}

var __defProp$1b = Object.defineProperty;
var __defProps$q = Object.defineProperties;
var __getOwnPropDescs$q = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1c = Object.getOwnPropertySymbols;
var __hasOwnProp$1c = Object.prototype.hasOwnProperty;
var __propIsEnum$1c = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1b = (obj, key, value) => key in obj ? __defProp$1b(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1b = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1c.call(b, prop))
      __defNormalProp$1b(a, prop, b[prop]);
  if (__getOwnPropSymbols$1c)
    for (var prop of __getOwnPropSymbols$1c(b)) {
      if (__propIsEnum$1c.call(b, prop))
        __defNormalProp$1b(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$q = (a, b) => __defProps$q(a, __getOwnPropDescs$q(b));
const progressVariants = [
  "linear",
  // 线性
  "circular"
  // 圆形
];
const Progress = /* @__PURE__ */ defineComponent({
  name: "VeProgress",
  props: __spreadProps$q(__spreadValues$1b(__spreadValues$1b(__spreadValues$1b(__spreadValues$1b(__spreadValues$1b({
    /**
     * @zh 进度条颜色
     */
    color: {
      type: [String, Boolean],
      default: "primary"
    },
    /**
     * @zh 是否在左侧
     */
    start: Boolean,
    /**
     * @zh 是否在右侧
     */
    end: Boolean
  }, makeProgressCircularProps()), makeProgressLinearProps()), makeThemeProps()), makeSizeProps()), makeTagProps()), {
    variant: {
      type: String,
      default: "linear",
      validator: (v) => progressVariants.includes(v)
    }
  }),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = provideTheme(props);
    const {
      variantClasses
    } = useVariant(props);
    const {
      sizeClasses,
      sizeStyles
    } = useSize(props);
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(toRef(props, "color"));
    const {
      intersectionRef,
      isIntersecting
    } = useIntersectionObserver();
    const model = useProxiedModel(props, "modelValue", props.modelValue, (val) => Math.max(0, Math.min(100, parseFloat(val != null ? val : 0))));
    const strokeWidth = computed(() => Number(props.strokeWidth));
    const size = computed(() => {
      return sizeStyles.value.width ? Number(props.size) : intersectionRef.value ? intersectionRef.value.getBoundingClientRect().width : Math.max(strokeWidth.value, 32);
    });
    const transitionDuration = ref();
    useRender(() => {
      return createVNode(props.tag, {
        "role": "progressbar",
        "aria-valuenow": props.indeterminate ? void 0 : model.value,
        "aria-valuemin": "0",
        "aria-valuemax": "100",
        "ref": intersectionRef,
        "class": ["ve-progress", variantClasses.value, themeClasses.value, sizeClasses.value, textColorClasses.value, {
          "ve-progress--indeterminate": !!props.indeterminate,
          "ve-progress--visible": isIntersecting.value,
          "ve-progress--start": props.start,
          "ve-progress--end": props.end
        }],
        "style": [sizeStyles.value, textColorStyles.value, {
          transitionDuration: transitionDuration.value
        }]
      }, {
        default: () => [props.variant === "circular" && createVNode(ProgressCircular, mergeProps(filterProgressCircularProps(props)[0], {
          "modelValue": model.value,
          "size": size.value
        }), null), props.variant === "linear" && createVNode(ProgressLinear, mergeProps(filterProgressLinearProps(props)[0], {
          "modelValue": model.value
        }), null), slots.default && createVNode("div", {
          "class": "ve-progress__wrapper"
        }, [slots.default({
          value: model.value
        })])]
      });
    });
    let timer;
    return {
      // eslint-disable-next-line vue/no-dupe-keys
      start: () => {
        if (timer)
          clearTimeout(timer);
        transitionDuration.value = "0s";
        model.value = 0;
        setTimeout(() => {
          transitionDuration.value = "4s";
          model.value = 80;
        }, 0);
        timer = setTimeout(() => {
          if (transitionDuration.value === "4s")
            transitionDuration.value = void 0;
          timer = void 0;
        }, 4e3);
      },
      finish: () => {
        return new Promise((resolve) => {
          transitionDuration.value = "0.2s";
          model.value = 100;
          setTimeout(() => {
            transitionDuration.value = void 0;
            if (model.value >= 100)
              resolve(model.value);
          }, 200);
        });
      }
    };
  }
});

var __defProp$1a = Object.defineProperty;
var __defProps$p = Object.defineProperties;
var __getOwnPropDescs$p = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1b = Object.getOwnPropertySymbols;
var __hasOwnProp$1b = Object.prototype.hasOwnProperty;
var __propIsEnum$1b = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1a = (obj, key, value) => key in obj ? __defProp$1a(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1a = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1b.call(b, prop))
      __defNormalProp$1a(a, prop, b[prop]);
  if (__getOwnPropSymbols$1b)
    for (var prop of __getOwnPropSymbols$1b(b)) {
      if (__propIsEnum$1b.call(b, prop))
        __defNormalProp$1a(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$p = (a, b) => __defProps$p(a, __getOwnPropDescs$p(b));
const alertTypes = ["success", "info", "warning", "error"];
const makeAlertProps = propsFactory(__spreadValues$1a(__spreadValues$1a(__spreadValues$1a({
  /**
   * @zh 警告信息是否显示
   */
  modelValue: {
    type: Boolean,
    default: true
  },
  /**
   * @zh 警告信息的类型
   */
  type: {
    type: String,
    default: "info",
    validator: (val) => alertTypes.includes(val)
  },
  /**
   * @zh 警告信息的图标
   */
  icon: {
    type: [String, Boolean, Object],
    default: true
  },
  /**
   * @zh 警告信息是否可关闭
   */
  closable: Boolean,
  /**
   * @zh 警告信息的关闭图标
   */
  closeIcon: {
    type: [String, Object],
    default: "$close"
  },
  /**
   * @zh 警告信息的关闭文本
   */
  closeText: String
}, makeTransitionProps({
  transition: {
    component: FadeInExpandTransition
  }
})), makeLoadingProps()), makeCardProps({
  shape: "rounded-sm",
  variant: "contained-outlined"
})), "alert");
const Alert = genericComponent()({
  name: "VeAlert",
  props: makeAlertProps(),
  emits: {
    "update:modelValue": (_) => true
  },
  setup(props, {
    slots
  }) {
    const {
      loadingClasses
    } = useLoading(props);
    const computedProps = computed(() => {
      var _a;
      return __spreadProps$p(__spreadValues$1a({}, props), {
        text: void 0,
        textColor: (_a = props.type) != null ? _a : props.textColor
      });
    });
    const isActive = useProxiedModel(props, "modelValue");
    const icon = computed(() => {
      if (props.icon === false)
        return void 0;
      if (typeof props.icon === "string")
        return props.icon;
      if (props.type)
        return `$${props.type}`;
      return void 0;
    });
    function onCloseClick(_) {
      isActive.value = false;
    }
    return () => {
      const [cardProps] = filterCardProps(computedProps.value);
      const hasLoading = props.loading;
      const hasIcon = !hasLoading && icon.value;
      const hasPrepend = hasIcon || hasLoading || slots.prepend;
      const hasTitle = !!props.title;
      const hasClosable = props.closable && (props.closeText || props.closeIcon);
      const hasAppend = hasClosable || slots.append;
      return createVNode(MaybeTransition, {
        "transition": props.transition
      }, {
        default: () => [isActive.value && createVNode(props.tag, {
          "role": "alert",
          "class": ["ve-alert", {
            "ve-alert--with-title": hasTitle
          }, loadingClasses.value]
        }, {
          default: () => [createVNode(Card, mergeProps(cardProps, {
            "tag": "div"
          }), {
            prepend: hasPrepend ? () => {
              var _a;
              return createVNode(Fragment, null, [hasIcon && createVNode(Icon, {
                "class": "ve-alert__icon",
                "size": "21",
                "icon": icon.value
              }, null), hasLoading && createVNode(Progress, {
                "class": "ve-alert__icon",
                "size": "21",
                "variant": "circular",
                "stroke-width": "2",
                "indeterminate": true
              }, null), (_a = slots.prepend) == null ? void 0 : _a.call(slots)]);
            } : void 0,
            headerText: () => {
              var _a, _b;
              return createVNode(Fragment, null, [hasTitle && createVNode("div", {
                "class": "ve-alert__title"
              }, [props.title]), (_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text]);
            },
            append: hasAppend ? () => {
              var _a;
              return createVNode(Fragment, null, [(_a = slots.append) == null ? void 0 : _a.call(slots), hasClosable && createVNode(Button, {
                "class": "ve-alert__close",
                "variant": "plain",
                "ripple": false,
                "icon": props.closeText ? false : props.closeIcon,
                "text": props.closeText,
                "onClick": onCloseClick
              }, null)]);
            } : void 0
          })]
        })]
      });
    };
  }
});
function filterAlertProps(props) {
  return pick(props, Object.keys(Alert.props));
}

function useResizeObserver(callback) {
  const resizeRef = ref();
  const contentRect = ref();
  const contentBoxSize = ref();
  const borderBoxSize = ref();
  if (SUPPORTS_RESIZE_OBSERVER) {
    const observer = new ResizeObserver((entries) => {
      callback == null ? void 0 : callback(entries, observer);
      if (!entries.length)
        return;
      contentRect.value = entries[0].contentRect;
      contentBoxSize.value = entries[0].contentBoxSize[0];
      borderBoxSize.value = entries[0].borderBoxSize[0];
    });
    onBeforeUnmount(() => {
      observer.disconnect();
    });
    watch(resizeRef, (newValue, oldValue) => {
      if (oldValue) {
        observer.unobserve(oldValue);
        contentRect.value = void 0;
        contentBoxSize.value = void 0;
        borderBoxSize.value = void 0;
      }
      if (newValue)
        observer.observe(newValue);
    }, {
      flush: "post"
    });
  }
  return {
    resizeRef,
    contentRect: readonly(contentRect),
    contentBoxSize: readonly(contentBoxSize),
    borderBoxSize: readonly(borderBoxSize)
  };
}

var __defProp$19 = Object.defineProperty;
var __defProps$o = Object.defineProperties;
var __getOwnPropDescs$o = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1a = Object.getOwnPropertySymbols;
var __hasOwnProp$1a = Object.prototype.hasOwnProperty;
var __propIsEnum$1a = Object.prototype.propertyIsEnumerable;
var __defNormalProp$19 = (obj, key, value) => key in obj ? __defProp$19(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$19 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1a.call(b, prop))
      __defNormalProp$19(a, prop, b[prop]);
  if (__getOwnPropSymbols$1a)
    for (var prop of __getOwnPropSymbols$1a(b)) {
      if (__propIsEnum$1a.call(b, prop))
        __defNormalProp$19(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$o = (a, b) => __defProps$o(a, __getOwnPropDescs$o(b));
const LayoutKey = Symbol.for("veno-ui:layout");
const ROOT_ZINDEX = 1e3;
const makeLayoutProps = propsFactory({
  overlaps: {
    type: Array,
    default: () => []
  },
  fullHeight: Boolean
}, "layout");
function provideLayout(props, name = getCurrentInstanceName()) {
  const rootVm = getCurrentInstance("provideLayout");
  const parentLayout = inject(LayoutKey, null);
  const rootZIndex = computed(() => parentLayout ? parentLayout.rootZIndex.value - 100 : ROOT_ZINDEX);
  const itemIds = reactive([]);
  const itemMap = /* @__PURE__ */ new Map();
  const { resizeRef, contentRect: layoutRect } = useResizeObserver();
  const overlays = ref([]);
  function generate() {
    return itemIds.map((id) => {
      var _a, _b, _c, _d;
      const item = itemMap.get(id).value;
      return {
        id,
        size: Number(item.size),
        position: (_a = item.position) != null ? _a : "absolute",
        anchor: (_b = item.anchor) != null ? _b : "left",
        active: !!item.active,
        priority: Number((_c = item.priority) != null ? _c : 0),
        layoutSize: Number((_d = item.layoutSize) != null ? _d : item.size),
        disableTransition: Boolean(item.disableTransition)
      };
    }).sort((a, b) => b.priority - a.priority).reduce(
      ({ items: items2, layer }, item) => ({
        items: [...items2, __spreadValues$19(__spreadValues$19({}, layer), item)],
        layer: __spreadProps$o(__spreadValues$19({}, layer), {
          [item.anchor]: layer[item.anchor] + (item.active ? item.layoutSize : 0)
        })
      }),
      {
        items: [],
        layer: { top: 0, right: 0, bottom: 0, left: 0 }
      }
    );
  }
  const items = computed(() => generate().items);
  const getLayoutItem = (id) => items.value.find((item) => item.id === id);
  const computedOverlaps = computed(() => {
    var _a;
    const overlaps = (_a = props.overlaps) != null ? _a : [];
    const map = /* @__PURE__ */ new Map();
    for (const overlap of overlaps.filter((item) => item.includes(":"))) {
      const [top, bottom] = overlap.split(":");
      const topLayoutItem = getLayoutItem(top);
      const bottomLayoutItem = getLayoutItem(bottom);
      if (!topLayoutItem || !bottomLayoutItem)
        continue;
      const { anchor: topAlign, layoutSize: topAmount } = topLayoutItem;
      const { anchor: bottomAlign, layoutSize: bottomAmount } = bottomLayoutItem;
      if (!topAlign || !bottomAlign || !topAmount || !bottomAmount)
        continue;
      map.set(bottom, { anchor: topAlign, amount: topAmount });
      map.set(top, { anchor: bottomAlign, amount: -bottomAmount });
    }
    return map;
  });
  const transitionEnabled = computed(() => !items.value.some((ref2) => ref2.disableTransition));
  provide(LayoutKey, {
    register: (vm, id, itemProps) => {
      itemMap.set(id, itemProps);
      const instances = findChildrenWithProvide(LayoutKey, rootVm == null ? void 0 : rootVm.vnode);
      const instanceIndex = instances.indexOf(vm);
      if (instanceIndex > -1) {
        itemIds.splice(instanceIndex, 0, id);
      } else {
        itemIds.push(id);
      }
      const layoutItemStyles = computed(() => {
        const { items: items2 } = generate();
        const index = items2.findIndex((i) => i.id === id);
        const item = items2[index];
        if (!item)
          throw new Error(`Could not find layout item "${id}`);
        const overlap = computedOverlaps.value.get(id);
        if (overlap)
          item[overlap.anchor] += overlap.amount;
        const isHorizontal = item.anchor === "left" || item.anchor === "right";
        const isOppositeHorizontal = item.anchor === "right";
        const isOppositeVertical = item.anchor === "bottom";
        return __spreadValues$19({
          [item.anchor]: item.anchor === "right" ? "calc(0px + var(--ve-scrollbar-offset, 0px))" : "0px",
          height: isHorizontal ? `calc(100% - ${item.top}px - ${item.bottom}px)` : `${item.size}px`,
          marginLeft: isOppositeHorizontal ? void 0 : `${item.left}px`,
          marginRight: isOppositeHorizontal ? `${item.right}px` : void 0,
          marginTop: item.anchor !== "bottom" ? `${item.top}px` : void 0,
          marginBottom: item.anchor !== "top" ? `${item.bottom}px` : void 0,
          width: !isHorizontal ? `calc(100% - ${item.left}px - ${item.right}px)` : `${item.size}px`,
          zIndex: rootZIndex.value + items2.length * 2 - index * 2,
          transform: `translate${isHorizontal ? "X" : "Y"}(${(item.active ? 0 : -110) * (isOppositeHorizontal || isOppositeVertical ? -1 : 1)}%)`,
          position: item.position === "absolute" || rootZIndex.value !== ROOT_ZINDEX ? "absolute" : "fixed"
        }, transitionEnabled.value ? void 0 : { transition: "none" });
      });
      const layoutItemScrimStyles = computed(() => ({
        zIndex: layoutItemStyles.value.zIndex - 1,
        position: rootZIndex.value === ROOT_ZINDEX ? "fixed" : "absolute"
      }));
      return {
        layoutItemStyles,
        layoutItemScrimStyles
      };
    },
    unregister: (id) => {
      itemIds.splice(itemIds.indexOf(id), 1);
      itemMap.delete(id);
    },
    mainStyles: computed(() => {
      const { layer } = generate();
      return __spreadValues$19({
        position: "relative",
        paddingLeft: convertToUnit(layer.left),
        paddingRight: convertToUnit(layer.right),
        paddingTop: convertToUnit(layer.top),
        paddingBottom: convertToUnit(layer.bottom)
      }, transitionEnabled.value ? void 0 : { transition: "none" });
    }),
    getLayoutItem,
    items,
    layoutRect,
    rootZIndex,
    overlays
  });
  return {
    layoutClasses: computed(() => ({
      [`${name}--full-height`]: props.fullHeight
    })),
    layoutStyles: computed(() => ({
      zIndex: rootZIndex.value
    })),
    getLayoutItem,
    items,
    layoutRect,
    layoutRef: resizeRef
  };
}
function useLayout() {
  const layout = inject(LayoutKey);
  if (!layout)
    throw new Error("[VenoUi] Could not find layout instance");
  return layout;
}

var __defProp$18 = Object.defineProperty;
var __defProps$n = Object.defineProperties;
var __getOwnPropDescs$n = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$19 = Object.getOwnPropertySymbols;
var __hasOwnProp$19 = Object.prototype.hasOwnProperty;
var __propIsEnum$19 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$18 = (obj, key, value) => key in obj ? __defProp$18(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$18 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$19.call(b, prop))
      __defNormalProp$18(a, prop, b[prop]);
  if (__getOwnPropSymbols$19)
    for (var prop of __getOwnPropSymbols$19(b)) {
      if (__propIsEnum$19.call(b, prop))
        __defNormalProp$18(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$n = (a, b) => __defProps$n(a, __getOwnPropDescs$n(b));
const makeLayoutItemProps = propsFactory({
  modelValue: {
    type: Boolean,
    default: true
  },
  name: String,
  position: {
    type: String,
    default: "absolute"
  },
  anchor: {
    type: String,
    default: "left"
  },
  priority: {
    type: [String, Number],
    default: 0
  }
}, "layout-item");
function useLayoutItem(props) {
  var _a;
  const layout = useLayout();
  const id = (_a = props.value.name) != null ? _a : `layout-item-${getUid()}`;
  const vm = getCurrentInstance("useLayoutItem");
  const isKeptAlive = ref(false);
  const {
    layoutItemStyles,
    layoutItemScrimStyles
  } = layout.register(vm, id, computed(() => __spreadProps$n(__spreadValues$18({}, props.value), {
    active: !isKeptAlive.value && props.value.active
  })));
  onDeactivated(() => isKeptAlive.value = true);
  onActivated(() => isKeptAlive.value = false);
  onBeforeUnmount(() => layout.unregister(id));
  return {
    layoutItemStyles,
    layoutRect: layout.layoutRect,
    layoutItemScrimStyles
  };
}

function useLayoutMain() {
  return useLayout();
}

const OFFSET_ZINDEX = 400;
function useOverlay(isActive) {
  const layout = useLayout();
  const id = getUid();
  watch(isActive, (value) => {
    if (value) {
      layout.overlays.value.push(id);
    } else {
      layout.overlays.value = layout.overlays.value.filter((x) => x !== id);
    }
  }, {
    immediate: true
  });
  const overlayZIndex = computed(() => ROOT_ZINDEX + OFFSET_ZINDEX + layout.overlays.value.indexOf(id) + 1);
  return {
    overlayZIndex,
    layoutRect: layout.layoutRect
  };
}

var __defProp$17 = Object.defineProperty;
var __getOwnPropSymbols$18 = Object.getOwnPropertySymbols;
var __hasOwnProp$18 = Object.prototype.hasOwnProperty;
var __propIsEnum$18 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$17 = (obj, key, value) => key in obj ? __defProp$17(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$17 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$18.call(b, prop))
      __defNormalProp$17(a, prop, b[prop]);
  if (__getOwnPropSymbols$18)
    for (var prop of __getOwnPropSymbols$18(b)) {
      if (__propIsEnum$18.call(b, prop))
        __defNormalProp$17(a, prop, b[prop]);
    }
  return a;
};
const ProvidersKey = Symbol.for("veno-ui:providers");
function createProviders(app, options) {
  const providers = shallowRef(__spreadValues$17({}, options));
  Object.values(providers.value).forEach((provider) => {
    var _a;
    (_a = provider.register) == null ? void 0 : _a.call(provider, app);
  });
  function createRootProvider() {
    return Object.values(providers.value).reduce((Prev, Cur) => (props, {
      slots
    }) => createVNode(Prev, {
      "registered": true
    }, {
      default: () => [createVNode(Cur, {
        "registered": true
      }, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      })]
    }), (props, {
      slots
    }) => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots);
    });
  }
  function get(key) {
    return providers.value[key];
  }
  function set(key, value) {
    providers.value[key] = value;
  }
  return {
    providers,
    get,
    set,
    createRootProvider
  };
}
function useProviders() {
  const providers = inject(ProvidersKey);
  if (!providers)
    throw new Error("Could not find Veno UI providers injection");
  return providers;
}

var __defProp$16 = Object.defineProperty;
var __getOwnPropSymbols$17 = Object.getOwnPropertySymbols;
var __hasOwnProp$17 = Object.prototype.hasOwnProperty;
var __propIsEnum$17 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$16 = (obj, key, value) => key in obj ? __defProp$16(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$16 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$17.call(b, prop))
      __defNormalProp$16(a, prop, b[prop]);
  if (__getOwnPropSymbols$17)
    for (var prop of __getOwnPropSymbols$17(b)) {
      if (__propIsEnum$17.call(b, prop))
        __defNormalProp$16(a, prop, b[prop]);
    }
  return a;
};
const App = /* @__PURE__ */ defineComponent({
  name: "VeApp",
  props: __spreadValues$16(__spreadValues$16({}, makeThemeProps()), makeLayoutProps({
    fullHeight: true
  })),
  setup(props, {
    slots
  }) {
    const theme = provideTheme(props);
    const {
      getLayoutItem,
      items,
      layoutClasses
    } = provideLayout(props);
    const {
      createRootProvider
    } = useProviders();
    useRender(() => {
      const RootProvider = createRootProvider();
      return createVNode("div", {
        "class": ["ve-app", theme.themeClasses.value, layoutClasses.value],
        "data-app": "true"
      }, [createVNode("div", {
        "class": "ve-app__wrapper"
      }, [createVNode(RootProvider, null, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      })])]);
    });
    return {
      theme,
      getLayoutItem,
      items
    };
  }
});

var __defProp$15 = Object.defineProperty;
var __defProps$m = Object.defineProperties;
var __getOwnPropDescs$m = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$16 = Object.getOwnPropertySymbols;
var __hasOwnProp$16 = Object.prototype.hasOwnProperty;
var __propIsEnum$16 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$15 = (obj, key, value) => key in obj ? __defProp$15(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$15 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$16.call(b, prop))
      __defNormalProp$15(a, prop, b[prop]);
  if (__getOwnPropSymbols$16)
    for (var prop of __getOwnPropSymbols$16(b)) {
      if (__propIsEnum$16.call(b, prop))
        __defNormalProp$15(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$m = (a, b) => __defProps$m(a, __getOwnPropDescs$m(b));
const NamedAnchorKey = Symbol.for("veno-ui:named-anchor");
const makeNamedAnchor = propsFactory({
  offset: {
    type: [String, Number],
    default: 12
  },
  scrollTarget: {
    type: [String, Object]
  }
}, "named-anchor");
function useNamedAnchor(props) {
  const active = ref();
  const names = ref(/* @__PURE__ */ new Set());
  const offset = computed(() => parseInt(props.offset, 10));
  const scrollTarget = computed(() => typeof props.scrollTarget === "string" ? document.querySelector(props.scrollTarget) : props.scrollTarget);
  const scrolling = ref(false);
  const { isWebHashHistory } = useRouterHistory();
  const route = useRoute();
  let timeout = 0;
  const activate = (name) => {
    var _a, _b, _c;
    const target = document.getElementById(name);
    if (target) {
      clearTimeout(timeout);
      scrolling.value = true;
      timeout = setTimeout(() => scrolling.value = false, 800);
      const container = (_a = scrollTarget.value) != null ? _a : window;
      const offsetTop = (_c = (_b = scrollTarget.value) == null ? void 0 : _b.scrollTop) != null ? _c : window.scrollY;
      container.scrollTo({
        top: target.getBoundingClientRect().top + offsetTop - offset.value,
        behavior: "smooth"
      });
    }
    active.value = name;
  };
  const findActiveHash = () => {
    var _a, _b;
    if (scrolling.value || !names.value.size)
      return;
    const offsetTop = ((_a = scrollTarget.value) == null ? void 0 : _a.getBoundingClientRect().top) || 0;
    active.value = (_b = [...names.value].reduce((pos, name) => {
      const el = document.getElementById(name);
      if (el && document.documentElement.contains(el)) {
        const box = el.getBoundingClientRect();
        pos.push({
          name,
          top: box.top - offsetTop,
          height: box.height
        });
      }
      return pos;
    }, []).sort((a, b) => a.top - b.top).reduce((prev, item) => {
      if (item.top + item.height < 0) {
        return prev;
      }
      if (item.top <= props.offset) {
        if (prev === null) {
          return item;
        } else if (item.top === prev.top) {
          if (item.name === active.value) {
            return item;
          } else {
            return prev;
          }
        } else if (item.top > prev.top) {
          return item;
        } else {
          return prev;
        }
      }
      return prev;
    }, null)) == null ? void 0 : _b.name;
  };
  const onScroll = throttle(findActiveHash, 17);
  onMounted(() => {
    var _a, _b;
    document.addEventListener("scroll", onScroll, true);
    if (isWebHashHistory.value && ((_b = (_a = route.value) == null ? void 0 : _a.query) == null ? void 0 : _b.anchor)) {
      activate(route.value.query.anchor);
    } else if (window.location.hash) {
      activate(decodeURIComponent(window.location.hash.substring(1)));
    } else {
      findActiveHash();
    }
  });
  onBeforeUnmount(() => {
    document.removeEventListener("scroll", onScroll, true);
  });
  const namedAnchor = {
    names,
    active,
    activate,
    register: (name) => {
      names.value.add(name);
    },
    unregister: (name) => {
      names.value.delete(name);
      if (active.value === name) {
        active.value = void 0;
      }
    }
  };
  provide(NamedAnchorKey, namedAnchor);
  return namedAnchor;
}
const makeNamedAnchorItem = propsFactory({
  value: {
    type: String,
    required: true
  }
}, "named-anchor-item");
function useNamedAnchorItem(props) {
  const parent = inject(NamedAnchorKey);
  if (!parent)
    throw new Error("[VenoUi] Could not find namedAnchor instance");
  const { isWebHashHistory } = useRouterHistory();
  const item = __spreadProps$m(__spreadValues$15({}, parent), {
    isWebHashHistory,
    to: computed(() => isWebHashHistory.value ? { query: { anchor: props.value }, replace: true } : { hash: `#${props.value}`, replace: true }),
    isActive: computed(() => parent.active.value === props.value)
  });
  parent.register(props.value);
  onBeforeUnmount(() => {
    parent.unregister(props.value);
  });
  return item;
}

function _isSlot$a(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Link = /* @__PURE__ */ defineComponent({
  name: "VeLink",
  props: {
    underline: {
      type: [Boolean, String],
      default: "hover"
    },
    linkIcon: {
      type: String,
      default: "$link"
    },
    prependIcon: [Boolean, String, Object],
    appendIcon: [Boolean, String, Object]
  },
  setup(props, {
    slots
  }) {
    return () => {
      return createVNode(Button, {
        "class": ["ve-link", {
          "ve-link--underline": props.underline === true,
          "ve-link--underline-hover": props.underline === "hover"
        }],
        "variant": "text",
        "ripple": false,
        "overlay": false,
        "prepend-icon": props.prependIcon === true ? props.linkIcon : typeof props.prependIcon === "boolean" ? void 0 : props.prependIcon,
        "append-icon": props.appendIcon === true ? props.linkIcon : typeof props.appendIcon === "boolean" ? void 0 : props.appendIcon
      }, _isSlot$a(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});

var __defProp$14 = Object.defineProperty;
var __defProps$l = Object.defineProperties;
var __getOwnPropDescs$l = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$15 = Object.getOwnPropertySymbols;
var __hasOwnProp$15 = Object.prototype.hasOwnProperty;
var __propIsEnum$15 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$14 = (obj, key, value) => key in obj ? __defProp$14(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$14 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$15.call(b, prop))
      __defNormalProp$14(a, prop, b[prop]);
  if (__getOwnPropSymbols$15)
    for (var prop of __getOwnPropSymbols$15(b)) {
      if (__propIsEnum$15.call(b, prop))
        __defNormalProp$14(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$l = (a, b) => __defProps$l(a, __getOwnPropDescs$l(b));
const AnchorItem = /* @__PURE__ */ defineComponent({
  name: "VeAnchorItem",
  props: __spreadValues$14({
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 文本
     */
    text: String
  }, makeNamedAnchorItem()),
  setup(props, {
    slots
  }) {
    const {
      to,
      activate,
      isActive
    } = useNamedAnchorItem(props);
    return () => {
      return createVNode("li", {
        "class": ["ve-anchor-item", {
          "ve-anchor-item--active": isActive.value
        }]
      }, [createVNode(Link, {
        "to": to.value,
        "underline": false,
        "color": isActive.value ? props.activeColor : void 0,
        "onClick": (e) => {
          e.preventDefault();
          e.stopPropagation();
          activate(props.value);
        }
      }, __spreadProps$l(__spreadValues$14({}, slots), {
        default: () => {
          var _a, _b;
          return (_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text;
        }
      }))]);
    };
  }
});

var __defProp$13 = Object.defineProperty;
var __getOwnPropSymbols$14 = Object.getOwnPropertySymbols;
var __hasOwnProp$14 = Object.prototype.hasOwnProperty;
var __propIsEnum$14 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$13 = (obj, key, value) => key in obj ? __defProp$13(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$13 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$14.call(b, prop))
      __defNormalProp$13(a, prop, b[prop]);
  if (__getOwnPropSymbols$14)
    for (var prop of __getOwnPropSymbols$14(b)) {
      if (__propIsEnum$14.call(b, prop))
        __defNormalProp$13(a, prop, b[prop]);
    }
  return a;
};
const Anchor = /* @__PURE__ */ defineComponent({
  name: "VeAnchor",
  props: __spreadValues$13({
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 锚点项
     */
    items: Array
  }, makeNamedAnchor()),
  setup(props, {
    slots
  }) {
    useNamedAnchor(props);
    provideDefaults({
      VeAnchorItem: {
        activeColor: toRef(props, "activeColor")
      }
    });
    return () => {
      var _a, _b;
      return createVNode("ul", {
        "class": "ve-anchor"
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots), (_b = props.items) == null ? void 0 : _b.map((item) => createVNode(AnchorItem, mergeProps({
        "key": item.value
      }, item), null))]);
    };
  }
});

var __defProp$12 = Object.defineProperty;
var __getOwnPropSymbols$13 = Object.getOwnPropertySymbols;
var __hasOwnProp$13 = Object.prototype.hasOwnProperty;
var __propIsEnum$13 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$12 = (obj, key, value) => key in obj ? __defProp$12(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$12 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$13.call(b, prop))
      __defNormalProp$12(a, prop, b[prop]);
  if (__getOwnPropSymbols$13)
    for (var prop of __getOwnPropSymbols$13(b)) {
      if (__propIsEnum$13.call(b, prop))
        __defNormalProp$12(a, prop, b[prop]);
    }
  return a;
};
const Badge = /* @__PURE__ */ defineComponent({
  name: "VeBadge",
  inheritAttrs: false,
  props: __spreadValues$12(__spreadValues$12(__spreadValues$12({
    /**
     * @zh 标记是否存在边框
     */
    bordered: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 标记的颜色
     */
    color: String,
    /**
     * @zh 标记的内容
     */
    content: [Number, String],
    /**
     * @zh 标记是否显示为点
     */
    dot: Boolean,
    /**
     * @zh 是否为浮动的标记
     */
    floating: Boolean,
    /**
     * @zh 标记的图标
     */
    icon: [String, Object],
    /**
     * @zh 是否为内联的标记
     */
    inline: Boolean,
    /**
     * @zh 标记的位置
     */
    location: {
      type: String,
      default: "top-right",
      validator: (value) => {
        const [vertical, horizontal] = (value != null ? value : "").split("-");
        return ["top", "bottom"].includes(vertical) && ["left", "right"].includes(horizontal);
      }
    },
    /**
     * @zh 标记的数量最大值
     */
    max: [Number, String],
    /**
     * @zh 标记的数量
     */
    modelValue: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 标记的 X 偏移值
     */
    offsetX: [Number, String],
    /**
     * @zh 标记的 Y 偏移值
     */
    offsetY: [Number, String],
    /**
     * @zh 标记的文本颜色
     */
    textColor: String
  }, makeShapeProps()), makeTagProps()), makeTransitionProps({
    transition: {
      component: FadeTransition
    }
  })),
  setup(props, {
    slots,
    attrs
  }) {
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, "color"));
    const {
      shapeClasses
    } = useShape(props);
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(toRef(props, "textColor"));
    const position = computed(() => props.floating ? props.dot ? 2 : 4 : props.dot ? 8 : 12);
    function calculatePosition(offset) {
      return `calc(100% - ${convertToUnit(position.value + Number(offset != null ? offset : 0))})`;
    }
    const locationStyles = computed(() => {
      var _a;
      const [vertical, horizontal] = ((_a = props.location) != null ? _a : "").split("-");
      const styles = {
        bottom: "auto",
        left: "auto",
        right: "auto",
        top: "auto"
      };
      if (!props.inline) {
        styles[horizontal === "left" ? "right" : "left"] = calculatePosition(props.offsetX);
        styles[vertical === "top" ? "bottom" : "top"] = calculatePosition(props.offsetY);
      }
      return styles;
    });
    return () => {
      const value = Number(props.content);
      const content = !props.max || isNaN(value) ? props.content : value <= props.max ? value : `${props.max}+`;
      const [badgeAttrs, restAttrs] = pick(attrs, ["aria-atomic", "aria-label", "aria-live", "role", "title"]);
      return createVNode(props.tag, mergeProps({
        "class": ["ve-badge", {
          "ve-badge--bordered": props.bordered,
          "ve-badge--dot": props.dot,
          "ve-badge--floating": props.floating,
          "ve-badge--inline": props.inline
        }]
      }, restAttrs), {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots), createVNode(MaybeTransition, {
            "transition": props.transition
          }, {
            default: () => {
              var _a2, _b;
              return [withDirectives(createVNode("span", mergeProps({
                "class": ["ve-badge__content", backgroundColorClasses.value, shapeClasses.value, textColorClasses.value],
                "style": [backgroundColorStyles.value, locationStyles.value, textColorStyles.value],
                "aria-atomic": "true",
                "aria-label": "locale string here",
                "aria-live": "polite",
                "role": "status"
              }, badgeAttrs), [!props.dot && (((_b = (_a2 = slots.badge) == null ? void 0 : _a2.call(slots)) != null ? _b : props.icon) ? createVNode(Icon, {
                "icon": props.icon
              }, null) : content)]), [[vShow, props.modelValue]])];
            }
          })];
        }
      });
    };
  }
});

var __defProp$11 = Object.defineProperty;
var __getOwnPropSymbols$12 = Object.getOwnPropertySymbols;
var __hasOwnProp$12 = Object.prototype.hasOwnProperty;
var __propIsEnum$12 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$11 = (obj, key, value) => key in obj ? __defProp$11(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$11 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$12.call(b, prop))
      __defNormalProp$11(a, prop, b[prop]);
  if (__getOwnPropSymbols$12)
    for (var prop of __getOwnPropSymbols$12(b)) {
      if (__propIsEnum$12.call(b, prop))
        __defNormalProp$11(a, prop, b[prop]);
    }
  return a;
};
const BreadcrumbKey = createSymbol("breadcrumb");
const Breadcrumb = genericComponent()({
  name: "VeBreadcrumb",
  props: __spreadValues$11({}, makeTagProps({
    tag: "nav"
  })),
  emits: {
    "update:modelValue": (_value) => true
  },
  setup(props, {
    slots
  }) {
    useGroup(props, BreadcrumbKey);
    return () => {
      return createVNode(props.tag, {
        "aria-label": "breadcrumb",
        "class": "ve-breadcrumb"
      }, {
        default: () => {
          var _a;
          return [createVNode("ol", null, [(_a = slots.default) == null ? void 0 : _a.call(slots)])];
        }
      });
    };
  }
});

var __defProp$10 = Object.defineProperty;
var __getOwnPropSymbols$11 = Object.getOwnPropertySymbols;
var __hasOwnProp$11 = Object.prototype.hasOwnProperty;
var __propIsEnum$11 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$10 = (obj, key, value) => key in obj ? __defProp$10(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$10 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$11.call(b, prop))
      __defNormalProp$10(a, prop, b[prop]);
  if (__getOwnPropSymbols$11)
    for (var prop of __getOwnPropSymbols$11(b)) {
      if (__propIsEnum$11.call(b, prop))
        __defNormalProp$10(a, prop, b[prop]);
    }
  return a;
};
const BreadcrumbItem = genericComponent()({
  name: "VeBreadcrumbItem",
  props: __spreadValues$10(__spreadValues$10({}, makeButtonProps({
    variant: "text"
  })), makeGroupItemProps()),
  setup(props, {
    slots
  }) {
    const {
      id,
      group
    } = useGroupItem(props, BreadcrumbKey);
    const hasNext = computed(() => {
      if (!group.items.value.length)
        return false;
      return group.items.value[group.items.value.length - 1].id !== id;
    });
    return () => {
      var _a, _b, _c, _d, _e, _f;
      return createVNode(Fragment, null, [createVNode("li", {
        "class": ["ve-breadcrumb-item", {
          "ve-breadcrumb-item--has-next": hasNext.value
        }]
      }, [createVNode(Button, props, slots)]), hasNext.value && createVNode("li", {
        "class": "ve-breadcrumb-separator",
        "aria-hidden": "true"
      }, [(_f = (_e = (_a = slots.separator) == null ? void 0 : _a.call(slots)) != null ? _e : (_d = (_b = group.vm) == null ? void 0 : (_c = _b.slots).separator) == null ? void 0 : _d.call(_c)) != null ? _f : createVNode(Icon, {
        "icon": "$separator"
      }, null)])]);
    };
  }
});

const CarouselActivator = genericComponent()({
  name: "VeCarouselActivator",
  props: {
    // TODO variant: 'dot' | 'line' | 'slider'
    active: Boolean
  },
  setup(props) {
    return () => createVNode("div", {
      "class": ["ve-carousel-activator", {
        "ve-carousel-activator--active": props.active
      }]
    }, null);
  }
});

var __defProp$$ = Object.defineProperty;
var __getOwnPropSymbols$10 = Object.getOwnPropertySymbols;
var __hasOwnProp$10 = Object.prototype.hasOwnProperty;
var __propIsEnum$10 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$$ = (obj, key, value) => key in obj ? __defProp$$(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$$ = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$10.call(b, prop))
      __defNormalProp$$(a, prop, b[prop]);
  if (__getOwnPropSymbols$10)
    for (var prop of __getOwnPropSymbols$10(b)) {
      if (__propIsEnum$10.call(b, prop))
        __defNormalProp$$(a, prop, b[prop]);
    }
  return a;
};
const CarouselKey = createSymbol("carousel");
const Carousel = /* @__PURE__ */ defineComponent({
  name: "VeCarousel",
  props: __spreadValues$$(__spreadValues$$({
    /**
     * @zh 自动播放
     */
    autoplay: Boolean,
    /**
     * @zh 播放的时间间隔
     */
    interval: {
      type: [Number, String],
      default: 6e3,
      validator: (value) => value > 0
    }
  }, makeGroupProps({
    mandatory: "force"
  })), makePaperProps({
    variant: "text",
    size: void 0,
    density: void 0
  })),
  emits: {
    "update:modelValue": (_value) => true
  },
  setup(props, {
    slots
  }) {
    const {
      paperStyles,
      paperClasses
    } = usePaper(props);
    const {
      isSelected,
      select,
      selected,
      next,
      items
    } = useGroup(props, CarouselKey);
    let slideTimeout;
    const restartTimeout = () => {
      slideTimeout && clearTimeout(slideTimeout);
      slideTimeout = void 0;
      window.requestAnimationFrame(() => {
        if (!props.autoplay)
          return;
        slideTimeout = window.setTimeout(next, +props.interval > 0 ? +props.interval : 6e3);
      });
    };
    watch([selected, toRef(props, "autoplay"), toRef(props, "interval")], restartTimeout);
    return () => createVNode(props.tag, {
      "class": ["ve-carousel", paperClasses.value],
      "style": paperStyles.value
    }, {
      default: () => {
        var _a;
        return [(_a = slots.default) == null ? void 0 : _a.call(slots), createVNode("div", {
          "class": "ve-carousel__controls"
        }, [items.value.map((v) => createVNode(CarouselActivator, {
          "active": isSelected(v.id),
          "onClick": () => select(v.id, true)
        }, null))])];
      }
    });
  }
});

var __defProp$_ = Object.defineProperty;
var __getOwnPropSymbols$$ = Object.getOwnPropertySymbols;
var __hasOwnProp$$ = Object.prototype.hasOwnProperty;
var __propIsEnum$$ = Object.prototype.propertyIsEnumerable;
var __defNormalProp$_ = (obj, key, value) => key in obj ? __defProp$_(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$_ = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$$.call(b, prop))
      __defNormalProp$_(a, prop, b[prop]);
  if (__getOwnPropSymbols$$)
    for (var prop of __getOwnPropSymbols$$(b)) {
      if (__propIsEnum$$.call(b, prop))
        __defNormalProp$_(a, prop, b[prop]);
    }
  return a;
};
const CarouselItem = /* @__PURE__ */ defineComponent({
  name: "VeCarouselItem",
  props: __spreadValues$_(__spreadValues$_({}, makeGroupItemProps()), makeTagProps()),
  setup(props, {
    slots
  }) {
    const {
      isSelected,
      group
    } = useGroupItem(props, CarouselKey);
    const {
      items,
      selected
    } = group;
    const transition = ref();
    watch(() => items.value.findIndex(({
      id
    }) => selected.value.includes(id)), (val, oldVal) => {
      transition.value = oldVal > val ? "ve-carousel-item-x-reverse-transition" : "ve-carousel-item-x-transition";
    });
    return () => createVNode(Transition, {
      "name": transition.value
    }, {
      default: () => [withDirectives(createVNode(props.tag, {
        "class": "ve-carousel-item"
      }, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      }), [[vShow, isSelected.value]])]
    });
  }
});

var __defProp$Z = Object.defineProperty;
var __getOwnPropSymbols$_ = Object.getOwnPropertySymbols;
var __hasOwnProp$_ = Object.prototype.hasOwnProperty;
var __propIsEnum$_ = Object.prototype.propertyIsEnumerable;
var __defNormalProp$Z = (obj, key, value) => key in obj ? __defProp$Z(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$Z = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$_.call(b, prop))
      __defNormalProp$Z(a, prop, b[prop]);
  if (__getOwnPropSymbols$_)
    for (var prop of __getOwnPropSymbols$_(b)) {
      if (__propIsEnum$_.call(b, prop))
        __defNormalProp$Z(a, prop, b[prop]);
    }
  return a;
};
const Label = /* @__PURE__ */ defineComponent({
  name: "VeLabel",
  props: __spreadValues$Z({
    disabled: Boolean,
    error: Boolean,
    text: String
  }, makeThemeProps()),
  setup(props, {
    slots
  }) {
    return () => {
      var _a, _b;
      return createVNode("label", {
        "class": ["ve-label", {
          "ve-label--disabled": props.disabled,
          "ve-label--error": props.error
        }]
      }, [(_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text]);
    };
  }
});

const FormKey = createSymbol("form");
const makeFormProps = propsFactory({
  disabled: Boolean,
  fastFail: Boolean,
  lazyValidation: Boolean,
  readonly: Boolean,
  valid: {
    type: Boolean,
    default: null
  },
  modelValue: Object,
  defaultValue: Object
});
function provideForm(props) {
  var _a;
  const vm = getCurrentInstance("provideForm");
  const valid = useProxiedModel(props, "valid");
  const model = useProxiedModel(props, "modelValue");
  const defaultValue = (_a = props.defaultValue) != null ? _a : {};
  if (!model.value && defaultValue) {
    model.value = JSON.parse(JSON.stringify(defaultValue));
  }
  const isDisabled = computed(() => props.disabled);
  const isReadonly = computed(() => props.readonly);
  const isValidating = ref(false);
  const items = /* @__PURE__ */ new Map();
  const watchs = /* @__PURE__ */ new Map();
  const errorMessages = ref([]);
  async function submit(e) {
    e.preventDefault();
    const results = [];
    let _valid = true;
    errorMessages.value = [];
    valid.value = null;
    isValidating.value = true;
    for (const [id, item] of items) {
      if (!item.validate)
        continue;
      const itemErrorMessages = await item.validate();
      if (itemErrorMessages.length > 0) {
        _valid = false;
        results.push({
          id,
          errorMessages: itemErrorMessages
        });
      }
      if (!_valid && props.fastFail)
        break;
    }
    errorMessages.value = results;
    valid.value = _valid;
    isValidating.value = false;
    vm == null ? void 0 : vm.emit("submit", model.value, e);
  }
  async function reset(e) {
    e.preventDefault();
    items.forEach((item) => {
      var _a2;
      return (_a2 = item.reset) == null ? void 0 : _a2.call(item);
    });
    valid.value = null;
    vm == null ? void 0 : vm.emit("reset", e);
  }
  async function resetValidation() {
    items.forEach((item) => {
      var _a2;
      return (_a2 = item.resetValidation) == null ? void 0 : _a2.call(item);
    });
    errorMessages.value = [];
    valid.value = null;
    vm == null ? void 0 : vm.emit("resetValidation");
  }
  provide(FormKey, {
    isDisabled,
    isReadonly,
    isValidating,
    items,
    register: (id, item) => {
      items.set(id, item);
      watchs.set(id, [
        watch(item.name, (name) => {
          if (!name)
            return;
          const val = getObjectValueByPath(model.value, name);
          if (val !== item.modelValue.value)
            item.modelValue.value = val;
        }, { immediate: true }),
        watch(item.modelValue, (value) => {
          const name = item.name.value;
          if (!name)
            return;
          if (value !== getObjectValueByPath(model.value, name)) {
            setObjectValueByPath(model.value, name, value);
          }
        }, { immediate: true, deep: true })
      ]);
    },
    unregister: (id) => {
      var _a2;
      items.delete(id);
      (_a2 = watchs.get(id)) == null ? void 0 : _a2.forEach((v) => v());
      watchs.delete(id);
    }
  });
  return {
    errorMessages,
    isDisabled,
    isReadonly,
    isValidating,
    items,
    submit,
    reset,
    resetValidation
  };
}
function useForm() {
  return inject(FormKey, null);
}

const SelectionGroupControlKey = createSymbol("selection-control-group");
const makeSelectionGroupControlProps = propsFactory({
  id: String,
  inline: Boolean,
  name: String,
  falseIcon: String,
  trueIcon: String,
  multiple: {
    type: Boolean,
    default: null
  },
  disabled: Boolean,
  readonly: Boolean,
  type: String,
  modelValue: null
}, "selection-control-group");
const SelectionGroupControl = /* @__PURE__ */ defineComponent({
  name: "VeSelectionGroupControl",
  props: makeSelectionGroupControlProps(),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const modelValue = useProxiedModel(props, "modelValue");
    const id = computed(() => props.name || props.id || `ve-selection-control-group-${getUid()}`);
    const multiple = computed(() => {
      return !!props.multiple || props.multiple == null && Array.isArray(modelValue.value);
    });
    const group = {
      disabled: toRef(props, "disabled"),
      inline: toRef(props, "inline"),
      modelValue,
      multiple,
      id,
      name: toRef(props, "name"),
      falseIcon: toRef(props, "falseIcon"),
      trueIcon: toRef(props, "trueIcon"),
      readonly: toRef(props, "readonly"),
      type: toRef(props, "type")
    };
    provide(SelectionGroupControlKey, group);
    useRender(() => {
      var _a;
      return createVNode("div", {
        "class": "ve-selection-group-control",
        "aria-labelled-by": props.type === "radio" ? group.id.value : void 0,
        "role": props.type === "radio" ? "radiogroup" : void 0
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots)]);
    });
    return group;
  }
});
function useSelectionGroupControl() {
  return inject(SelectionGroupControlKey, null);
}

var __defProp$Y = Object.defineProperty;
var __getOwnPropSymbols$Z = Object.getOwnPropertySymbols;
var __hasOwnProp$Z = Object.prototype.hasOwnProperty;
var __propIsEnum$Z = Object.prototype.propertyIsEnumerable;
var __defNormalProp$Y = (obj, key, value) => key in obj ? __defProp$Y(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$Y = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$Z.call(b, prop))
      __defNormalProp$Y(a, prop, b[prop]);
  if (__getOwnPropSymbols$Z)
    for (var prop of __getOwnPropSymbols$Z(b)) {
      if (__propIsEnum$Z.call(b, prop))
        __defNormalProp$Y(a, prop, b[prop]);
    }
  return a;
};
const makeSelectionControlProps = propsFactory(__spreadValues$Y(__spreadValues$Y(__spreadValues$Y({
  color: String,
  disabled: Boolean,
  error: Boolean,
  id: String,
  inline: Boolean,
  label: String,
  falseIcon: String,
  trueIcon: String,
  multiple: {
    type: Boolean,
    default: null
  },
  name: String,
  readonly: Boolean,
  trueValue: null,
  falseValue: null,
  modelValue: null,
  type: String,
  value: null,
  valueComparator: {
    type: Function,
    default: deepEqual
  }
}, makeThemeProps()), makeSizeProps()), makeDensityProps()), "selection-control");
const SelectionControl = genericComponent()({
  name: "VeSelectionControl",
  inheritAttrs: false,
  props: makeSelectionControlProps(),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    attrs,
    slots
  }) {
    const group = useSelectionGroupControl();
    const {
      sizeClasses,
      sizeStyles
    } = useSize(props);
    const {
      densityClasses
    } = useDensity(props);
    const modelValue = useProxiedModel(props, "modelValue");
    const trueValue = computed(() => props.trueValue !== void 0 ? props.trueValue : props.value !== void 0 ? props.value : true);
    const falseValue = computed(() => props.falseValue !== void 0 ? props.falseValue : false);
    const isMultiple = computed(() => (group == null ? void 0 : group.multiple.value) || !!props.multiple || props.multiple == null && Array.isArray(modelValue.value));
    const model = computed({
      get() {
        const val = group ? group.modelValue.value : modelValue.value;
        if (isMultiple.value) {
          return (val || []).some((v) => props.valueComparator(v, trueValue.value));
        }
        return props.valueComparator(val, trueValue.value);
      },
      set(val) {
        const currentValue = val ? trueValue.value : falseValue.value;
        let newVal = currentValue;
        if (isMultiple.value) {
          const oldVal = group ? group.modelValue.value : modelValue.value;
          if (val) {
            newVal = [...wrapInArray(oldVal), currentValue];
          } else {
            newVal = wrapInArray(oldVal).filter((v) => !props.valueComparator(v, trueValue.value));
          }
        }
        if (group) {
          group.modelValue.value = newVal;
        } else {
          modelValue.value = newVal;
        }
      }
    });
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(computed(() => {
      return model.value ? props.color : void 0;
    }));
    const icon = computed(() => {
      var _a, _b;
      return model.value ? (_a = group == null ? void 0 : group.trueIcon.value) != null ? _a : props.trueIcon : (_b = group == null ? void 0 : group.falseIcon.value) != null ? _b : props.falseIcon;
    });
    const id = computed(() => props.name || props.id || `ve-selection-control-${getUid()}`);
    const isFocused = ref(false);
    const isFocusVisible = ref(false);
    const inputRef = ref();
    const form = useForm();
    onBeforeMount(() => {
      form == null ? void 0 : form.register(id.value, {
        name: toRef(props, "name"),
        modelValue: model
      });
    });
    onBeforeUnmount(() => {
      form == null ? void 0 : form.unregister(id.value);
    });
    function onFocus(e) {
      isFocused.value = true;
      if (!SUPPORTS_FOCUS_VISIBLE || SUPPORTS_FOCUS_VISIBLE && e.target.matches(":focus-visible")) {
        isFocusVisible.value = true;
      }
    }
    function onBlur() {
      isFocused.value = false;
      isFocusVisible.value = false;
    }
    useRender(() => {
      var _a, _b, _c, _d;
      const slotProps = {
        label: props.label,
        model,
        textColorClasses,
        textColorStyles,
        props: {
          onFocus,
          onBlur,
          id: id.value
        }
      };
      const type = (_a = group == null ? void 0 : group.type.value) != null ? _a : props.type;
      const hasLabel = !!(slots.label || props.label || props.value);
      const [rootAttrs, restAttrs] = filterInputAttrs(attrs);
      return createVNode("div", mergeProps(rootAttrs, {
        "class": ["ve-selection-control", {
          "ve-selection-control--dirty": model.value,
          "ve-selection-control--disabled": props.disabled,
          "ve-selection-control--error": props.error,
          "ve-selection-control--focused": isFocused.value,
          "ve-selection-control--focus-visible": isFocusVisible.value,
          "ve-selection-control--inline": (group == null ? void 0 : group.inline.value) || props.inline
        }, sizeClasses.value, densityClasses.value, textColorClasses.value],
        "style": sizeStyles.value
      }), [createVNode("div", {
        "class": "ve-selection-control__wrapper"
      }, [(_b = slots.default) == null ? void 0 : _b.call(slots, slotProps), createVNode("div", {
        "class": "ve-selection-control__input",
        "style": textColorStyles.value
      }, [icon.value && createVNode(Icon, {
        "icon": icon.value
      }, null), (_c = slots.input) == null ? void 0 : _c.call(slots, slotProps), withDirectives(createVNode("input", mergeProps({
        "class": "ve-native-control",
        "ref": inputRef,
        "onUpdate:modelValue": ($event) => model.value = $event,
        "disabled": props.disabled,
        "id": id.value,
        "onBlur": onBlur,
        "onFocus": onFocus,
        "readonly": props.readonly,
        "type": type,
        "value": trueValue.value,
        "name": (_d = group == null ? void 0 : group.name.value) != null ? _d : props.name,
        "aria-checked": type === "checkbox" ? model.value : void 0
      }, restAttrs), null), [[vModelDynamic, model.value]])])]), hasLabel && createVNode(Label, {
        "for": id.value
      }, {
        default: () => {
          var _a2, _b2, _c2;
          return [(_c2 = (_b2 = (_a2 = slots.label) == null ? void 0 : _a2.call(slots, slotProps)) != null ? _b2 : props.label) != null ? _c2 : props.value];
        }
      })]);
    });
    return {
      isFocused,
      inputRef
    };
  }
});
function filterSelectionControlProps(props) {
  return pick(props, Object.keys(SelectionControl.props));
}

var __defProp$X = Object.defineProperty;
var __getOwnPropSymbols$Y = Object.getOwnPropertySymbols;
var __hasOwnProp$Y = Object.prototype.hasOwnProperty;
var __propIsEnum$Y = Object.prototype.propertyIsEnumerable;
var __defNormalProp$X = (obj, key, value) => key in obj ? __defProp$X(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$X = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$Y.call(b, prop))
      __defNormalProp$X(a, prop, b[prop]);
  if (__getOwnPropSymbols$Y)
    for (var prop of __getOwnPropSymbols$Y(b)) {
      if (__propIsEnum$Y.call(b, prop))
        __defNormalProp$X(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$9(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Checkbox = /* @__PURE__ */ defineComponent({
  name: "VeCheckbox",
  props: __spreadValues$X({
    /**
     * @zh 不确定的
     */
    indeterminate: Boolean,
    /**
     * @zh 不确定的图标
     */
    indeterminateIcon: {
      type: String,
      default: "$checkboxIndeterminate"
    }
  }, makeSelectionControlProps({
    type: "checkbox",
    falseIcon: "$checkboxOff",
    trueIcon: "$checkboxOn",
    color: "primary"
  })),
  emits: {
    "update:modelValue": (_val) => true,
    "update:indeterminate": (_val) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    const indeterminate = useProxiedModel(props, "indeterminate");
    const falseIcon = computed(() => {
      return indeterminate.value ? props.indeterminateIcon : props.falseIcon;
    });
    const trueIcon = computed(() => {
      return indeterminate.value ? props.indeterminateIcon : props.trueIcon;
    });
    function onChange(val) {
      if (indeterminate.value) {
        indeterminate.value = false;
      } else {
        emit("update:modelValue", val);
      }
    }
    return () => {
      const [controlProps] = filterSelectionControlProps(props);
      return createVNode(SelectionControl, mergeProps(controlProps, {
        "class": "ve-checkbox",
        "onUpdate:modelValue": onChange,
        "falseIcon": falseIcon.value,
        "trueIcon": trueIcon.value,
        "aria-checked": indeterminate.value ? "mixed" : void 0
      }), _isSlot$9(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});

var __defProp$W = Object.defineProperty;
var __getOwnPropSymbols$X = Object.getOwnPropertySymbols;
var __hasOwnProp$X = Object.prototype.hasOwnProperty;
var __propIsEnum$X = Object.prototype.propertyIsEnumerable;
var __defNormalProp$W = (obj, key, value) => key in obj ? __defProp$W(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$W = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$X.call(b, prop))
      __defNormalProp$W(a, prop, b[prop]);
  if (__getOwnPropSymbols$X)
    for (var prop of __getOwnPropSymbols$X(b)) {
      if (__propIsEnum$X.call(b, prop))
        __defNormalProp$W(a, prop, b[prop]);
    }
  return a;
};
const Messages = /* @__PURE__ */ defineComponent({
  name: "VeMessages",
  props: __spreadValues$W({
    active: Boolean,
    value: {
      type: [Array, String],
      default: () => []
    }
  }, makeTransitionProps({
    transition: {
      component: FadeTransition,
      group: true
    }
  })),
  setup(props, {
    slots
  }) {
    const messages = computed(() => wrapInArray(props.value));
    return () => {
      const hasMessages = messages.value.length > 0 && props.active;
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "tag": "div",
        "class": "ve-messages"
      }, {
        default: () => {
          var _a;
          return [hasMessages && messages.value.map((message, i) => createVNode("div", {
            "class": "ve-messages__message",
            "key": i
          }, [message])), (_a = slots == null ? void 0 : slots.default) == null ? void 0 : _a.call(slots)];
        }
      });
    };
  }
});

const makeValidationProps = propsFactory({
  /**
   * @zh 是否为禁用状态
   */
  disabled: Boolean,
  /**
   * @zh 是否为错误状态
   */
  error: Boolean,
  /**
   * @zh 错误消息
   */
  errorMessages: {
    type: [Array, String],
    default: () => []
  },
  /**
   * @zh 最大错误数
   */
  maxErrors: {
    type: [Number, String],
    default: 1
  },
  /**
   * @zh 是否只读
   */
  readonly: Boolean,
  /**
   * @zh 验证规则
   */
  rules: {
    type: Array,
    default: () => []
  },
  /**
   * @zh 验证值
   */
  modelValue: null
});
function useValidation(props, name = getCurrentInstanceName()) {
  const errorMessages = ref([]);
  const isPristine = ref(true);
  const isDisabled = computed(() => !!props.disabled);
  const isReadonly = computed(() => !!props.readonly);
  const isValid = computed(() => {
    var _a;
    if (props.error || ((_a = props.errorMessages) == null ? void 0 : _a.length) || errorMessages.value.length)
      return false;
    return isPristine.value ? null : true;
  });
  const isValidating = ref(false);
  const validationClasses = computed(() => {
    return {
      [`${name}--error`]: isValid.value === false,
      [`${name}--disabled`]: isDisabled.value,
      [`${name}--readonly`]: isReadonly.value
    };
  });
  const vm = getCurrentInstance("useValidation");
  function reset() {
    resetValidation();
    vm == null ? void 0 : vm.emit("update:modelValue", null);
  }
  function resetValidation() {
    isPristine.value = true;
    errorMessages.value = [];
  }
  async function validate() {
    var _a, _b;
    const results = [];
    errorMessages.value = [];
    isValidating.value = true;
    for (const rule of props.rules) {
      if (results.length >= (props.maxErrors || 1)) {
        break;
      }
      const handler = typeof rule === "function" ? rule : () => rule;
      const result = await handler((_b = (_a = props == null ? void 0 : props.modelValue) == null ? void 0 : _a.value) != null ? _b : props.modelValue);
      if (result === true)
        continue;
      if (typeof result !== "string") {
        console.warn(`${result} is not a valid value. Rule functions must return boolean true or a string.`);
        continue;
      }
      results.push(result);
    }
    errorMessages.value = results;
    isValidating.value = false;
    isPristine.value = false;
    return errorMessages.value;
  }
  return {
    errorMessages,
    isDisabled,
    isReadonly,
    isPristine,
    isValid,
    isValidating,
    reset,
    resetValidation,
    validate,
    validationClasses
  };
}

var __defProp$V = Object.defineProperty;
var __defProps$k = Object.defineProperties;
var __getOwnPropDescs$k = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$W = Object.getOwnPropertySymbols;
var __hasOwnProp$W = Object.prototype.hasOwnProperty;
var __propIsEnum$W = Object.prototype.propertyIsEnumerable;
var __defNormalProp$V = (obj, key, value) => key in obj ? __defProp$V(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$V = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$W.call(b, prop))
      __defNormalProp$V(a, prop, b[prop]);
  if (__getOwnPropSymbols$W)
    for (var prop of __getOwnPropSymbols$W(b)) {
      if (__propIsEnum$W.call(b, prop))
        __defNormalProp$V(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$k = (a, b) => __defProps$k(a, __getOwnPropDescs$k(b));
function filterFormControlSlots(slots) {
  return pick(slots, FormControlSlots);
}
const FormControlEmits = {
  "click:prepend": (_event) => true,
  "click:label": (_event) => true,
  "click:append": (_event) => true,
  "update:modelValue": (_modelValue) => true
};
const FormControlSlots = ["prepend", "label", "default", "append", "details"];
const FormControl = genericComponent()({
  name: "VeFormControl",
  props: __spreadValues$V(__spreadValues$V(__spreadValues$V(__spreadValues$V({
    /**
     * @zh 后置图标
     */
    appendIcon: [String, Object],
    /**
     * @zh 布局方向
     */
    direction: {
      type: String,
      default: "horizontal",
      validator: (v) => ["horizontal", "vertical"].includes(v)
    },
    /**
     * @zh 聚焦的
     */
    focused: Boolean,
    /**
     * @zh 隐藏详情
     */
    hideDetails: [Boolean, String],
    /**
     * @zh 存在提示
     */
    hint: String,
    /**
     * @zh 内联
     */
    inline: Boolean,
    /**
     * @zh 标签文本
     */
    label: [Boolean, String],
    /**
     * @zh 标签ID
     */
    labelId: String,
    /**
     * @zh 标签宽度
     */
    labelWidth: [String, Number],
    /**
     * @zh 提示消息
     */
    messages: {
      type: [Array, String],
      default: () => []
    },
    /**
     * @zh 名称
     */
    name: String,
    /**
     * @zh 后置图标
     */
    prependIcon: String,
    /**
     * @zh 持续显示的提示
     */
    persistentHint: Boolean
  }, makeDimensionProps()), makeSizeProps()), makeDensityProps()), makeValidationProps()),
  emits: FormControlEmits,
  setup(props, {
    slots,
    emit
  }) {
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      sizeClasses,
      sizeStyles
    } = useSize(props);
    const model = useProxiedModel(props, "modelValue");
    const computedDimensionStyles = computed(() => {
      var _a;
      return __spreadProps$k(__spreadValues$V({}, dimensionStyles.value), {
        minHeight: (_a = dimensionStyles.value.minHeight) != null ? _a : dimensionStyles.value.height
      });
    });
    const {
      densityClasses
    } = useDensity(props);
    const {
      errorMessages,
      isDisabled,
      isReadonly,
      isPristine,
      isValid,
      isValidating,
      reset,
      resetValidation,
      validate,
      validationClasses
    } = useValidation(props);
    const form = useForm();
    const id = computed(() => {
      var _a;
      return (_a = props.name) != null ? _a : `ve-form-control-${getUid()}`;
    });
    onBeforeMount(() => {
      form == null ? void 0 : form.register(id.value, {
        name: toRef(props, "name"),
        modelValue: model,
        validate,
        reset,
        resetValidation
      });
    });
    onBeforeUnmount(() => {
      form == null ? void 0 : form.unregister(id.value);
    });
    const slotProps = computed(() => ({
      isDisabled,
      isReadonly,
      isPristine,
      isValid,
      isValidating,
      reset,
      resetValidation,
      validate
    }));
    useRender(() => {
      var _a, _b, _c, _d;
      const hasPrepend = !!(slots.prepend || props.prependIcon);
      const hasLabel = !!(slots.label || props.label);
      const hasAppend = !!(slots.append || props.appendIcon);
      const hasHint = !!(slots.hint || props.hint);
      const hasMessages = !!(slots.messages || ((_a = props.messages) == null ? void 0 : _a.length) || errorMessages.value.length);
      const hasDetails = !props.hideDetails || props.hideDetails === "auto" && (hasMessages || hasHint);
      const showMessages = hasMessages || hasHint && (props.persistentHint || props.focused);
      return createVNode("div", {
        "class": ["ve-form-control", {
          [`ve-form-control--${props.direction}`]: !!props.direction,
          "ve-form-control--hide-details": props.hideDetails,
          "ve-form-control--inline": props.inline
        }, sizeClasses.value, densityClasses.value, validationClasses.value]
      }, [hasPrepend && createVNode("div", {
        "class": "ve-form-control__prepend"
      }, [(_b = slots.prepend) == null ? void 0 : _b.call(slots, slotProps.value), props.prependIcon && createVNode(Icon, {
        "onClick": (e) => emit("click:prepend", e),
        "icon": props.prependIcon
      }, null)]), hasLabel && createVNode("div", {
        "class": "ve-form-control__label",
        "style": {
          width: convertToUnit(props.labelWidth)
        }
      }, [createVNode(Label, {
        "disabled": isDisabled.value,
        "error": isValid.value === false,
        "onClick": (e) => emit("click:label", e),
        "for": props.labelId
      }, {
        default: () => {
          var _a2, _b2;
          return [(_b2 = (_a2 = slots.label) == null ? void 0 : _a2.call(slots, slotProps.value)) != null ? _b2 : props.label];
        }
      })]), slots.default && createVNode("div", {
        "class": "ve-form-control__control",
        "style": [sizeStyles.value, computedDimensionStyles.value]
      }, [slots.default(slotProps.value)]), hasAppend && createVNode("div", {
        "class": "ve-form-control__append"
      }, [props.appendIcon && createVNode(Icon, {
        "onClick": (e) => emit("click:append", e),
        "icon": props.appendIcon
      }, null), (_c = slots == null ? void 0 : slots.append) == null ? void 0 : _c.call(slots, slotProps.value)]), hasDetails && createVNode("div", {
        "class": "ve-form-control__details"
      }, [createVNode(Messages, {
        "active": showMessages,
        "value": hasMessages ? props.messages : [props.hint]
      }, {
        default: slots.messages
      }), (_d = slots.details) == null ? void 0 : _d.call(slots, slotProps.value)])]);
    });
    return {
      isDisabled,
      isReadonly,
      isPristine,
      isValid,
      isValidating,
      reset,
      resetValidation,
      validate
    };
  }
});

var __defProp$U = Object.defineProperty;
var __defProps$j = Object.defineProperties;
var __getOwnPropDescs$j = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$V = Object.getOwnPropertySymbols;
var __hasOwnProp$V = Object.prototype.hasOwnProperty;
var __propIsEnum$V = Object.prototype.propertyIsEnumerable;
var __defNormalProp$U = (obj, key, value) => key in obj ? __defProp$U(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$U = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$V.call(b, prop))
      __defNormalProp$U(a, prop, b[prop]);
  if (__getOwnPropSymbols$V)
    for (var prop of __getOwnPropSymbols$V(b)) {
      if (__propIsEnum$V.call(b, prop))
        __defNormalProp$U(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$j = (a, b) => __defProps$j(a, __getOwnPropDescs$j(b));
var __objRest$3 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$V.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$V)
    for (var prop of __getOwnPropSymbols$V(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$V.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
const CheckboxGroup = /* @__PURE__ */ defineComponent({
  name: "VeCheckboxGroup",
  props: __spreadValues$U(__spreadValues$U(__spreadValues$U({
    /**
     * @zh 复选框的所有可选项
     */
    items: Array
  }, makeSelectionGroupControlProps({
    type: "checkbox",
    falseIcon: "$checkboxOff",
    trueIcon: "$checkboxOn",
    multiple: true
  })), makeSizeProps()), makeDensityProps()),
  emits: {
    "update:modelValue": (_val) => true
  },
  setup(props, {
    slots
  }) {
    const id = computed(() => props.id || `ve-checkbox-group-${getUid()}`);
    const model = useProxiedModel(props, "modelValue");
    const items = computed(() => {
      var _a;
      return (_a = props.items) == null ? void 0 : _a.map((itemProps) => typeof itemProps === "string" ? {
        value: itemProps
      } : itemProps);
    });
    provideDefaults({
      VeCheckbox: {
        size: toRef(props, "size"),
        density: toRef(props, "density"),
        readonly: toRef(props, "readonly"),
        disabled: toRef(props, "disabled")
      }
    });
    return () => {
      const _a = props, {
        density,
        size
      } = _a, restProps = __objRest$3(_a, [
        "density",
        "size"
      ]);
      return createVNode(FormControl, {
        "class": "ve-checkbox-group",
        "density": density,
        "name": props.name,
        "size": size,
        "modelValue": model.value,
        "onUpdate:modelValue": ($event) => model.value = $event
      }, __spreadProps$j(__spreadValues$U({}, slots), {
        default: ({
          isDisabled,
          isReadonly,
          props: controlProps
        }) => {
          return createVNode(SelectionGroupControl, mergeProps(restProps, controlProps, {
            "id": id.value,
            "disabled": isDisabled.value,
            "readonly": isReadonly.value,
            "modelValue": model.value,
            "onUpdate:modelValue": ($event) => model.value = $event
          }), {
            default: () => {
              var _a2, _b;
              return [(_a2 = items.value) == null ? void 0 : _a2.map((itemProps) => createVNode(Checkbox, itemProps, null)), (_b = slots.default) == null ? void 0 : _b.call(slots)];
            }
          });
        }
      }));
    };
  }
});

const aliases$1 = {
  sh: "bash",
  shell: "bash",
  vue: "markup",
  html: "markup",
  md: "markdown",
  ts: "typescript",
  js: "javascript"
};
async function prismjsHighlightCode(prismjs, code, language) {
  language = language.toLowerCase();
  if (language in aliases$1) {
    language = aliases$1[language];
  }
  if (!prismjs.languages[language]) {
    console.warn(`[VenoUi] Syntax highlight for language "${language}" is not supported. try "import 'prismjs/components/prism-${language}.js'" .`);
    return code;
  }
  return prismjs.highlight(
    code,
    prismjs.languages[language],
    language
  );
}

const aliases = {
  template: "vue-html"
};
async function shikiHighlightCode(shiki, code, language) {
  language = language.toLowerCase();
  if (language in aliases) {
    language = aliases[language];
  }
  try {
    const highlighter = await shiki;
    await highlighter.loadLanguage(language);
    return highlighter.codeToHtml(code, language).replace(/[\s\S]*code>([\s\S]*)<\/code[\s\S]*/, "$1");
  } catch (e) {
    console.warn(`[VenoUi] Syntax highlight for language "${language}" error: ${e}" .`);
    return code;
  }
}

const HighlighterKey = createSymbol("highlighter");
function createHighlighter(options) {
  return ref({
    highlight: async (code, language) => {
      var _a;
      const type = (_a = options == null ? void 0 : options.type) != null ? _a : "shiki";
      if (language === "text") {
        return code;
      } else if (type === "shiki" && (options == null ? void 0 : options.shiki)) {
        return await shikiHighlightCode(options.shiki, code, language);
      } else if (type === "prismjs" && (options == null ? void 0 : options.prismjs)) {
        return await prismjsHighlightCode(options.prismjs, code, language);
      } else {
        return code;
      }
    }
  });
}
function useHighlighter() {
  const highlighter = inject(HighlighterKey);
  if (!highlighter)
    throw new Error("[VenoUi] Could not find highlighter instance");
  return highlighter;
}

const makeScrollbar = propsFactory({
  /**
   * @zh 美化滚动条
   */
  beautifyScrollbar: {
    type: Boolean,
    default: true
  }
}, "scrollbar");
function useScrollbar(props, name = getCurrentInstanceName()) {
  const scrollbarClasses = computed(() => props.beautifyScrollbar ? `${name}--beautify-scrollbar` : null);
  return {
    scrollbarClasses
  };
}

var __defProp$T = Object.defineProperty;
var __getOwnPropSymbols$U = Object.getOwnPropertySymbols;
var __hasOwnProp$U = Object.prototype.hasOwnProperty;
var __propIsEnum$U = Object.prototype.propertyIsEnumerable;
var __defNormalProp$T = (obj, key, value) => key in obj ? __defProp$T(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$T = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$U.call(b, prop))
      __defNormalProp$T(a, prop, b[prop]);
  if (__getOwnPropSymbols$U)
    for (var prop of __getOwnPropSymbols$U(b)) {
      if (__propIsEnum$U.call(b, prop))
        __defNormalProp$T(a, prop, b[prop]);
    }
  return a;
};
const HTML_ESCAPE_TEST_RE = /[&<>"]/;
const HTML_ESCAPE_REPLACE_RE = /[&<>"]/g;
const HTML_REPLACEMENTS = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;"
};
function replaceUnsafeChar(ch) {
  return HTML_REPLACEMENTS[ch];
}
function escapeHtml(str) {
  if (HTML_ESCAPE_TEST_RE.test(str)) {
    return str.replace(HTML_ESCAPE_REPLACE_RE, replaceUnsafeChar);
  }
  return str;
}
const Code = /* @__PURE__ */ defineComponent({
  name: "VeCode",
  props: __spreadValues$T(__spreadValues$T(__spreadValues$T({
    /**
     * @zh 需要高亮的代码
     */
    code: [String, Object],
    /**
     * @zh 背景颜色
     */
    color: String,
    /**
     * @zh 显示代码语言
     */
    showLanguage: Boolean,
    /**
     * @zh 显示行号
     */
    showLineNumbers: Boolean,
    /**
     * @zh 高亮的行号
     */
    highlightedLineNumbers: Array,
    /**
     * @zh 使用行内样式
     */
    inline: Boolean,
    /**
     * @zh 代码语言
     */
    language: {
      type: String,
      default: "text"
    }
  }, makeThemeProps()), makeShapeProps()), makeScrollbar()),
  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = provideTheme(props);
    const {
      shapeClasses
    } = useShape(props);
    const highlighter = useHighlighter();
    const {
      scrollbarClasses
    } = useScrollbar(props);
    const code = computed(() => {
      var _a, _b;
      let value = "";
      if (props.code) {
        value = typeof props.code === "object" ? JSON.stringify(props.code, null, 2) : (_a = props.code) != null ? _a : "";
      } else if (slots.default) {
        value = (_b = flattenFragments(slots.default()).filter((node) => node.children && typeof node.children === "string")[0]) == null ? void 0 : _b.children;
      }
      return decodeURIComponent(value).replace(/\n$/, "").replace(/^\n/, "");
    });
    const highlightedCode = ref(escapeHtml(code.value));
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(props, "color");
    const language = computed(() => typeof props.code === "object" ? "json" : props.language);
    const lineNumbers = computed(() => code.value.split("\n").map((v, i) => i + 1));
    const highlightedLines = computed(() => {
      return lineNumbers.value.filter((lineNumber) => {
        var _a;
        return (_a = props.highlightedLineNumbers) == null ? void 0 : _a.some((v) => {
          let start = v;
          let end;
          if (typeof v === "object") {
            [start, end] = v;
          }
          if (start && end) {
            return lineNumber >= start && lineNumber <= end;
          }
          return lineNumber === start;
        });
      });
    });
    async function highlight() {
      var _a;
      highlightedCode.value = await ((_a = highlighter.value) == null ? void 0 : _a.highlight(code.value, language.value));
    }
    onMounted(highlight);
    watch([code, language], highlight);
    return () => {
      var _a;
      if (props.inline) {
        return createVNode("code", {
          "class": ["ve-code", "ve-code--inline", themeClasses.value, shapeClasses.value, backgroundColorClasses.value],
          "style": backgroundColorStyles.value,
          "innerHTML": escapeHtml(highlightedCode.value)
        }, null);
      }
      const showLines = props.showLineNumbers || !!((_a = props.highlightedLineNumbers) == null ? void 0 : _a.length);
      return createVNode("div", {
        "class": ["ve-code", "ve-code--block", {
          "ve-code--show-line-numbers": !!props.showLineNumbers
        }, themeClasses.value, shapeClasses.value, backgroundColorClasses.value],
        "style": backgroundColorStyles.value
      }, [showLines && createVNode("div", {
        "class": "ve-code__lines"
      }, [lineNumbers.value.map((number) => createVNode("div", {
        "class": "ve-code__line"
      }, [highlightedLines.value.includes(number) && createVNode("div", {
        "class": "ve-code__line-overlay",
        "innerHTML": "&nbsp;"
      }, null), props.showLineNumbers ? createVNode("span", {
        "class": "ve-code__line-number"
      }, [number]) : createVNode("br", null, null)]))]), createVNode("pre", {
        "class": ["ve-code__preformatted", scrollbarClasses.value]
      }, [createVNode("code", {
        "innerHTML": highlightedCode.value
      }, null)]), props.showLanguage && createVNode("span", {
        "class": "ve-code__language"
      }, [language.value])]);
    };
  }
});

var __defProp$S = Object.defineProperty;
var __getOwnPropSymbols$T = Object.getOwnPropertySymbols;
var __hasOwnProp$T = Object.prototype.hasOwnProperty;
var __propIsEnum$T = Object.prototype.propertyIsEnumerable;
var __defNormalProp$S = (obj, key, value) => key in obj ? __defProp$S(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$S = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$T.call(b, prop))
      __defNormalProp$S(a, prop, b[prop]);
  if (__getOwnPropSymbols$T)
    for (var prop of __getOwnPropSymbols$T(b)) {
      if (__propIsEnum$T.call(b, prop))
        __defNormalProp$S(a, prop, b[prop]);
    }
  return a;
};
const Counter = genericComponent()({
  name: "VeCounter",
  props: __spreadValues$S({
    active: Boolean,
    max: [Number, String],
    value: {
      type: [Number, String],
      default: 0
    }
  }, makeTransitionProps({
    transition: {
      component: FadeTransition
    }
  })),
  setup(props, {
    slots
  }) {
    const counter = computed(() => {
      return props.max ? `${props.value} / ${props.max}` : String(props.value);
    });
    return () => {
      return createVNode(MaybeTransition, {
        "transition": props.transition
      }, {
        default: () => {
          var _a, _b;
          return [withDirectives(createVNode("div", {
            "class": "ve-counter"
          }, [(_b = (_a = slots.default) == null ? void 0 : _a.call(slots, {
            counter: counter.value,
            max: Number(props.max),
            value: Number(props.value)
          })) != null ? _b : counter.value]), [[vShow, props.active]])];
        }
      });
    };
  }
});

var __defProp$R = Object.defineProperty;
var __defProps$i = Object.defineProperties;
var __getOwnPropDescs$i = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$S = Object.getOwnPropertySymbols;
var __hasOwnProp$S = Object.prototype.hasOwnProperty;
var __propIsEnum$S = Object.prototype.propertyIsEnumerable;
var __defNormalProp$R = (obj, key, value) => key in obj ? __defProp$R(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$R = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$S.call(b, prop))
      __defNormalProp$R(a, prop, b[prop]);
  if (__getOwnPropSymbols$S)
    for (var prop of __getOwnPropSymbols$S(b)) {
      if (__propIsEnum$S.call(b, prop))
        __defNormalProp$R(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$i = (a, b) => __defProps$i(a, __getOwnPropDescs$i(b));
const makeInputControlProps = propsFactory(__spreadValues$R(__spreadValues$R({
  /**
   * @zh 后置内联图标
   */
  appendInnerIcon: [String, Object],
  /**
   * @zh 是否可清除
   */
  clearable: Boolean,
  /**
   * @zh 清除图标
   */
  clearIcon: {
    type: [String, Object],
    default: "$clear"
  },
  /**
   * @zh 是否禁用
   */
  disabled: Boolean,
  /**
   * @zh 前置内联图标
   */
  prependInnerIcon: [String, Object],
  /**
   * @zh 前缀
   */
  prefix: String,
  /**
   * @zh 前缀图标
   */
  prefixIcon: [String, Object],
  /**
   * @zh 后缀
   */
  suffix: String,
  /**
   * @zh 后缀图标
   */
  suffixIcon: [String, Object]
}, makeVariantProps({
  variant: "contained"
})), makeShapeProps({
  shape: "rounded-sm"
})), "input-control");
function filterInputControlSlots(slots) {
  return pick(slots, InputControlSlots);
}
const InputControlEmits = {
  "click:clear": (_event) => true,
  "click:prepend-inner": (_event) => true,
  "click:prefix": (_event) => true,
  "click:suffix": (_event) => true,
  "click:append-inner": (_event) => true,
  "click:control": (_event) => true,
  "update:active": (_active) => true,
  "update:modelValue": (_modelValue) => true
};
const InputControlSlots = ["prepend-inner", "prefix", "default", "suffix", "append-inner", "clear"];
const InputControl = genericComponent()({
  name: "VeInputControl",
  props: __spreadValues$R({
    active: Boolean,
    dirty: Boolean
  }, makeInputControlProps()),
  emits: InputControlEmits,
  setup(props, {
    slots,
    emit
  }) {
    const isActive = useProxiedModel(props, "active");
    const isFocused = ref(false);
    const controlRef = ref();
    const inputRef = ref();
    const {
      variantClasses,
      colorClasses,
      colorStyles
    } = useVariant(props);
    const {
      shapeClasses
    } = useShape(props);
    watchEffect(() => isActive.value = isFocused.value || props.dirty);
    function focus() {
      isFocused.value = true;
    }
    function blur() {
      isFocused.value = false;
    }
    const slotProps = computed(() => ({
      isActive: isActive.value,
      isDirty: props.dirty,
      isFocused: isFocused.value,
      controlRef,
      inputRef,
      focus,
      blur
    }));
    function onClick(e) {
      if (e.target !== document.activeElement) {
        e.preventDefault();
      }
      emit("click:control", e);
    }
    useRender(() => {
      var _a, _b, _c, _d, _e, _f, _g, _h, _i;
      const hasPrependInner = !!(props.prependInnerIcon || slots["prepend-inner"]);
      const hasPrefix = !!(props.prefix || props.prefixIcon || slots.prefix);
      const hasSuffix = !!(props.suffix || props.suffixIcon || slots.suffix);
      const hasClear = !!(props.clearable || slots.clear);
      const hasAppendInner = !!(props.appendInnerIcon || slots["append-inner"]);
      return createVNode("div", {
        "class": ["ve-input-control", {
          "ve-input-control--active": isActive.value,
          "ve-input-control--disabled": props.disabled,
          "ve-input-control--dirty": props.dirty,
          "ve-input-control--focused": isFocused.value,
          "ve-input-control--prepended": hasPrependInner,
          "ve-input-control--prefixed": hasPrefix,
          "ve-input-control--suffixed": hasSuffix,
          "ve-input-control--appended": hasClear || hasAppendInner
        }, colorClasses.value, variantClasses.value, shapeClasses.value],
        "style": colorStyles.value,
        "onClick": onClick
      }, [genOverlays(false, "ve-input-control"), hasPrependInner && createVNode("div", {
        "class": "ve-input-control__prepend-inner"
      }, [(_a = slots["prepend-inner"]) == null ? void 0 : _a.call(slots, slotProps.value), props.prependInnerIcon && createVNode(Icon, {
        "onClick": (e) => emit("click:prepend-inner", e),
        "icon": props.prependInnerIcon
      }, null)]), createVNode("div", {
        "class": "ve-input-control__input"
      }, [hasPrefix && createVNode("span", {
        "class": "ve-input-control__prefix"
      }, [(_c = (_b = slots.prefix) == null ? void 0 : _b.call(slots, slotProps.value)) != null ? _c : props.prefix, props.prefixIcon && createVNode(Icon, {
        "onClick": (e) => emit("click:prefix", e),
        "icon": props.prefixIcon
      }, null)]), (_d = slots.default) == null ? void 0 : _d.call(slots, __spreadProps$i(__spreadValues$R({}, slotProps.value), {
        props: {
          class: "ve-native-control"
        }
      })), hasSuffix && createVNode("span", {
        "class": "ve-input-control__suffix"
      }, [props.suffixIcon && createVNode(Icon, {
        "onClick": (e) => emit("click:suffix", e),
        "icon": props.suffixIcon
      }, null), (_f = (_e = slots.suffix) == null ? void 0 : _e.call(slots, slotProps.value)) != null ? _f : props.suffix])]), hasClear && createVNode("div", {
        "class": ["ve-input-control__clearable", {
          "ve-input-control__clearable--has-append-inner": hasAppendInner
        }]
      }, [(_h = (_g = slots.clear) == null ? void 0 : _g.call(slots, slotProps.value)) != null ? _h : createVNode(Button, {
        "icon": props.clearIcon,
        "ripple": false,
        "shape": "circle",
        "size": "1em",
        "onClick": (e) => emit("click:clear", e),
        "variant": "text"
      }, null)]), hasAppendInner && createVNode("div", {
        "class": "ve-input-control__append-inner"
      }, [props.appendInnerIcon && createVNode(Icon, {
        "icon": props.appendInnerIcon,
        "onClick": (e) => emit("click:append-inner", e)
      }, null), (_i = slots["append-inner"]) == null ? void 0 : _i.call(slots, slotProps.value)])]);
    });
    return {
      inputRef,
      controlRef
    };
  }
});
function filterInputControlProps(attrs) {
  return pick(attrs, Object.keys(InputControl.props));
}

var __defProp$Q = Object.defineProperty;
var __defProps$h = Object.defineProperties;
var __getOwnPropDescs$h = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$R = Object.getOwnPropertySymbols;
var __hasOwnProp$R = Object.prototype.hasOwnProperty;
var __propIsEnum$R = Object.prototype.propertyIsEnumerable;
var __defNormalProp$Q = (obj, key, value) => key in obj ? __defProp$Q(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$Q = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$R.call(b, prop))
      __defNormalProp$Q(a, prop, b[prop]);
  if (__getOwnPropSymbols$R)
    for (var prop of __getOwnPropSymbols$R(b)) {
      if (__propIsEnum$R.call(b, prop))
        __defNormalProp$Q(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$h = (a, b) => __defProps$h(a, __getOwnPropDescs$h(b));
const dirtyTypes = ["color", "file", "time", "date", "datetime-local", "week", "month"];
const makeInputProps = propsFactory(__spreadValues$Q({
  /**
   * @zh 自动聚焦
   */
  autofocus: Boolean,
  /**
   * @zh 自动调整大小
   */
  autoResize: Boolean,
  /**
   * @zh 计数器
   */
  counter: [Boolean, Number, String],
  /**
   * @zh 计数器值
   */
  counterValue: Function,
  /**
   * @zh ID
   */
  id: String,
  /**
   * @zh 输入框需要传送到那个 DOM
   */
  inputAttach: [Boolean, String, Object],
  /**
   * @zh textarea 独有最大行数
   */
  maxRows: {
    type: [Number, String],
    validator: (v) => !isNaN(parseFloat(v))
  },
  /**
   * @zh 控件的值
   */
  controlValue: null,
  /**
   * @zh 输入框的值
   */
  modelValue: null,
  /**
   * @zh 输入框 name
   */
  name: String,
  /**
   * @zh textarea 独有不允许重置大小
   */
  noResize: Boolean,
  /**
   * @zh 持续显示的计数器
   */
  persistentCounter: Boolean,
  /**
   * @zh 占位符内容
   */
  placeholder: String,
  /**
   * @zh textarea 独有最小行数
   */
  rows: {
    type: [Number, String],
    default: 5,
    validator: (v) => !isNaN(parseFloat(v))
  },
  /**
   * @zh 输入框类型
   */
  type: {
    type: String,
    default: "text"
  },
  /**
   * @zh 宽度值
   */
  width: [String, Number]
}, makeInputControlProps()));
const InputEmits = __spreadProps$h(__spreadValues$Q(__spreadValues$Q({}, FormControlEmits), InputControlEmits), {
  "update:modelValue": (_) => true,
  "update:controlValue": (_) => true
});
const Input = genericComponent()({
  name: "VeInput",
  directives: {
    Intersect
  },
  props: makeInputProps(),
  emits: InputEmits,
  setup(props, {
    attrs,
    slots,
    emit
  }) {
    const vm = getCurrentInstance("VeInput");
    const inputControlRef = ref();
    const formControlRef = ref();
    const controlHeight = ref();
    const controlWidth = ref(props.width);
    const model = useProxiedModel(props, "modelValue");
    const controlValue = vm.vnode && propIsDefined(vm.vnode, "controlValue") ? useProxiedModel(props, "controlValue") : model;
    const id = computed(() => props.id || `ve-input-${getUid()}`);
    const internalDirty = ref(false);
    const isDirty = computed(() => {
      return internalDirty.value || !!model.value || dirtyTypes.includes(props.type);
    });
    const counterValue = computed(() => {
      return typeof props.counterValue === "function" ? props.counterValue(model.value) : (model.value || "").toString().length;
    });
    const max = computed(() => {
      if (attrs.maxlength)
        return attrs.maxlength;
      if (!props.counter || typeof props.counter !== "number" && typeof props.counter !== "string")
        return void 0;
      return props.counter;
    });
    function focus() {
      var _a, _b;
      (_b = (_a = inputControlRef.value) == null ? void 0 : _a.inputRef) == null ? void 0 : _b.focus();
    }
    function blur() {
      var _a, _b;
      (_b = (_a = inputControlRef.value) == null ? void 0 : _a.inputRef) == null ? void 0 : _b.blur();
    }
    function onIntersect(isIntersecting, entries) {
      var _a, _b;
      if (!props.autofocus || !isIntersecting)
        return;
      (_b = (_a = entries[0].target) == null ? void 0 : _a.focus) == null ? void 0 : _b.call(_a);
    }
    const mirrorRef = ref();
    function resize() {
      if (!props.autoResize)
        return;
      nextTick(() => {
        var _a;
        if (!mirrorRef.value)
          return;
        if (props.type === "textarea") {
          const style = getComputedStyle(mirrorRef.value);
          const padding = (parseFloat(style.getPropertyValue("--ve-native-control---padding-top")) || 0) + (parseFloat(style.getPropertyValue("--ve-native-control---padding-bottom")) || 0);
          const lineHeight = parseFloat(style.lineHeight);
          const minHeight = parseFloat(props.rows) * lineHeight + padding;
          const maxHeight = parseFloat(props.maxRows) * lineHeight + padding || Infinity;
          controlHeight.value = Math.min(maxHeight, Math.max(minHeight, mirrorRef.value.scrollHeight));
        } else {
          controlWidth.value = Math.max(parseFloat((_a = props.width) != null ? _a : 100), mirrorRef.value.scrollWidth);
        }
      });
    }
    onMounted(resize);
    watch(model, resize);
    watch(() => props.rows, resize);
    watch(() => props.maxRows, resize);
    let observer;
    watch(mirrorRef, (val) => {
      if (val) {
        observer = new ResizeObserver(resize);
        observer.observe(mirrorRef.value);
      } else {
        observer == null ? void 0 : observer.disconnect();
      }
    });
    onBeforeUnmount(() => {
      observer == null ? void 0 : observer.disconnect();
    });
    function onControlClick(e) {
      focus();
      emit("click:control", e);
    }
    function onClear(e) {
      e.stopPropagation();
      focus();
      nextTick(() => {
        model.value = "";
        emit("click:clear", e);
      });
    }
    useRender(() => {
      const isTextarea = props.type === "textarea";
      const hasCounter = !!(slots.counter || props.counter || props.counterValue);
      const [inputControlProps] = filterInputControlProps(props);
      const [, nativeControlAttrs] = filterInputAttrs(attrs);
      const [formControlSlots] = filterFormControlSlots(slots);
      const [inputControlSlots] = filterInputControlSlots(slots);
      return createVNode(FormControl, {
        "ref": formControlRef,
        "class": ["ve-input", {
          "ve-input--textarea": isTextarea,
          "ve-input--auto-resize": props.autoResize,
          "ve-input--no-resize": props.noResize || props.autoResize
        }],
        "labelId": id.value,
        "style": controlHeight.value ? {
          "--ve-form-control---height": convertToUnit(controlHeight.value)
        } : null,
        "name": props.name,
        "onClick:prepend": (e) => emit("click:prepend", e),
        "onClick:label": (e) => emit("click:label", e),
        "onClick:append": (e) => emit("click:append", e),
        "modelValue": controlValue.value,
        "onUpdate:modelValue": ($event) => controlValue.value = $event,
        "width": controlWidth.value
      }, __spreadProps$h(__spreadValues$Q({}, formControlSlots), {
        default: ({
          isDisabled,
          isReadonly
        }) => {
          return createVNode(InputControl, mergeProps(inputControlProps, {
            "ref": inputControlRef,
            "onMousedown": (e) => {
              var _a;
              if (e.target === ((_a = inputControlRef.value) == null ? void 0 : _a.inputRef))
                return;
              e.preventDefault();
            },
            "dirty": !!model.value,
            "active": isDirty.value,
            "onClick:clear": onClear,
            "onClick:prependInner": (e) => emit("click:prepend-inner", e),
            "onClick:prefix": (e) => emit("click:prefix", e),
            "onClick:suffix": (e) => emit("click:suffix", e),
            "onClick:appendInner": (e) => emit("click:append-inner", e),
            "onClick:control": onControlClick,
            "onUpdate:active": (val) => internalDirty.value = val,
            "role": "textbox"
          }), __spreadProps$h(__spreadValues$Q({}, inputControlSlots), {
            default: (slotProps) => {
              var _a, _b;
              const {
                inputRef,
                focus: focus2,
                blur: blur2,
                props: nativeControlProps
              } = slotProps;
              if (isTextarea) {
                return createVNode(Fragment, null, [(_a = slots.default) == null ? void 0 : _a.call(slots, slotProps), IN_BROWSER && createVNode(Teleport, {
                  "disabled": !props.inputAttach,
                  "to": typeof props.inputAttach === "boolean" ? null : props.inputAttach
                }, {
                  default: () => [withDirectives(createVNode("textarea", mergeProps({
                    "onUpdate:modelValue": ($event) => model.value = $event,
                    "autofocus": props.autofocus,
                    "disabled": isDisabled.value,
                    "id": id.value,
                    "name": props.name,
                    "onFocus": focus2,
                    "onBlur": blur2,
                    "placeholder": props.placeholder,
                    "readonly": isReadonly.value,
                    "ref": inputRef,
                    "rows": props.rows
                  }, nativeControlProps, nativeControlAttrs), null), [[vModelText, model.value], [resolveDirective("intersect"), {
                    handler: onIntersect
                  }, null, {
                    once: true
                  }]]), props.autoResize && withDirectives(createVNode("textarea", mergeProps({
                    "class": "ve-input__textarea-mirror",
                    "onUpdate:modelValue": ($event) => model.value = $event,
                    "ref": mirrorRef,
                    "readonly": true,
                    "aria-hidden": "true"
                  }, nativeControlProps), null), [[vModelText, model.value]])]
                })]);
              } else {
                return createVNode(Fragment, null, [(_b = slots.default) == null ? void 0 : _b.call(slots, slotProps), IN_BROWSER && createVNode(Teleport, {
                  "disabled": !props.inputAttach,
                  "to": typeof props.inputAttach === "boolean" ? null : props.inputAttach
                }, {
                  default: () => [withDirectives(createVNode("input", mergeProps({
                    "onUpdate:modelValue": ($event) => model.value = $event,
                    "onInput": (e) => {
                      if (mirrorRef.value) {
                        mirrorRef.value.textContent = e.target.value;
                        resize();
                      }
                    },
                    "autofocus": props.autofocus,
                    "disabled": isDisabled.value,
                    "id": id.value,
                    "name": props.name,
                    "onFocus": focus2,
                    "onBlur": blur2,
                    "placeholder": props.placeholder,
                    "readonly": isReadonly.value,
                    "ref": inputRef,
                    "type": props.type
                  }, nativeControlProps, nativeControlAttrs), null), [[resolveDirective("intersect"), {
                    handler: onIntersect
                  }, null, {
                    once: true
                  }], [vModelDynamic, model.value]]), props.autoResize && createVNode("span", mergeProps({
                    "class": "ve-input__input-mirror",
                    "ref": mirrorRef,
                    "aria-hidden": "true"
                  }, nativeControlProps), [model.value])]
                })]);
              }
            }
          }));
        },
        details: hasCounter ? () => {
          return createVNode(Fragment, null, [createVNode("span", null, null), createVNode(Counter, {
            "active": props.persistentCounter || isDirty.value,
            "value": counterValue.value,
            "max": max.value
          }, {
            default: slots.counter
          })]);
        } : formControlSlots == null ? void 0 : formControlSlots.details
      }));
    });
    return {
      formControlRef,
      inputControlRef,
      blur,
      focus
    };
  }
});

var __defProp$P = Object.defineProperty;
var __getOwnPropSymbols$Q = Object.getOwnPropertySymbols;
var __hasOwnProp$Q = Object.prototype.hasOwnProperty;
var __propIsEnum$Q = Object.prototype.propertyIsEnumerable;
var __defNormalProp$P = (obj, key, value) => key in obj ? __defProp$P(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$P = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$Q.call(b, prop))
      __defNormalProp$P(a, prop, b[prop]);
  if (__getOwnPropSymbols$Q)
    for (var prop of __getOwnPropSymbols$Q(b)) {
      if (__propIsEnum$Q.call(b, prop))
        __defNormalProp$P(a, prop, b[prop]);
    }
  return a;
};
const Scrim = /* @__PURE__ */ defineComponent({
  name: "VeScrim",
  inheritAttrs: false,
  props: __spreadValues$P({
    modelValue: Boolean,
    color: String
  }, makeTransitionProps({
    transition: {
      component: FadeTransition
    }
  })),
  setup(props, {
    attrs
  }) {
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, "color"));
    return () => {
      return createVNode(MaybeTransition, {
        "transition": props.transition,
        "appear": true
      }, {
        default: () => [props.modelValue && createVNode("div", mergeProps({
          "class": ["ve-scrim", backgroundColorClasses.value],
          "style": backgroundColorStyles.value
        }, attrs), null)]
      });
    };
  }
});

const makeDelayProps = propsFactory({
  closeDelay: [Number, String],
  openDelay: [Number, String]
}, "delay");
function useDelay(props, cb) {
  const delays = {};
  const runDelayFactory = (prop) => () => {
    if (!IN_BROWSER)
      return Promise.resolve(true);
    const active = prop === "openDelay";
    delays.closeDelay && window.clearTimeout(delays.closeDelay);
    delete delays.closeDelay;
    delays.openDelay && window.clearTimeout(delays.openDelay);
    delete delays.openDelay;
    return new Promise((resolve) => {
      var _a;
      delays[prop] = window.setTimeout(() => {
        cb == null ? void 0 : cb(active);
        resolve(active);
      }, Number((_a = props[prop]) != null ? _a : 0));
    });
  };
  return {
    runCloseDelay: runDelayFactory("closeDelay"),
    runOpenDelay: runDelayFactory("openDelay")
  };
}

var __defProp$O = Object.defineProperty;
var __getOwnPropSymbols$P = Object.getOwnPropertySymbols;
var __hasOwnProp$P = Object.prototype.hasOwnProperty;
var __propIsEnum$P = Object.prototype.propertyIsEnumerable;
var __defNormalProp$O = (obj, key, value) => key in obj ? __defProp$O(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$O = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$P.call(b, prop))
      __defNormalProp$O(a, prop, b[prop]);
  if (__getOwnPropSymbols$P)
    for (var prop of __getOwnPropSymbols$P(b)) {
      if (__propIsEnum$P.call(b, prop))
        __defNormalProp$O(a, prop, b[prop]);
    }
  return a;
};
const makeActivatorProps = propsFactory(__spreadValues$O({
  /**
   * @zh 激活器
   */
  activator: [String, Object],
  /**
   * @zh 激活器属性
   */
  activatorProps: {
    type: Object,
    default: () => ({})
  },
  /**
   * @zh 点击时打开
   */
  openOnClick: {
    type: Boolean,
    default: void 0
  },
  /**
   * @zh 悬停时打开
   */
  openOnHover: Boolean,
  /**
   * @zh 获取焦点时打开
   */
  openOnFocus: {
    type: Boolean,
    default: void 0
  }
}, makeDelayProps()), "activator");
function useActivator(props, { isActive }) {
  const activatedPosition = ref();
  const activatorEl = ref();
  let isHovered = false;
  let isFocused = false;
  const openOnFocus = computed(() => {
    return props.openOnFocus || props.openOnFocus == null && props.openOnHover;
  });
  const openOnClick = computed(() => {
    return props.openOnClick || props.openOnClick == null && !props.openOnHover && !openOnFocus.value;
  });
  const { runOpenDelay, runCloseDelay } = useDelay(props, (value) => {
    const hovered = props.openOnHover && isHovered;
    const focused = openOnFocus.value && isFocused;
    if (value === (hovered || focused)) {
      isActive.value = value;
    }
  });
  function onEnter(e) {
    activatorEl.value = e.currentTarget || e.target;
    isHovered = true;
    runOpenDelay();
  }
  function onLeave(_) {
    isHovered = false;
    runCloseDelay();
  }
  const availableEvents = {
    click: (e) => {
      e.stopPropagation();
      activatedPosition.value = { left: e.clientX, top: e.clientY };
      activatorEl.value = e.currentTarget || e.target;
      isActive.value = !isActive.value;
    },
    mouseenter: onEnter,
    mouseleave: onLeave,
    touchstartPassive: onEnter,
    touchend: onLeave,
    contextmenu: (e) => e.preventDefault(),
    focus: (e) => {
      if (SUPPORTS_FOCUS_VISIBLE && !e.target.matches(":focus-visible"))
        return;
      e.stopPropagation();
      activatorEl.value = e.currentTarget || e.target;
      isFocused = true;
      runOpenDelay();
    },
    blur: (e) => {
      e.stopPropagation();
      isFocused = false;
      runCloseDelay();
    }
  };
  const activatorEvents = computed(() => {
    const events = {};
    if (openOnClick.value) {
      events.click = availableEvents.click;
    }
    if (props.openOnHover) {
      if (SUPPORTS_TOUCH) {
        events.touchstartPassive = availableEvents.touchstartPassive;
        events.contextmenu = availableEvents.contextmenu;
        events.touchend = availableEvents.touchend;
      } else {
        events.mouseenter = availableEvents.mouseenter;
        events.mouseleave = availableEvents.mouseleave;
      }
    }
    if (openOnFocus.value) {
      events.focus = availableEvents.focus;
      events.blur = availableEvents.blur;
    }
    return events;
  });
  const contentEvents = computed(() => {
    const events = {};
    if (props.openOnHover) {
      if (SUPPORTS_TOUCH) {
        events.touchstartPassive = (_) => isHovered = true;
        events.contextmenu = availableEvents.contextmenu;
        events.touchend = availableEvents.touchend;
      } else {
        events.mouseenter = (_) => isHovered = true;
        events.mouseleave = availableEvents.mouseleave;
      }
    }
    return events;
  });
  const activatorRef = ref();
  watchEffect(() => {
    if (!activatorRef.value)
      return;
    nextTick(() => {
      const activator = activatorRef.value;
      activatorEl.value = isComponentInstance(activator) ? activator.$el : activator;
    });
  });
  const state = {
    activatedPosition,
    activatorEl,
    activatorRef,
    activatorEvents,
    contentEvents
  };
  let scope;
  watch(() => !!props.activator, (val) => {
    if (val && IN_BROWSER) {
      scope = effectScope();
      scope.run(() => useActivatorInScope(props, state));
    } else {
      scope == null ? void 0 : scope.stop();
    }
  }, { flush: "post", immediate: true });
  return state;
}
function useActivatorInScope(props, { activatorEl, activatorEvents }) {
  watch(() => props.activator, (val, oldVal) => {
    if (oldVal && val !== oldVal) {
      const activator = getActivator(oldVal);
      activator && unbindActivatorProps(activator);
    }
    if (val) {
      nextTick(() => bindActivatorProps());
    }
  }, { immediate: true });
  watch(() => props.activatorProps, () => bindActivatorProps());
  onScopeDispose(unbindActivatorProps);
  function bindActivatorProps(el = getActivator(), activatorProps = props.activatorProps) {
    if (!el)
      return;
    Object.entries(activatorEvents.value).forEach(([name, cb]) => {
      el.addEventListener(name, cb);
    });
    Object.keys(activatorProps).forEach((k) => {
      if (activatorProps[k] == null) {
        el.removeAttribute(k);
      } else {
        el.setAttribute(k, activatorProps[k]);
      }
    });
  }
  function unbindActivatorProps(el = getActivator(), activatorProps = props.activatorProps) {
    if (!el)
      return;
    Object.entries(activatorEvents.value).forEach(([name, cb]) => {
      el.removeEventListener(name, cb);
    });
    Object.keys(activatorProps).forEach((k) => {
      el.removeAttribute(k);
    });
  }
  const vm = getCurrentInstance("useActivator");
  function getActivator(selector = props.activator) {
    if (selector) {
      activatorEl.value = querySelector(selector, vm);
    }
    return activatorEl.value;
  }
}

function staticPositionStrategy() {
}

var __defProp$N = Object.defineProperty;
var __defProps$g = Object.defineProperties;
var __getOwnPropDescs$g = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$O = Object.getOwnPropertySymbols;
var __hasOwnProp$O = Object.prototype.hasOwnProperty;
var __propIsEnum$O = Object.prototype.propertyIsEnumerable;
var __defNormalProp$N = (obj, key, value) => key in obj ? __defProp$N(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$N = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$O.call(b, prop))
      __defNormalProp$N(a, prop, b[prop]);
  if (__getOwnPropSymbols$O)
    for (var prop of __getOwnPropSymbols$O(b)) {
      if (__propIsEnum$O.call(b, prop))
        __defNormalProp$N(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$g = (a, b) => __defProps$g(a, __getOwnPropDescs$g(b));
function connectedPositionStrategy(data, props, contentStyles, anchorClasses) {
  if (!data.activatorEl.value)
    return;
  const activatorFixed = isFixedPosition(data.activatorEl.value);
  if (activatorFixed) {
    Object.assign(contentStyles.value, {
      position: "fixed"
    });
  }
  const preferredAnchor = computed(() => parseAnchor(props.anchor));
  const preferredOrigin = computed(() => {
    switch (props.origin) {
      case "overlap":
        return preferredAnchor.value;
      case "auto":
        return oppositeAnchor(preferredAnchor.value);
      default:
        return parseAnchor(props.origin);
    }
  });
  const doesOverlap = computed(() => {
    return preferredAnchor.value.side === preferredOrigin.value.side;
  });
  const configuredMaxHeight = computed(() => {
    const val = parseFloat(String(props.maxHeight));
    return isNaN(val) ? Infinity : val;
  });
  const configuredMinWidth = computed(() => {
    const val = parseFloat(String(props.minWidth));
    return isNaN(val) ? Infinity : val;
  });
  let observe = false;
  const observer = new ResizeObserver(() => {
    if (observe) {
      updatePosition();
    }
  });
  observer.observe(data.activatorEl.value);
  onScopeDispose(() => {
    observer.disconnect();
  });
  watch(
    () => [preferredAnchor.value, preferredOrigin.value, props.offset],
    () => updatePosition(),
    { immediate: !activatorFixed }
  );
  if (activatorFixed)
    nextTick(() => updatePosition());
  requestAnimationFrame(() => {
    if (contentStyles.value.maxHeight) {
      updatePosition();
    }
  });
  function updatePosition() {
    observe = false;
    requestAnimationFrame(() => {
      requestAnimationFrame(() => observe = true);
    });
    const targetBox = data.activatorEl.value.getBoundingClientRect();
    if (props.offset) {
      targetBox.x -= +props.offset;
      targetBox.y -= +props.offset;
      targetBox.width += +props.offset * 2;
      targetBox.height += +props.offset * 2;
    }
    let contentBox;
    {
      const scrollables = /* @__PURE__ */ new Map();
      data.contentEl.value.querySelectorAll("*").forEach((el) => {
        const x2 = el.scrollLeft;
        const y2 = el.scrollTop;
        if (x2 || y2) {
          scrollables.set(el, [x2, y2]);
        }
      });
      const initialMaxWidth = data.contentEl.value.style.maxWidth;
      const initialMaxHeight = data.contentEl.value.style.maxHeight;
      data.contentEl.value.style.removeProperty("max-width");
      data.contentEl.value.style.removeProperty("max-height");
      contentBox = nullifyTransforms(data.contentEl.value);
      contentBox.x -= parseFloat(data.contentEl.value.style.left) || 0;
      contentBox.y -= parseFloat(data.contentEl.value.style.top) || 0;
      data.contentEl.value.style.maxWidth = initialMaxWidth;
      data.contentEl.value.style.maxHeight = initialMaxHeight;
      scrollables.forEach((position, el) => {
        el.scrollTo(...position);
      });
    }
    const maxHeight = configuredMaxHeight.value;
    const contentWidth = Math.max(configuredMinWidth.value, contentBox.width);
    const contentHeight = Math.min(maxHeight, contentBox.height);
    contentBox = new Box(__spreadProps$g(__spreadValues$N({}, contentBox), {
      height: Math.min(contentHeight, maxHeight)
    }));
    const scrollParent = getScrollParent(data.contentEl.value);
    const viewportWidth = scrollParent.clientWidth;
    const viewportHeight = Math.min(scrollParent.clientHeight, window.innerHeight);
    const viewportMargin = 12;
    const freeSpace = {
      top: targetBox.top - viewportMargin,
      bottom: viewportHeight - targetBox.bottom - viewportMargin,
      left: targetBox.left - viewportMargin,
      right: viewportWidth - targetBox.right - viewportMargin
    };
    let anchor = preferredAnchor.value;
    let origin = preferredOrigin.value;
    {
      const { side } = anchor;
      const { top, bottom, left, right } = freeSpace;
      if (side === "top" && top < contentHeight && bottom > top || side === "bottom" && bottom < contentHeight && top > bottom || side === "start" && left < contentWidth && right > left || side === "end" && right < contentWidth && left > right) {
        anchor = oppositeAnchor(anchor);
        origin = oppositeAnchor(anchor);
      }
    }
    const targetPoint = anchorToPoint(anchor, targetBox);
    const contentPoint = anchorToPoint(origin, contentBox);
    let { x, y } = getOffset(targetPoint, contentPoint);
    let maxWidth = null;
    {
      if (doesOverlap.value || ["center", "top", "bottom"].includes(anchor.side)) {
        maxWidth = Math.min(
          viewportWidth,
          Math.max(targetBox.width, viewportWidth - viewportMargin * 2)
        );
      } else if (anchor.side === "end") {
        maxWidth = freeSpace.right;
      } else if (anchor.side === "start") {
        maxWidth = freeSpace.left;
      }
    }
    const minWidth = Math.min(configuredMinWidth.value, maxWidth, targetBox.width);
    if (contentWidth !== Infinity) {
      if (anchor.side === "top" || anchor.side === "bottom") {
        const maxX = viewportWidth - Math.min(maxWidth != null ? maxWidth : contentWidth, contentWidth) - viewportMargin;
        if (x > maxX) {
          x = maxX;
          anchor.align = "end";
          origin = oppositeAnchor(anchor);
        } else if (x < 0) {
          x = 0;
          anchor.align = "start";
          origin = oppositeAnchor(anchor);
        }
      }
    }
    Object.assign(contentStyles.value, {
      "--ve-overlay-anchor-origin": physicalAnchor(anchor, data.activatorEl.value),
      "transformOrigin": physicalAnchor(origin, data.activatorEl.value),
      "top": convertToUnit(Math.round(y)),
      "left": convertToUnit(Math.round(x)),
      "minWidth": convertToUnit(minWidth),
      "maxWidth": convertToUnit(maxWidth),
      "maxHeight": convertToUnit(maxHeight)
    });
    anchorClasses.value = [
      `ve-overlay--side-${anchor.side}`,
      `ve-overlay--align-${anchor.align}`
    ];
  }
  return { updatePosition };
}

function pointerPositionStrategy(data, props, contentStyles, _anchorClasses) {
  const updatePosition = (e) => {
    var _a, _b;
    const box = { left: e.clientX, top: e.clientY };
    Object.assign(contentStyles.value, {
      position: "fixed",
      left: convertToUnit(box.left + +((_a = props.offset) != null ? _a : 0)),
      top: convertToUnit(box.top + +((_b = props.offset) != null ? _b : 0))
    });
  };
  document.addEventListener("mousemove", updatePosition);
  onScopeDispose(() => {
    document.removeEventListener("mousemove", updatePosition);
  });
  return {
    updatePosition: void 0
  };
}

const POSITION_STRATEGIES = {
  static: staticPositionStrategy,
  // specific viewport position, usually centered
  connected: connectedPositionStrategy,
  // connected to a certain element
  pointer: pointerPositionStrategy
  // pointer position
};
const makePositionStrategyProps = propsFactory({
  /**
   * @zh 定位策略
   */
  positionStrategy: {
    type: [String, Function],
    default: "static",
    validator: (val) => typeof val === "function" || val in POSITION_STRATEGIES
  },
  /**
   * @zh 锚点位置
   */
  anchor: {
    type: String,
    default: "bottom"
  },
  /**
   * @zh 原始点策略
   */
  origin: {
    type: String,
    default: "auto"
  },
  /**
   * @zh 偏移值
   */
  offset: [Number, String]
}, "position-strategy");
function usePositionStrategy(props, data) {
  const contentStyles = ref({});
  const anchorClasses = ref([]);
  const updatePosition = ref();
  let scope;
  watchEffect(async () => {
    scope == null ? void 0 : scope.stop();
    updatePosition.value = void 0;
    if (!(IN_BROWSER && data.isActive.value && props.positionStrategy))
      return;
    scope = effectScope();
    await nextTick();
    scope.run(() => {
      var _a;
      const strategy = typeof props.positionStrategy === "function" ? props.positionStrategy : POSITION_STRATEGIES[props.positionStrategy];
      updatePosition.value = (_a = strategy(
        data,
        props,
        contentStyles,
        anchorClasses
      )) == null ? void 0 : _a.updatePosition;
    });
  });
  IN_BROWSER && window.addEventListener("resize", onResize, { passive: true });
  onScopeDispose(() => {
    IN_BROWSER && window.removeEventListener("resize", onResize);
    updatePosition.value = void 0;
    scope == null ? void 0 : scope.stop();
  });
  function onResize(e) {
    var _a;
    (_a = updatePosition.value) == null ? void 0 : _a.call(updatePosition, e);
  }
  return {
    contentStyles,
    anchorClasses,
    updatePosition
  };
}

function bindScroll(el, onScroll) {
  const scrollElements = [document, ...getScrollParents(el)];
  scrollElements.forEach((el2) => {
    el2.addEventListener("scroll", onScroll, { passive: true });
  });
  onScopeDispose(() => {
    scrollElements.forEach((el2) => {
      el2.removeEventListener("scroll", onScroll);
    });
  });
}

function closeScrollStrategy(data, _name) {
  var _a;
  function onScroll(_e) {
    data.isActive.value = false;
  }
  bindScroll((_a = data.activatorEl.value) != null ? _a : data.contentEl.value, onScroll);
}

function blockScrollStrategy(data, name) {
  var _a;
  const rootParent = (_a = data.root.value) == null ? void 0 : _a.offsetParent;
  const scrollableParent = rootParent && hasScrollbar(rootParent);
  if (scrollableParent) {
    data.root.value.classList.add(`${name}--scroll-blocked`);
  }
  const scrollElements = rootParent ? [] : [.../* @__PURE__ */ new Set([
    ...getScrollParents(data.activatorEl.value),
    ...getScrollParents(data.contentEl.value)
  ])].filter((el) => !el.classList.contains(`${name}-scroll-blocked`));
  scrollElements.forEach((el) => {
    el.style.setProperty("--ve-scrollbar-offset", convertToUnit(getScrollbarWidth(el)));
    el.classList.add(`${name}-scroll-blocked`);
  });
  onScopeDispose(() => {
    if (scrollableParent) {
      data.root.value.classList.remove(`${name}--scroll-blocked`);
    }
    scrollElements.forEach((el) => {
      el.style.removeProperty("--ve-scrollbar-offset");
      el.classList.remove(`${name}-scroll-blocked`);
    });
  });
}

function repositionScrollStrategy(data, _name) {
  var _a;
  let slow = false;
  let raf = -1;
  function update(e) {
    requestNewFrame(() => {
      var _a2, _b;
      const start = performance.now();
      (_b = (_a2 = data.updatePosition).value) == null ? void 0 : _b.call(_a2, e);
      const time = performance.now() - start;
      slow = time / (1e3 / 60) > 2;
    });
  }
  bindScroll((_a = data.activatorEl.value) != null ? _a : data.contentEl.value, (e) => {
    if (slow) {
      cancelAnimationFrame(raf);
      raf = requestAnimationFrame(() => {
        raf = requestAnimationFrame(() => {
          update(e);
        });
      });
    } else {
      update(e);
    }
  });
}

const scrollStrategies = {
  none: null,
  close: closeScrollStrategy,
  block: blockScrollStrategy,
  reposition: repositionScrollStrategy
};
const makeScrollStrategyProps = propsFactory({
  /**
   * @zh 滚动策略
   */
  scrollStrategy: {
    type: [Boolean, String, Function],
    default: "block",
    validator: (val) => typeof val === "function" || typeof val === "boolean" || val in scrollStrategies
  }
});
function useScrollStrategy(props, data, name = getCurrentInstanceName()) {
  if (!IN_BROWSER)
    return;
  let scope;
  watchEffect(async () => {
    scope == null ? void 0 : scope.stop();
    if (!data.isActive.value || !props.scrollStrategy || typeof props.scrollStrategy === "boolean")
      return;
    scope = effectScope();
    await nextTick();
    scope.run(() => {
      var _a;
      if (typeof props.scrollStrategy === "function") {
        props.scrollStrategy(data, name);
      } else if (typeof props.scrollStrategy === "string" && props.scrollStrategy in scrollStrategies) {
        (_a = scrollStrategies[props.scrollStrategy]) == null ? void 0 : _a.call(scrollStrategies, data, name);
      }
    });
  });
}

function useTeleport(target = false) {
  const teleportTarget = computed(() => {
    const _target = unref(target);
    if (_target === true || !IN_BROWSER)
      return void 0;
    const targetElement = _target === false ? document.body : typeof _target === "string" ? document.querySelector(_target) : _target;
    if (targetElement == null) {
      warn(`Unable to locate target ${_target}`);
      return void 0;
    }
    if (!useTeleport.cache.has(targetElement)) {
      const el = document.createElement("div");
      el.className = "ve-overlay-container";
      targetElement.appendChild(el);
      useTeleport.cache.set(targetElement, el);
    }
    return useTeleport.cache.get(targetElement);
  });
  return { teleportTarget };
}
useTeleport.cache = /* @__PURE__ */ new WeakMap();

const makeLazyProps = propsFactory({
  /**
   * @zh 急切的
   */
  eager: Boolean
}, "lazy");
function useLazy(props, active) {
  const isBooted = ref(false);
  const hasContent = computed(() => isBooted.value || props.eager || active.value);
  watch(active, () => isBooted.value = true);
  function onAfterLeave() {
    if (!props.eager)
      isBooted.value = false;
  }
  return { isBooted, hasContent, onAfterLeave };
}

const stack = ref([]);
function useStack(isActive) {
  const vm = getCurrentInstance("stack");
  let scope;
  watch(isActive, (val) => {
    if (val) {
      scope = effectScope();
      scope.run(() => {
        stack.value.push(vm);
        onScopeDispose(() => {
          stack.value.splice(stack.value.indexOf(vm), 1);
        });
      });
    } else {
      scope == null ? void 0 : scope.stop();
    }
  }, { immediate: true });
  const isTop = computed(() => {
    return toRaw(stack.value[stack.value.length - 1]) === vm;
  });
  return {
    isTop
  };
}

var __defProp$M = Object.defineProperty;
var __getOwnPropSymbols$N = Object.getOwnPropertySymbols;
var __hasOwnProp$N = Object.prototype.hasOwnProperty;
var __propIsEnum$N = Object.prototype.propertyIsEnumerable;
var __defNormalProp$M = (obj, key, value) => key in obj ? __defProp$M(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$M = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$N.call(b, prop))
      __defNormalProp$M(a, prop, b[prop]);
  if (__getOwnPropSymbols$N)
    for (var prop of __getOwnPropSymbols$N(b)) {
      if (__propIsEnum$N.call(b, prop))
        __defNormalProp$M(a, prop, b[prop]);
    }
  return a;
};
const makeOverlayProps = propsFactory(__spreadValues$M(__spreadValues$M(__spreadValues$M(__spreadValues$M(__spreadValues$M(__spreadValues$M(__spreadValues$M({
  /**
   * @zh 是否展示
   */
  modelValue: Boolean,
  /**
   * @zh 使用绝对定位
   */
  absolute: Boolean,
  /**
   * @zh 绑定到的 DOM
   */
  attach: [Boolean, String, Object],
  /**
   * @zh 使用容器形式
   */
  contained: Boolean,
  /**
   * @zh 包裹内容 div 的 style
   */
  contentStyle: null,
  /**
   * @zh 包裹内容 div 的 class
   */
  contentClass: null,
  /**
   * @zh 没有点击动画
   */
  noClickAnimation: Boolean,
  /**
   * @zh 持续显示（额外关闭行为不受控）
   */
  persistent: Boolean,
  /**
   * @zh 无遮罩层
   */
  scrim: {
    type: [String, Boolean],
    default: true
  }
}, makeActivatorProps()), makeDimensionProps()), makePositionStrategyProps()), makeScrollStrategyProps()), makeThemeProps()), makeTransitionProps({
  transition: {
    component: FadeTransition
  }
})), makeLazyProps()), "overlay");
const Overlay = genericComponent()({
  name: "VeOverlay",
  inheritAttrs: false,
  directives: {
    ClickOutside
  },
  props: makeOverlayProps(),
  emits: {
    "click:outside": (_event) => true,
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots,
    attrs,
    emit
  }) {
    const isActive = useProxiedModel(props, "modelValue");
    const isInternalActive = ref(isActive.value);
    const {
      teleportTarget
    } = useTeleport(computed(() => props.attach || props.contained));
    const {
      themeClasses
    } = provideTheme(props);
    const {
      hasContent,
      onAfterLeave: onAfterLeaveByLazy
    } = useLazy(props, isActive);
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      isTop
    } = useStack(isActive);
    const root = ref();
    const contentEl = ref();
    const {
      overlayZIndex
    } = useOverlay(isInternalActive);
    const {
      activatedPosition,
      activatorEl,
      activatorRef,
      activatorEvents,
      contentEvents
    } = useActivator(props, {
      isActive
    });
    const {
      contentStyles,
      anchorClasses,
      updatePosition
    } = usePositionStrategy(props, {
      activatedPosition,
      activatorEl,
      contentEl,
      isActive
    });
    useScrollStrategy(props, {
      root,
      contentEl,
      activatorEl,
      isActive: isInternalActive,
      updatePosition
    });
    const animateClick = () => {
      var _a;
      if (props.noClickAnimation)
        return;
      (_a = contentEl.value) == null ? void 0 : _a.animate([{
        transformOrigin: "center"
      }, {
        transform: "scale(1.03)"
      }, {
        transformOrigin: "center"
      }], {
        duration: 150,
        easing: standardEasing
      });
    };
    const onClickOutside = (e) => {
      emit("click:outside", e);
      if (!props.persistent) {
        isActive.value = false;
      } else {
        animateClick();
      }
    };
    const onKeydown = ({
      key
    }) => {
      if (key === keyValues.esc && isTop.value) {
        if (!props.persistent) {
          isActive.value = false;
        } else {
          animateClick();
        }
      }
    };
    watch(isActive, (val) => {
      if (val)
        isInternalActive.value = true;
      if (IN_BROWSER) {
        if (val) {
          window.addEventListener("keydown", onKeydown);
        } else {
          window.removeEventListener("keydown", onKeydown);
        }
      }
    }, {
      immediate: true
    });
    useBackButton((next) => {
      if (isTop.value && isActive.value) {
        next(false);
        if (!props.persistent) {
          isActive.value = false;
        } else {
          animateClick();
        }
      } else {
        next();
      }
    });
    const top = ref();
    watch(() => {
      return isActive.value && (props.absolute || props.contained) && teleportTarget.value == null;
    }, (val) => {
      if (val) {
        const scrollParent = getScrollParent(root.value);
        if (scrollParent && scrollParent !== document.scrollingElement) {
          top.value = scrollParent.scrollTop;
        }
      }
    });
    const onAfterLeave = () => {
      isInternalActive.value = false;
      onAfterLeaveByLazy();
    };
    const closeConditional = () => {
      return isActive.value && isTop.value;
    };
    const close = () => {
      isActive.value = false;
    };
    useRender(() => {
      var _a;
      const on = toHandlers(activatorEvents.value);
      return createVNode(Fragment, null, [(_a = slots.activator) == null ? void 0 : _a.call(slots, {
        close,
        isActive: isActive.value,
        props: mergeProps({
          ref: activatorRef
        }, on, props.activatorProps),
        on
      }), IN_BROWSER && createVNode(Teleport, {
        "disabled": !teleportTarget.value,
        "to": teleportTarget.value
      }, {
        default: () => [hasContent.value && createVNode("div", mergeProps({
          "class": ["ve-overlay", {
            "ve-overlay--absolute": props.absolute || props.contained,
            "ve-overlay--active": isActive.value,
            "ve-overlay--contained": props.contained
          }, anchorClasses.value, themeClasses.value],
          "ref": root,
          "style": {
            top: convertToUnit(top.value),
            zIndex: overlayZIndex.value
          }
        }, attrs), [createVNode(Scrim, {
          "color": typeof props.scrim === "string" ? props.scrim : void 0,
          "modelValue": isActive.value && !!props.scrim
        }, null), createVNode(MaybeTransition, {
          "appear": true,
          "onAfterLeave": onAfterLeave,
          "persisted": true,
          "transition": props.transition,
          "target": activatorEl.value
        }, {
          default: () => {
            var _a2;
            return [withDirectives(createVNode("div", mergeProps({
              "ref": contentEl,
              "class": ["ve-overlay__wrapper", props.contentClass],
              "style": [props.contentStyle, dimensionStyles.value, contentStyles.value]
            }, toHandlers(contentEvents.value)), [(_a2 = slots.default) == null ? void 0 : _a2.call(slots, {
              close,
              isActive
            })]), [[vShow, isActive.value], [resolveDirective("click-outside"), {
              handler: onClickOutside,
              closeConditional,
              include: () => [activatorEl.value]
            }]])];
          }
        })])]
      })]);
    });
    return {
      animateClick,
      close,
      contentEl,
      activatorEl,
      updatePosition
    };
  }
});

var __defProp$L = Object.defineProperty;
var __getOwnPropSymbols$M = Object.getOwnPropertySymbols;
var __hasOwnProp$M = Object.prototype.hasOwnProperty;
var __propIsEnum$M = Object.prototype.propertyIsEnumerable;
var __defNormalProp$L = (obj, key, value) => key in obj ? __defProp$L(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$L = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$M.call(b, prop))
      __defNormalProp$L(a, prop, b[prop]);
  if (__getOwnPropSymbols$M)
    for (var prop of __getOwnPropSymbols$M(b)) {
      if (__propIsEnum$M.call(b, prop))
        __defNormalProp$L(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$8(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Menu = genericComponent()({
  name: "VeMenu",
  props: __spreadValues$L({
    modelValue: Boolean,
    id: String
  }, makeTransitionProps({
    transition: {
      component: MenuTransition
    }
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const isActive = useProxiedModel(props, "modelValue");
    const overlayRef = ref();
    const id = computed(() => props.id || `ve-menu-${getUid()}`);
    useRender(() => {
      return createVNode(Overlay, {
        "ref": overlayRef,
        "modelValue": isActive.value,
        "onUpdate:modelValue": ($event) => isActive.value = $event,
        "class": "ve-menu",
        "transition": props.transition,
        "absolute": true,
        "positionStrategy": "connected",
        "scrollStrategy": "reposition",
        "closeDelay": 100,
        "minWidth": 0,
        "offset": 4,
        "scrim": false,
        "activatorProps": {
          "aria-haspopup": "menu",
          "aria-expanded": String(isActive.value),
          "aria-owns": id.value
        }
      }, _isSlot$8(slots) ? slots : {
        default: () => [slots]
      });
    });
    return {
      overlayRef
    };
  }
});

const MAP = {
  year: {
    alias: "Y",
    get: "getFullYear",
    set: "setFullYear",
    startOf: "YYYY-01-01 00:00:00",
    // TODO
    endOf: "YYYY-12-$1 23:59:59.999"
  },
  month: {
    alias: "M",
    get: "getMonth",
    set: "setMonth",
    startOf: "YYYY-MM-01 00:00:00",
    endOf: "YYYY-MM-31 23:59:59.999"
  },
  day: {
    alias: "D",
    get: "getDate",
    set: "setDate",
    startOf: "YYYY-MM-DD 00:00:00",
    endOf: "YYYY-MM-DD 23:59:59.999"
  },
  hour: {
    alias: "H",
    get: "getHours",
    set: "setHours",
    startOf: "YYYY-MM-DD HH:00:00",
    endOf: "YYYY-MM-DD HH:59:59.999"
  },
  minute: {
    alias: "m",
    get: "getMinutes",
    set: "setMinutes",
    startOf: "YYYY-MM-DD HH:mm:00",
    endOf: "YYYY-MM-DD HH:mm:59.999"
  },
  second: {
    alias: "s",
    get: "getSeconds",
    set: "setSeconds",
    startOf: "YYYY-MM-DD HH:mm:ss.000",
    endOf: "YYYY-MM-DD HH:mm:ss.999"
  },
  millisecond: {
    alias: "ms",
    get: "getMilliseconds",
    set: "setMilliseconds",
    startOf: "YYYY-MM-DD HH:mm:ss.000",
    endOf: "YYYY-MM-DD HH:mm:ss.999"
  }
};

const defaultDateFormat = "YYYY-MM-DD HH:mm:ss";
function createDate(options) {
  let date;
  {
    if (!options) {
      date = /* @__PURE__ */ new Date();
    } else if (typeof options === "string") {
      date = new Date(options.replace(/-/g, "/"));
    } else {
      date = new Date(options);
    }
  }
  function tap(cb1, cb2) {
    const res = cb1();
    cb2(res);
    return res;
  }
  const ctx = {
    add(value, unit) {
      return tap(() => this.clone(), (cloned) => {
        const get = MAP[unit].get;
        const set = MAP[unit].set;
        if (set in cloned && get in cloned) {
          cloned[set](
            cloned[get]() + value
          );
        }
      });
    },
    subtract(value, unit) {
      return this.add(-value, unit);
    },
    startOf(unit) {
      return createDate(this.format(MAP[unit].startOf));
    },
    endOf(unit) {
      return createDate(this.format(MAP[unit].endOf));
    },
    format(value = defaultDateFormat) {
      const formatted = this.toObject();
      const { format, counter } = value.split("").reduce(({ format: format2, counter: counter2 }, key) => {
        if (key in formatted && format2[format2.length - 1] === key) {
          counter2[key] = counter2[key] || 1;
          counter2[key]++;
        } else {
          format2 += key;
        }
        return { format: format2, counter: counter2 };
      }, { format: "", counter: {} });
      return format.replace(/\w/g, (key) => {
        if (key in formatted) {
          const val = formatted[key];
          if (key in counter) {
            return padNumber(val, counter[key]);
          }
          return String(val);
        }
        return String(key);
      });
    },
    clone: () => createDate(date),
    unix() {
      return ~~(date.getTime() / 1e3);
    },
    valueOf() {
      return date.valueOf();
    },
    toDate() {
      return date;
    },
    toObject() {
      return {
        Y: date.getFullYear(),
        M: date.getMonth() + 1,
        D: date.getDate(),
        H: date.getHours(),
        m: date.getMinutes(),
        s: date.getSeconds(),
        ms: date.getMilliseconds(),
        // weekday
        d: date.getDay()
      };
    }
  };
  return new Proxy(ctx, {
    get: (target, prop) => {
      return prop in target ? target[prop] : prop in date ? date[prop].bind(date) : void 0;
    },
    has: (target, prop) => {
      return prop in target || prop in date;
    }
  });
}

const DateRangeKey = Symbol.for("veno-ui:date-range");

var __defProp$K = Object.defineProperty;
var __defProps$f = Object.defineProperties;
var __getOwnPropDescs$f = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$L = Object.getOwnPropertySymbols;
var __hasOwnProp$L = Object.prototype.hasOwnProperty;
var __propIsEnum$L = Object.prototype.propertyIsEnumerable;
var __defNormalProp$K = (obj, key, value) => key in obj ? __defProp$K(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$K = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$L.call(b, prop))
      __defNormalProp$K(a, prop, b[prop]);
  if (__getOwnPropSymbols$L)
    for (var prop of __getOwnPropSymbols$L(b)) {
      if (__propIsEnum$L.call(b, prop))
        __defNormalProp$K(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$f = (a, b) => __defProps$f(a, __getOwnPropDescs$f(b));
const ROWS_COUNT = 6;
const COLS_COUNT = 7;
const CELLS_COUNT = ROWS_COUNT * COLS_COUNT;
const WEEKDAYS = ["\u65E5", "\u4E00", "\u4E8C", "\u4E09", "\u56DB", "\u4E94", "\u516D"];
const DatePickerPanel = /* @__PURE__ */ defineComponent({
  name: "VeDatePickerPanel",
  props: {
    /**
     * @zh 激活的日期的按钮颜色
     */
    activeColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 每周的第一天是周几（0 - 周日、1 - 周一）。
     */
    firstDayOfWeek: {
      type: [String, Number],
      default: 0,
      validator: (val) => Number(val) in WEEKDAYS
    },
    /**
     * @zh 时间格式化
     */
    format: {
      type: [String, Function],
      default: "YYYY-MM-DD"
    },
    /**
     * @zh 最大时间值
     */
    max: String,
    /**
     * @zh 最小时间值
     */
    min: String,
    /**
     * @zh 时间值
     */
    modelValue: String,
    /**
     * @zh 双箭头往前翻页图标
     */
    prevDoubleIcon: {
      type: String,
      default: "$prevDouble"
    },
    /**
     * @zh 单箭头往前翻页图标
     */
    prevIcon: {
      type: String,
      default: "$prev"
    },
    /**
     * @zh 单箭头往后翻页图标
     */
    nextIcon: {
      type: String,
      default: "$next"
    },
    /**
     * @zh 双箭头往后翻页图标
     */
    nextDoubleIcon: {
      type: String,
      default: "$nextDouble"
    }
  },
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const firstDayOfWeek = computed(() => Number(props.firstDayOfWeek));
    const max = computed(() => props.max ? createDate(props.max) : void 0);
    const min = computed(() => props.min ? createDate(props.min) : void 0);
    const model = useProxiedModel(props, "modelValue", props.modelValue, (v) => createDate(v), (v) => formatter(v));
    const range = inject(DateRangeKey, null);
    const selected = computed(() => {
      if (range) {
        return range.selected.value.map((v) => valueFormatter(v.startOf("day")));
      }
      return wrapInArray(valueFormatter(model.value.startOf("day")));
    });
    const weekdays = computed(() => createRange(7).map((i) => WEEKDAYS[(i + firstDayOfWeek.value) % 7]));
    const internalModel = ref(model.value.startOf("month"));
    const month = computed(() => internalModel.value.format("M"));
    watch(model, (val) => {
      internalModel.value = val.startOf("month");
    });
    function formatter(date) {
      return typeof props.format === "string" ? date.format(props.format) : props.format(date);
    }
    function valueFormatter(date) {
      return createDate(formatter(date)).valueOf();
    }
    const rows = computed(() => {
      const now = valueFormatter(createDate().startOf("day"));
      const sharedProps = {
        icon: true,
        variant: "text",
        shape: "circle",
        size: "small"
      };
      const cells = [];
      const weekDay = Number(internalModel.value.format("d"));
      const offsetDay = firstDayOfWeek.value - weekDay;
      let date = internalModel.value.add(offsetDay, "day");
      createRange(CELLS_COUNT).forEach((_) => {
        const current = date;
        date = date.add(1, "day");
        const text = formatter(current);
        const value = valueFormatter(current);
        const selectedIndex = selected.value.findIndex((v) => v === value);
        const isActive = selectedIndex > -1;
        const isToday = now == value;
        const variant = isActive ? "contained" : isToday ? "outlined" : "text";
        const color = isActive || isToday ? props.activeColor : void 0;
        function onClick() {
          if (range) {
            range.select(text);
            range.isPreview.value && range.preview(false);
          } else {
            model.value = current;
          }
        }
        cells.push({
          isActive,
          selectedIndex,
          isOtherMonth: current.format("M") !== month.value,
          text,
          value,
          props: __spreadProps$f(__spreadValues$K({}, sharedProps), {
            variant,
            color,
            text: current.format("D"),
            onClick
          })
        });
      });
      const rows2 = createRange(ROWS_COUNT).map((_, index) => {
        return cells.slice(index * COLS_COUNT, (index + 1) * COLS_COUNT);
      });
      rows2.unshift(weekdays.value.map((text) => ({
        props: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          text,
          disabled: true
        })
      })));
      return rows2;
    });
    const controls = computed(() => {
      const sharedProps = {
        variant: "text",
        shape: "circle",
        size: "small"
      };
      const hasPrev = min.value ? internalModel.value.valueOf() > min.value.valueOf() : true;
      const hasNext = max.value ? internalModel.value.valueOf() < max.value.valueOf() : true;
      return {
        prevDouble: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          icon: props.prevDoubleIcon,
          onClick: prevYear,
          disabled: !hasPrev
        }),
        prev: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          icon: props.prevIcon,
          onClick: prevMonth,
          disabled: !hasPrev
        }),
        date: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          shape: "rounded-sm",
          style: {
            fontSize: "14px"
          },
          text: internalModel.value.format("YYYY-MM")
        }),
        next: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          icon: props.nextIcon,
          onClick: nextMonth,
          disabled: !hasNext
        }),
        nextDouble: __spreadProps$f(__spreadValues$K({}, sharedProps), {
          icon: props.nextDoubleIcon,
          onClick: nextYear,
          disabled: !hasNext
        })
      };
    });
    function prevYear() {
      internalModel.value = internalModel.value.subtract(1, "year");
    }
    function nextYear() {
      internalModel.value = internalModel.value.add(1, "year");
    }
    function prevMonth() {
      internalModel.value = internalModel.value.subtract(1, "month");
    }
    function nextMonth() {
      internalModel.value = internalModel.value.add(1, "month");
    }
    function onMousemove(text) {
      if (!range)
        return;
      if (range.selected.value.length === 1) {
        !range.isPreview.value && range.preview(true);
      }
      if (range.isPreview.value) {
        range.select(text);
      }
    }
    return () => {
      return createVNode(Card, {
        "class": "ve-date-picker-panel",
        "divided": true,
        "onMousedown": (e) => e.preventDefault()
      }, __spreadProps$f(__spreadValues$K({}, slots), {
        header: () => createVNode(Fragment, null, [createVNode(Button, controls.value.prevDouble, null), createVNode(Button, controls.value.prev, null), createVNode("div", {
          "class": "ve-date-picker-panel__date"
        }, [createVNode(Button, controls.value.date, null)]), createVNode(Button, controls.value.next, null), createVNode(Button, controls.value.nextDouble, null)]),
        text: () => createVNode(Fragment, null, [rows.value.map((cols) => createVNode("div", {
          "class": "ve-date-picker-panel__row"
        }, [cols.map((col) => createVNode("div", {
          "key": col.value,
          "class": ["ve-date-picker-panel__cell", {
            "ve-date-picker-panel__cell--active": col.isActive,
            "ve-date-picker-panel__cell--other-month": col.isOtherMonth,
            "ve-date-picker-panel__cell--range-in": col.value && (range == null ? void 0 : range.inRange(col.value)),
            "ve-date-picker-panel__cell--range-start": col.selectedIndex === 0,
            "ve-date-picker-panel__cell--range-end": col.selectedIndex === 1
          }],
          "onMousemove": () => onMousemove(col.text)
        }, [createVNode(Button, col.props, null)]))]))])
      }));
    };
  }
});

const DateRangePickerPanel = /* @__PURE__ */ defineComponent({
  name: "VeDateRangePickerPanel",
  props: {
    /**
     * @zh 时间格式化
     */
    format: {
      type: [Array, Function],
      default: () => ["YYYY-MM-DD", "YYYY-MM-DD"]
    },
    /**
     * @zh 时间值
     */
    modelValue: {
      type: Array,
      default: () => []
    }
  },
  emits: {
    "update:modelValue": (_value) => true,
    "preview": (_value) => true
  },
  setup(props, {
    emit
  }) {
    const model = useProxiedModel(props, "modelValue");
    const selected = computed(() => {
      return model.value.map(createDate).sort((a, b) => a.valueOf() - b.valueOf());
    });
    const isPreview = ref(false);
    function formatter(dates) {
      return typeof props.format === "function" ? props.format(dates) : dates.map((date, i) => date.format(props.format[i]));
    }
    function preview(value) {
      isPreview.value = value;
      emit("preview", isPreview.value);
    }
    function select(value) {
      const length = model.value.length;
      if (length === 1 || isPreview.value && length > 0) {
        if (model.value[1] === value)
          return;
        model.value = formatter([model.value[0], value].map(createDate));
      } else {
        if (model.value[0] === value)
          return;
        model.value = formatter([value].map(createDate));
      }
    }
    function inRange(value) {
      if (selected.value.length < 2)
        return false;
      return selected.value[0].valueOf() <= value && selected.value[1].valueOf() >= value;
    }
    provide(DateRangeKey, {
      selected,
      select,
      inRange,
      preview,
      isPreview
    });
    return () => {
      return createVNode(Card, {
        "class": "ve-date-range-picker-panel"
      }, {
        default: () => [createVNode(DatePickerPanel, {
          "format": defaultDateFormat,
          "modelValue": createDate().startOf("month").format(),
          "max": createDate().startOf("month").format()
        }, null), createVNode(DatePickerPanel, {
          "format": defaultDateFormat,
          "modelValue": createDate().add(1, "month").startOf("month").format(),
          "min": createDate().add(1, "month").startOf("month").format()
        }, null)]
      });
    };
  }
});

var __defProp$J = Object.defineProperty;
var __defProps$e = Object.defineProperties;
var __getOwnPropDescs$e = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$K = Object.getOwnPropertySymbols;
var __hasOwnProp$K = Object.prototype.hasOwnProperty;
var __propIsEnum$K = Object.prototype.propertyIsEnumerable;
var __defNormalProp$J = (obj, key, value) => key in obj ? __defProp$J(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$J = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$K.call(b, prop))
      __defNormalProp$J(a, prop, b[prop]);
  if (__getOwnPropSymbols$K)
    for (var prop of __getOwnPropSymbols$K(b)) {
      if (__propIsEnum$K.call(b, prop))
        __defNormalProp$J(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$e = (a, b) => __defProps$e(a, __getOwnPropDescs$e(b));
const DatePicker = genericComponent()({
  name: "VeDatePicker",
  props: {
    /**
     * @zh 输入框后追加的图标
     */
    appendInnerIcon: {
      type: String,
      default: "$calendar"
    },
    /**
     * @zh 时间格式化
     */
    format: [Array, String, Function],
    /**
     * @zh 输入框ID
     */
    id: String,
    /**
     * @zh 绑定值
     */
    modelValue: {
      type: [String, Array],
      default: () => []
    },
    /**
     * @zh 点击清除后是否展开菜单面板
     */
    openOnClear: Boolean,
    /**
     * @zh 面板的属性
     */
    panelProps: Object,
    /**
     * @zh 只读
     */
    readonly: Boolean,
    /**
     * @zh 开启范围时间选择
     */
    range: Boolean
  },
  emits: {
    "update:modelValue": (_modelValue) => true,
    "change": (_modelValue) => true
  },
  setup(props, {
    slots,
    emit
  }) {
    const activator = ref();
    const inputRef = ref();
    const isActiveMenu = ref(false);
    const id = computed(() => props.id || `ve-date-picker-${getUid()}`);
    const model = useProxiedModel(props, "modelValue", [], (v) => wrapInArray(v), (v) => props.range ? v : v[0]);
    const panelProps = computed(() => {
      const panelProps2 = __spreadValues$J({}, props.panelProps);
      if (props.format) {
        panelProps2.format = props.format;
      }
      return panelProps2;
    });
    watch(() => inputRef.value, (val) => {
      activator.value = val.$el.querySelector(".ve-input-control");
    });
    function onClear(_e) {
      model.value = [];
      if (props.openOnClear) {
        isActiveMenu.value = true;
      }
    }
    function onKeydown({
      key
    }) {
      if ([keyValues.enter, keyValues.space].includes(key) && !isActiveMenu.value) {
        isActiveMenu.value = true;
      }
      if (key === keyValues.esc && isActiveMenu.value) {
        isActiveMenu.value = false;
      }
    }
    function blur() {
      var _a;
      (_a = inputRef.value) == null ? void 0 : _a.blur();
    }
    function onChange() {
      emit("change", props.range ? model.value : model.value[0]);
    }
    return () => {
      return createVNode(Input, {
        "appendInnerIcon": props.appendInnerIcon,
        "class": ["ve-date-picker", {
          "ve-date-picker--active-menu": isActiveMenu.value
        }],
        "id": id.value,
        "modelValue": model.value.join(" ~ ") || void 0,
        "onClick:clear": onClear,
        "onClick:control": () => {
          if (props.readonly)
            return;
          if (isActiveMenu.value) {
            blur();
          } else {
            isActiveMenu.value = true;
          }
        },
        "onBlur": () => isActiveMenu.value = false,
        "onKeydown": onKeydown,
        "onMousedown": (e) => e.preventDefault(),
        "ref": inputRef,
        "readonly": true
      }, __spreadProps$e(__spreadValues$J({}, slots), {
        default: () => createVNode(Fragment, null, [activator.value && createVNode(Menu, {
          "contentClass": "ve-date-picker-menu-wrapper",
          "id": `${id.value}-menu`,
          "modelValue": isActiveMenu.value,
          "onUpdate:modelValue": ($event) => isActiveMenu.value = $event,
          "activator": activator.value,
          "openOnClick": false
        }, {
          default: () => [!props.range && createVNode(DatePickerPanel, mergeProps(panelProps.value, {
            "modelValue": model.value[0],
            "onUpdate:modelValue": (val) => {
              model.value = [val];
              blur();
              onChange();
            }
          }), null), props.range && createVNode(DateRangePickerPanel, mergeProps(panelProps.value, {
            "modelValue": model.value,
            "onUpdate:modelValue": ($event) => model.value = $event,
            "onPreview": (v) => {
              if (!v) {
                blur();
                onChange();
              }
            }
          }), null)]
        })])
      }));
    };
  }
});

const DefaultsProvider = /* @__PURE__ */ defineComponent$1({
  name: "VeDefaultsProvider",
  props: {
    defaults: Object,
    reset: [Number, String],
    root: Boolean,
    scoped: Boolean
  },
  setup(props, {
    slots
  }) {
    const {
      defaults,
      reset,
      root,
      scoped
    } = toRefs(props);
    provideDefaults(defaults, {
      reset,
      root,
      scoped
    });
    return () => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots);
    };
  }
});

const deviceModels = {
  iphonex: {
    width: 375,
    height: 812,
    statusBarHeight: 24
  },
  iphone6plus: {
    width: 414,
    height: 736,
    statusBarHeight: 24
  },
  iphone7plus: {
    width: 414,
    height: 736,
    statusBarHeight: 24
  },
  iphone8plus: {
    width: 414,
    height: 736,
    statusBarHeight: 24
  },
  iphone6: {
    width: 375,
    height: 667,
    statusBarHeight: 24
  },
  iphone7: {
    width: 375,
    height: 667,
    statusBarHeight: 24
  },
  iphone8: {
    width: 375,
    height: 667,
    statusBarHeight: 24
  }
};
const makeDeviceProps = propsFactory({
  model: String,
  autoHeight: Boolean
}, "device");
function useDevice(props) {
  const deviceModel = computed(() => {
    return props.model && props.model in deviceModels ? deviceModels[props.model] : {
      width: "100%",
      height: "100%",
      statusBarHeight: 0
    };
  });
  const deviceStyles = computed(() => {
    return {
      width: convertToUnit(deviceModel.value.width),
      height: props.autoHeight ? null : convertToUnit(deviceModel.value.height),
      minHeight: props.autoHeight ? convertToUnit(deviceModel.value.height) : null
    };
  });
  return {
    deviceModel,
    deviceStyles
  };
}

var __defProp$I = Object.defineProperty;
var __getOwnPropSymbols$J = Object.getOwnPropertySymbols;
var __hasOwnProp$J = Object.prototype.hasOwnProperty;
var __propIsEnum$J = Object.prototype.propertyIsEnumerable;
var __defNormalProp$I = (obj, key, value) => key in obj ? __defProp$I(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$I = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$J.call(b, prop))
      __defNormalProp$I(a, prop, b[prop]);
  if (__getOwnPropSymbols$J)
    for (var prop of __getOwnPropSymbols$J(b)) {
      if (__propIsEnum$J.call(b, prop))
        __defNormalProp$I(a, prop, b[prop]);
    }
  return a;
};
const DeviceStatusBar = genericComponent()({
  name: "VeDeviceStatusBar",
  props: __spreadValues$I(__spreadValues$I({
    height: {
      type: Number,
      default: 20
    },
    battery: {
      type: Number,
      default: 100
    },
    operator: {
      type: String,
      default: "Z+"
    }
  }, makeTagProps()), makeColorProps()),
  setup(props) {
    function getClockValue() {
      const now = /* @__PURE__ */ new Date();
      const hour = now.getHours();
      const minute = now.getMinutes();
      return `${hour >= 12 ? "\u4E0B\u5348" : "\u4E0A\u5348"}${Math.abs(hour - 12)}:${String(minute).padStart(2, "0")}`;
    }
    const clock = ref(getClockValue());
    const clockTimer = setInterval(() => {
      clock.value = getClockValue();
    }, 1e3);
    onBeforeUnmount(() => {
      clearInterval(clockTimer);
    });
    const {
      colorClasses,
      colorStyles
    } = useColor(computed(() => {
      const {
        textColor,
        color
      } = unref(props);
      return {
        background: color,
        text: textColor
      };
    }));
    return () => {
      return createVNode(props.tag, {
        "class": ["ve-device-status-bar", colorClasses.value],
        "style": [{
          height: convertToUnit(props.height)
        }, colorStyles.value]
      }, {
        default: () => [createVNode("div", {
          "class": "ve-device-status-bar__clock"
        }, [clock.value]), createVNode("div", {
          "class": "ve-device-status-bar__mobile-signal"
        }, [[...Array(4)].map((_) => createVNode("div", null, null))]), createVNode("div", {
          "class": "ve-device-status-bar__mobile-operator"
        }, [props.operator]), createVNode("div", {
          "class": "ve-device-status-bar__wifi-signal"
        }, [[...Array(3)].map((_) => createVNode("div", null, null))]), createVNode("div", {
          "class": "ve-device-status-bar__spacer"
        }, null), createVNode("div", {
          "class": "ve-device-status-bar__battery-percentage"
        }, [props.battery, createTextVNode("%")]), createVNode("div", {
          "class": "ve-device-status-bar__battery"
        }, [createVNode("div", {
          "style": {
            width: `${props.battery}%`
          }
        }, null)])]
      });
    };
  }
});

var __defProp$H = Object.defineProperty;
var __getOwnPropSymbols$I = Object.getOwnPropertySymbols;
var __hasOwnProp$I = Object.prototype.hasOwnProperty;
var __propIsEnum$I = Object.prototype.propertyIsEnumerable;
var __defNormalProp$H = (obj, key, value) => key in obj ? __defProp$H(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$H = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$I.call(b, prop))
      __defNormalProp$H(a, prop, b[prop]);
  if (__getOwnPropSymbols$I)
    for (var prop of __getOwnPropSymbols$I(b)) {
      if (__propIsEnum$I.call(b, prop))
        __defNormalProp$H(a, prop, b[prop]);
    }
  return a;
};
const Device = /* @__PURE__ */ defineComponent({
  name: "VeDevice",
  props: __spreadValues$H(__spreadValues$H(__spreadValues$H({
    battery: {
      type: Number,
      default: 100
    },
    operator: {
      type: String,
      default: "Z+"
    },
    headerColor: String
  }, makeDeviceProps()), makeTagProps()), makeVariantProps()),
  setup(props, {
    slots
  }) {
    const {
      colorClasses,
      colorStyles,
      variantClasses
    } = useVariant(props);
    const {
      deviceModel,
      deviceStyles
    } = useDevice(props);
    return () => {
      return createVNode(props.tag, {
        "class": ["ve-device", variantClasses.value, colorClasses.value],
        "style": [deviceStyles.value, colorStyles.value]
      }, {
        default: () => {
          var _a, _b;
          return [createVNode("div", {
            "class": "ve-device__app-header",
            "style": {
              backgroundColor: props.headerColor
            }
          }, [deviceModel.value.statusBarHeight > 0 && createVNode(DeviceStatusBar, {
            "height": deviceModel.value.statusBarHeight,
            "battery": props.battery,
            "operator": props.operator
          }, null), slots.header && createVNode("div", {
            "class": "ve-device__app-bar"
          }, [(_a = slots.header) == null ? void 0 : _a.call(slots)])]), createVNode("div", {
            "class": "ve-device__app-main"
          }, [(_b = slots.default) == null ? void 0 : _b.call(slots)]), props.autoHeight && typeof deviceModel.value.height === "number" && createVNode("div", {
            "class": "ve-device__height-tip",
            "style": {
              top: convertToUnit(deviceModel.value.height - 21)
            }
          }, [props.model, createTextVNode("\u9AD8\u5EA6")])];
        }
      });
    };
  }
});

var __defProp$G = Object.defineProperty;
var __defProps$d = Object.defineProperties;
var __getOwnPropDescs$d = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$H = Object.getOwnPropertySymbols;
var __hasOwnProp$H = Object.prototype.hasOwnProperty;
var __propIsEnum$H = Object.prototype.propertyIsEnumerable;
var __defNormalProp$G = (obj, key, value) => key in obj ? __defProp$G(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$G = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$H.call(b, prop))
      __defNormalProp$G(a, prop, b[prop]);
  if (__getOwnPropSymbols$H)
    for (var prop of __getOwnPropSymbols$H(b)) {
      if (__propIsEnum$H.call(b, prop))
        __defNormalProp$G(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$d = (a, b) => __defProps$d(a, __getOwnPropDescs$d(b));
const Dialog = genericComponent()({
  name: "VeDialog",
  props: __spreadValues$G({
    /**
     * @zh 全屏
     */
    fullscreen: Boolean,
    /**
     * @zh ID
     */
    id: String,
    /**
     * @zh 是否显示
     */
    modelValue: Boolean,
    /**
     * @zh 是否可以滚动
     */
    scrollable: Boolean,
    /**
     * @zh 可以拖拽的
     */
    draggable: Boolean
  }, makeTransitionProps({
    transition: {
      component: DialogTransition
    }
  })),
  emits: {
    "update:modelValue": (_) => true
  },
  setup(props, {
    slots
  }) {
    const isActive = useProxiedModel(props, "modelValue");
    const id = computed(() => props.id || `ve-dialog-${getUid()}`);
    return () => createVNode(Overlay, {
      "aria-role": "dialog",
      "aria-modal": "true",
      "activator-props": {
        "aria-haspopup": "dialog",
        "aria-expanded": String(isActive.value),
        "aria-describedby": id.value
      },
      "class": ["ve-dialog", {
        "ve-dialog--fullscreen": props.fullscreen,
        "ve-dialog--scrollable": props.scrollable
      }],
      "contentClass": "ve-dialog__wrapper",
      "id": id.value,
      "transition": props.transition,
      "modelValue": isActive.value,
      "onUpdate:modelValue": ($event) => isActive.value = $event
    }, __spreadProps$d(__spreadValues$G({}, slots), {
      default: slots.default
    }));
  }
});

const DisplayKey = Symbol.for("veno-ui:display");
const defaultDisplayOptions = {
  mobileBreakpoint: "lg",
  thresholds: {
    xs: 0,
    sm: 600,
    md: 960,
    lg: 1280,
    xl: 1920,
    xxl: 2560
  }
};
const parseDisplayOptions = (options = defaultDisplayOptions) => {
  return deepMerge(defaultDisplayOptions, options);
};
function getClientWidth() {
  return IN_BROWSER ? Math.max(
    document.documentElement.clientWidth,
    window.innerWidth
  ) : 0;
}
function getClientHeight() {
  return IN_BROWSER ? Math.max(
    document.documentElement.clientHeight,
    window.innerHeight
  ) : 0;
}
function getPlatform() {
  const userAgent = IN_BROWSER ? window.navigator.userAgent : "ssr";
  function match(regexp) {
    return Boolean(userAgent.match(regexp));
  }
  const android = match(/android/i);
  const ios = match(/iphone|ipad|ipod/i);
  const cordova = match(/cordova/i);
  const electron = match(/electron/i);
  const chrome = match(/chrome/i);
  const edge = match(/edge/i);
  const firefox = match(/firefox/i);
  const opera = match(/opera/i);
  const win = match(/win/i);
  const mac = match(/mac/i);
  const linux = match(/linux/i);
  const ssr = match(/ssr/i);
  return {
    android,
    ios,
    cordova,
    electron,
    chrome,
    edge,
    firefox,
    opera,
    win,
    mac,
    linux,
    touch: SUPPORTS_TOUCH,
    ssr
  };
}
function createDisplay(options) {
  const { thresholds, mobileBreakpoint } = parseDisplayOptions(options);
  const height = ref(getClientHeight());
  const platform = getPlatform();
  const state = reactive({});
  const width = ref(getClientWidth());
  function onResize() {
    height.value = getClientHeight();
    width.value = getClientWidth();
  }
  watchEffect(() => {
    const xs = width.value < thresholds.sm;
    const sm = width.value < thresholds.md && !xs;
    const md = width.value < thresholds.lg && !(sm || xs);
    const lg = width.value < thresholds.xl && !(md || sm || xs);
    const xl = width.value < thresholds.xxl && !(lg || md || sm || xs);
    const xxl = width.value >= thresholds.xxl;
    const name = xs ? "xs" : sm ? "sm" : md ? "md" : lg ? "lg" : xl ? "xl" : "xxl";
    const breakpointValue = typeof mobileBreakpoint === "number" ? mobileBreakpoint : thresholds[mobileBreakpoint];
    const mobile = !platform.ssr ? width.value < breakpointValue : platform.android || platform.ios || platform.opera;
    state.xs = xs;
    state.sm = sm;
    state.md = md;
    state.lg = lg;
    state.xl = xl;
    state.xxl = xxl;
    state.smAndUp = !xs;
    state.mdAndUp = !(xs || sm);
    state.lgAndUp = !(xs || sm || md);
    state.xlAndUp = !(xs || sm || md || lg);
    state.smAndDown = !(md || lg || xl || xxl);
    state.mdAndDown = !(lg || xl || xxl);
    state.lgAndDown = !(xl || xxl);
    state.xlAndDown = !xxl;
    state.name = name;
    state.height = height.value;
    state.width = width.value;
    state.mobile = mobile;
    state.mobileBreakpoint = mobileBreakpoint;
    state.platform = platform;
    state.thresholds = thresholds;
  });
  if (IN_BROWSER) {
    window.addEventListener("resize", onResize, { passive: true });
  }
  return toRefs(state);
}
function useDisplay() {
  const display = inject(DisplayKey);
  if (!display)
    throw new Error("[VenoUi] Could not find display injection");
  return display;
}

const HORIZON = 100;
const HISTORY = 20;
function kineticEnergyToVelocity(work) {
  const sqrt2 = 1.41421356237;
  return (work < 0 ? -1 : 1) * Math.sqrt(Math.abs(work)) * sqrt2;
}
function calculateImpulseVelocity(samples) {
  if (samples.length < 2) {
    return 0;
  }
  if (samples.length === 2) {
    if (samples[1].t === samples[0].t) {
      return 0;
    }
    return (samples[1].d - samples[0].d) / (samples[1].t - samples[0].t);
  }
  let work = 0;
  for (let i = samples.length - 1; i > 0; i--) {
    if (samples[i].t === samples[i - 1].t) {
      continue;
    }
    const vprev = kineticEnergyToVelocity(work);
    const vcurr = (samples[i].d - samples[i - 1].d) / (samples[i].t - samples[i - 1].t);
    work += (vcurr - vprev) * Math.abs(vcurr);
    if (i === samples.length - 1) {
      work *= 0.5;
    }
  }
  return kineticEnergyToVelocity(work) * 1e3;
}
function useVelocity() {
  const touches = {};
  function addMovement(e) {
    Array.from(e.changedTouches).forEach((touch) => {
      var _a;
      const samples = (_a = touches[touch.identifier]) != null ? _a : touches[touch.identifier] = new CircularBuffer(HISTORY);
      samples.push([e.timeStamp, touch]);
    });
  }
  function endTouch(e) {
    Array.from(e.changedTouches).forEach((touch) => {
      delete touches[touch.identifier];
    });
  }
  function getVelocity(id) {
    var _a;
    const samples = (_a = touches[id]) == null ? void 0 : _a.values().reverse();
    if (!samples) {
      throw new Error(`No samples for touch id ${id}`);
    }
    const newest = samples[0];
    const x = [];
    const y = [];
    for (const val of samples) {
      if (newest[0] - val[0] > HORIZON)
        break;
      x.push({ t: val[0], d: val[1].clientX });
      y.push({ t: val[0], d: val[1].clientY });
    }
    return {
      x: calculateImpulseVelocity(x),
      y: calculateImpulseVelocity(y),
      get direction() {
        const { x: x2, y: y2 } = this;
        const [absX, absY] = [Math.abs(x2), Math.abs(y2)];
        return absX > absY && x2 >= 0 ? "right" : absX > absY && x2 <= 0 ? "left" : absY > absX && y2 >= 0 ? "down" : absY > absX && y2 <= 0 ? "up" : oops$1();
      }
    };
  }
  return { addMovement, endTouch, getVelocity };
}
function oops$1() {
  throw new Error();
}

function useTouch({ isActive, isTemporary, width, touchless, position }) {
  const onTouchmove = throttle((e) => handleTouchmove(e), 69);
  onMounted(() => {
    window.addEventListener("touchstart", onTouchstart, { passive: true });
    window.addEventListener("touchmove", onTouchmove, { passive: false });
    window.addEventListener("touchend", onTouchend, { passive: true });
  });
  onBeforeUnmount(() => {
    window.removeEventListener("touchstart", onTouchstart);
    window.removeEventListener("touchmove", onTouchmove);
    window.removeEventListener("touchend", onTouchend);
  });
  const isHorizontal = computed(() => position.value !== "bottom");
  const { addMovement, endTouch, getVelocity } = useVelocity();
  let maybeDragging = false;
  const isDragging = ref(false);
  const dragProgress = ref(0);
  const offset = ref(0);
  let start;
  function getOffset(pos, active) {
    return (position.value === "left" ? pos : position.value === "right" ? document.documentElement.clientWidth - pos : position.value === "bottom" ? document.documentElement.clientHeight - pos : oops()) - (active ? width.value : 0);
  }
  function getProgress(pos, limit = true) {
    const progress = position.value === "left" ? (pos - offset.value) / width.value : position.value === "right" ? (document.documentElement.clientWidth - pos - offset.value) / width.value : position.value === "bottom" ? (document.documentElement.clientHeight - pos - offset.value) / width.value : oops();
    return limit ? Math.max(0, Math.min(1, progress)) : progress;
  }
  function onTouchstart(e) {
    if (touchless.value || !isActive.value)
      return;
    const touchX = e.changedTouches[0].clientX;
    const touchY = e.changedTouches[0].clientY;
    const touchZone = 25;
    const inTouchZone = position.value === "left" ? touchX < touchZone : position.value === "right" ? touchX > document.documentElement.clientWidth - touchZone : position.value === "bottom" ? touchY > document.documentElement.clientHeight - touchZone : position.value === "top" ? touchY < touchZone : oops();
    const inElement = isActive.value && (position.value === "left" ? touchX < width.value : position.value === "right" ? touchX > document.documentElement.clientWidth - width.value : position.value === "bottom" ? touchY > document.documentElement.clientHeight - width.value : position.value === "top" ? touchY < width.value : oops());
    if (inTouchZone || inElement || isActive.value && isTemporary.value) {
      maybeDragging = true;
      start = [touchX, touchY];
      offset.value = getOffset(isHorizontal.value ? touchX : touchY, isActive.value);
      dragProgress.value = getProgress(isHorizontal.value ? touchX : touchY);
      endTouch(e);
      addMovement(e);
    }
  }
  function handleTouchmove(e) {
    const touchX = e.changedTouches[0].clientX;
    const touchY = e.changedTouches[0].clientY;
    if (maybeDragging) {
      if (!e.cancelable) {
        maybeDragging = false;
        return;
      }
      const dx = Math.abs(touchX - start[0]);
      const dy = Math.abs(touchY - start[1]);
      const thresholdMet = isHorizontal.value ? dx > dy && dx > 3 : dy > dx && dy > 3;
      if (thresholdMet) {
        isDragging.value = true;
        maybeDragging = false;
      } else if ((isHorizontal.value ? dy : dx) > 3) {
        maybeDragging = false;
      }
    }
    if (!isDragging.value)
      return;
    e.preventDefault();
    addMovement(e);
    const progress = getProgress(isHorizontal.value ? touchX : touchY, false);
    dragProgress.value = Math.max(0, Math.min(1, progress));
    if (progress > 1) {
      offset.value = getOffset(isHorizontal.value ? touchX : touchY, true);
    } else if (progress < 0) {
      offset.value = getOffset(isHorizontal.value ? touchX : touchY, false);
    }
  }
  function onTouchend(e) {
    maybeDragging = false;
    if (!isDragging.value)
      return;
    addMovement(e);
    isDragging.value = false;
    const velocity = getVelocity(e.changedTouches[0].identifier);
    const vx = Math.abs(velocity.x);
    const vy = Math.abs(velocity.y);
    const thresholdMet = isHorizontal.value ? vx > vy && vx > 400 : vy > vx && vy > 3;
    if (thresholdMet) {
      isActive.value = velocity.direction === ({
        left: "right",
        right: "left",
        bottom: "up",
        top: "down"
      }[position.value] || oops());
    } else {
      isActive.value = dragProgress.value > 0.5;
    }
  }
  const dragStyles = computed(() => {
    return isDragging.value ? {
      transform: position.value === "left" ? `translateX(calc(-100% + ${dragProgress.value * width.value}px))` : position.value === "right" ? `translateX(calc(100% - ${dragProgress.value * width.value}px))` : position.value === "bottom" ? `translateY(calc(100% - ${dragProgress.value * width.value}px))` : position.value === "top" ? `translateY(calc(-100% + ${dragProgress.value * width.value}px))` : oops(),
      transition: "none"
    } : void 0;
  });
  return {
    isDragging,
    dragProgress,
    dragStyles
  };
}
function oops() {
  throw new Error();
}

var __defProp$F = Object.defineProperty;
var __getOwnPropSymbols$G = Object.getOwnPropertySymbols;
var __hasOwnProp$G = Object.prototype.hasOwnProperty;
var __propIsEnum$G = Object.prototype.propertyIsEnumerable;
var __defNormalProp$F = (obj, key, value) => key in obj ? __defProp$F(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$F = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$G.call(b, prop))
      __defNormalProp$F(a, prop, b[prop]);
  if (__getOwnPropSymbols$G)
    for (var prop of __getOwnPropSymbols$G(b)) {
      if (__propIsEnum$G.call(b, prop))
        __defNormalProp$F(a, prop, b[prop]);
    }
  return a;
};
const Drawer = /* @__PURE__ */ defineComponent({
  name: "VeDrawer",
  props: __spreadValues$F(__spreadValues$F(__spreadValues$F(__spreadValues$F(__spreadValues$F({
    /**
     * @zh 禁用大小调整监听
     */
    disableResizeWatcher: Boolean,
    /**
     * @zh 禁用路由监听
     */
    disableRouteWatcher: Boolean,
    /**
     * @zh 背景颜色
     */
    color: String,
    /**
     * @zh 悬停时展开
     */
    expandOnHover: Boolean,
    /**
     * @zh 持续激活
     */
    permanent: Boolean,
    /**
     * @zh 最小化
     */
    rail: Boolean,
    /**
     * @zh 最小化宽度
     */
    railWidth: {
      type: [Number, String],
      default: 52
    },
    /**
     * @zh 显示激活/隐藏按钮
     */
    showToggler: Boolean,
    /**
     * @zh 临时抽屉
     */
    temporary: Boolean,
    /**
     * @zh 可触摸
     */
    touchless: Boolean,
    /**
     * @zh 宽度
     */
    width: {
      type: [Number, String],
      default: 256
    }
  }, makeTagProps({
    tag: "nav"
  })), makeScrollbar()), makeThemeProps()), makeBorderProps()), makeLayoutItemProps({
    position: "fixed",
    anchor: "left",
    modelValue: null
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    attrs,
    slots
  }) {
    const {
      themeClasses
    } = provideTheme(props);
    const {
      borderClasses
    } = useBorder(props);
    const {
      scrollbarClasses
    } = useScrollbar(props);
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, "color"));
    const {
      mobile,
      platform
    } = useDisplay();
    const router = useRouter();
    const isActive = useProxiedModel(props, "modelValue", null, (v) => !!v);
    const isHovering = ref(false);
    const width = computed(() => {
      return props.rail && props.expandOnHover && isHovering.value ? Number(props.width) : Number(props.rail ? props.railWidth : props.width);
    });
    const isTemporary = computed(() => !props.permanent && !!(mobile.value || props.temporary));
    const hasToggler = computed(() => props.showToggler && !mobile.value);
    watch(isTemporary, (val) => {
      if (!props.disableResizeWatcher && !props.permanent)
        isActive.value = !val;
    });
    if (router) {
      watch(router.currentRoute, () => {
        if (!props.disableRouteWatcher && isTemporary.value)
          isActive.value = false;
      });
    }
    watch(() => props.permanent, (val) => {
      if (val)
        isActive.value = true;
    });
    onBeforeMount(() => {
      if (props.modelValue !== null || isTemporary.value)
        return;
      isActive.value = props.permanent || !mobile.value;
    });
    const {
      isDragging,
      dragProgress,
      dragStyles
    } = useTouch({
      isActive,
      isTemporary,
      width,
      touchless: toRef(props, "touchless"),
      position: toRef(props, "anchor")
    });
    const layoutSize = computed(() => {
      const size = isTemporary.value ? 0 : props.rail && props.expandOnHover ? Number(props.railWidth) : width.value;
      return isDragging.value ? size * dragProgress.value : size;
    });
    const priority = computed(() => isTemporary.value ? parseInt(props.priority, 10) + 1 : props.priority);
    const {
      layoutItemStyles: _layoutItemStyles,
      layoutItemScrimStyles
    } = useLayoutItem(computed(() => ({
      name: props.name,
      position: props.position,
      anchor: props.anchor,
      size: width.value,
      layoutSize: layoutSize.value,
      priority: priority.value,
      active: isActive.value || isDragging.value,
      disableTransition: isDragging.value
    })));
    const layoutItemStyles = computed(() => {
      const styles = _layoutItemStyles.value;
      if (!platform.value.ssr && hasToggler.value && styles.transform) {
        styles.transform = styles.transform.replace("110", "90");
      }
      return styles;
    });
    return () => {
      var _a;
      const slotProps = {
        onClick: () => {
          isActive.value = true;
        }
      };
      return createVNode(Fragment, null, [(_a = slots.activator) == null ? void 0 : _a.call(slots, {
        props: slotProps
      }), createVNode(props.tag, mergeProps({
        "onMouseenter": () => isHovering.value = true,
        "onMouseleave": () => isHovering.value = false,
        "class": ["ve-drawer", {
          "ve-drawer--active": isActive.value,
          "ve-drawer--top": props.anchor === "top",
          "ve-drawer--bottom": props.anchor === "bottom",
          "ve-drawer--start": props.anchor === "left",
          "ve-drawer--end": props.anchor === "right",
          "ve-drawer--expand-on-hover": props.expandOnHover,
          "ve-drawer--rail": props.rail,
          "ve-drawer--is-hovering": isHovering.value,
          "ve-drawer--temporary": isTemporary.value,
          "ve-drawer--has-toggler": hasToggler.value
        }, themeClasses.value, backgroundColorClasses.value, borderClasses.value],
        "style": [layoutItemStyles.value, backgroundColorStyles.value, dragStyles.value]
      }, attrs), {
        default: () => {
          var _a2;
          return [createVNode("div", {
            "class": ["ve-drawer__wrapper", scrollbarClasses.value]
          }, [(_a2 = slots.default) == null ? void 0 : _a2.call(slots)]), hasToggler.value && createVNode(Button, {
            "position": "absolute",
            "class": "ve-drawer__toggler",
            "icon": "$toggler",
            "top": props.anchor === "left" || props.anchor === "right" ? 204 : void 0,
            "left": props.anchor === "bottom" || props.anchor === "top" ? 204 : props.anchor === "right" ? 0 : void 0,
            "right": props.anchor === "left" ? 0 : void 0,
            "bottom": props.anchor === "top" ? 0 : void 0,
            "size": "small",
            "density": "ultra-high",
            "border": true,
            "shape": "circle",
            "onClick": () => {
              isActive.value = !isActive.value;
            }
          }, null)];
        }
      }), createVNode(Scrim, {
        "modelValue": isTemporary.value && !!(isDragging.value || isActive.value),
        "style": [layoutItemScrimStyles.value, isDragging.value ? {
          opacity: dragProgress.value * 0.2,
          transition: "none"
        } : void 0],
        "onClick": () => isActive.value = false
      }, null)]);
    };
  }
});

const usePointer = (props = {}) => {
  const isPointerDown = ref(false);
  const isPointerMoving = ref(false);
  const pointerCurrentPosition = ref();
  const pointerDownAt = ref();
  const pointerDownEl = ref();
  const pointerDownPosition = ref();
  const pointerMovement = computed(() => {
    if (!pointerCurrentPosition.value || !pointerDownPosition.value)
      return void 0;
    return {
      left: pointerCurrentPosition.value.left - pointerDownPosition.value.left,
      top: pointerCurrentPosition.value.top - pointerDownPosition.value.top
    };
  });
  const minDelay = computed(() => SUPPORTS_TOUCH ? 5 : 0);
  const maxDelay = computed(() => SUPPORTS_TOUCH ? 50 : 0);
  const unregisterListeners = () => {
    if (SUPPORTS_TOUCH) {
      document.removeEventListener("touchmove", pointerMove);
      document.removeEventListener("touchend", pointerUp);
    } else {
      document.removeEventListener("mousemove", pointerMove);
      document.removeEventListener("mouseup", pointerUp);
    }
  };
  const pointerDown = (e) => {
    if (props.pointerDownStopPropagation)
      e.stopPropagation();
    if (props.pointerDownPreventDefault)
      e.preventDefault();
    pointerDownAt.value = Date.now();
    if (e instanceof MouseEvent) {
      pointerDownEl.value = e.target || e.relatedTarget;
    } else {
      pointerDownEl.value = e.target;
    }
    pointerDownPosition.value = pointerCurrentPosition.value = getPointerPosition(e);
    isPointerDown.value = true;
    if (SUPPORTS_TOUCH) {
      document.addEventListener("touchmove", pointerMove, { passive: !props.pointerMovePreventDefault });
      document.addEventListener("touchend", pointerUp, { passive: true });
    } else {
      document.addEventListener("mousemove", pointerMove);
      document.addEventListener("mouseup", pointerUp);
    }
  };
  function pointerMove(e) {
    if (isPointerMoving.value) {
      if (props.pointerMovePreventDefault && e.cancelable)
        e.preventDefault();
      pointerCurrentPosition.value = getPointerPosition(e);
    } else {
      const time = Date.now() - pointerDownAt.value;
      if (time < minDelay.value) ; else if (time < maxDelay.value) {
        unregisterListeners();
      } else if (distance(pointerDownPosition.value, getPointerPosition(e)) > 0) {
        isPointerMoving.value = true;
      }
    }
  }
  function pointerUp(e) {
    pointerCurrentPosition.value = getPointerPosition(e);
    pointerDownEl.value = void 0;
    isPointerDown.value = false;
    isPointerMoving.value = false;
    unregisterListeners();
  }
  onScopeDispose(() => {
    unregisterListeners();
  });
  const availableEvents = {
    touchstartPassive: pointerDown,
    touchstart: pointerDown,
    mousedown: pointerDown
  };
  return {
    isPointerDown: readonly(isPointerDown),
    isPointerMoving: readonly(isPointerMoving),
    pointerCurrentPosition: readonly(pointerCurrentPosition),
    pointerDown,
    pointerMove,
    pointerUp,
    pointerDownEl,
    pointerDownPosition: readonly(pointerDownPosition),
    pointerMovement: readonly(pointerMovement),
    pointerEvents: computed(() => {
      const events = {};
      if (SUPPORTS_TOUCH) {
        if (!props.pointerDownPreventDefault) {
          events.touchstartPassive = availableEvents.touchstartPassive;
        } else {
          events.touchstart = availableEvents.touchstart;
        }
      } else {
        events.mousedown = availableEvents.mousedown;
      }
      return events;
    })
  };
};
function distance(position1, position2) {
  return Math.sqrt((position2.left - position1.left) ** 2 + (position2.top - position1.top) ** 2);
}
function getPointerPosition(e) {
  return e instanceof TouchEvent ? e.touches.length > 0 ? { left: e.touches[0].clientX, top: e.touches[0].clientY } : { left: 0, top: 0 } : { left: e.clientX, top: e.clientY };
}

const DraggableSortableGroupKey = Symbol.for("veno-ui:draggable-sortable-group");
function createDraggableSortableGroup() {
  const items = /* @__PURE__ */ new Map();
  const swapping = ref(false);
  const find = (targetId, targetEl) => {
    for (const [id, item] of items) {
      if (id !== targetId) {
        const res = item.findContains(targetEl);
        if (res) {
          return [item, id, res.key, res.el];
        }
      }
    }
    return [void 0, void 0, void 0, void 0];
  };
  return {
    register: (id, item) => items.set(id, item),
    unregister: (id) => items.delete(id),
    trySwap: async (from, to) => {
      if (swapping.value)
        return;
      const [toItem, toParentId, toParentKey] = find(from.id, to.el);
      if (from.id === toParentId || !(toItem == null ? void 0 : toItem.group.value))
        return;
      const fromItem = items.get(from.id);
      if (!(fromItem == null ? void 0 : fromItem.group.value) || toItem.group.value !== fromItem.group.value)
        return;
      swapping.value = true;
      const value = fromItem.clone(from.key);
      if (fromItem.put.value && toItem.put.value) {
        await fromItem.leave(from.key);
      }
      if (toItem.put.value) {
        await toItem.enter(toParentKey, value, from);
      }
      swapping.value = false;
    }
  };
}
function useDraggableSortableGroupItem(id, item) {
  const group = inject(DraggableSortableGroupKey);
  group == null ? void 0 : group.register(id, item);
  onScopeDispose(() => {
    group == null ? void 0 : group.unregister(id);
  });
  return group;
}

const makeDraggableSortableProps = propsFactory({
  /**
   * @zh 移动项到另一组时克隆的方法
   */
  clone: Function,
  /**
   * @zh 每项的 key
   */
  itemKey: {
    type: [String, Function],
    default: () => (v) => v
  },
  /**
   * @zh 需要排序的列表
   */
  modelValue: {
    type: Array,
    default: () => []
  },
  /**
   * @zh 移动项到另一个组时是否移除元素
   */
  put: {
    type: Boolean,
    default: true
  },
  /**
   * @zh 组名
   */
  group: String
}, "draggable-sortable");
function useDraggableSortable(props, name = getCurrentInstanceName()) {
  const model = useProxiedModel(props, "modelValue", props.modelValue);
  const modelEls = /* @__PURE__ */ new Map();
  const modelIndexes = computed(() => {
    const indexes = /* @__PURE__ */ new Map();
    model.value.forEach((value, index) => indexes.set(typeof props.itemKey === "function" ? props.itemKey(value, index) : value[props.itemKey], index));
    return indexes;
  });
  const ghostEl = ref();
  const ghostVNode = ref();
  const active = ref();
  const indexToKey = (index) => {
    for (const [key, i] of modelIndexes.value) {
      if (index === i)
        return key;
    }
    return void 0;
  };
  const keyToIndex = (key) => modelIndexes.value.get(key);
  const keyToValue = (key) => model.value[modelIndexes.value.get(key)];
  const {
    isPointerMoving,
    pointerDown,
    pointerUp,
    pointerDownEl,
    pointerCurrentPosition,
    pointerMovement,
    pointerEvents
  } = usePointer({
    pointerMovePreventDefault: true
  });
  const ghostBox = ref();
  const id = `draggable-sortable-group-item-${getUid()}`;
  const item = {
    findContains: (target) => {
      if (target) {
        for (const [key, el] of modelEls) {
          if (el === target || (el == null ? void 0 : el.contains(target))) {
            return {
              key,
              el
            };
          }
        }
      }
      return void 0;
    },
    put: toRef(props, "put"),
    group: toRef(props, "group"),
    clone: (key) => {
      var _a, _b;
      const value = keyToValue(key);
      return (_b = (_a = props.clone) == null ? void 0 : _a.call(props, value)) != null ? _b : value;
    },
    enter: async (key, value, from) => {
      const index = keyToIndex(key);
      model.value.splice(index, 0, value);
      await nextTick();
      const el = modelEls.get(indexToKey(index));
      const box = el.getBoundingClientRect();
      pointerDown(new MouseEvent("mousedown", {
        clientY: from.position.top - (from.box.top - box.top),
        clientX: from.position.left - (from.box.left - box.left),
        relatedTarget: el
      }));
    },
    leave: async (key) => {
      model.value.splice(keyToIndex(key), 1);
      if (key === active.value) {
        pointerUp(new MouseEvent("mouseup", {
          clientY: pointerCurrentPosition.value.top,
          clientX: pointerCurrentPosition.value.left
        }));
      }
    }
  };
  const group = useDraggableSortableGroupItem(id, item);
  watch(modelIndexes, () => modelEls.clear());
  watch(pointerDownEl, (targetEl) => {
    var _a;
    ghostBox.value = targetEl ? (_a = item.findContains(targetEl)) == null ? void 0 : _a.el.getBoundingClientRect() : void 0;
  });
  watch(isPointerMoving, (val) => {
    var _a;
    active.value = val ? (_a = item.findContains(pointerDownEl.value)) == null ? void 0 : _a.key : void 0;
  });
  watch(pointerCurrentPosition, (val) => {
    var _a;
    if (!val || !active.value)
      return;
    const targetEl = document.elementFromPoint(val.left, val.top) || void 0;
    const key = (_a = item.findContains(targetEl)) == null ? void 0 : _a.key;
    if (key && active.value !== key) {
      if (item.put.value) {
        const oldIndex = keyToIndex(active.value);
        const newIndex = keyToIndex(key);
        model.value.splice(newIndex, 0, model.value.splice(oldIndex, 1)[0]);
      }
    } else if (!key && item.group.value && targetEl && pointerDownEl.value) {
      group == null ? void 0 : group.trySwap({
        id,
        key: active.value,
        box: ghostEl.value.getBoundingClientRect(),
        position: val
      }, {
        el: targetEl
      });
    }
  });
  return {
    active,
    model,
    modelIndexes,
    modelEls,
    keyToIndex,
    indexToKey,
    keyToValue,
    pointerEvents,
    ghostVNode,
    genGhost: () => {
      var _a, _b, _c, _d;
      return createVNode("div", {
        "ref": ghostEl,
        "class": `${name}__ghost`,
        "style": {
          left: convertToUnit((_a = ghostBox.value) == null ? void 0 : _a.left),
          top: convertToUnit((_b = ghostBox.value) == null ? void 0 : _b.top),
          width: convertToUnit((_c = ghostBox.value) == null ? void 0 : _c.width),
          height: convertToUnit((_d = ghostBox.value) == null ? void 0 : _d.height),
          transform: pointerMovement.value ? `translate3d(${convertToUnit(pointerMovement.value.left)}, ${convertToUnit(pointerMovement.value.top)}, 0px)` : void 0
        }
      }, [ghostVNode.value]);
    }
  };
}

var __defProp$E = Object.defineProperty;
var __getOwnPropSymbols$F = Object.getOwnPropertySymbols;
var __hasOwnProp$F = Object.prototype.hasOwnProperty;
var __propIsEnum$F = Object.prototype.propertyIsEnumerable;
var __defNormalProp$E = (obj, key, value) => key in obj ? __defProp$E(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$E = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$F.call(b, prop))
      __defNormalProp$E(a, prop, b[prop]);
  if (__getOwnPropSymbols$F)
    for (var prop of __getOwnPropSymbols$F(b)) {
      if (__propIsEnum$F.call(b, prop))
        __defNormalProp$E(a, prop, b[prop]);
    }
  return a;
};
const DraggableSortable = /* @__PURE__ */ defineComponent({
  name: "VeDraggableSortable",
  inheritAttrs: false,
  props: __spreadValues$E({}, makeDraggableSortableProps()),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const {
      model,
      modelEls,
      active,
      pointerEvents,
      keyToIndex,
      indexToKey,
      ghostVNode,
      genGhost
    } = useDraggableSortable(props);
    const vnodes = computed(() => {
      return model.value.map((value, index) => {
        var _a;
        const key = indexToKey(index);
        const draggable = mergeProps(toHandlers(pointerEvents.value), {
          style: {
            cursor: "move"
          }
        });
        const droppable = {
          ref: (v) => {
            modelEls.set(key, isComponentInstance(v) ? v.$el : v);
          }
        };
        const vnode = (_a = slots.item) == null ? void 0 : _a.call(slots, {
          item: value,
          draggable,
          droppable,
          props: mergeProps(draggable, droppable)
        });
        if (vnode && vnode[0]) {
          if (!vnode[0].key)
            vnode[0].key = key;
          vnode[0].props = mergeProps(vnode[0].props || {}, {
            class: {
              "ve-draggable-sortable--active": key === active.value
            }
          });
        }
        return vnode;
      });
    });
    watch(active, (val) => {
      var _a;
      const vnode = (_a = vnodes.value[keyToIndex(val)]) == null ? void 0 : _a[0];
      if (vnode) {
        ghostVNode.value = cloneVNode(vnode);
      } else {
        ghostVNode.value = void 0;
      }
    });
    return () => {
      return createVNode(Fragment, null, [vnodes.value, ghostVNode.value && genGhost()]);
    };
  }
});

function _isSlot$7(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Radio = /* @__PURE__ */ defineComponent({
  name: "VeRadio",
  props: makeSelectionControlProps({
    type: "radio",
    falseIcon: "$radioOff",
    trueIcon: "$radioOn",
    color: "primary"
  }),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    return () => {
      return createVNode(SelectionControl, mergeProps({
        "class": "ve-radio"
      }, props, {
        "onUpdate:modelValue": (val) => emit("update:modelValue", val)
      }), _isSlot$7(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});

var __defProp$D = Object.defineProperty;
var __defProps$c = Object.defineProperties;
var __getOwnPropDescs$c = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$E = Object.getOwnPropertySymbols;
var __hasOwnProp$E = Object.prototype.hasOwnProperty;
var __propIsEnum$E = Object.prototype.propertyIsEnumerable;
var __defNormalProp$D = (obj, key, value) => key in obj ? __defProp$D(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$D = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$E.call(b, prop))
      __defNormalProp$D(a, prop, b[prop]);
  if (__getOwnPropSymbols$E)
    for (var prop of __getOwnPropSymbols$E(b)) {
      if (__propIsEnum$E.call(b, prop))
        __defNormalProp$D(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$c = (a, b) => __defProps$c(a, __getOwnPropDescs$c(b));
var __objRest$2 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$E.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$E)
    for (var prop of __getOwnPropSymbols$E(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$E.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
const RadioGroup = /* @__PURE__ */ defineComponent({
  name: "VeRadioGroup",
  props: __spreadValues$D(__spreadValues$D(__spreadValues$D({
    /**
     * @zh 单选组的所有可选项
     */
    items: Array
  }, makeSelectionGroupControlProps({
    type: "radio",
    trueIcon: "$radioOn",
    falseIcon: "$radioOff"
  })), makeSizeProps()), makeDensityProps()),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const id = computed(() => props.id || `ve-radio-group-${getUid()}`);
    const model = useProxiedModel(props, "modelValue");
    const items = computed(() => {
      var _a;
      return (_a = props.items) == null ? void 0 : _a.map((itemProps) => typeof itemProps === "string" ? {
        value: itemProps
      } : itemProps);
    });
    provideDefaults({
      VeRadio: {
        size: toRef(props, "size"),
        density: toRef(props, "density"),
        readonly: toRef(props, "readonly"),
        disabled: toRef(props, "disabled")
      }
    });
    return () => {
      const _a = props, {
        density,
        size
      } = _a, restProps = __objRest$2(_a, [
        "density",
        "size"
      ]);
      return createVNode(FormControl, {
        "class": "ve-radio-group",
        "density": density,
        "name": props.name,
        "size": size,
        "modelValue": model.value,
        "onUpdate:modelValue": ($event) => model.value = $event
      }, __spreadProps$c(__spreadValues$D({}, slots), {
        default: ({
          isDisabled,
          isReadonly,
          props: controlProps
        }) => createVNode(SelectionGroupControl, mergeProps(restProps, controlProps, {
          "id": id.value,
          "disabled": isDisabled.value,
          "readonly": isReadonly.value,
          "modelValue": model.value,
          "onUpdate:modelValue": ($event) => model.value = $event
        }), {
          default: () => {
            var _a2, _b;
            return [(_a2 = items.value) == null ? void 0 : _a2.map((itemProps) => createVNode(Radio, itemProps, null)), (_b = slots.default) == null ? void 0 : _b.call(slots)];
          }
        })
      }));
    };
  }
});

const singleOpenStrategy = ({ id, value, opened, parents }) => {
  if (value) {
    const newOpened = /* @__PURE__ */ new Set();
    newOpened.add(id);
    let parent = parents.get(id);
    while (parent != null) {
      newOpened.add(parent);
      parent = parents.get(parent);
    }
    return newOpened;
  } else {
    opened.delete(id);
    return opened;
  }
};

const multipleOpenStrategy = ({ id, value, opened, parents }) => {
  if (value) {
    let parent = parents.get(id);
    opened.add(id);
    while (parent != null) {
      opened.add(parent);
      parent = parents.get(parent);
    }
    return opened;
  } else {
    opened.delete(id);
  }
  return opened;
};

const classicSelectStrategy = {
  select: ({ id, value, selected, children, parents }) => {
    const items = [id];
    while (items.length) {
      const item = items.shift();
      selected.set(item, value ? "on" : "off");
      if (children.has(item)) {
        items.push(...children.get(item));
      }
    }
    let parent = parents.get(id);
    while (parent) {
      const childrenIds = children.get(parent);
      const everySelected = childrenIds.every((cid) => selected.get(cid) === "on");
      const noneSelected = childrenIds.every((cid) => !selected.has(cid) || selected.get(cid) === "off");
      selected.set(parent, everySelected ? "on" : noneSelected ? "off" : "indeterminate");
      parent = parents.get(parent);
    }
    return selected;
  },
  in: (v, children, parents) => {
    let map = /* @__PURE__ */ new Map();
    for (const id of v || []) {
      map = classicSelectStrategy.select({
        id,
        value: true,
        selected: new Map(map),
        children,
        parents
      });
    }
    return map;
  },
  out: (v, children) => {
    const arr = [];
    for (const [key, value] of v.entries()) {
      if (value === "on" && !children.has(key))
        arr.push(key);
    }
    return arr;
  }
};

const independentSelectStrategy = {
  select: ({ id, value, selected }) => {
    selected.set(id, value ? "on" : "off");
    return selected;
  },
  in: (v, children, parents) => {
    let map = /* @__PURE__ */ new Map();
    for (const id of v || []) {
      map = independentSelectStrategy.select({
        id,
        value: true,
        selected: new Map(map),
        children,
        parents
      });
    }
    return map;
  },
  out: (v) => {
    const arr = [];
    for (const [key, value] of v.entries()) {
      if (value === "on")
        arr.push(key);
    }
    return arr;
  }
};

const leafSelectStrategy = (single = false) => {
  const strategy = {
    select: ({ id, value, selected, children }) => {
      if (children.has(id))
        return selected;
      if (single)
        return /* @__PURE__ */ new Map([[id, value ? "on" : "off"]]);
      selected.set(id, value ? "on" : "off");
      return selected;
    },
    in: (v, children, parents) => {
      let map = /* @__PURE__ */ new Map();
      for (const id of v != null ? v : []) {
        map = strategy.select({
          id,
          value: true,
          selected: new Map(map),
          children,
          parents
        });
      }
      return map;
    },
    out: independentSelectStrategy.out
  };
  return strategy;
};

const classicActiveStrategy = (single) => {
  return ({ id, value, active }) => {
    const newActive = single ? /* @__PURE__ */ new Set() : active;
    if (value) {
      newActive.add(id);
    } else {
      newActive.delete(id);
    }
    return newActive;
  };
};

var __defProp$C = Object.defineProperty;
var __defProps$b = Object.defineProperties;
var __getOwnPropDescs$b = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$D = Object.getOwnPropertySymbols;
var __hasOwnProp$D = Object.prototype.hasOwnProperty;
var __propIsEnum$D = Object.prototype.propertyIsEnumerable;
var __defNormalProp$C = (obj, key, value) => key in obj ? __defProp$C(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$C = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$D.call(b, prop))
      __defNormalProp$C(a, prop, b[prop]);
  if (__getOwnPropSymbols$D)
    for (var prop of __getOwnPropSymbols$D(b)) {
      if (__propIsEnum$D.call(b, prop))
        __defNormalProp$C(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$b = (a, b) => __defProps$b(a, __getOwnPropDescs$b(b));
const NestedKey = Symbol.for("veno-ui:nested");
const emptyNested = {
  id: ref(null),
  root: {
    register: () => null,
    unregister: () => null,
    parents: ref(/* @__PURE__ */ new Map()),
    children: ref(/* @__PURE__ */ new Map()),
    open: () => null,
    select: () => null,
    opened: ref(/* @__PURE__ */ new Set()),
    selected: ref(/* @__PURE__ */ new Map()),
    active: ref(/* @__PURE__ */ new Set()),
    activate: () => null,
    selectedValues: ref([])
  }
};
const makeNestedProps = propsFactory({
  /**
   * @zh 选择策略
   */
  selectStrategy: [String, Function],
  /**
   * @zh 打开策略
   */
  openStrategy: [String, Function],
  /**
   * @zh 激活策略
   */
  activeStrategy: [String, Function],
  /**
   * @zh 打开项的值
   */
  opened: {
    type: [Boolean, Array],
    default: () => []
  },
  /**
   * @zh 选择项的值
   */
  selected: Array,
  /**
   * @zh 激活项的值
   */
  active: Array,
  /**
   * @zh 卸载 DOM 后删除
   */
  deleteAfterUnmount: {
    type: Boolean,
    default: true
  }
}, "nested");
const useNested = (props) => {
  let isUnmounted = false;
  const children = ref(/* @__PURE__ */ new Map());
  const parents = ref(/* @__PURE__ */ new Map());
  const opened = useProxiedModel(
    props,
    "opened",
    props.opened,
    (v) => typeof v === "boolean" ? new Set(v === true ? [...children.value.keys()] : []) : new Set(v),
    (v) => [...v.values()]
  );
  const active = useProxiedModel(
    props,
    "active",
    props.active,
    (v) => new Set(v),
    (v) => [...v.values()]
  );
  const activeStrategy = computed(() => {
    if (typeof props.activeStrategy === "string") {
      switch (props.activeStrategy) {
        case "single":
          return classicActiveStrategy(true);
        case "multiple":
        default:
          return classicActiveStrategy();
      }
    }
    return props.activeStrategy;
  });
  const selectStrategy = computed(() => {
    if (typeof props.selectStrategy === "string") {
      switch (props.selectStrategy) {
        case "single-leaf":
          return leafSelectStrategy(true);
        case "leaf":
          return leafSelectStrategy();
        case "independent":
          return independentSelectStrategy;
        case "classic":
        default:
          return classicSelectStrategy;
      }
    }
    return props.selectStrategy;
  });
  const openStrategy = computed(() => {
    if (typeof props.openStrategy === "string") {
      switch (props.openStrategy) {
        case "single":
          return singleOpenStrategy;
        case "multiple":
        default:
          return multipleOpenStrategy;
      }
    }
    return props.openStrategy;
  });
  const selected = useProxiedModel(
    props,
    "selected",
    props.selected,
    (v) => selectStrategy.value.in(v, children.value, parents.value),
    (v) => selectStrategy.value.out(v, children.value, parents.value)
  );
  onBeforeUnmount(() => {
    isUnmounted = true;
  });
  const nested = {
    id: ref(null),
    root: {
      opened,
      selected,
      active,
      selectedValues: computed(() => {
        const arr = [];
        for (const [key, value] of selected.value.entries()) {
          if (value === "on")
            arr.push(key);
        }
        return arr;
      }),
      register: (id, parentId, isGroup) => {
        parentId && parents.value.set(id, parentId);
        isGroup && children.value.set(id, []);
        if (parentId != null) {
          children.value.set(parentId, [...children.value.get(parentId) || [], id]);
        }
      },
      unregister: (id) => {
        var _a;
        if (isUnmounted)
          return;
        children.value.delete(id);
        const parent = parents.value.get(id);
        if (parent) {
          const list = (_a = children.value.get(parent)) != null ? _a : [];
          children.value.set(parent, list.filter((child) => child !== id));
        }
        parents.value.delete(id);
        opened.value.delete(id);
        if (props.deleteAfterUnmount) {
          active.value.delete(id);
          selected.value.delete(id);
        }
      },
      open: (id, value, event) => {
        const newOpened = openStrategy.value({
          id,
          value,
          opened: new Set(opened.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newOpened && (opened.value = newOpened);
      },
      select: (id, value, event) => {
        const newSelected = selectStrategy.value.select({
          id,
          value,
          selected: new Map(selected.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newSelected && (selected.value = newSelected);
      },
      activate: (id, value, event) => {
        const newActive = activeStrategy.value({
          id,
          value,
          active: new Set(active.value),
          children: children.value,
          parents: parents.value,
          event
        });
        newActive && (active.value = newActive);
      },
      children,
      parents
    }
  };
  provide(NestedKey, nested);
  return nested.root;
};
const useNestedItem = (id) => {
  const parent = inject(NestedKey, emptyNested);
  const computedId = computed(() => {
    var _a;
    return (_a = id.value) != null ? _a : getUid().toString();
  });
  const item = __spreadProps$b(__spreadValues$C({}, parent), {
    id: computedId,
    parent: computed(() => parent.root.parents.value.get(computedId.value)),
    select: (selected, e) => parent.root.select(computedId.value, selected, e),
    isSelected: computed(() => parent.root.selected.value.get(computedId.value) === "on"),
    activate: (activated, e) => parent.root.activate(computedId.value, activated, e),
    isActive: computed(() => parent.root.active.value.has(computedId.value))
  });
  parent.root.register(computedId.value, parent.id.value, false);
  onBeforeUnmount(() => {
    parent.root.unregister(computedId.value);
  });
  return item;
};
const useNestedGroup = (props) => {
  const parent = inject(NestedKey, emptyNested);
  const id = computed(() => {
    var _a;
    return (_a = props.value) != null ? _a : getUid().toString();
  });
  const group = __spreadProps$b(__spreadValues$C({}, parent), {
    id,
    open: (open, e) => parent.root.open(id.value, open, e),
    isOpen: computed(() => parent.root.opened.value.has(id.value)),
    isSelected: computed(() => parent.root.selected.value.get(id.value) === "on"),
    isIndeterminate: computed(() => parent.root.selected.value.get(id.value) === "indeterminate")
  });
  parent.root.register(id.value, parent.id.value, true);
  onBeforeUnmount(() => {
    parent.root.unregister(id.value);
  });
  provide(NestedKey, group);
  return group;
};

const ListKey = Symbol.for("veno-ui:list");
function provideList() {
  const parent = inject(ListKey, { hasPrepend: ref(false), updateHasPrepend: () => null });
  const data = {
    hasPrepend: ref(false),
    updateHasPrepend: (value) => {
      if (value)
        data.hasPrepend.value = value;
    }
  };
  provide(ListKey, data);
  return parent;
}
function useList() {
  return inject(ListKey, null);
}

var __defProp$B = Object.defineProperty;
var __getOwnPropSymbols$C = Object.getOwnPropertySymbols;
var __hasOwnProp$C = Object.prototype.hasOwnProperty;
var __propIsEnum$C = Object.prototype.propertyIsEnumerable;
var __defNormalProp$B = (obj, key, value) => key in obj ? __defProp$B(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$B = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$C.call(b, prop))
      __defNormalProp$B(a, prop, b[prop]);
  if (__getOwnPropSymbols$C)
    for (var prop of __getOwnPropSymbols$C(b)) {
      if (__propIsEnum$C.call(b, prop))
        __defNormalProp$B(a, prop, b[prop]);
    }
  return a;
};
const ListGroup = genericComponent()({
  name: "VeListGroup",
  props: __spreadValues$B({
    /**
     * @zh 列表组收起时的图标
     */
    collapseIcon: {
      type: [String, Object],
      default: "$collapse"
    },
    /**
     * @zh 列表组展开时的图标
     */
    expandIcon: {
      type: [String, Object],
      default: "$expand"
    },
    /**
     * @zh 列表组的值
     */
    value: null
  }, makeTagProps()),
  setup(props, {
    slots
  }) {
    const {
      isOpen,
      open
    } = useNestedGroup(props);
    const list = useList();
    const onClick = (e) => {
      open(!isOpen.value, e);
    };
    const activatorProps = computed(() => ({
      onClick,
      appendIcon: isOpen.value ? props.collapseIcon : props.expandIcon,
      class: "ve-list-group__header",
      value: props.value ? `${props.value}_header` : void 0
    }));
    return () => {
      return createVNode(props.tag, {
        "class": ["ve-list-group", {
          "ve-list-group--prepend": list == null ? void 0 : list.hasPrepend.value
        }]
      }, {
        default: () => {
          var _a;
          return [(_a = slots.activator) == null ? void 0 : _a.call(slots, {
            props: activatorProps.value
          }), createVNode(ExpandTransition, null, {
            default: () => {
              var _a2;
              return [withDirectives(createVNode("div", {
                "class": "ve-list-group__items"
              }, [(_a2 = slots.default) == null ? void 0 : _a2.call(slots)]), [[vShow, isOpen.value]])];
            }
          })];
        }
      });
    };
  }
});

const ListItemAvatar = /* @__PURE__ */ defineComponent({
  name: "VeListItemAvatar",
  props: makeAvatarProps(),
  setup(props, {
    slots
  }) {
    return () => {
      return createVNode(Avatar, mergeProps({
        "class": ["ve-list-item-avatar", {
          "ve-list-item-avatar--start": props.start,
          "ve-list-item-avatar--end": props.end
        }]
      }, props), slots);
    };
  }
});

const ListItemHeader = createSimpleFunctional("ve-list-item-header");

const ListItemTitle = createSimpleFunctional("ve-list-item-title");

const ListItemSubtitle = createSimpleFunctional("ve-list-item-subtitle");

var __defProp$A = Object.defineProperty;
var __defProps$a = Object.defineProperties;
var __getOwnPropDescs$a = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$B = Object.getOwnPropertySymbols;
var __hasOwnProp$B = Object.prototype.hasOwnProperty;
var __propIsEnum$B = Object.prototype.propertyIsEnumerable;
var __defNormalProp$A = (obj, key, value) => key in obj ? __defProp$A(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$A = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$B.call(b, prop))
      __defNormalProp$A(a, prop, b[prop]);
  if (__getOwnPropSymbols$B)
    for (var prop of __getOwnPropSymbols$B(b)) {
      if (__propIsEnum$B.call(b, prop))
        __defNormalProp$A(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$a = (a, b) => __defProps$a(a, __getOwnPropDescs$a(b));
const ListItem = genericComponent()({
  name: "VeListItem",
  directives: {
    Ripple
  },
  props: __spreadValues$A(__spreadValues$A(__spreadValues$A({
    /**
     * @zh 是否激活
     */
    active: Boolean,
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 激活时的 class
     */
    activeClass: String,
    /**
     * @zh 后置头像
     */
    appendAvatar: String,
    /**
     * @zh 后置图标
     */
    appendIcon: [String, Object],
    /**
     * @zh 是否是一个链接
     */
    link: Boolean,
    /**
     * @zh 前置头像
     */
    prependAvatar: String,
    /**
     * @zh 前置图标
     */
    prependIcon: [String, Object],
    /**
     * @zh 点击时是否有波纹
     */
    ripple: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 副标题
     */
    subtitle: String,
    /**
     * @zh 文本内容
     */
    text: String,
    /**
     * @zh 标题
     */
    title: String,
    /**
     * @zh 列表项的值
     */
    value: null
  }, makePaperProps({
    variant: "text",
    size: void 0
  })), makeDisabledProps()), makeRouterProps()),
  setup(props, {
    slots,
    attrs
  }) {
    const link = useLink(props, attrs);
    const id = computed(() => {
      var _a;
      return (_a = props.value) != null ? _a : link.href.value;
    });
    const {
      activate,
      isActive: isNestedActive,
      select,
      isSelected,
      root,
      parent
    } = useNestedItem(id);
    const list = useList();
    const isActive = computed(() => {
      var _a;
      return props.active || ((_a = link.isExactActive) == null ? void 0 : _a.value) || isNestedActive.value;
    });
    const {
      paperClasses,
      paperStyles
    } = usePaper(computed(() => {
      var _a;
      return __spreadProps$a(__spreadValues$A({}, props), {
        color: isActive.value ? (_a = props.activeColor) != null ? _a : props.color : props.color
      });
    }));
    const {
      disabledClasses
    } = useDisabled(props);
    onMounted(() => {
      var _a;
      if (((_a = link.isExactActive) == null ? void 0 : _a.value) && parent.value != null) {
        root.open(parent.value, true);
      }
    });
    watch(() => {
      var _a;
      return (_a = link.isExactActive) == null ? void 0 : _a.value;
    }, (val) => {
      if (val && parent.value != null) {
        root.open(parent.value, true);
      }
    });
    const slotProps = computed(() => ({
      isActive: isActive.value,
      activate,
      select,
      isSelected: isSelected.value
    }));
    return () => {
      const Tag = link.isLink.value ? "a" : props.tag;
      const hasTitle = slots.title || props.title;
      const hasSubtitle = slots.subtitle || props.subtitle;
      const hasText = slots.text || props.text;
      const hasHeader = !!(hasText || hasTitle || hasSubtitle);
      const hasAppend = !!(slots.append || props.appendAvatar || props.appendIcon);
      const hasPrepend = !!(slots.prepend || props.prependAvatar || props.prependIcon);
      const isClickable = !props.disabled && (link.isClickable.value || props.link);
      list == null ? void 0 : list.updateHasPrepend(hasPrepend);
      return withDirectives(createVNode(Tag, {
        "class": ["ve-list-item", {
          "ve-list-item--active": isActive.value,
          "ve-list-item--link": isClickable,
          "ve-list-item--prepend": !hasPrepend && (list == null ? void 0 : list.hasPrepend.value),
          [`${props.activeClass}`]: isActive.value && props.activeClass
        }, paperClasses.value, disabledClasses.value],
        "style": paperStyles.value,
        "href": link.href.value,
        "tabindex": isClickable ? 0 : void 0,
        "onClick": isClickable && ((e) => {
          var _a;
          (_a = link.navigate) == null ? void 0 : _a.call(link, e);
          props.value != null && activate(!isNestedActive.value, e);
        })
      }, {
        default: () => {
          var _a, _b, _c, _d, _e;
          return [genOverlays(isClickable, "ve-list-item"), hasPrepend && ((_b = (_a = slots.prepend) == null ? void 0 : _a.call(slots, slotProps.value)) != null ? _b : createVNode(ListItemAvatar, {
            "start": true,
            "color": "inherit",
            "variant": "text",
            "density": props.density,
            "icon": props.prependIcon,
            "image": props.prependAvatar
          }, null)), hasHeader && createVNode(ListItemHeader, null, {
            default: () => {
              var _a2, _b2;
              return [hasTitle && createVNode(ListItemTitle, null, {
                default: () => {
                  var _a3, _b3;
                  return [(_b3 = (_a3 = slots.title) == null ? void 0 : _a3.call(slots, {
                    title: props.title
                  })) != null ? _b3 : props.title];
                }
              }), hasSubtitle && createVNode(ListItemSubtitle, null, {
                default: () => {
                  var _a3, _b3;
                  return [(_b3 = (_a3 = slots.subtitle) == null ? void 0 : _a3.call(slots, {
                    subtitle: props.subtitle
                  })) != null ? _b3 : props.subtitle];
                }
              }), hasText && createVNode("div", null, [(_b2 = (_a2 = slots.text) == null ? void 0 : _a2.call(slots, {
                text: props.text
              })) != null ? _b2 : props.text])];
            }
          }), (_c = slots.default) == null ? void 0 : _c.call(slots, slotProps.value), hasAppend && ((_e = (_d = slots.append) == null ? void 0 : _d.call(slots, slotProps.value)) != null ? _e : createVNode(ListItemAvatar, {
            "end": true,
            "color": "inherit",
            "variant": "text",
            "density": props.density,
            "icon": props.appendIcon,
            "image": props.appendAvatar
          }, null))];
        }
      }), [[resolveDirective("ripple"), isClickable && props.ripple]]);
    };
  }
});

var __defProp$z = Object.defineProperty;
var __getOwnPropSymbols$A = Object.getOwnPropertySymbols;
var __hasOwnProp$A = Object.prototype.hasOwnProperty;
var __propIsEnum$A = Object.prototype.propertyIsEnumerable;
var __defNormalProp$z = (obj, key, value) => key in obj ? __defProp$z(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$z = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$A.call(b, prop))
      __defNormalProp$z(a, prop, b[prop]);
  if (__getOwnPropSymbols$A)
    for (var prop of __getOwnPropSymbols$A(b)) {
      if (__propIsEnum$A.call(b, prop))
        __defNormalProp$z(a, prop, b[prop]);
    }
  return a;
};
const ListSubheader = /* @__PURE__ */ defineComponent({
  name: "VeListSubheader",
  props: __spreadValues$z({
    /**
     * @zh 副标题颜色
     */
    color: String,
    inset: Boolean
  }, makeTagProps()),
  setup(props, {
    slots
  }) {
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(toRef(props, "color"));
    return () => createVNode(props.tag, {
      "class": ["ve-list-subheader", {
        "ve-list-subheader--inset": props.inset
      }, textColorClasses.value],
      "style": {
        textColorStyles
      }
    }, {
      default: () => [slots.default && createVNode("div", {
        "class": "ve-list-subheader__text"
      }, [slots.default()])]
    });
  }
});

const ListChildren = genericComponent()({
  name: "VeListChildren",
  props: {
    items: Array
  },
  setup(props, {
    slots
  }) {
    provideList();
    return () => {
      var _a, _b, _c;
      return (_c = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _c : (_b = props.items) == null ? void 0 : _b.map(({
        children,
        props: itemProps,
        type
      }, index) => {
        var _a2, _b2;
        switch (type) {
          case "divider":
            return createVNode(Divider, itemProps, null);
          case "subheader":
            return createVNode(ListSubheader, itemProps, slots);
          default:
            return children ? createVNode(ListGroup, {
              "value": itemProps == null ? void 0 : itemProps.value
            }, {
              default: () => createVNode(ListChildren, {
                "items": children
              }, slots),
              activator: ({
                props: activatorProps
              }) => {
                var _a3, _b3;
                return (_b3 = (_a3 = slots.header) == null ? void 0 : _a3.call(slots, {
                  item: itemProps,
                  index,
                  props: activatorProps
                })) != null ? _b3 : createVNode(ListItem, mergeProps(itemProps, activatorProps), null);
              }
            }) : (_b2 = (_a2 = slots.item) == null ? void 0 : _a2.call(slots, {
              item: itemProps,
              index
            })) != null ? _b2 : createVNode(ListItem, itemProps, slots);
        }
      });
    };
  }
});

var __defProp$y = Object.defineProperty;
var __getOwnPropSymbols$z = Object.getOwnPropertySymbols;
var __hasOwnProp$z = Object.prototype.hasOwnProperty;
var __propIsEnum$z = Object.prototype.propertyIsEnumerable;
var __defNormalProp$y = (obj, key, value) => key in obj ? __defProp$y(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$y = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$z.call(b, prop))
      __defNormalProp$y(a, prop, b[prop]);
  if (__getOwnPropSymbols$z)
    for (var prop of __getOwnPropSymbols$z(b)) {
      if (__propIsEnum$z.call(b, prop))
        __defNormalProp$y(a, prop, b[prop]);
    }
  return a;
};
var __objRest$1 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$z.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$z)
    for (var prop of __getOwnPropSymbols$z(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$z.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _isSlot$6(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
function parseItems$1(items) {
  if (!items)
    return void 0;
  return items.map((item) => {
    if (typeof item === "string")
      return {
        type: "item",
        props: {
          value: item,
          title: item
        }
      };
    const _a = item, {
      $type,
      $children
    } = _a, props = __objRest$1(_a, [
      "$type",
      "$children"
    ]);
    if ($type === "subheader")
      return {
        type: "subheader",
        props
      };
    if ($type === "divider")
      return {
        type: "divider",
        props
      };
    return {
      type: "item",
      props,
      children: parseItems$1($children)
    };
  });
}
const List = genericComponent()({
  name: "VeList",
  props: __spreadValues$y(__spreadValues$y(__spreadValues$y({
    /**
     * @zh 是否为导航列表
     */
    nav: Boolean,
    /**
     * @zh 数据驱动时列表项数据
     */
    items: Array
  }, makeNestedProps({
    selectStrategy: "leaf",
    openStrategy: "multiple",
    activeStrategy: "single"
  })), makePaperProps({
    size: void 0
  })), makeDisabledProps()),
  emits: {
    "update:selected": (_selected) => true,
    "update:opened": (_opened) => true,
    "update:active": (_active) => true
  },
  setup(props, {
    slots
  }) {
    const items = computed(() => parseItems$1(props.items));
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const {
      disabledClasses
    } = useDisabled(props);
    const {
      open,
      select,
      activate
    } = useNested(props);
    provideList();
    provideDefaults({
      VeListItem: {
        density: toRef(props, "density")
      }
    });
    useRender(() => {
      return createVNode(props.tag, {
        "class": ["ve-list", {
          "ve-list--nav": props.nav
        }, paperClasses.value, disabledClasses.value],
        "style": paperStyles.value
      }, {
        default: () => {
          var _a, _b;
          return [(_a = slots.prepend) == null ? void 0 : _a.call(slots), createVNode(ListChildren, {
            "items": items.value
          }, _isSlot$6(slots) ? slots : {
            default: () => [slots]
          }), (_b = slots.append) == null ? void 0 : _b.call(slots)];
        }
      });
    });
    return {
      open,
      select,
      activate
    };
  }
});

var __defProp$x = Object.defineProperty;
var __getOwnPropSymbols$y = Object.getOwnPropertySymbols;
var __hasOwnProp$y = Object.prototype.hasOwnProperty;
var __propIsEnum$y = Object.prototype.propertyIsEnumerable;
var __defNormalProp$x = (obj, key, value) => key in obj ? __defProp$x(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$x = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$y.call(b, prop))
      __defNormalProp$x(a, prop, b[prop]);
  if (__getOwnPropSymbols$y)
    for (var prop of __getOwnPropSymbols$y(b)) {
      if (__propIsEnum$y.call(b, prop))
        __defNormalProp$x(a, prop, b[prop]);
    }
  return a;
};
const TagGroupKey = Symbol.for("veno-ui:chip-group");
const TagGroup = /* @__PURE__ */ defineComponent({
  name: "VeTagGroup",
  props: __spreadValues$x(__spreadValues$x({
    column: Boolean,
    valueComparator: {
      type: Function,
      default: deepEqual
    }
  }, makeGroupProps({
    selectedClass: "ve-tag--active"
  })), makePaperProps({
    variant: "contained-text"
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const {
      isSelected,
      select,
      next,
      prev,
      selected
    } = useGroup(props, TagGroupKey);
    provideDefaults({
      VeTag: {
        color: toRef(props, "color"),
        size: toRef(props, "size"),
        variant: toRef(props, "variant")
      }
    });
    return () => createVNode(props.tag, {
      "class": ["ve-tag-group", {
        "ve-tag-group--column": props.column
      }, paperClasses.value],
      "style": paperStyles.value
    }, {
      default: () => {
        var _a;
        return [(_a = slots.default) == null ? void 0 : _a.call(slots, {
          isSelected,
          select,
          next,
          prev,
          selected: selected.value
        })];
      }
    });
  }
});

var __defProp$w = Object.defineProperty;
var __getOwnPropSymbols$x = Object.getOwnPropertySymbols;
var __hasOwnProp$x = Object.prototype.hasOwnProperty;
var __propIsEnum$x = Object.prototype.propertyIsEnumerable;
var __defNormalProp$w = (obj, key, value) => key in obj ? __defProp$w(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$w = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$x.call(b, prop))
      __defNormalProp$w(a, prop, b[prop]);
  if (__getOwnPropSymbols$x)
    for (var prop of __getOwnPropSymbols$x(b)) {
      if (__propIsEnum$x.call(b, prop))
        __defNormalProp$w(a, prop, b[prop]);
    }
  return a;
};
const Tag = /* @__PURE__ */ defineComponent({
  name: "VeTag",
  directives: {
    Ripple
  },
  props: __spreadValues$w(__spreadValues$w(__spreadValues$w(__spreadValues$w(__spreadValues$w({
    /**
     * @zh 激活时的 class
     */
    activeClass: String,
    /**
     * @zh 追加的头像图片
     */
    appendAvatar: String,
    /**
     * @zh 追加的图标
     */
    appendIcon: [String, Object],
    /**
     * @zh 可关闭
     */
    closable: Boolean,
    /**
     * @zh 关闭图标
     */
    closeIcon: {
      type: [String, Object],
      default: "$close"
    },
    /**
     * @zh 是否显示
     */
    modelValue: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 前置的头像图片
     */
    prependAvatar: String,
    /**
     * @zh 前置的图标
     */
    prependIcon: [String, Object],
    /**
     * @zh 涟漪动画
     */
    ripple: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 标签文字
     */
    text: String,
    /**
     * @zh 是否为链接
     */
    link: Boolean
  }, makeLoadingProps()), makeTransitionProps({
    transition: {
      component: FadeInExpandTransition
    }
  })), makePaperProps({
    tag: "span",
    shape: "rounded-sm",
    variant: "contained-text"
  })), makeGroupItemProps()), makeRouterProps()),
  emits: {
    "click:close": (_event) => true,
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    attrs,
    emit,
    slots
  }) {
    const isActive = useProxiedModel(props, "modelValue");
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const {
      loadingClasses
    } = useLoading(props);
    const group = useGroupItem(props, TagGroupKey, false);
    const link = useLink(props, attrs);
    function onCloseClick(e) {
      isActive.value = false;
      emit("click:close", e);
    }
    return () => {
      const Tag2 = link.isLink.value ? "a" : props.tag;
      const hasAppend = !!(slots.append || props.appendIcon || props.appendAvatar);
      const hasClose = !!(props.loading || slots.close || props.closable);
      const hasPrepend = !!(slots.prepend || props.prependIcon || props.prependAvatar);
      const isClickable = !props.disabled && (!!group || link.isClickable.value || props.link);
      const onClickFunc = props.link ? props.link : group == null ? void 0 : group.toggle;
      return createVNode(MaybeTransition, {
        "transition": props.transition
      }, {
        default: () => [isActive.value && withDirectives(createVNode(Tag2, {
          "class": ["ve-tag", {
            "ve-tag--link": isClickable
          }, paperClasses.value, loadingClasses.value, group == null ? void 0 : group.selectedClass.value],
          "style": paperStyles.value,
          "href": link.href.value,
          "onClick": isClickable && onClickFunc
        }, {
          default: () => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            return [genOverlays(isClickable, "ve-tag"), hasPrepend && createVNode("div", {
              "class": ["ve-tag__prepend", {
                "ve-tag__prepend--avatar": props.prependAvatar
              }]
            }, [(_b = (_a = slots.prepend) == null ? void 0 : _a.call(slots)) != null ? _b : createVNode(Avatar, {
              "color": "inherit",
              "variant": "text",
              "icon": props.prependIcon,
              "image": props.prependAvatar
            }, null)]), (_d = (_c = slots.default) == null ? void 0 : _c.call(slots, {
              isSelected: group == null ? void 0 : group.isSelected.value,
              selectedClass: group == null ? void 0 : group.selectedClass.value,
              select: group == null ? void 0 : group.select,
              toggle: group == null ? void 0 : group.toggle,
              value: group == null ? void 0 : group.value.value,
              disabled: props.disabled
            })) != null ? _d : props.text, hasAppend && createVNode("div", {
              "class": "ve-tag__append"
            }, [(_f = (_e = slots.append) == null ? void 0 : _e.call(slots)) != null ? _f : createVNode(Avatar, {
              "color": "inherit",
              "variant": "text",
              "icon": props.appendIcon,
              "image": props.appendAvatar
            }, null)]), hasClose && createVNode("div", {
              "class": "ve-tag__close"
            }, [(_h = (_g = slots.close) == null ? void 0 : _g.call(slots, {
              props: {
                onClick: onCloseClick
              }
            })) != null ? _h : createVNode(Button, {
              "variant": "plain",
              "ripple": false,
              "loading": props.loading,
              "icon": props.closeIcon,
              "onClick": onCloseClick
            }, null)])];
          }
        }), [[resolveDirective("ripple"), isClickable && props.ripple, null]])]
      });
    };
  }
});

var __defProp$v = Object.defineProperty;
var __defProps$9 = Object.defineProperties;
var __getOwnPropDescs$9 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$w = Object.getOwnPropertySymbols;
var __hasOwnProp$w = Object.prototype.hasOwnProperty;
var __propIsEnum$w = Object.prototype.propertyIsEnumerable;
var __defNormalProp$v = (obj, key, value) => key in obj ? __defProp$v(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$v = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$w.call(b, prop))
      __defNormalProp$v(a, prop, b[prop]);
  if (__getOwnPropSymbols$w)
    for (var prop of __getOwnPropSymbols$w(b)) {
      if (__propIsEnum$w.call(b, prop))
        __defNormalProp$v(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$9 = (a, b) => __defProps$9(a, __getOwnPropDescs$9(b));
function defaultFilter(value, query, _item) {
  if (value == null || query == null)
    return -1;
  return value.toString().toLocaleLowerCase().indexOf(query.toString().toLocaleLowerCase());
}
const Select = genericComponent()({
  name: "VeSelect",
  props: __spreadValues$v({
    /**
     * @zh 追加的内联图标
     */
    appendInnerIcon: {
      type: String,
      default: "$dropdown"
    },
    /**
     * @zh 可选项卸载后是否从已选项中移除
     */
    deleteAfterUnmount: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 可过滤的
     */
    filterable: Boolean,
    /**
     * @zh ID
     */
    id: String,
    /**
     * @zh 选择框可选项
     */
    items: Array,
    /**
     * @zh 可选项文本字段
     */
    itemText: {
      type: String,
      default: "text"
    },
    /**
     * @zh 可选项值字段
     */
    itemValue: {
      type: String,
      default: "value"
    },
    /**
     * @zh 加载中
     */
    loading: Boolean,
    /**
     * @zh 当前值
     */
    modelValue: {
      type: null,
      default: () => []
    },
    /**
     * @zh 是否多选
     */
    multiple: Boolean,
    /**
     * @zh 无数据时显示的文本
     */
    noDataText: {
      type: String,
      default: "\u6682\u65E0\u6570\u636E"
    },
    /**
     * @zh 是否在清除时打开可选菜单
     */
    openOnClear: Boolean,
    /**
     * @zh 输入框占位符
     */
    placeholder: String,
    /**
     * @zh 查询字符串
     */
    query: String,
    /**
     * @zh 标签
     */
    tags: Boolean,
    /**
     * @zh 只读
     */
    readonly: Boolean,
    /**
     * @zh 返回对象值
     */
    returnObject: Boolean
  }, makeScrollbar()),
  emits: {
    "click:clear": (_event) => true,
    "update:modelValue": (_modelValue) => true,
    "update:query": (_query) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    const activator = ref();
    const pendingIndex = ref();
    const id = computed(() => props.id || `ve-select-${getUid()}`);
    const inputRef = ref();
    const isActiveMenu = ref(false);
    const listRef = ref();
    const menuRef = ref();
    const mirrorRef = ref();
    const tagInputRef = ref();
    const tagInputWidth = ref();
    const items = computed(() => {
      var _a, _b;
      return (_b = (_a = props.items) == null ? void 0 : _a.map(normalizeItem)) != null ? _b : [];
    });
    const {
      scrollbarClasses
    } = useScrollbar(props);
    const model = useProxiedModel(props, "modelValue");
    const arrayModel = computed({
      get: () => wrapInArray(model.value),
      set: (v) => model.value = props.multiple ? v : v[0]
    });
    const query = ref(props.query);
    const active = computed({
      get: () => arrayModel.value.map((v) => v && typeof v === "object" ? v[props.itemValue] : v),
      set: (val) => {
        arrayModel.value = props.returnObject ? val.map(getItem).filter((v) => v !== void 0) : val;
        if (!props.multiple)
          isActiveMenu.value = false;
      }
    });
    const selections = computed(() => {
      return active.value.map((v) => {
        return items.value.find((i) => i.value === v);
      }).filter((v) => v !== void 0);
    });
    const onUpdateQuery = debounce((v) => {
      if (props.loading)
        return;
      emit("update:query", v);
    }, 300);
    const inputValue = computed({
      get: () => {
        if (props.filterable && isActiveMenu.value)
          return query.value || void 0;
        if (props.tags)
          return void 0;
        return selections.value.map((item) => item.text).join(", ") || void 0;
      },
      set: (val) => {
        query.value = val;
        onUpdateQuery(val);
        if (isActiveMenu.value) {
          nextTick(() => {
            var _a, _b, _c;
            (_c = (_b = (_a = menuRef.value) == null ? void 0 : _a.overlayRef) == null ? void 0 : _b.updatePosition) == null ? void 0 : _c.call(_b);
          });
        }
      }
    });
    const placeholder = computed(() => {
      return props.tags && active.value.length > 0 ? void 0 : props.placeholder;
    });
    const filteredItems = computed(() => items.value.filter((v) => !v.filtered));
    function getItem(v) {
      var _a;
      return (_a = props.items) == null ? void 0 : _a.find((i) => {
        const i1 = typeof i === "object" ? i[props.itemValue] : i;
        const v1 = typeof v === "object" ? v[props.itemValue] : v;
        return i1 === v1;
      });
    }
    function normalizeItem(item) {
      var _a;
      let v;
      if (typeof item === "object") {
        const value = item[props.itemValue];
        const text = String((_a = item[props.itemText]) != null ? _a : value);
        v = {
          text,
          value
        };
      } else {
        v = {
          text: String(item),
          value: item
        };
      }
      if (props.filterable && query.value) {
        v.filtered = defaultFilter(v.text, query.value) === -1;
      }
      return v;
    }
    watch(() => inputRef.value, (val) => {
      activator.value = val.$el.querySelector(".ve-input-control");
    });
    watch(() => props.query, (val) => {
      query.value = val;
    });
    function onBlur() {
      isActiveMenu.value = false;
    }
    function onClear(e) {
      arrayModel.value = [];
      if (props.openOnClear) {
        isActiveMenu.value = true;
      } else {
        inputRef.value.blur();
      }
      emit("click:clear", e);
    }
    function onControl() {
      var _a;
      if (props.readonly)
        return;
      if (isActiveMenu.value) {
        (_a = inputRef.value) == null ? void 0 : _a.blur();
      } else {
        isActiveMenu.value = true;
      }
    }
    const onKeydownMove = debounce(({
      key
    }) => {
      var _a;
      const index = (_a = pendingIndex.value) != null ? _a : filteredItems.value.findIndex(({
        value
      }) => value === active.value[0]);
      const lastIndex = filteredItems.value.length - 1;
      if (key === keyValues.up) {
        pendingIndex.value = [-1, 0].includes(index) ? lastIndex : Math.max(0, index - 1);
      }
      if (key === keyValues.down) {
        pendingIndex.value = [-1, lastIndex].includes(index) ? 0 : Math.min(lastIndex, index + 1);
      }
      nextTick(() => {
        const el = listRef.value.$el;
        if (!el)
          return;
        const itemEl = el.querySelector(".ve-select__item--pendding");
        if (!itemEl)
          return;
        const itemTop = itemEl.offsetTop;
        if (itemTop <= el.scrollTop) {
          el.scrollTop -= el.scrollTop - itemTop;
        } else {
          const itemBottom = itemEl.offsetTop + itemEl.offsetHeight;
          const scrollBottom = el.scrollTop + el.offsetHeight;
          if (itemBottom >= scrollBottom) {
            el.scrollTop += itemBottom - scrollBottom;
          }
        }
      });
    }, 30);
    const onKeydownEnter = debounce(() => {
      if (!isActiveMenu.value) {
        isActiveMenu.value = true;
      } else if (filteredItems.value.length > 0) {
        const index = pendingIndex.value in filteredItems.value ? pendingIndex.value : 0;
        const value = filteredItems.value[index].value;
        if (props.multiple) {
          active.value = active.value.includes(value) ? active.value.filter((v) => v !== value) : active.value.concat([value]);
        } else {
          active.value = [value];
        }
      }
    }, 60);
    const onKeydownDelete = debounce(() => {
      active.value = active.value.filter((_, i) => i !== active.value.length - 1);
    }, 60);
    function onKeydown(e) {
      const {
        key
      } = e;
      if ([keyValues.up, keyValues.down].includes(key)) {
        e.preventDefault();
        onKeydownMove(e);
      }
      if ([keyValues.enter, keyValues.space, " "].includes(key)) {
        e.preventDefault();
        onKeydownEnter();
      }
      if (key === keyValues.backspace && isActiveMenu.value && props.multiple && props.filterable && props.tags && !query.value && active.value.length > 0) {
        onKeydownDelete();
      }
      if (key === keyValues.esc && isActiveMenu.value) {
        isActiveMenu.value = false;
      }
    }
    function resizeTagInput() {
      tagInputWidth.value = Math.max(0, mirrorRef.value.scrollWidth) + 1;
    }
    let observer;
    watch(mirrorRef, (val) => {
      if (val) {
        observer = new ResizeObserver(resizeTagInput);
        observer.observe(mirrorRef.value);
      } else {
        observer == null ? void 0 : observer.disconnect();
      }
    });
    onBeforeUnmount(() => {
      observer == null ? void 0 : observer.disconnect();
    });
    watch(isActiveMenu, (val) => {
      if (!val)
        pendingIndex.value = void 0;
    });
    return () => {
      const inputProps = props.multiple && !props.tags ? {
        autoResize: true,
        rows: 1,
        type: "textarea"
      } : {};
      const [listSlots, inputSlots] = pick(slots, ["item", "header", "title", "subtitle"]);
      return createVNode(Input, mergeProps(inputProps, {
        "class": ["ve-select", {
          "ve-select--active-menu": isActiveMenu.value
        }],
        "id": id.value,
        "inputAttach": tagInputRef.value,
        "controlValue": model.value,
        "modelValue": inputValue.value,
        "onUpdate:modelValue": ($event) => inputValue.value = $event,
        "onBlur": onBlur,
        "onClick:clear": onClear,
        "onClick:control": onControl,
        "onInput": (e) => {
          if (mirrorRef.value) {
            mirrorRef.value.textContent = e.target.value;
            resizeTagInput();
          }
        },
        "onKeydown": onKeydown,
        "onMousedown": (e) => e.preventDefault(),
        "placeholder": placeholder.value,
        "readonly": !props.filterable,
        "ref": inputRef
      }), __spreadProps$9(__spreadValues$v({}, inputSlots), {
        "append-inner": () => createVNode(Fragment, null, [!props.loading && createVNode(Icon, {
          "icon": props.appendInnerIcon
        }, null), props.loading && createVNode(Progress, {
          "size": "14",
          "variant": "circular",
          "stroke-width": "2",
          "indeterminate": true
        }, null)]),
        "default": () => createVNode(Fragment, null, [activator.value && createVNode(Menu, {
          "ref": menuRef,
          "contentClass": "ve-select__menu-wrapper",
          "id": `${id.value}-menu`,
          "modelValue": isActiveMenu.value,
          "onUpdate:modelValue": ($event) => isActiveMenu.value = $event,
          "activator": activator.value,
          "minWidth": void 0,
          "openOnClick": false,
          "eager": true
        }, {
          default: () => [createVNode(List, {
            "ref": listRef,
            "class": scrollbarClasses.value,
            "maxHeight": 250,
            "items": items.value,
            "active": active.value,
            "onUpdate:active": ($event) => active.value = $event,
            "activeStrategy": props.multiple ? "multiple" : "single",
            "deleteAfterUnmount": props.deleteAfterUnmount
          }, __spreadProps$9(__spreadValues$v({}, listSlots), {
            item: (itemSlot) => {
              const {
                item,
                index
              } = itemSlot;
              const itemSlotProps = {
                onMousedown: (e) => e.preventDefault(),
                class: {
                  "ve-select__item--pendding": pendingIndex.value === index
                }
              };
              if (slots.item) {
                return slots.item(__spreadProps$9(__spreadValues$v({}, itemSlot), {
                  props: itemSlotProps
                }));
              }
              return withDirectives(createVNode(ListItem, mergeProps(itemSlotProps, item, {
                "link": true,
                "key": item.value
              }), {
                prepend: props.multiple ? () => createVNode(ListItemAvatar, {
                  "start": true,
                  "color": "inherit",
                  "variant": "text"
                }, {
                  default: () => [createVNode(Checkbox, {
                    "model-value": active.value.includes(item.value)
                  }, null)]
                }) : void 0
              }), [[vShow, !item.filtered]]);
            },
            append: () => {
              var _a, _b;
              return createVNode(Fragment, null, [filteredItems.value.length === 0 && ((_b = (_a = slots["no-data"]) == null ? void 0 : _a.call(slots)) != null ? _b : createVNode(ListItem, {
                "text": props.noDataText
              }, null))]);
            }
          }))]
        }), props.tags && createVNode(TagGroup, {
          "class": "ve-select__selections",
          "size": "x-small"
        }, {
          default: () => [selections.value.map((item) => {
            var _a, _b;
            function close() {
              active.value = active.value.filter((v) => v !== item.value);
            }
            return (_b = (_a = slots.tag) == null ? void 0 : _a.call(slots, {
              item,
              close
            })) != null ? _b : createVNode(Tag, {
              "aria-hidden": "true",
              "tag": "div",
              "key": item.value,
              "closable": true,
              "text": item.text,
              "onClick:close": (e) => {
                e.stopPropagation();
                close();
              }
            }, null);
          }), createVNode("div", {
            "class": "ve-select__tag-input",
            "style": {
              width: convertToUnit(selections.value.length > 0 ? tagInputWidth.value : "100%")
            },
            "ref": tagInputRef
          }, [createVNode("span", {
            "class": "ve-select__tag-input-mirror",
            "ref": mirrorRef,
            "aria-hidden": "true"
          }, [query.value])])]
        })])
      }));
    };
  }
});

var __defProp$u = Object.defineProperty;
var __defProps$8 = Object.defineProperties;
var __getOwnPropDescs$8 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$v = Object.getOwnPropertySymbols;
var __hasOwnProp$v = Object.prototype.hasOwnProperty;
var __propIsEnum$v = Object.prototype.propertyIsEnumerable;
var __defNormalProp$u = (obj, key, value) => key in obj ? __defProp$u(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$u = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$v.call(b, prop))
      __defNormalProp$u(a, prop, b[prop]);
  if (__getOwnPropSymbols$v)
    for (var prop of __getOwnPropSymbols$v(b)) {
      if (__propIsEnum$v.call(b, prop))
        __defNormalProp$u(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$8 = (a, b) => __defProps$8(a, __getOwnPropDescs$8(b));
const Switch = /* @__PURE__ */ defineComponent({
  name: "VeSwitch",
  props: makeSelectionControlProps({
    type: "checkbox",
    color: "primary"
  }),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    emit,
    slots
  }) {
    const control = ref();
    function onClick() {
      var _a, _b;
      (_b = (_a = control.value) == null ? void 0 : _a.inputRef) == null ? void 0 : _b.click();
    }
    return () => {
      return createVNode(SelectionControl, mergeProps({
        "ref": control,
        "class": "ve-switch"
      }, props, {
        "onUpdate:modelValue": (val) => emit("update:modelValue", val)
      }), __spreadProps$8(__spreadValues$u({}, slots), {
        default: ({
          textColorClasses,
          textColorStyles
        }) => createVNode("div", {
          "class": ["ve-switch__track", textColorClasses.value],
          "style": [textColorStyles.value],
          "onClick": onClick
        }, null),
        input: () => {
          return createVNode("div", {
            "class": "ve-switch__thumb"
          }, null);
        }
      }));
    };
  }
});

var __getOwnPropSymbols$u = Object.getOwnPropertySymbols;
var __hasOwnProp$u = Object.prototype.hasOwnProperty;
var __propIsEnum$u = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$u.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$u)
    for (var prop of __getOwnPropSymbols$u(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$u.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
const FormChildren = /* @__PURE__ */ defineComponent({
  name: "VeFormChildren",
  props: {
    /**
     * @zh 数据驱动的表单列表项
     */
    items: Array
  },
  setup(props, {
    slots
  }) {
    const items = computed(() => {
      var _a;
      return (_a = props.items) == null ? void 0 : _a.map((item) => {
        const _a2 = item, {
          $type: type
        } = _a2, props2 = __objRest(_a2, [
          "$type"
        ]);
        return {
          type,
          props: props2
        };
      });
    });
    return () => {
      var _a, _b, _c;
      return (_c = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _c : (_b = items.value) == null ? void 0 : _b.map(({
        type,
        props: itemProps
      }) => {
        switch (type) {
          case "textarea":
            return createVNode(Input, mergeProps({
              "type": "textarea"
            }, itemProps), null);
          case "select":
            return createVNode(Select, itemProps, null);
          case "switch":
            const [controlProps, switchProps] = pick(itemProps || {}, ["label"]);
            return createVNode(FormControl, controlProps, {
              default: () => [createVNode(Switch, switchProps, null)]
            });
          case "date-picker":
            return createVNode(DatePicker, itemProps, null);
          case "checkbox":
            return createVNode(CheckboxGroup, itemProps, null);
          case "radio":
            return createVNode(RadioGroup, itemProps, null);
          case "input":
          default:
            return createVNode(Input, itemProps, null);
        }
      });
    };
  }
});

var __defProp$t = Object.defineProperty;
var __getOwnPropSymbols$t = Object.getOwnPropertySymbols;
var __hasOwnProp$t = Object.prototype.hasOwnProperty;
var __propIsEnum$t = Object.prototype.propertyIsEnumerable;
var __defNormalProp$t = (obj, key, value) => key in obj ? __defProp$t(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$t = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$t.call(b, prop))
      __defNormalProp$t(a, prop, b[prop]);
  if (__getOwnPropSymbols$t)
    for (var prop of __getOwnPropSymbols$t(b)) {
      if (__propIsEnum$t.call(b, prop))
        __defNormalProp$t(a, prop, b[prop]);
    }
  return a;
};
const Form = /* @__PURE__ */ defineComponent({
  name: "VeForm",
  props: __spreadValues$t(__spreadValues$t(__spreadValues$t(__spreadValues$t({
    /**
     * @zh 布局方向
     */
    direction: {
      type: String,
      default: "horizontal",
      validator: (v) => ["horizontal", "vertical"].includes(v)
    },
    /**
     * @zh 隐藏详情
     */
    hideDetails: [Boolean, String],
    /**
     * @zh 内联
     */
    inline: Boolean,
    /**
     * @zh 数据驱动的表单列表项
     */
    items: Array,
    /**
     * @zh 标签宽度
     */
    labelWidth: [Number, String]
  }, makeSizeProps()), makeDensityProps()), makeFormProps()), makeVariantProps()),
  emits: {
    "update:valid": (_valid) => true,
    "update:modelValue": (_modelValue) => true,
    "resetValidation": () => true,
    "reset": (_event) => true,
    "submit": (_value, _event) => true
  },
  setup(props, {
    slots
  }) {
    const form = provideForm(props);
    const defaults = {
      variant: toRef(props, "variant"),
      size: toRef(props, "size"),
      density: toRef(props, "density"),
      direction: toRef(props, "direction"),
      inline: toRef(props, "inline"),
      labelWidth: toRef(props, "labelWidth"),
      hideDetails: toRef(props, "hideDetails"),
      readonly: toRef(props, "readonly"),
      disabled: toRef(props, "disabled")
    };
    provideDefaults({
      // input control
      VeInput: defaults,
      VeSelect: defaults,
      // select control
      VeRadioGroup: defaults,
      VeCheckboxGroup: defaults,
      VeSwitch: defaults,
      // form control
      VeFormControl: defaults,
      // button
      VeButton: {
        density: defaults.density,
        disabled: defaults.disabled
      }
    });
    useRender(() => {
      var _a;
      return createVNode("form", {
        "class": ["ve-form", {
          [`ve-form--${props.direction}`]: !!props.direction,
          "ve-form--inline": props.inline
        }],
        "novalidate": true,
        "onReset": form.reset,
        "onSubmit": form.submit
      }, [createVNode(FormChildren, {
        "items": props.items
      }, null), (_a = slots.default) == null ? void 0 : _a.call(slots, form)]);
    });
    return form;
  }
});

var __defProp$s = Object.defineProperty;
var __getOwnPropSymbols$s = Object.getOwnPropertySymbols;
var __hasOwnProp$s = Object.prototype.hasOwnProperty;
var __propIsEnum$s = Object.prototype.propertyIsEnumerable;
var __defNormalProp$s = (obj, key, value) => key in obj ? __defProp$s(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$s = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$s.call(b, prop))
      __defNormalProp$s(a, prop, b[prop]);
  if (__getOwnPropSymbols$s)
    for (var prop of __getOwnPropSymbols$s(b)) {
      if (__propIsEnum$s.call(b, prop))
        __defNormalProp$s(a, prop, b[prop]);
    }
  return a;
};
const Container = /* @__PURE__ */ defineComponent({
  name: "VeContainer",
  props: __spreadValues$s({
    fluid: {
      type: Boolean,
      default: false
    }
  }, makeTagProps()),
  setup(props, {
    slots
  }) {
    return () => createVNode(props.tag, {
      "class": ["ve-container", {
        "ve-container--fluid": props.fluid
      }]
    }, slots);
  }
});

var __defProp$r = Object.defineProperty;
var __defProps$7 = Object.defineProperties;
var __getOwnPropDescs$7 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$r = Object.getOwnPropertySymbols;
var __hasOwnProp$r = Object.prototype.hasOwnProperty;
var __propIsEnum$r = Object.prototype.propertyIsEnumerable;
var __defNormalProp$r = (obj, key, value) => key in obj ? __defProp$r(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$r = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$r.call(b, prop))
      __defNormalProp$r(a, prop, b[prop]);
  if (__getOwnPropSymbols$r)
    for (var prop of __getOwnPropSymbols$r(b)) {
      if (__propIsEnum$r.call(b, prop))
        __defNormalProp$r(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$7 = (a, b) => __defProps$7(a, __getOwnPropDescs$7(b));
function _isSlot$5(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const breakpoints$1 = ["sm", "md", "lg", "xl", "xxl"];
const breakpointProps = (() => {
  return breakpoints$1.reduce((props, val) => {
    props[val] = {
      type: [Boolean, String, Number],
      default: false
    };
    return props;
  }, {});
})();
const offsetProps = (() => {
  return breakpoints$1.reduce((props, val) => {
    props[`offset${capitalize(val)}`] = {
      type: [String, Number],
      default: null
    };
    return props;
  }, {});
})();
const orderProps = (() => {
  return breakpoints$1.reduce((props, val) => {
    props[`order${capitalize(val)}`] = {
      type: [String, Number],
      default: null
    };
    return props;
  }, {});
})();
const propMap$1 = {
  col: Object.keys(breakpointProps),
  offset: Object.keys(offsetProps),
  order: Object.keys(orderProps)
};
function breakpointClass$1(type, prop, val) {
  let className = type;
  if (val == null || val === false) {
    return void 0;
  }
  if (prop) {
    const breakpoint = prop.replace(type, "");
    className += `-${breakpoint}`;
  }
  if (type === "col" && (val === "" || val === true)) {
    return `ve-${className}`.toLowerCase();
  }
  className += `-${val}`;
  return `ve-col--${className}`.toLowerCase();
}
const makeColProps = propsFactory(__spreadProps$7(__spreadValues$r(__spreadProps$7(__spreadValues$r(__spreadProps$7(__spreadValues$r({
  cols: {
    type: [Boolean, String, Number],
    default: false
  }
}, breakpointProps), {
  offset: {
    type: [String, Number],
    default: null
  }
}), offsetProps), {
  order: {
    type: [String, Number],
    default: null
  }
}), orderProps), {
  alignSelf: {
    type: String,
    default: null,
    validator: (str) => ["auto", "start", "end", "center", "baseline", "stretch"].includes(str)
  }
}), "col");
const Col = /* @__PURE__ */ defineComponent({
  name: "VeCol",
  props: __spreadValues$r(__spreadValues$r({}, makeTagProps()), makeColProps()),
  setup(props, {
    slots
  }) {
    const classes = computed(() => {
      const classList = [];
      let type;
      for (type in propMap$1) {
        propMap$1[type].forEach((prop) => {
          const value = props[prop];
          const className = breakpointClass$1(type, prop, value);
          if (className)
            classList.push(className);
        });
      }
      const hasColClasses = classList.some((className) => className.startsWith("ve-col-") && !className.startsWith("ve-col--"));
      classList.push({
        "ve-col": !hasColClasses || !props.cols,
        [`ve-col-${props.cols}`]: props.cols,
        [`ve-col--offset-${props.offset}`]: props.offset,
        [`ve-col--order-${props.order}`]: props.order,
        [`ve-col--align-self-${props.alignSelf}`]: props.alignSelf
      });
      return classList;
    });
    return () => createVNode(props.tag, {
      "class": classes.value
    }, _isSlot$5(slots) ? slots : {
      default: () => [slots]
    });
  }
});

var __defProp$q = Object.defineProperty;
var __defProps$6 = Object.defineProperties;
var __getOwnPropDescs$6 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$q = Object.getOwnPropertySymbols;
var __hasOwnProp$q = Object.prototype.hasOwnProperty;
var __propIsEnum$q = Object.prototype.propertyIsEnumerable;
var __defNormalProp$q = (obj, key, value) => key in obj ? __defProp$q(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$q = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$q.call(b, prop))
      __defNormalProp$q(a, prop, b[prop]);
  if (__getOwnPropSymbols$q)
    for (var prop of __getOwnPropSymbols$q(b)) {
      if (__propIsEnum$q.call(b, prop))
        __defNormalProp$q(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$6 = (a, b) => __defProps$6(a, __getOwnPropDescs$6(b));
function _isSlot$4(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const breakpoints = ["sm", "md", "lg", "xl", "xxl"];
const alignments = ["start", "end", "center"];
function makeProps(prefix, def) {
  return breakpoints.reduce((props, val) => {
    props[prefix + capitalize(val)] = def();
    return props;
  }, {});
}
const alignValidator = (str) => [...alignments, "baseline", "stretch"].includes(str);
const alignProps = makeProps("align", () => ({
  type: String,
  default: null,
  validator: alignValidator
}));
const justifyValidator = (str) => [...alignments, "space-between", "space-around"].includes(str);
const justifyProps = makeProps("justify", () => ({
  type: String,
  default: null,
  validator: justifyValidator
}));
const alignContentValidator = (str) => [...alignments, "space-between", "space-around", "stretch"].includes(str);
const alignContentProps = makeProps("alignContent", () => ({
  type: String,
  default: null,
  validator: alignContentValidator
}));
const propMap = {
  align: Object.keys(alignProps),
  justify: Object.keys(justifyProps),
  alignContent: Object.keys(alignContentProps)
};
const classMap = {
  align: "align",
  justify: "justify",
  alignContent: "align-content"
};
function breakpointClass(type, prop, val) {
  let className = classMap[type];
  if (val == null) {
    return void 0;
  }
  if (prop) {
    const breakpoint = prop.replace(type, "");
    className += `-${breakpoint}`;
  }
  className += `-${val}`;
  return className.toLowerCase();
}
const GUTTERS = ["xs", "sm", "md", "lg", "xl", "xxl", "x-small", "small", "medium", "large", "x-large", "xx-large"];
const GUTTERS_ALIASES = {
  "x-small": "xs",
  "small": "sm",
  "medium": "md",
  "large": "lg",
  "x-large": "xl",
  "xx-large": "xxl"
};
const makeRowProps = propsFactory(__spreadValues$q(__spreadProps$6(__spreadValues$q(__spreadProps$6(__spreadValues$q({
  gutter: {
    type: [Number, String],
    default: "xl"
  },
  align: {
    type: String,
    default: null,
    validator: alignValidator
  }
}, alignProps), {
  justify: {
    type: String,
    default: null,
    validator: justifyValidator
  }
}), justifyProps), {
  alignContent: {
    type: String,
    default: null,
    validator: alignContentValidator
  }
}), alignContentProps), "row");
const Row = /* @__PURE__ */ defineComponent({
  name: "VeRow",
  props: __spreadValues$q(__spreadValues$q({}, makeTagProps()), makeRowProps()),
  setup(props, {
    slots
  }) {
    const classes = computed(() => {
      const classList = [];
      let type;
      for (type in propMap) {
        propMap[type].forEach((prop) => {
          const value = props[prop];
          const className = breakpointClass(type, prop, value);
          if (className)
            classList.push(className);
        });
      }
      if (GUTTERS.includes(props.gutter)) {
        let gutter = props.gutter;
        if (props.gutter in GUTTERS_ALIASES) {
          gutter = GUTTERS_ALIASES[gutter];
        }
        classList.push(`ve-row--gutter-${gutter}`);
      }
      classList.push({
        [`ve-row--align-${props.align}`]: props.align,
        [`ve-row--justify-${props.justify}`]: props.justify,
        [`ve-row--align-content-${props.alignContent}`]: props.alignContent
      });
      return classList;
    });
    const styles = computed(() => {
      if (GUTTERS.includes(props.gutter))
        return {};
      return {
        "--ve-row-gutter": convertToUnit(props.gutter)
      };
    });
    return () => createVNode(props.tag, {
      "class": ["ve-row", classes.value],
      "style": styles.value
    }, _isSlot$4(slots) ? slots : {
      default: () => [slots]
    });
  }
});

var __defProp$p = Object.defineProperty;
var __getOwnPropSymbols$p = Object.getOwnPropertySymbols;
var __hasOwnProp$p = Object.prototype.hasOwnProperty;
var __propIsEnum$p = Object.prototype.propertyIsEnumerable;
var __defNormalProp$p = (obj, key, value) => key in obj ? __defProp$p(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$p = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$p.call(b, prop))
      __defNormalProp$p(a, prop, b[prop]);
  if (__getOwnPropSymbols$p)
    for (var prop of __getOwnPropSymbols$p(b)) {
      if (__propIsEnum$p.call(b, prop))
        __defNormalProp$p(a, prop, b[prop]);
    }
  return a;
};
const ToolbarTitle = /* @__PURE__ */ defineComponent({
  name: "VeToolbarTitle",
  props: __spreadValues$p({
    text: String
  }, makeTagProps()),
  setup(props, {
    slots
  }) {
    return () => {
      const hasText = !!(slots.text || props.text);
      return createVNode(props.tag, {
        "class": "ve-toolbar-title"
      }, {
        default: () => {
          var _a, _b, _c;
          return [hasText && createVNode("div", {
            "class": "ve-toolbar-title__wrapper"
          }, [(_b = (_a = slots.text) == null ? void 0 : _a.call(slots)) != null ? _b : props.text]), (_c = slots.default) == null ? void 0 : _c.call(slots)];
        }
      });
    };
  }
});

var __defProp$o = Object.defineProperty;
var __defProps$5 = Object.defineProperties;
var __getOwnPropDescs$5 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$o = Object.getOwnPropertySymbols;
var __hasOwnProp$o = Object.prototype.hasOwnProperty;
var __propIsEnum$o = Object.prototype.propertyIsEnumerable;
var __defNormalProp$o = (obj, key, value) => key in obj ? __defProp$o(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$o = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$o.call(b, prop))
      __defNormalProp$o(a, prop, b[prop]);
  if (__getOwnPropSymbols$o)
    for (var prop of __getOwnPropSymbols$o(b)) {
      if (__propIsEnum$o.call(b, prop))
        __defNormalProp$o(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$5 = (a, b) => __defProps$5(a, __getOwnPropDescs$5(b));
const makeToolbarProps = propsFactory(__spreadValues$o({
  title: String
}, makePaperProps({
  tag: "header",
  height: 64
})), "toolbar");
function filterToolbarProps(attrs) {
  return pick(attrs, Object.keys(Toolbar.props));
}
const Toolbar = /* @__PURE__ */ defineComponent({
  name: "VeToolbar",
  props: makeToolbarProps(),
  setup(props, {
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(computed(() => __spreadProps$5(__spreadValues$o({}, props), {
      height: void 0
    })));
    provideDefaults({
      VeButton: {
        variant: "text"
      }
    });
    return () => {
      const hasTitle = !!(props.title || slots.title);
      return createVNode(props.tag, {
        "class": ["ve-toolbar", paperClasses.value],
        "style": paperStyles.value
      }, {
        default: () => {
          var _a, _b, _c;
          return [createVNode("div", {
            "class": "ve-toolbar__wrapper",
            "style": {
              height: convertToUnit(props.height)
            }
          }, [slots.prepend && createVNode("div", {
            "class": "ve-toolbar__prepend"
          }, [(_a = slots.prepend) == null ? void 0 : _a.call(slots)]), hasTitle && createVNode(ToolbarTitle, {
            "text": props.title
          }, {
            text: slots.title
          }), (_b = slots.default) == null ? void 0 : _b.call(slots), slots.append && createVNode("div", {
            "class": "ve-toolbar__append"
          }, [(_c = slots.append) == null ? void 0 : _c.call(slots)])])];
        }
      });
    };
  }
});

var __defProp$n = Object.defineProperty;
var __getOwnPropSymbols$n = Object.getOwnPropertySymbols;
var __hasOwnProp$n = Object.prototype.hasOwnProperty;
var __propIsEnum$n = Object.prototype.propertyIsEnumerable;
var __defNormalProp$n = (obj, key, value) => key in obj ? __defProp$n(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$n = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$n.call(b, prop))
      __defNormalProp$n(a, prop, b[prop]);
  if (__getOwnPropSymbols$n)
    for (var prop of __getOwnPropSymbols$n(b)) {
      if (__propIsEnum$n.call(b, prop))
        __defNormalProp$n(a, prop, b[prop]);
    }
  return a;
};
const ToolbarItems = /* @__PURE__ */ defineComponent({
  name: "VeToolbarItems",
  props: __spreadValues$n({}, makeVariantProps({
    variant: "contained-text"
  })),
  setup(props, {
    slots
  }) {
    provideDefaults({
      VeButton: {
        color: toRef(props, "color"),
        textColor: toRef(props, "textColor"),
        variant: toRef(props, "variant")
      }
    });
    return () => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots);
    };
  }
});

var __defProp$m = Object.defineProperty;
var __getOwnPropSymbols$m = Object.getOwnPropertySymbols;
var __hasOwnProp$m = Object.prototype.hasOwnProperty;
var __propIsEnum$m = Object.prototype.propertyIsEnumerable;
var __defNormalProp$m = (obj, key, value) => key in obj ? __defProp$m(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$m = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$m.call(b, prop))
      __defNormalProp$m(a, prop, b[prop]);
  if (__getOwnPropSymbols$m)
    for (var prop of __getOwnPropSymbols$m(b)) {
      if (__propIsEnum$m.call(b, prop))
        __defNormalProp$m(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$3(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Header = /* @__PURE__ */ defineComponent({
  name: "VeHeader",
  props: __spreadValues$m(__spreadValues$m({}, makeToolbarProps()), makeLayoutItemProps({
    position: "fixed",
    anchor: "top"
  })),
  setup(props, {
    slots
  }) {
    const {
      layoutItemStyles
    } = useLayoutItem(computed(() => ({
      position: props.position,
      anchor: props.anchor,
      size: props.height,
      active: props.modelValue,
      priority: props.priority
    })));
    return () => {
      const [toolbarProps] = filterToolbarProps(props);
      return createVNode(Toolbar, mergeProps(toolbarProps, {
        "class": "ve-header",
        "style": layoutItemStyles.value
      }), _isSlot$3(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});

const HeaderNavIcon = /* @__PURE__ */ defineComponent({
  name: "VeHeaderNavIcon",
  props: {
    icon: {
      type: String,
      default: "$menu"
    }
  },
  setup(props, {
    slots
  }) {
    return () => createVNode(Button, {
      "class": "ve-header-nav-icon",
      "icon": props.icon
    }, slots);
  }
});

var __defProp$l = Object.defineProperty;
var __getOwnPropSymbols$l = Object.getOwnPropertySymbols;
var __hasOwnProp$l = Object.prototype.hasOwnProperty;
var __propIsEnum$l = Object.prototype.propertyIsEnumerable;
var __defNormalProp$l = (obj, key, value) => key in obj ? __defProp$l(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$l = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$l.call(b, prop))
      __defNormalProp$l(a, prop, b[prop]);
  if (__getOwnPropSymbols$l)
    for (var prop of __getOwnPropSymbols$l(b)) {
      if (__propIsEnum$l.call(b, prop))
        __defNormalProp$l(a, prop, b[prop]);
    }
  return a;
};
const HeaderTitle = /* @__PURE__ */ defineComponent({
  name: "VeHeaderTitle",
  props: __spreadValues$l({
    text: String
  }, makeTagProps({
    tag: "header"
  })),
  setup(props, {
    slots
  }) {
    return () => {
      const hasDefault = slots.default || props.text;
      return createVNode(props.tag, {
        "class": "ve-header-title"
      }, {
        default: () => {
          var _a, _b;
          return [hasDefault && createVNode("div", {
            "class": "ve-header-title__wrapper"
          }, [(_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text])];
        }
      });
    };
  }
});

var __defProp$k = Object.defineProperty;
var __getOwnPropSymbols$k = Object.getOwnPropertySymbols;
var __hasOwnProp$k = Object.prototype.hasOwnProperty;
var __propIsEnum$k = Object.prototype.propertyIsEnumerable;
var __defNormalProp$k = (obj, key, value) => key in obj ? __defProp$k(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$k = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$k.call(b, prop))
      __defNormalProp$k(a, prop, b[prop]);
  if (__getOwnPropSymbols$k)
    for (var prop of __getOwnPropSymbols$k(b)) {
      if (__propIsEnum$k.call(b, prop))
        __defNormalProp$k(a, prop, b[prop]);
    }
  return a;
};
const Hover = /* @__PURE__ */ defineComponent({
  name: "VeHover",
  props: __spreadValues$k({
    disabled: Boolean,
    modelValue: {
      type: Boolean,
      default: void 0
    }
  }, makeDelayProps()),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const hover = useProxiedModel(props, "modelValue");
    const {
      runOpenDelay,
      runCloseDelay
    } = useDelay(props, (value) => {
      !props.disabled && (hover.value = value);
    });
    return () => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots, {
        hover: hover.value,
        props: {
          onMouseenter: runOpenDelay,
          onMouseleave: runCloseDelay
        }
      });
    };
  }
});

var __defProp$j = Object.defineProperty;
var __getOwnPropSymbols$j = Object.getOwnPropertySymbols;
var __hasOwnProp$j = Object.prototype.hasOwnProperty;
var __propIsEnum$j = Object.prototype.propertyIsEnumerable;
var __defNormalProp$j = (obj, key, value) => key in obj ? __defProp$j(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$j = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$j.call(b, prop))
      __defNormalProp$j(a, prop, b[prop]);
  if (__getOwnPropSymbols$j)
    for (var prop of __getOwnPropSymbols$j(b)) {
      if (__propIsEnum$j.call(b, prop))
        __defNormalProp$j(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$2(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Layout = /* @__PURE__ */ defineComponent({
  name: "VeLayout",
  props: __spreadValues$j(__spreadValues$j({}, makeTagProps()), makeLayoutProps()),
  setup(props, {
    slots
  }) {
    const {
      layoutClasses,
      getLayoutItem,
      items
    } = provideLayout(props);
    useRender(() => createVNode(props.tag, {
      "class": ["ve-layout", layoutClasses.value]
    }, _isSlot$2(slots) ? slots : {
      default: () => [slots]
    }));
    return {
      getLayoutItem,
      items
    };
  }
});

var __defProp$i = Object.defineProperty;
var __getOwnPropSymbols$i = Object.getOwnPropertySymbols;
var __hasOwnProp$i = Object.prototype.hasOwnProperty;
var __propIsEnum$i = Object.prototype.propertyIsEnumerable;
var __defNormalProp$i = (obj, key, value) => key in obj ? __defProp$i(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$i = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$i.call(b, prop))
      __defNormalProp$i(a, prop, b[prop]);
  if (__getOwnPropSymbols$i)
    for (var prop of __getOwnPropSymbols$i(b)) {
      if (__propIsEnum$i.call(b, prop))
        __defNormalProp$i(a, prop, b[prop]);
    }
  return a;
};
function _isSlot$1(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const LayoutItem = /* @__PURE__ */ defineComponent({
  name: "VeLayoutItem",
  props: __spreadValues$i(__spreadValues$i({
    size: {
      type: [String, Number],
      default: 64
    }
  }, makeTagProps()), makeLayoutItemProps()),
  setup(props, {
    slots
  }) {
    const {
      layoutItemStyles
    } = useLayoutItem(computed(() => ({
      priority: props.priority,
      position: props.position,
      anchor: props.anchor,
      size: props.size,
      active: props.modelValue
    })));
    return () => createVNode(props.tag, {
      "class": ["ve-layout-item"],
      "style": layoutItemStyles.value
    }, _isSlot$1(slots) ? slots : {
      default: () => [slots]
    });
  }
});

var __defProp$h = Object.defineProperty;
var __getOwnPropSymbols$h = Object.getOwnPropertySymbols;
var __hasOwnProp$h = Object.prototype.hasOwnProperty;
var __propIsEnum$h = Object.prototype.propertyIsEnumerable;
var __defNormalProp$h = (obj, key, value) => key in obj ? __defProp$h(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$h = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$h.call(b, prop))
      __defNormalProp$h(a, prop, b[prop]);
  if (__getOwnPropSymbols$h)
    for (var prop of __getOwnPropSymbols$h(b)) {
      if (__propIsEnum$h.call(b, prop))
        __defNormalProp$h(a, prop, b[prop]);
    }
  return a;
};
const Lazy = genericComponent()({
  name: "VeLazy",
  directives: {
    Intersect
  },
  props: __spreadValues$h(__spreadValues$h(__spreadValues$h({
    modelValue: Boolean,
    options: {
      type: Object,
      // For more information on types, navigate to:
      // https://developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API
      default: () => ({
        root: void 0,
        rootMargin: void 0,
        threshold: void 0
      })
    }
  }, makeDimensionProps()), makeTagProps()), makeTransitionProps({
    transition: {
      component: FadeTransition
    }
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const {
      dimensionStyles
    } = useDimension(props);
    const isActive = useProxiedModel(props, "modelValue");
    function onIntersect(isIntersecting) {
      if (isActive.value)
        return;
      isActive.value = isIntersecting;
    }
    return () => withDirectives(createVNode(props.tag, {
      "class": "ve-lazy",
      "style": dimensionStyles.value
    }, {
      default: () => [isActive.value && createVNode(MaybeTransition, {
        "transition": props.transition
      }, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      })]
    }), [[resolveDirective("intersect"), onIntersect, props.options]]);
  }
});

var __defProp$g = Object.defineProperty;
var __getOwnPropSymbols$g = Object.getOwnPropertySymbols;
var __hasOwnProp$g = Object.prototype.hasOwnProperty;
var __propIsEnum$g = Object.prototype.propertyIsEnumerable;
var __defNormalProp$g = (obj, key, value) => key in obj ? __defProp$g(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$g = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$g.call(b, prop))
      __defNormalProp$g(a, prop, b[prop]);
  if (__getOwnPropSymbols$g)
    for (var prop of __getOwnPropSymbols$g(b)) {
      if (__propIsEnum$g.call(b, prop))
        __defNormalProp$g(a, prop, b[prop]);
    }
  return a;
};
const Main = /* @__PURE__ */ defineComponent({
  name: "VeMain",
  props: __spreadValues$g(__spreadValues$g({}, makeTagProps({
    tag: "main"
  })), makeColorProps()),
  setup(props, {
    slots
  }) {
    const {
      mainStyles
    } = useLayoutMain();
    const {
      colorClasses,
      colorStyles
    } = useColor(computed(() => {
      const {
        textColor,
        color
      } = unref(props);
      return {
        background: color,
        text: textColor
      };
    }));
    return () => createVNode(props.tag, {
      "class": ["ve-main", colorClasses.value],
      "style": [mainStyles.value, colorStyles.value]
    }, {
      default: () => {
        var _a;
        return [createVNode("div", {
          "class": "ve-main__wrap"
        }, [(_a = slots.default) == null ? void 0 : _a.call(slots)])];
      }
    });
  }
});

var __defProp$f = Object.defineProperty;
var __getOwnPropSymbols$f = Object.getOwnPropertySymbols;
var __hasOwnProp$f = Object.prototype.hasOwnProperty;
var __propIsEnum$f = Object.prototype.propertyIsEnumerable;
var __defNormalProp$f = (obj, key, value) => key in obj ? __defProp$f(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$f = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$f.call(b, prop))
      __defNormalProp$f(a, prop, b[prop]);
  if (__getOwnPropSymbols$f)
    for (var prop of __getOwnPropSymbols$f(b)) {
      if (__propIsEnum$f.call(b, prop))
        __defNormalProp$f(a, prop, b[prop]);
    }
  return a;
};
const MessageKey = Symbol.for("veno-ui:message");
const NotificationKey = Symbol.for("veno-ui:notification");
const message = createMessage();
const notification = createMessage();
function createMessage() {
  const items = ref([]);
  function open(props) {
    return function(text, rest) {
      const id = `ve-message-${getUid()}`;
      const item = __spreadValues$f(__spreadValues$f({
        id,
        text,
        modelValue: true,
        variant: "contained",
        elevation: 15,
        duration: 3e3,
        close: () => close(id)
      }, props), rest);
      items.value.push(item);
      if (item.duration > 0) {
        return new Promise((resolve) => {
          setTimeout(() => {
            item.close();
            resolve(item);
          }, item.duration);
        });
      }
      return item.close;
    };
  }
  function close(id) {
    const item = items.value.find((v) => v.id === id);
    if (item) {
      item.modelValue = false;
    }
  }
  function remove(id) {
    items.value.splice(items.value.findIndex((v) => v.id === id), 1);
  }
  return {
    items,
    open,
    info: open({ type: "info" }),
    success: open({ type: "success" }),
    warning: open({ type: "warning" }),
    error: open({ type: "error" }),
    loading: open({ loading: true }),
    close,
    remove
  };
}
function provideMessage() {
  const message2 = createMessage();
  provide(MessageKey, message2);
  return message2;
}
function useMessage() {
  const message2 = inject(MessageKey);
  if (!message2)
    throw new Error("[VenoUi] Could not find message instance");
  return message2;
}
function provideNotification() {
  const notification2 = createMessage();
  provide(NotificationKey, notification2);
  return notification2;
}
function useNotification() {
  const notification2 = inject(NotificationKey);
  if (!notification2)
    throw new Error("[VenoUi] Could not find notification instance");
  return notification2;
}

var __defProp$e = Object.defineProperty;
var __defProps$4 = Object.defineProperties;
var __getOwnPropDescs$4 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$e = Object.getOwnPropertySymbols;
var __hasOwnProp$e = Object.prototype.hasOwnProperty;
var __propIsEnum$e = Object.prototype.propertyIsEnumerable;
var __defNormalProp$e = (obj, key, value) => key in obj ? __defProp$e(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$e = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$e.call(b, prop))
      __defNormalProp$e(a, prop, b[prop]);
  if (__getOwnPropSymbols$e)
    for (var prop of __getOwnPropSymbols$e(b)) {
      if (__propIsEnum$e.call(b, prop))
        __defNormalProp$e(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$4 = (a, b) => __defProps$4(a, __getOwnPropDescs$4(b));
const MessageProvider = /* @__PURE__ */ defineComponent({
  name: "VeMessageProvider",
  register(app) {
    app.provide(MessageKey, message);
  },
  props: {
    registered: Boolean
  },
  setup(props, {
    slots
  }) {
    const message2 = !props.registered ? provideMessage() : useMessage();
    const {
      items,
      remove
    } = message2;
    useRender(() => {
      var _a;
      return createVNode(Fragment, null, [(_a = slots.default) == null ? void 0 : _a.call(slots), createVNode(Overlay, {
        "modelValue": items.value.length > 0,
        "scrim": false,
        "scrollStrategy": "none",
        "class": ["ve-message-provider"]
      }, __spreadProps$4(__spreadValues$e({}, slots), {
        default: () => createVNode("ul", null, [items.value.map((item) => {
          const [alertProps] = filterAlertProps(item);
          return createVNode(Alert, mergeProps({
            "key": item.id,
            "tag": "li",
            "appear": true,
            "modelValue": item.modelValue,
            "onUpdate:modelValue": ($event) => item.modelValue = $event,
            "on-after-leave": () => remove(item.id)
          }, alertProps), null);
        })])
      }))]);
    });
    return message2;
  }
});

var __defProp$d = Object.defineProperty;
var __defProps$3 = Object.defineProperties;
var __getOwnPropDescs$3 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$d = Object.getOwnPropertySymbols;
var __hasOwnProp$d = Object.prototype.hasOwnProperty;
var __propIsEnum$d = Object.prototype.propertyIsEnumerable;
var __defNormalProp$d = (obj, key, value) => key in obj ? __defProp$d(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$d = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$d.call(b, prop))
      __defNormalProp$d(a, prop, b[prop]);
  if (__getOwnPropSymbols$d)
    for (var prop of __getOwnPropSymbols$d(b)) {
      if (__propIsEnum$d.call(b, prop))
        __defNormalProp$d(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$3 = (a, b) => __defProps$3(a, __getOwnPropDescs$3(b));
const NotificationProvider = /* @__PURE__ */ defineComponent({
  name: "VeNotificationProvider",
  register(app) {
    app.provide(NotificationKey, notification);
  },
  props: {
    registered: Boolean
  },
  setup(props, {
    slots
  }) {
    const notification2 = props.registered ? useNotification() : provideNotification();
    const {
      items,
      remove
    } = notification2;
    useRender(() => {
      var _a;
      return createVNode(Fragment, null, [(_a = slots.default) == null ? void 0 : _a.call(slots), createVNode(Overlay, {
        "modelValue": items.value.length > 0,
        "scrim": false,
        "scrollStrategy": "none",
        "class": "ve-notification-provider"
      }, __spreadProps$3(__spreadValues$d({}, slots), {
        default: () => createVNode("ul", null, [items.value.map((item) => {
          const [alertProps] = filterAlertProps(item);
          return createVNode(Alert, mergeProps({
            "key": item.id,
            "tag": "li",
            "appear": true,
            "modelValue": item.modelValue,
            "onUpdate:modelValue": ($event) => item.modelValue = $event,
            "on-after-leave": () => remove(item.id),
            "min-width": "300",
            "transition": {
              component: SlideRightFadeInExpandTransition
            }
          }, alertProps), null);
        })])
      }))]);
    });
    return notification2;
  }
});

function useRefs() {
  const refs = ref([]);
  onBeforeUpdate(() => refs.value = []);
  function updateRef(e, i) {
    refs.value[i] = e;
  }
  return { refs, updateRef };
}

var __defProp$c = Object.defineProperty;
var __defProps$2 = Object.defineProperties;
var __getOwnPropDescs$2 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$c = Object.getOwnPropertySymbols;
var __hasOwnProp$c = Object.prototype.hasOwnProperty;
var __propIsEnum$c = Object.prototype.propertyIsEnumerable;
var __defNormalProp$c = (obj, key, value) => key in obj ? __defProp$c(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$c = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$c.call(b, prop))
      __defNormalProp$c(a, prop, b[prop]);
  if (__getOwnPropSymbols$c)
    for (var prop of __getOwnPropSymbols$c(b)) {
      if (__propIsEnum$c.call(b, prop))
        __defNormalProp$c(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$2 = (a, b) => __defProps$2(a, __getOwnPropDescs$2(b));
const Pagination = /* @__PURE__ */ defineComponent({
  name: "VePagination",
  props: __spreadValues$c({
    /**
     * @zh 激活时的颜色
     */
    activeColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 导航的无障碍标签值
     */
    ariaLabel: {
      type: String,
      default: "\u5206\u9875\u5BFC\u822A"
    },
    /**
     * @zh 当前页的无障碍标签值
     */
    currentPageAriaLabel: {
      type: String,
      default: "\u5F53\u524D\u9875 {0}"
    },
    /**
     * @zh 是否禁用
     */
    disabled: Boolean,
    /**
     * @zh 省略值
     */
    ellipsis: {
      type: String,
      default: "..."
    },
    /**
     * @zh 第一页的无障碍标签值
     */
    firstAriaLabel: {
      type: String,
      default: "\u9996\u9875"
    },
    /**
     * @zh 第一页初始值
     */
    firstPage: {
      type: [Number, String],
      default: 1
    },
    /**
     * @zh 第一页的按钮图标
     */
    firstIcon: {
      type: String,
      default: "$first"
    },
    /**
     * @zh 最后一页的无障碍标签值
     */
    lastAriaLabel: {
      type: String,
      default: "\u6700\u540E\u9875"
    },
    /**
     * @zh 最后一页的按钮图标
     */
    lastIcon: {
      type: String,
      default: "$last"
    },
    /**
     * @zh 当前页
     */
    modelValue: {
      type: [Number, String],
      default: (props) => props.firstPage,
      validator: (val) => val % 1 === 0
    },
    /**
     * @zh 下一页的无障碍标签值
     */
    nextAriaLabel: {
      type: String,
      default: "\u4E0B\u4E00\u9875"
    },
    /**
     * @zh 下一页的按钮图标
     */
    nextIcon: {
      type: String,
      default: "$next"
    },
    /**
     * @zh 上一页的按钮图标
     */
    prevIcon: {
      type: String,
      default: "$prev"
    },
    /**
     * @zh 页面的无障碍标签值
     */
    pageAriaLabel: {
      type: String,
      default: "\u8F6C\u5230\u9875\u9762 {0}"
    },
    /**
     * @zh 每页条数
     */
    perPage: {
      type: [Number, String],
      default: 10,
      validator: (val) => val % 1 === 0
    },
    /**
     * @zh 每页条数可选项
     */
    perPageOptions: {
      type: Array,
      default: () => [10, 20, 50, 100]
    },
    /**
     * @zh 上一页的无障碍标签值
     */
    previousAriaLabel: {
      type: String,
      default: "\u4E0A\u4E00\u9875"
    },
    /**
     * @zh 显示首页和最后一页
     */
    showFirstLastPage: Boolean,
    /**
     * @zh 显示快速跳跃
     */
    showQuickJumper: Boolean,
    /**
     * @zh 显示每页条数选择器
     */
    showPerPageSelect: Boolean,
    /**
     * @zh 总条数
     */
    total: {
      type: [Number, String],
      default: 0,
      validator: (val) => val % 1 === 0
    },
    /**
     * @zh 总显示页数
     */
    totalVisible: {
      type: [Number, String],
      validator: (val) => val % 1 === 0
    }
  }, makePaperProps({
    tag: "nav",
    variant: "text",
    shape: "rounded-sm"
  })),
  emits: {
    "update:modelValue": (_modelValue) => true,
    "update:perPage": (_perPage) => true,
    "first": (_value) => true,
    "prev": (_value) => true,
    "next": (_value) => true,
    "last": (_value) => true
  },
  setup(props, {
    slots,
    emit
  }) {
    const internalPage = ref();
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    const page = useProxiedModel(props, "modelValue", props.modelValue, (v) => parseInt(v != null ? v : 1, 10));
    const perPage = useProxiedModel(props, "perPage", props.perPage, (v) => parseInt(v != null ? v : 10, 10));
    const total = computed(() => parseInt(props.total, 10));
    const firstPage = computed(() => parseInt(props.firstPage, 10));
    const lastPage = computed(() => Math.ceil(total.value / perPage.value));
    const maxButtons = ref(-1);
    const {
      resizeRef
    } = useResizeObserver((entries) => {
      if (!entries.length)
        return;
      const {
        target,
        contentRect
      } = entries[0];
      const firstItem = target.querySelector(".ve-pagination__wrapper > *");
      if (!firstItem)
        return;
      let totalWidth = contentRect.width - 96;
      if (props.showPerPageSelect)
        totalWidth -= 100;
      if (props.showQuickJumper)
        totalWidth -= 100;
      const itemWidth = firstItem.getBoundingClientRect().width + 10;
      maxButtons.value = Math.max(0, Math.floor(totalWidth / itemWidth));
    });
    const totalVisible = computed(() => {
      if (props.totalVisible)
        return Math.min(parseInt(props.totalVisible, 10), lastPage.value);
      if (maxButtons.value >= 0)
        return maxButtons.value;
      return Math.min(7, lastPage.value);
    });
    const range = computed(() => {
      if (lastPage.value <= 0)
        return [];
      if (totalVisible.value === 1)
        return [Math.min(Math.max(firstPage.value, page.value), firstPage.value + lastPage.value)];
      if (lastPage.value <= totalVisible.value)
        return createRange(lastPage.value, firstPage.value);
      const middle = Math.ceil(totalVisible.value / 2);
      const left = middle;
      const right = lastPage.value - middle;
      if (page.value < left) {
        return [...createRange(Math.max(1, totalVisible.value - 2), firstPage.value), props.ellipsis, lastPage.value];
      }
      if (page.value > right) {
        const rangeLength2 = totalVisible.value - 2;
        const rangeStart2 = lastPage.value - rangeLength2 + firstPage.value;
        return [firstPage.value, props.ellipsis, ...createRange(rangeLength2, rangeStart2)];
      }
      const rangeLength = Math.max(1, totalVisible.value - 4);
      const rangeStart = rangeLength === 1 ? page.value : page.value - Math.ceil(rangeLength / 2) + firstPage.value;
      return [firstPage.value, props.ellipsis, ...createRange(rangeLength, rangeStart), props.ellipsis, lastPage.value];
    });
    function setValue(e, value, event) {
      e.preventDefault();
      page.value = value;
      event && emit(event, value);
    }
    const {
      refs,
      updateRef
    } = useRefs();
    const items = computed(() => {
      const sharedProps = {
        density: props.density,
        shape: props.shape,
        size: props.size
      };
      return range.value.map((item, index) => {
        const ref2 = (e) => updateRef(e, index);
        if (typeof item === "string") {
          return {
            isActive: false,
            page: item,
            props: __spreadProps$2(__spreadValues$c({}, sharedProps), {
              ref: ref2,
              ellipsis: true,
              icon: true,
              disabled: true,
              variant: props.variant,
              border: props.border
            })
          };
        } else {
          const isActive = item === page.value;
          return {
            isActive,
            page: item,
            props: __spreadProps$2(__spreadValues$c({}, sharedProps), {
              ref: ref2,
              ellipsis: false,
              icon: true,
              disabled: props.disabled || lastPage.value < 2,
              elevation: props.elevation,
              variant: isActive ? "outlined" : props.variant,
              border: props.border,
              color: isActive ? props.activeColor : void 0,
              ariaCurrent: isActive,
              ariaLabel: isActive ? props.currentPageAriaLabel : props.pageAriaLabel,
              onClick: (e) => setValue(e, item)
            })
          };
        }
      });
    });
    const controls = computed(() => {
      const sharedProps = {
        color: void 0,
        density: props.density,
        shape: props.shape,
        size: props.size,
        variant: "outlined",
        border: props.border
      };
      const prevDisabled = props.disabled || page.value <= firstPage.value;
      const nextDisabled = props.disabled || page.value >= firstPage.value + lastPage.value - 1;
      return {
        first: props.showFirstLastPage ? __spreadProps$2(__spreadValues$c({}, sharedProps), {
          icon: props.firstIcon,
          onClick: (e) => setValue(e, firstPage.value, "first"),
          disabled: prevDisabled,
          ariaLabel: props.firstAriaLabel,
          ariaDisabled: prevDisabled
        }) : void 0,
        prev: __spreadProps$2(__spreadValues$c({}, sharedProps), {
          icon: props.prevIcon,
          onClick: (e) => setValue(e, page.value - 1, "prev"),
          disabled: prevDisabled,
          ariaLabel: props.previousAriaLabel,
          ariaDisabled: prevDisabled
        }),
        next: __spreadProps$2(__spreadValues$c({}, sharedProps), {
          icon: props.nextIcon,
          onClick: (e) => setValue(e, page.value + 1, "next"),
          disabled: nextDisabled,
          ariaLabel: props.nextAriaLabel,
          ariaDisabled: nextDisabled
        }),
        last: props.showFirstLastPage ? __spreadProps$2(__spreadValues$c({}, sharedProps), {
          icon: props.lastIcon,
          onClick: (e) => setValue(e, firstPage.value + lastPage.value - 1, "last"),
          disabled: nextDisabled,
          ariaLabel: props.lastAriaLabel,
          ariaDisabled: nextDisabled
        }) : void 0
      };
    });
    function updateFocus() {
      var _a;
      const currentIndex = page.value - firstPage.value;
      (_a = refs.value[currentIndex]) == null ? void 0 : _a.$el.focus();
    }
    function onKeydown({
      key
    }) {
      if (key === keyValues.left && !props.disabled && page.value > firstPage.value) {
        page.value = page.value - 1;
        nextTick(updateFocus);
      } else if (key === keyValues.right && !props.disabled && page.value < firstPage.value + lastPage.value - 1) {
        page.value = page.value + 1;
        nextTick(updateFocus);
      }
    }
    return () => createVNode(props.tag, {
      "ref": resizeRef,
      "class": ["ve-pagination", paperClasses.value],
      "style": paperStyles.value,
      "role": "navigation",
      "aria-label": props.ariaLabel,
      "onKeydown": onKeydown
    }, {
      default: () => {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        return [createVNode("ul", {
          "class": "ve-pagination__wrapper"
        }, [props.showFirstLastPage && createVNode("li", {
          "class": "ve-pagination__first"
        }, [(_b = (_a = slots.first) == null ? void 0 : _a.call(slots, controls.value.first)) != null ? _b : createVNode(Button, controls.value.first, null)]), createVNode("li", {
          "class": "ve-pagination__prev"
        }, [(_d = (_c = slots.prev) == null ? void 0 : _c.call(slots, controls.value.prev)) != null ? _d : createVNode(Button, controls.value.prev, null)]), items.value.map((item, index) => {
          var _a2, _b2;
          return createVNode("li", {
            "key": `${index}_${item.page}`,
            "class": ["ve-pagination__item", {
              "ve-pagination__item--is-active": item.isActive
            }]
          }, [(_b2 = (_a2 = slots.item) == null ? void 0 : _a2.call(slots, item)) != null ? _b2 : createVNode(Button, item.props, {
            default: () => [item.page]
          })]);
        }), createVNode("li", {
          "class": "ve-pagination__next"
        }, [(_f = (_e = slots.next) == null ? void 0 : _e.call(slots, controls.value.next)) != null ? _f : createVNode(Button, controls.value.next, null)]), props.showFirstLastPage && createVNode("li", {
          "class": "ve-pagination__last"
        }, [(_h = (_g = slots.last) == null ? void 0 : _g.call(slots, controls.value.last)) != null ? _h : createVNode(Button, controls.value.last, null)]), props.showPerPageSelect && createVNode("li", {
          "class": "ve-pagination__per-page"
        }, [createVNode(Select, {
          "hide-details": true,
          "width": "95",
          "modelValue": perPage.value,
          "onUpdate:modelValue": ($event) => perPage.value = $event,
          "items": props.perPageOptions.map((v) => ({
            text: `${v} / \u9875`,
            value: parseInt(v, 10)
          }))
        }, null)]), props.showQuickJumper && createVNode("li", {
          "class": "ve-pagination__quick-jumper"
        }, [createVNode(Input, {
          "hide-details": true,
          "width": "60",
          "modelValue": internalPage.value,
          "onUpdate:modelValue": ($event) => internalPage.value = $event,
          "type": "number",
          "onKeydown": ({
            key
          }) => {
            if (key === keyValues.enter && internalPage.value && internalPage.value > 0 && internalPage.value <= lastPage.value) {
              page.value = internalPage.value;
              internalPage.value = void 0;
            }
          },
          "onBlur": () => {
            if (internalPage.value && internalPage.value > 0 && internalPage.value <= lastPage.value) {
              page.value = internalPage.value;
              internalPage.value = void 0;
            }
          }
        }, {
          prepend: () => createVNode("span", null, [createTextVNode("\u8DF3\u81F3")])
        })])])];
      }
    });
  }
});

const Paper = /* @__PURE__ */ defineComponent({
  name: "VePaper",
  props: makePaperProps(),
  setup(props, {
    slots
  }) {
    const {
      paperClasses,
      paperStyles
    } = usePaper(props);
    return () => createVNode(props.tag, {
      "class": ["ve-paper", paperClasses.value],
      "style": paperStyles.value
    }, slots);
  }
});

var __defProp$b = Object.defineProperty;
var __getOwnPropSymbols$b = Object.getOwnPropertySymbols;
var __hasOwnProp$b = Object.prototype.hasOwnProperty;
var __propIsEnum$b = Object.prototype.propertyIsEnumerable;
var __defNormalProp$b = (obj, key, value) => key in obj ? __defProp$b(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$b = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$b.call(b, prop))
      __defNormalProp$b(a, prop, b[prop]);
  if (__getOwnPropSymbols$b)
    for (var prop of __getOwnPropSymbols$b(b)) {
      if (__propIsEnum$b.call(b, prop))
        __defNormalProp$b(a, prop, b[prop]);
    }
  return a;
};
const Scrollbar = /* @__PURE__ */ defineComponent({
  name: "VeScrollbar",
  props: __spreadValues$b(__spreadValues$b({}, makeTagProps()), makeScrollbar()),
  setup(props, {
    slots
  }) {
    const {
      scrollbarClasses
    } = useScrollbar(props);
    return () => {
      var _a;
      return createVNode("div", {
        "class": ["ve-scrollbar", scrollbarClasses.value]
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots)]);
    };
  }
});

function bias(val) {
  const c = 0.501;
  const x = Math.abs(val);
  return Math.sign(val) * (x / ((1 / c - 2) * (1 - x) + 1));
}
function calculateUpdatedOffset({
  selectedElement,
  containerSize,
  contentSize,
  isRtl,
  currentScrollOffset,
  isHorizontal
}) {
  const clientSize = isHorizontal ? selectedElement.clientWidth : selectedElement.clientHeight;
  const offsetStart = isHorizontal ? selectedElement.offsetLeft : selectedElement.offsetTop;
  const adjustedOffsetStart = isRtl ? contentSize - offsetStart - clientSize : offsetStart;
  if (isRtl) {
    currentScrollOffset = -currentScrollOffset;
  }
  const totalSize = containerSize + currentScrollOffset;
  const itemOffset = clientSize + adjustedOffsetStart;
  const additionalOffset = clientSize * 0.4;
  if (adjustedOffsetStart <= currentScrollOffset) {
    currentScrollOffset = Math.max(adjustedOffsetStart - additionalOffset, 0);
  } else if (totalSize <= itemOffset) {
    currentScrollOffset = Math.min(currentScrollOffset - (totalSize - itemOffset - additionalOffset), contentSize - containerSize);
  }
  return isRtl ? -currentScrollOffset : currentScrollOffset;
}
function calculateCenteredOffset({
  selectedElement,
  containerSize,
  contentSize,
  isRtl,
  isHorizontal
}) {
  const clientSize = isHorizontal ? selectedElement.clientWidth : selectedElement.clientHeight;
  const offsetStart = isHorizontal ? selectedElement.offsetLeft : selectedElement.offsetTop;
  if (isRtl) {
    const offsetCentered = contentSize - offsetStart - clientSize / 2 - containerSize / 2;
    return -Math.min(contentSize - containerSize, Math.max(0, offsetCentered));
  } else {
    const offsetCentered = offsetStart + clientSize / 2 - containerSize / 2;
    return Math.min(contentSize - containerSize, Math.max(0, offsetCentered));
  }
}

var __defProp$a = Object.defineProperty;
var __getOwnPropSymbols$a = Object.getOwnPropertySymbols;
var __hasOwnProp$a = Object.prototype.hasOwnProperty;
var __propIsEnum$a = Object.prototype.propertyIsEnumerable;
var __defNormalProp$a = (obj, key, value) => key in obj ? __defProp$a(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$a = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$a.call(b, prop))
      __defNormalProp$a(a, prop, b[prop]);
  if (__getOwnPropSymbols$a)
    for (var prop of __getOwnPropSymbols$a(b)) {
      if (__propIsEnum$a.call(b, prop))
        __defNormalProp$a(a, prop, b[prop]);
    }
  return a;
};
const SlideGroupKey = createSymbol("slide-group");
const SlideGroup = /* @__PURE__ */ defineComponent({
  name: "VeSlideGroup",
  props: __spreadValues$a(__spreadValues$a({
    activeClass: {
      type: String,
      default: "v-slide-item--active"
    },
    centerActive: Boolean,
    direction: {
      type: String,
      default: "horizontal"
    },
    symbol: {
      type: null,
      default: SlideGroupKey
    },
    nextIcon: {
      type: String,
      default: "$next"
    },
    prevIcon: {
      type: String,
      default: "$prev"
    },
    showArrows: {
      type: [Boolean, String],
      validator: (v) => typeof v === "boolean" || ["always", "desktop", "mobile"].includes(v)
    }
  }, makeTagProps()), makeGroupProps()),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const isRtl = ref(false);
    const {
      mobile
    } = useDisplay();
    const group = useGroup(props, props.symbol);
    const isOverflowing = ref(false);
    const scrollOffset = ref(0);
    const containerSize = ref(0);
    const contentSize = ref(0);
    const isHorizontal = computed(() => props.direction === "horizontal");
    const {
      resizeRef: containerRef,
      contentRect: containerRect
    } = useResizeObserver();
    const {
      resizeRef: contentRef,
      contentRect
    } = useResizeObserver();
    watchEffect(() => {
      if (!containerRect.value || !contentRect.value)
        return;
      const sizeProperty = isHorizontal.value ? "width" : "height";
      containerSize.value = containerRect.value[sizeProperty];
      contentSize.value = contentRect.value[sizeProperty];
      isOverflowing.value = containerSize.value + 1 < contentSize.value;
    });
    watch(group.selected, (selected) => {
      if (!selected.length || !contentRef.value)
        return;
      const index = group.items.value.findIndex((item) => item.id === selected[selected.length - 1]);
      const selectedElement = contentRef.value.children[index];
      if (index === 0 || !isOverflowing.value) {
        scrollOffset.value = 0;
      } else if (props.centerActive) {
        scrollOffset.value = calculateCenteredOffset({
          selectedElement,
          containerSize: containerSize.value,
          contentSize: contentSize.value,
          isRtl: isRtl.value,
          isHorizontal: isHorizontal.value
        });
      } else if (isOverflowing.value) {
        scrollOffset.value = calculateUpdatedOffset({
          selectedElement,
          containerSize: containerSize.value,
          contentSize: contentSize.value,
          isRtl: isRtl.value,
          currentScrollOffset: scrollOffset.value,
          isHorizontal: isHorizontal.value
        });
      }
    });
    const disableTransition = ref(false);
    let startTouch = 0;
    let startOffset = 0;
    function onTouchstart(e) {
      const sizeProperty = isHorizontal.value ? "clientX" : "clientY";
      startOffset = scrollOffset.value;
      startTouch = e.touches[0][sizeProperty];
      disableTransition.value = true;
    }
    function onTouchmove(e) {
      if (!isOverflowing.value)
        return;
      const sizeProperty = isHorizontal.value ? "clientX" : "clientY";
      scrollOffset.value = startOffset + startTouch - e.touches[0][sizeProperty];
    }
    function onTouchend(_event) {
      const maxScrollOffset = contentSize.value - containerSize.value;
      if (isRtl.value) {
        if (scrollOffset.value > 0 || !isOverflowing.value) {
          scrollOffset.value = 0;
        } else if (scrollOffset.value <= -maxScrollOffset) {
          scrollOffset.value = -maxScrollOffset;
        }
      } else {
        if (scrollOffset.value < 0 || !isOverflowing.value) {
          scrollOffset.value = 0;
        } else if (scrollOffset.value >= maxScrollOffset) {
          scrollOffset.value = maxScrollOffset;
        }
      }
      disableTransition.value = false;
    }
    function onScroll() {
      containerRef.value && (containerRef.value.scrollLeft = 0);
    }
    const isFocused = ref(false);
    function onFocusin(e) {
      isFocused.value = true;
      if (!isOverflowing.value || !contentRef.value)
        return;
      for (const el of e.composedPath()) {
        for (const item of contentRef.value.children) {
          if (item === el) {
            scrollOffset.value = calculateUpdatedOffset({
              selectedElement: item,
              containerSize: containerSize.value,
              contentSize: contentSize.value,
              isRtl: isRtl.value,
              currentScrollOffset: scrollOffset.value,
              isHorizontal: isHorizontal.value
            });
            return;
          }
        }
      }
    }
    function onFocusout(_e) {
      isFocused.value = false;
    }
    function onFocus(e) {
      var _a;
      if (!isFocused.value && !(e.relatedTarget && ((_a = contentRef.value) == null ? void 0 : _a.contains(e.relatedTarget))))
        focus();
    }
    function onKeydown(e) {
      if (!contentRef.value)
        return;
      if (e.key === (isHorizontal.value ? "ArrowRight" : "ArrowDown")) {
        focus("next");
      } else if (e.key === (isHorizontal.value ? "ArrowLeft" : "ArrowUp")) {
        focus("prev");
      } else if (e.key === "Home") {
        focus("first");
      } else if (e.key === "End") {
        focus("last");
      }
    }
    function focus(location) {
      var _a, _b, _c, _d, _e;
      if (!contentRef.value)
        return;
      if (!location) {
        contentRef.value.querySelector("[tabindex]");
        const focusable = [...contentRef.value.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')].filter((el) => !el.hasAttribute("disabled"));
        (_a = focusable[0]) == null ? void 0 : _a.focus();
      } else if (location === "next") {
        const el = (_b = contentRef.value.querySelector(":focus")) == null ? void 0 : _b.nextElementSibling;
        if (el)
          el.focus();
        else
          focus("first");
      } else if (location === "prev") {
        const el = (_c = contentRef.value.querySelector(":focus")) == null ? void 0 : _c.previousElementSibling;
        if (el)
          el.focus();
        else
          focus("last");
      } else if (location === "first") {
        (_d = contentRef.value.firstElementChild) == null ? void 0 : _d.focus();
      } else if (location === "last") {
        (_e = contentRef.value.lastElementChild) == null ? void 0 : _e.focus();
      }
    }
    function scrollTo(location) {
      const sign = isRtl.value ? -1 : 1;
      const newAbosluteOffset = sign * scrollOffset.value + (location === "prev" ? -1 : 1) * containerSize.value;
      scrollOffset.value = sign * clamp(newAbosluteOffset, 0, contentSize.value - containerSize.value);
    }
    const contentStyles = computed(() => {
      const scrollAmount = scrollOffset.value <= 0 ? bias(-scrollOffset.value) : scrollOffset.value > contentSize.value - containerSize.value ? -(contentSize.value - containerSize.value) + bias(contentSize.value - containerSize.value - scrollOffset.value) : -scrollOffset.value;
      return {
        transform: `translate${isHorizontal.value ? "X" : "Y"}(${scrollAmount}px)`,
        transition: disableTransition.value ? "none" : "",
        willChange: disableTransition.value ? "transform" : ""
      };
    });
    const slotProps = computed(() => ({
      next: group.next,
      prev: group.prev,
      select: group.select,
      isSelected: group.isSelected
    }));
    const hasAffixes = computed(() => {
      switch (props.showArrows) {
        case "always":
          return true;
        case "desktop":
          return mobile.value;
        case true:
          return isOverflowing.value || Math.abs(scrollOffset.value) > 0;
        case "mobile":
          return mobile.value || isOverflowing.value || Math.abs(scrollOffset.value) > 0;
        default:
          return !mobile.value && (isOverflowing.value || Math.abs(scrollOffset.value) > 0);
      }
    });
    const hasPrev = computed(() => {
      return hasAffixes.value && scrollOffset.value > 0;
    });
    const hasNext = computed(() => {
      if (!hasAffixes.value)
        return false;
      return contentSize.value > Math.abs(scrollOffset.value) + containerSize.value;
    });
    useRender(() => createVNode(props.tag, {
      "class": ["ve-slide-group", {
        "ve-slide-group--vertical": !isHorizontal.value,
        "ve-slide-group--has-affixes": hasAffixes.value,
        "ve-slide-group--is-overflowing": isOverflowing.value
      }],
      "tabindex": isFocused.value || group.selected.value.length ? -1 : 0,
      "onFocus": onFocus
    }, {
      default: () => {
        var _a, _b, _c, _d, _e;
        return [hasAffixes.value && createVNode("div", {
          "class": ["ve-slide-group__prev", {
            "ve-slide-group__prev--disabled": !hasPrev.value
          }],
          "onClick": () => scrollTo("prev")
        }, [(_b = (_a = slots.prev) == null ? void 0 : _a.call(slots, slotProps.value)) != null ? _b : createVNode(FadeTransition, null, {
          default: () => [createVNode(Icon, {
            "icon": props.prevIcon
          }, null)]
        })]), createVNode("div", {
          "ref": containerRef,
          "class": "ve-slide-group__container",
          "onScroll": onScroll
        }, [createVNode("div", {
          "ref": contentRef,
          "class": "ve-slide-group__content",
          "style": contentStyles.value,
          "onTouchstart": onTouchstart,
          "onTouchmove": onTouchmove,
          "onTouchend": onTouchend,
          "onFocusin": onFocusin,
          "onFocusout": onFocusout,
          "onKeydown": onKeydown
        }, [(_c = slots.default) == null ? void 0 : _c.call(slots, slotProps.value)])]), hasAffixes.value && createVNode("div", {
          "class": ["ve-slide-group__next", {
            "ve-slide-group__next--disabled": !hasNext.value
          }],
          "onClick": () => scrollTo("next")
        }, [(_e = (_d = slots.next) == null ? void 0 : _d.call(slots, slotProps.value)) != null ? _e : createVNode(FadeTransition, null, {
          default: () => [createVNode(Icon, {
            "icon": props.nextIcon
          }, null)]
        })])];
      }
    }));
    return {
      selected: group.selected,
      scrollTo,
      scrollOffset,
      focus
    };
  }
});

var __defProp$9 = Object.defineProperty;
var __getOwnPropSymbols$9 = Object.getOwnPropertySymbols;
var __hasOwnProp$9 = Object.prototype.hasOwnProperty;
var __propIsEnum$9 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$9 = (obj, key, value) => key in obj ? __defProp$9(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$9 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$9.call(b, prop))
      __defNormalProp$9(a, prop, b[prop]);
  if (__getOwnPropSymbols$9)
    for (var prop of __getOwnPropSymbols$9(b)) {
      if (__propIsEnum$9.call(b, prop))
        __defNormalProp$9(a, prop, b[prop]);
    }
  return a;
};
const SlideGroupItem = /* @__PURE__ */ defineComponent({
  name: "VeSlideGroupItem",
  props: __spreadValues$9({}, makeGroupItemProps()),
  setup(props, {
    slots
  }) {
    const group = useGroupItem(props, SlideGroupKey);
    return () => {
      var _a;
      return (_a = slots.default) == null ? void 0 : _a.call(slots, {
        isSelected: group.isSelected.value,
        select: group.select
      });
    };
  }
});

var __defProp$8 = Object.defineProperty;
var __getOwnPropSymbols$8 = Object.getOwnPropertySymbols;
var __hasOwnProp$8 = Object.prototype.hasOwnProperty;
var __propIsEnum$8 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$8 = (obj, key, value) => key in obj ? __defProp$8(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$8 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$8.call(b, prop))
      __defNormalProp$8(a, prop, b[prop]);
  if (__getOwnPropSymbols$8)
    for (var prop of __getOwnPropSymbols$8(b)) {
      if (__propIsEnum$8.call(b, prop))
        __defNormalProp$8(a, prop, b[prop]);
    }
  return a;
};
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Spacer = /* @__PURE__ */ defineComponent({
  name: "VeSpacer",
  props: __spreadValues$8(__spreadValues$8({}, makeRowProps()), makeColProps({
    cols: "auto"
  })),
  setup(props, {
    slots
  }) {
    return () => {
      var _a, _b;
      let _slot;
      const children = flattenFragments((_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : []);
      if (!children.length) {
        return createVNode("div", {
          "class": "ve-spacer"
        }, null);
      }
      const [rowProps] = pick(props, Object.keys(Row.props));
      const [colProps] = pick(props, Object.keys(Col.props));
      return createVNode(Row, mergeProps({
        "class": "ve-spacer"
      }, rowProps), _isSlot(_slot = children.map((child, index) => createVNode(Col, mergeProps(colProps, {
        "key": index
      }), _isSlot(child) ? child : {
        default: () => [child]
      }))) ? _slot : {
        default: () => [_slot]
      });
    };
  }
});

var __defProp$7 = Object.defineProperty;
var __defProps$1 = Object.defineProperties;
var __getOwnPropDescs$1 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$7 = Object.getOwnPropertySymbols;
var __hasOwnProp$7 = Object.prototype.hasOwnProperty;
var __propIsEnum$7 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$7 = (obj, key, value) => key in obj ? __defProp$7(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$7 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$7.call(b, prop))
      __defNormalProp$7(a, prop, b[prop]);
  if (__getOwnPropSymbols$7)
    for (var prop of __getOwnPropSymbols$7(b)) {
      if (__propIsEnum$7.call(b, prop))
        __defNormalProp$7(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$1 = (a, b) => __defProps$1(a, __getOwnPropDescs$1(b));
const defaultPagination = {
  page: 1,
  perPage: 10,
  perPageOptions: [10, 20, 50, 100],
  total: 0,
  totalVisible: 7,
  showQuickJumper: false,
  showPerPageSelect: false
};
const makeDataIteratorProps = propsFactory({
  remote: Boolean,
  items: {
    type: Array,
    default: () => []
  },
  mustSort: Boolean,
  multiSort: Boolean,
  sortBy: {
    type: [String, Array],
    default: () => []
  },
  sortDesc: {
    type: [Boolean, Array],
    default: () => []
  },
  customSort: {
    type: Function,
    default: sortItems
  },
  locale: {
    type: String,
    default: "en-US"
  },
  pagination: {
    type: Object,
    defualt: () => __spreadValues$7({}, defaultPagination)
  }
}, "data-iterator");
function toggle(key, oldBy, oldDesc, page, mustSort, multiSort) {
  let by = oldBy.slice();
  let desc = oldDesc.slice();
  const byIndex = by.findIndex((k) => k === key);
  if (byIndex < 0) {
    if (!multiSort) {
      by = [];
      desc = [];
    }
    by.push(key);
    desc.push(false);
  } else if (byIndex >= 0 && !desc[byIndex]) {
    desc[byIndex] = true;
  } else if (!mustSort) {
    by.splice(byIndex, 1);
    desc.splice(byIndex, 1);
  } else {
    desc[byIndex] = false;
  }
  if (!deepEqual(by, oldBy) || !deepEqual(desc, oldDesc)) {
    page = 1;
  }
  return { by, desc, page };
}
function useDataIterator(props) {
  const vm = getCurrentInstance("useDataIterator");
  const pagination = useProxiedModel(
    props,
    "pagination",
    props.pagination,
    (val) => {
      var _a;
      const pagination2 = __spreadValues$7(__spreadValues$7({}, defaultPagination), val);
      return reactive(__spreadProps$1(__spreadValues$7({}, pagination2), {
        page: Number(pagination2.page),
        perPage: Number(pagination2.perPage),
        total: props.remote ? Number((_a = pagination2.total) != null ? _a : props.items.length) : props.items.length
      }));
    }
  );
  const sortBy = useProxiedModel(props, "sortBy");
  const sortDesc = useProxiedModel(props, "sortDesc");
  function updateOptions() {
    vm.emit("update:options", {
      pagination: pagination.value,
      sortBy: sortBy.value,
      sortDesc: sortDesc.value
    });
  }
  function sortItems2(items2) {
    return props.customSort(
      items2,
      wrapInArray(sortBy.value),
      wrapInArray(sortDesc.value),
      props.locale
    );
  }
  function paginateItems(items2) {
    return items2.slice(
      (pagination.value.page - 1) * pagination.value.perPage,
      Math.min(pagination.value.total, pagination.value.page * pagination.value.perPage)
    );
  }
  const items = computed(() => {
    if (props.remote)
      return props.items;
    let items2 = props.items.slice();
    items2 = sortItems2(items2);
    items2 = paginateItems(items2);
    return items2;
  });
  function sort(key) {
    var _a, _b;
    if (Array.isArray(key)) {
      const options = {
        sortBy: key,
        sortDesc: key.map((s) => {
          const i = wrapInArray(sortBy.value).findIndex((k) => k === s);
          return i > -1 ? wrapInArray(sortDesc.value)[i] : false;
        }),
        pagination: __spreadValues$7({}, pagination.value)
      };
      sortBy.value = options.sortBy;
      sortDesc.value = options.sortDesc;
      vm.emit("update:options", options);
    } else {
      const { by, desc, page } = toggle(
        key,
        wrapInArray(sortBy.value),
        wrapInArray(sortDesc.value),
        pagination.value.page,
        props.mustSort,
        props.multiSort
      );
      const options = {
        sortBy: props.multiSort ? by : (_a = by[0]) != null ? _a : null,
        sortDesc: props.multiSort ? desc : (_b = desc[0]) != null ? _b : null,
        pagination: __spreadProps$1(__spreadValues$7({}, pagination.value), {
          page
        })
      };
      sortBy.value = options.sortBy;
      sortDesc.value = options.sortDesc;
      pagination.value.page = options.pagination.page;
      vm.emit("update:options", options);
    }
  }
  return {
    items,
    pagination,
    sortBy,
    sortDesc,
    sort,
    updateOptions
  };
}

const TableTh = /* @__PURE__ */ defineComponent({
  name: "VeTableTh",
  props: {
    /**
     * @zh 可排序
     */
    sortable: Boolean,
    /**
     * @zh 倒序是否倒序
     */
    sortDesc: Boolean,
    /**
     * @zh 排序的图标
     */
    sortIcon: {
      type: String,
      default: "$sort"
    },
    /**
     * @zh 排序激活时的颜色
     */
    sortActiveColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 过滤器的图标
     */
    filterIcon: {
      type: String,
      default: "$filter"
    },
    /**
     * @zh 过滤器
     */
    filters: {
      type: Array,
      default: () => []
    },
    /**
     * @zh 固定方式
     */
    fixed: [Boolean, String],
    /**
     * @zh 对齐方式
     */
    align: {
      type: String,
      default: "start"
    }
  },
  setup(props, {
    slots
  }) {
    return () => {
      var _a;
      return createVNode("th", {
        "class": ["ve-table-th", `text-${props.align}`, {
          "ve-table-th--sortable": props.sortable,
          "ve-table-th--sorted": props.sortDesc !== void 0,
          "ve-table-th--fixed-start": props.fixed === "start",
          "ve-table-th--fixed-end": props.fixed === "end"
        }]
      }, [createVNode("div", {
        "class": "ve-table-th__wrapper"
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots), props.sortable && createVNode(Icon, {
        "class": {
          "ve-table-th__sorter": true,
          "ve-table-th__sorter--desc": props.sortDesc === true
        },
        "icon": props.sortIcon,
        "color": props.sortDesc !== void 0 ? props.sortActiveColor : void 0
      }, null)]), props.filters.length > 0 && createVNode(Button, {
        "class": "ve-table-th__filter",
        "icon": props.filterIcon,
        "variant": "text",
        "onClick": (e) => {
          e.stopPropagation();
        }
      }, null)]);
    };
  }
});
function filterTableThProps(attrs) {
  return pick(attrs, Object.keys(TableTh.props));
}

const TableNoData = /* @__PURE__ */ defineComponent({
  name: "VeTableNoData",
  props: {
    icon: {
      type: String,
      default: "$nodata"
    },
    text: {
      type: String,
      default: "\u6682\u65E0\u6570\u636E"
    }
  },
  setup(props, {
    slots
  }) {
    return () => {
      var _a, _b;
      return createVNode("div", {
        "class": "ve-table-no-data"
      }, [createVNode(Icon, {
        "icon": props.icon,
        "size": 48,
        "class": "mb-3"
      }, null), createVNode("div", null, [(_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text])]);
    };
  }
});

var __defProp$6 = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$6 = Object.getOwnPropertySymbols;
var __hasOwnProp$6 = Object.prototype.hasOwnProperty;
var __propIsEnum$6 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$6 = (obj, key, value) => key in obj ? __defProp$6(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$6 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$6.call(b, prop))
      __defNormalProp$6(a, prop, b[prop]);
  if (__getOwnPropSymbols$6)
    for (var prop of __getOwnPropSymbols$6(b)) {
      if (__propIsEnum$6.call(b, prop))
        __defNormalProp$6(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
const Table = /* @__PURE__ */ defineComponent({
  name: "VeTable",
  props: __spreadValues$6(__spreadValues$6(__spreadValues$6({
    /**
     * @zh 隐藏边框
     */
    hideBorder: Boolean,
    /**
     * @zh 隐藏表头
     */
    hideHeader: Boolean,
    /**
     * @zh 固定表头
     */
    fixedHeader: Boolean,
    /**
     * @zh 表头
     */
    headers: {
      type: Array,
      default: () => []
    },
    /**
     * @zh 已选择的
     */
    selected: {
      type: Array,
      default: () => []
    },
    /**
     * @zh 排序的图标
     */
    sortIcon: {
      type: String,
      default: "$sort"
    },
    /**
     * @zh 排序激活时的颜色
     */
    sortActiveColor: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 加载中
     */
    loading: Boolean,
    /**
     * @zh 唯一键
     */
    itemKey: {
      type: String,
      default: "id"
    },
    /**
     * @zh 隐藏分页
     */
    hidePagination: Boolean
  }, makeDataIteratorProps()), makePaperProps({
    border: true,
    shape: "rounded-sm"
  })), makeScrollbar()),
  emits: {
    "update:pagination": (_) => true,
    "update:sortBy": (_) => true,
    "update:sortDesc": (_) => true,
    "update:options": (_) => true,
    "update:selected": (_) => true
  },
  setup(props, {
    slots
  }) {
    const containerRef = ref();
    const scrollLeft = ref(0);
    const selected = useProxiedModel(props, "selected");
    const isAllSelected = computed(() => {
      return selected.value.map((v) => v[props.itemKey]).sort().join("") === props.items.map((v) => v[props.itemKey]).sort().join("");
    });
    const {
      paperClasses,
      paperStyles
    } = usePaper(props, "ve-table__table");
    const {
      scrollbarClasses
    } = useScrollbar(props);
    const {
      items,
      pagination,
      sortBy: rawSortBy,
      sortDesc: rawSortDesc,
      sort,
      updateOptions
    } = useDataIterator(props);
    const headers = computed(() => {
      const length = props.headers.length;
      return props.headers.map((header, index) => {
        return __spreadProps(__spreadValues$6({}, header), {
          fixed: header.fixed === true ? index < (length - 1) / 2 ? "start" : "end" : header.fixed
        });
      });
    });
    const sortBy = computed(() => wrapInArray(rawSortBy.value));
    const sortDesc = computed(() => wrapInArray(rawSortDesc.value));
    const scrollPositionClasses = computed(() => {
      if (containerRef.value && scrollLeft.value === 0) {
        return "ve-table--scroll-position-start";
      } else if (containerRef.value && scrollLeft.value + containerRef.value.offsetWidth >= containerRef.value.scrollWidth) {
        return "ve-table--scroll-position-end";
      } else {
        return "ve-table--scroll-position-center";
      }
    });
    function handleScroll({
      target
    }) {
      scrollLeft.value = target.scrollLeft;
    }
    function genColProps(header) {
      var _a, _b;
      const styles = {
        width: convertToUnit(header.width),
        minWidth: convertToUnit((_a = header.minWidth) != null ? _a : header.width),
        maxWidth: convertToUnit((_b = header.maxWidth) != null ? _b : header.width)
      };
      return {
        style: styles
      };
    }
    function isSortDesc(header) {
      return sortDesc.value[sortBy.value.findIndex((v) => v === header.value)];
    }
    useRender(() => {
      const hasColgroup = !slots.colgroup && props.headers.length > 0;
      const hasThead = !slots.header && !props.hideHeader && props.headers.length > 0;
      const hasTbody = !slots.default;
      const hasPagination = hasTbody && !props.hidePagination;
      return createVNode(props.tag, {
        "class": ["ve-table", {
          "ve-table--fixed-header": props.fixedHeader
        }, scrollPositionClasses.value]
      }, {
        default: () => {
          var _a, _b, _c, _d, _e;
          return [createVNode("div", {
            "ref": containerRef,
            "onScroll": throttle(handleScroll, 128),
            "class": ["ve-table__table", paperClasses.value, scrollbarClasses.value],
            "style": paperStyles.value
          }, [createVNode("table", null, [hasColgroup && createVNode("colgroup", null, [headers.value.map((header) => {
            return createVNode("col", genColProps(header), null);
          })]), (_a = slots.colgroup) == null ? void 0 : _a.call(slots), hasThead && createVNode("thead", null, [props.loading && createVNode("tr", {
            "class": "ve-table__progress"
          }, [createVNode("th", {
            "colspan": props.headers.length
          }, [createVNode(Progress, {
            "color": "primary",
            "indeterminate": true,
            "stroke-width": 3
          }, null)])]), createVNode("tr", null, [headers.value.map((header, index) => {
            return createVNode(TableTh, mergeProps(filterTableThProps(header)[0], {
              "sort-icon": props.sortIcon,
              "sort-active-color": props.sortActiveColor,
              "sort-desc": isSortDesc(header),
              "onClick": () => header.sortable && sort(header.value)
            }), {
              default: () => {
                var _a2, _b2, _c2;
                return [header.$type === "selection" ? createVNode(Checkbox, {
                  "indeterminate": selected.value.length > 0 && !isAllSelected.value,
                  "onUpdate:indeterminate": (val) => {
                    if (!val) {
                      selected.value = props.items;
                    }
                  },
                  "modelValue": isAllSelected.value,
                  "onUpdate:modelValue": (val) => {
                    if (val) {
                      selected.value = props.items;
                    } else {
                      selected.value = [];
                    }
                  }
                }, null) : (_c2 = (_b2 = (_a2 = slots[`header.${header.value}`]) == null ? void 0 : _a2.call(slots, {
                  header,
                  index
                })) != null ? _b2 : header.text) != null ? _c2 : header.value];
              }
            });
          })])]), (_b = slots.header) == null ? void 0 : _b.call(slots), hasTbody && createVNode("tbody", null, [items.value.map((item, index) => {
            var _a2;
            return createVNode("tr", {
              "key": (_a2 = item[props.itemKey]) != null ? _a2 : index
            }, [headers.value.map((header) => {
              var _a3, _b2;
              return createVNode("td", {
                "class": ["ve-table-td", {
                  "ve-table-td--sorted": isSortDesc(header) !== void 0,
                  "ve-table-td--fixed-start": header.fixed === "start",
                  "ve-table-td--fixed-end": header.fixed === "end"
                }]
              }, [header.$type === "selection" ? createVNode(Checkbox, {
                "modelValue": selected.value.findIndex((v) => v[props.itemKey] === item[props.itemKey]) > -1,
                "onUpdate:modelValue": (val) => {
                  if (val) {
                    selected.value.push(item);
                  } else {
                    selected.value = selected.value.filter((v) => v[props.itemKey] !== item[props.itemKey]);
                  }
                }
              }, null) : (_b2 = (_a3 = slots[`item.${header.value}`]) == null ? void 0 : _a3.call(slots, {
                item,
                index
              })) != null ? _b2 : getObjectValueByPath(item, header.value)]);
            })]);
          }), !items.value.length && createVNode("tr", null, [createVNode("td", {
            "colspan": props.headers.length
          }, [(_d = (_c = slots.nodata) == null ? void 0 : _c.call(slots)) != null ? _d : createVNode(TableNoData, null, null)])])]), (_e = slots.default) == null ? void 0 : _e.call(slots)])]), hasPagination && createVNode(Pagination, mergeProps({
            "class": "ve-table__pagination"
          }, pagination.value, {
            "modelValue": pagination.value.page,
            "onUpdate:modelValue": (v) => {
              pagination.value.page = v;
              updateOptions();
            },
            "onUpdate:perPage": (v) => {
              pagination.value.perPage = v;
              updateOptions();
            }
          }), null)];
        }
      });
    });
    return {
      exportCSV(name) {
        downloadCSV(name, props.headers, items.value);
      }
    };
  }
});

const TabsKey = createSymbol("tabs");

var __defProp$5 = Object.defineProperty;
var __getOwnPropSymbols$5 = Object.getOwnPropertySymbols;
var __hasOwnProp$5 = Object.prototype.hasOwnProperty;
var __propIsEnum$5 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$5 = (obj, key, value) => key in obj ? __defProp$5(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$5 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$5.call(b, prop))
      __defNormalProp$5(a, prop, b[prop]);
  if (__getOwnPropSymbols$5)
    for (var prop of __getOwnPropSymbols$5(b)) {
      if (__propIsEnum$5.call(b, prop))
        __defNormalProp$5(a, prop, b[prop]);
    }
  return a;
};
const Tab = /* @__PURE__ */ defineComponent({
  name: "VeTab",
  props: __spreadValues$5(__spreadValues$5(__spreadValues$5(__spreadValues$5({
    fixed: Boolean,
    icon: [Boolean, String],
    prependIcon: String,
    appendIcon: String,
    stacked: Boolean,
    title: String,
    ripple: {
      type: Boolean,
      default: true
    },
    color: String,
    sliderColor: String,
    hideSlider: Boolean,
    direction: {
      type: String,
      default: "horizontal"
    }
  }, makeTagProps()), makeRouterProps()), makeGroupItemProps({
    selectedClass: "ve-tab--selected"
  })), makeThemeProps()),
  setup(props, {
    slots,
    attrs
  }) {
    const {
      isSelected,
      select,
      selectedClass
    } = useGroupItem(props, TabsKey);
    const {
      textColorClasses: sliderColorClasses,
      textColorStyles: sliderColorStyles
    } = useTextColor(props, "sliderColor");
    const isHorizontal = computed(() => props.direction === "horizontal");
    provideDefaults({
      VeButton: {
        block: toRef(props, "fixed"),
        color: computed(() => isSelected.value ? props.color : void 0),
        variant: "text"
      }
    }, {
      scoped: true
    });
    const rootEl = ref();
    const sliderEl = ref();
    watch(isSelected, (isSelected2) => {
      var _a, _b;
      if (isSelected2) {
        const prevEl = (_b = (_a = rootEl.value) == null ? void 0 : _a.$el.parentElement) == null ? void 0 : _b.querySelector(".ve-tab--selected .ve-tab__slider");
        const nextEl = sliderEl.value;
        if (!prevEl || !nextEl)
          return;
        const color = getComputedStyle(prevEl).color;
        const prevBox = prevEl.getBoundingClientRect();
        const nextBox = nextEl.getBoundingClientRect();
        const xy = isHorizontal.value ? "x" : "y";
        const XY = isHorizontal.value ? "X" : "Y";
        const rightBottom = isHorizontal.value ? "right" : "bottom";
        const widthHeight = isHorizontal.value ? "width" : "height";
        const prevPos = prevBox[xy];
        const nextPos = nextBox[xy];
        const delta = prevPos > nextPos ? prevBox[rightBottom] - nextBox[rightBottom] : prevBox[xy] - nextBox[xy];
        const origin = Math.sign(delta) > 0 ? isHorizontal.value ? "right" : "bottom" : Math.sign(delta) < 0 ? isHorizontal.value ? "left" : "top" : "center";
        const size = Math.abs(delta) + (Math.sign(delta) < 0 ? prevBox[widthHeight] : nextBox[widthHeight]);
        const scale = size / Math.max(prevBox[widthHeight], nextBox[widthHeight]);
        const initialScale = prevBox[widthHeight] / nextBox[widthHeight];
        const sigma = 1.5;
        nextEl.animate({
          backgroundColor: [color, ""],
          transform: [`translate${XY}(${delta}px) scale${XY}(${initialScale})`, `translate${XY}(${delta / sigma}px) scale${XY}(${(scale - 1) / sigma + 1})`, ""],
          transformOrigin: Array(3).fill(origin)
        }, {
          duration: 225,
          easing: standardEasing
        });
      }
    });
    useRender(() => {
      const [btnProps] = pick(props, ["href", "to", "replace", "icon", "stacked", "prependIcon", "appendIcon", "ripple", "theme", "disabled"]);
      return createVNode(Button, mergeProps({
        "ref": rootEl,
        "class": ["ve-tab", selectedClass.value],
        "tabindex": isSelected.value ? 0 : -1,
        "role": "tab",
        "aria-selected": String(isSelected.value),
        "onClick": () => !props.disabled && select(!isSelected.value)
      }, btnProps, attrs), {
        default: () => [slots.default ? slots.default() : props.title, !props.hideSlider && createVNode("div", {
          "ref": sliderEl,
          "class": ["ve-tab__slider", sliderColorClasses.value],
          "style": sliderColorStyles.value
        }, null)]
      });
    });
    return {
      isSelected
    };
  }
});

var __defProp$4 = Object.defineProperty;
var __getOwnPropSymbols$4 = Object.getOwnPropertySymbols;
var __hasOwnProp$4 = Object.prototype.hasOwnProperty;
var __propIsEnum$4 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$4 = (obj, key, value) => key in obj ? __defProp$4(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$4 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$4.call(b, prop))
      __defNormalProp$4(a, prop, b[prop]);
  if (__getOwnPropSymbols$4)
    for (var prop of __getOwnPropSymbols$4(b)) {
      if (__propIsEnum$4.call(b, prop))
        __defNormalProp$4(a, prop, b[prop]);
    }
  return a;
};
function parseItems(items) {
  if (!items)
    return [];
  return items.map((item) => {
    if (typeof item === "string")
      return {
        title: item,
        value: item
      };
    return item;
  });
}
const Tabs = /* @__PURE__ */ defineComponent({
  name: "VeTabs",
  props: __spreadValues$4(__spreadValues$4({
    alignWithTitle: Boolean,
    color: String,
    direction: {
      type: String,
      default: "horizontal"
    },
    fixedTabs: Boolean,
    items: {
      type: Array,
      default: () => []
    },
    stacked: Boolean,
    backgroundColor: String,
    centered: Boolean,
    grow: Boolean,
    height: {
      type: [Number, String],
      default: void 0
    },
    hideSlider: Boolean,
    optional: Boolean,
    right: Boolean,
    sliderColor: String
  }, makeDensityProps()), makeTagProps()),
  setup(props, {
    slots,
    attrs
  }) {
    const parsedItems = computed(() => parseItems(props.items));
    const {
      densityClasses
    } = useDensity(props);
    provideDefaults({
      Tab: {
        color: toRef(props, "color"),
        direction: toRef(props, "direction"),
        stacked: toRef(props, "stacked"),
        fixed: toRef(props, "fixedTabs"),
        sliderColor: toRef(props, "sliderColor"),
        hideSlider: toRef(props, "hideSlider")
      }
    });
    return () => createVNode(SlideGroup, mergeProps({
      "class": ["ve-tabs", `ve-tabs--${props.direction}`, {
        "ve-tabs--align-with-title": props.alignWithTitle,
        "ve-tabs--centered": props.centered,
        "ve-tabs--fixed-tabs": props.fixedTabs,
        "ve-tabs--grow": props.grow,
        "ve-tabs--right": props.right,
        "ve-tabs--stacked": props.stacked
      }, densityClasses.value],
      "role": "tablist",
      "symbol": TabsKey,
      "mandatory": "force",
      "direction": props.direction
    }, attrs), {
      default: () => [slots.default ? slots.default() : parsedItems.value.map((item) => createVNode(Tab, mergeProps(item, {
        "key": item.title
      }), null))]
    });
  }
});

const Textarea = genericComponent()({
  name: "Textarea",
  props: makeInputProps({
    type: "textarea"
  }),
  emit: InputEmits,
  setup(props) {
    return () => {
      return createVNode(Input, props, null);
    };
  }
});

var __defProp$3 = Object.defineProperty;
var __getOwnPropSymbols$3 = Object.getOwnPropertySymbols;
var __hasOwnProp$3 = Object.prototype.hasOwnProperty;
var __propIsEnum$3 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$3 = (obj, key, value) => key in obj ? __defProp$3(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$3 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$3.call(b, prop))
      __defNormalProp$3(a, prop, b[prop]);
  if (__getOwnPropSymbols$3)
    for (var prop of __getOwnPropSymbols$3(b)) {
      if (__propIsEnum$3.call(b, prop))
        __defNormalProp$3(a, prop, b[prop]);
    }
  return a;
};
const ThemeProvider = /* @__PURE__ */ defineComponent({
  name: "VeThemeProvider",
  props: __spreadValues$3(__spreadValues$3({}, makeTagProps()), makeThemeProps()),
  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = provideTheme(props);
    return () => {
      return createVNode(props.tag, {
        "class": ["ve-theme-provider", themeClasses.value]
      }, {
        default: () => {
          var _a;
          return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
        }
      });
    };
  }
});

var __defProp$2 = Object.defineProperty;
var __getOwnPropSymbols$2 = Object.getOwnPropertySymbols;
var __hasOwnProp$2 = Object.prototype.hasOwnProperty;
var __propIsEnum$2 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$2 = (obj, key, value) => key in obj ? __defProp$2(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$2 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$2.call(b, prop))
      __defNormalProp$2(a, prop, b[prop]);
  if (__getOwnPropSymbols$2)
    for (var prop of __getOwnPropSymbols$2(b)) {
      if (__propIsEnum$2.call(b, prop))
        __defNormalProp$2(a, prop, b[prop]);
    }
  return a;
};
const Tooltip = genericComponent()({
  name: "VeTooltip",
  props: __spreadValues$2({
    /**
     * @zh DOM ID
     */
    id: String,
    /**
     * @zh 工具提示内容
     */
    text: String,
    /**
     * @zh 是否显示箭头
     */
    arrow: {
      type: Boolean,
      default: true
    }
  }, makeOverlayProps({
    anchor: "top",
    maxWidth: 300,
    minWidth: 0,
    offset: 10,
    openOnClick: false,
    openOnHover: true,
    origin: "auto",
    positionStrategy: "connected",
    scrollStrategy: "reposition",
    transition: {
      component: ScaleTransition
    }
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const isActive = useProxiedModel(props, "modelValue");
    const id = computed(() => props.id || `ve-tooltip-${getUid()}`);
    const anchor = computed(() => {
      return props.anchor.split(" ").length > 1 ? props.anchor : `${props.anchor} center`;
    });
    const origin = computed(() => {
      return props.origin === "auto" || props.origin === "overlap" || props.origin.split(" ").length > 1 || props.anchor.split(" ").length > 1 ? props.origin : `${props.origin} center`;
    });
    return () => {
      return createVNode(Overlay, mergeProps(props, {
        "absolute": true,
        "activatorProps": {
          "aria-describedby": id.value
        },
        "anchor": anchor.value,
        "class": "ve-tooltip",
        "contentClass": "ve-tooltip__wrapper",
        "id": id.value,
        "origin": origin.value,
        "persistent": true,
        "role": "tooltip",
        "scrim": false,
        "modelValue": isActive.value,
        "onUpdate:modelValue": ($event) => isActive.value = $event
      }), {
        default: () => {
          var _a, _b;
          return [(_b = (_a = slots.default) == null ? void 0 : _a.call(slots)) != null ? _b : props.text, props.arrow && createVNode("div", {
            "class": "ve-tooltip__arrow"
          }, null)];
        },
        activator: slots.activator
      });
    };
  }
});

var __defProp$1 = Object.defineProperty;
var __getOwnPropSymbols$1 = Object.getOwnPropertySymbols;
var __hasOwnProp$1 = Object.prototype.hasOwnProperty;
var __propIsEnum$1 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1 = (obj, key, value) => key in obj ? __defProp$1(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$1 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$1.call(b, prop))
      __defNormalProp$1(a, prop, b[prop]);
  if (__getOwnPropSymbols$1)
    for (var prop of __getOwnPropSymbols$1(b)) {
      if (__propIsEnum$1.call(b, prop))
        __defNormalProp$1(a, prop, b[prop]);
    }
  return a;
};
function createCursorSvg(options) {
  const {
    type,
    rotation
  } = options;
  let path;
  switch (type) {
    case "rotate":
      path = '<path d="M22.4789 9.45728L25.9935 12.9942L22.4789 16.5283V14.1032C18.126 14.1502 14.6071 17.6737 14.5675 22.0283H17.05L13.513 25.543L9.97889 22.0283H12.5674C12.6071 16.5691 17.0214 12.1503 22.4789 12.1031L22.4789 9.45728Z" fill="black"/><path fill-rule="evenodd" clip-rule="evenodd" d="M21.4789 7.03223L27.4035 12.9945L21.4789 18.9521V15.1868C18.4798 15.6549 16.1113 18.0273 15.649 21.0284H19.475L13.5128 26.953L7.55519 21.0284H11.6189C12.1243 15.8155 16.2679 11.6677 21.4789 11.1559L21.4789 7.03223ZM22.4789 12.1031C17.0214 12.1503 12.6071 16.5691 12.5674 22.0284H9.97889L13.513 25.543L17.05 22.0284H14.5675C14.5705 21.6896 14.5947 21.3558 14.6386 21.0284C15.1157 17.4741 17.9266 14.6592 21.4789 14.1761C21.8063 14.1316 22.1401 14.1069 22.4789 14.1032V16.5284L25.9935 12.9942L22.4789 9.45729L22.4789 12.1031Z" fill="white"/>';
      break;
    case "resize":
      path = '<path d="m9 17.9907v.005l5.997 5.996.001-3.999h1.999 2.02v4l5.98-6.001-5.98-5.999.001 4.019-2.021.002h-2l.001-4.022zm1.411.003 3.587-3.588-.001 2.587h3.5 2.521v-2.585l3.565 3.586-3.564 3.585-.001-2.585h-2.521l-3.499-.001-.001 2.586z" fill="white"/><path d="m17.4971 18.9932h2.521v2.586l3.565-3.586-3.565-3.585v2.605h-2.521-3.5v-2.607l-3.586 3.587 3.586 3.586v-2.587z" fill="black"/>';
      break;
    case "resize2":
      path = '<path d="m19.7432 17.0869-4.072 4.068 2.829 2.828-8.473-.013-.013-8.47 2.841 2.842 4.075-4.068 1.414-1.415-2.844-2.842h8.486v8.484l-2.83-2.827z" fill="white"/><path d="m18.6826 16.7334-4.427 4.424 1.828 1.828-5.056-.016-.014-5.054 1.842 1.841 4.428-4.422 2.474-2.475-1.844-1.843h5.073v5.071l-1.83-1.828z" fill="black"/>';
      break;
  }
  return `<svg height="32" width="32" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg"><defs><filter id="shadow" color-interpolation-filters="sRGB"><feDropShadow dx="1" dy="1" stdDeviation="1.2" flood-opacity=".5"/></filter></defs><g fill="none" transform="rotate(${rotation} 16 16)" filter="url(%23shadow)">${path}</g></svg>`.replace(/"/g, "'");
}
const cursors = {
  "rotate-top-left": (rotation) => createCursorSvg({
    type: "rotate",
    rotation: 360 + rotation
  }),
  "rotate-top-right": (rotation) => createCursorSvg({
    type: "rotate",
    rotation: 90 + rotation
  }),
  "rotate-bottom-left": (rotation) => createCursorSvg({
    type: "rotate",
    rotation: 270 + rotation
  }),
  "rotate-bottom-right": (rotation) => createCursorSvg({
    type: "rotate",
    rotation: 180 + rotation
  }),
  "resize-left": (rotation) => createCursorSvg({
    type: "resize",
    rotation: 180 + rotation
  }),
  "resize-top": (rotation) => createCursorSvg({
    type: "resize",
    rotation: 90 + rotation
  }),
  "resize-right": (rotation) => createCursorSvg({
    type: "resize",
    rotation: 180 + rotation
  }),
  "resize-bottom": (rotation) => createCursorSvg({
    type: "resize",
    rotation: 90 + rotation
  }),
  "resize-top-left": (rotation) => createCursorSvg({
    type: "resize2",
    rotation: 90 + rotation
  }),
  "resize-top-right": (rotation) => createCursorSvg({
    type: "resize2",
    rotation: 180 + rotation
  }),
  "resize-bottom-right": (rotation) => createCursorSvg({
    type: "resize2",
    rotation: 90 + rotation
  }),
  "resize-bottom-left": (rotation) => createCursorSvg({
    type: "resize2",
    rotation: 180 + rotation
  })
};
function calculateRotation(point, origin, angle) {
  const radian = angle * Math.PI / 180;
  return {
    x: (point.x - origin.x) * Math.cos(radian) - (point.y - origin.y) * Math.sin(radian) + origin.x,
    y: (point.x - origin.x) * Math.sin(radian) + (point.y - origin.y) * Math.cos(radian) + origin.y
  };
}
function calculateCenter(point1, point2) {
  return {
    x: point1.x + (point2.x - point1.x) / 2,
    y: point1.y + (point2.y - point1.y) / 2
  };
}
function calculateHypotenuse(point1, point2) {
  return Math.sqrt((point1.x - point2.x) ** 2 + (point1.y - point2.y) ** 2);
}
const Transformable = /* @__PURE__ */ defineComponent({
  name: "Transformable",
  props: __spreadValues$1({
    /**
     * @zh 位置大小及旋转
     */
    modelValue: {
      type: Object,
      default: () => ({
        top: 0,
        left: 0,
        width: 100,
        height: 100,
        rotation: 0
      })
    },
    /**
     * @zh 可以移动
     */
    moveable: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 可以旋转
     */
    rotatable: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 可以调整尺寸
     */
    resizable: {
      type: Boolean,
      default: true
    },
    /**
     * @zh 颜色
     */
    color: {
      type: String,
      default: "primary"
    },
    /**
     * @zh 定位模式
     */
    position: {
      type: String,
      default: "absolute"
    },
    /**
     * @zh 隐藏显示可拖拽的锚点
     */
    hideAnchors: {
      type: Boolean,
      default: false
    }
  }, makeTagProps({
    tag: "svg"
  })),
  emits: {
    "update:modelValue": (_modelValue) => true
  },
  setup(props, {
    slots
  }) {
    const {
      textColorClasses,
      textColorStyles
    } = useTextColor(props, "color");
    const model = useProxiedModel(props, "modelValue", props.modelValue);
    const isTransforming = ref(false);
    const active = ref();
    const anchors = computed(() => {
      const {
        width,
        height
      } = model.value;
      const size = 8;
      const size1 = size * 1.6;
      const size2 = size * 2.25;
      return [{
        type: "rotate-top-left",
        x: -size2,
        y: -size2,
        width: size2,
        height: size2
      }, {
        type: "rotate-top-right",
        x: width,
        y: -size2,
        width: size2,
        height: size2
      }, {
        type: "rotate-bottom-left",
        x: -size2,
        y: height,
        width: size2,
        height: size2
      }, {
        type: "rotate-bottom-right",
        x: width,
        y: height,
        width: size2,
        height: size2
      }, {
        type: "resize-top",
        x: 0,
        y: -size / 2,
        width,
        height: size
      }, {
        type: "resize-right",
        x: width - size / 2,
        y: 0,
        width: size,
        height
      }, {
        type: "resize-bottom",
        x: 0,
        y: height - size / 2,
        width,
        height: size
      }, {
        type: "resize-left",
        x: -size / 2,
        y: 0,
        width: size,
        height
      }, {
        type: "resize-top-left",
        x: -size / 2,
        y: -size / 2,
        width: size,
        height: size,
        transparent: false
      }, {
        type: "resize-top-right",
        x: width - size / 2,
        y: -size / 2,
        width: size,
        height: size,
        transparent: false
      }, {
        type: "resize-bottom-left",
        x: -size / 2,
        y: height - size / 2,
        width: size,
        height: size,
        transparent: false
      }, {
        type: "resize-bottom-right",
        x: width - size / 2,
        y: height - size / 2,
        width: size,
        height: size,
        transparent: false
      }, {
        type: "resize-top-left",
        x: -size1 / 2,
        y: -size1 / 2,
        width: size1,
        height: size1
      }, {
        type: "resize-top-right",
        x: width - size1 / 2,
        y: -size1 / 2,
        width: size1,
        height: size1
      }, {
        type: "resize-bottom-left",
        x: -size1 / 2,
        y: height - size1 / 2,
        width: size1,
        height: size1
      }, {
        type: "resize-bottom-right",
        x: width - size1 / 2,
        y: height - size1 / 2,
        width: size1,
        height: size1
      }];
    });
    const styles = computed(() => {
      const {
        left,
        top,
        width,
        height,
        rotation
      } = model.value;
      const radian = rotation * Math.PI / 180;
      const cos = Math.cos(radian);
      const sin = Math.sin(radian);
      return {
        width: convertToUnit(width),
        height: convertToUnit(height),
        transform: `matrix(${cos}, ${sin}, ${-sin}, ${cos}, ${left}, ${top})`
      };
    });
    function getCursor(type) {
      if (type === "move")
        return "move";
      const {
        rotation = 0
      } = model.value;
      return `url("data:image/svg+xml,${cursors[type](rotation)}") 16 16, pointer`;
    }
    function start(event, index) {
      event.preventDefault();
      event.stopPropagation();
      const {
        left,
        top,
        width,
        height,
        rotation
      } = model.value;
      const anchor = index === void 0 ? {
        type: "move",
        x: 0,
        y: 0,
        width: 0,
        height: 0
      } : anchors.value[index];
      active.value = anchor.type;
      const isMove = anchor.type === "move";
      const isRotation = anchor.type.startsWith("rotate");
      const isHorizontal = anchor.type === "resize-left" || anchor.type === "resize-right";
      const isHorizontalVertical = anchor.type.split("-").length === 2;
      const centerPoint = {
        x: left + width / 2,
        y: top + height / 2
      };
      const startingPointBefore = {
        x: left + anchor.x + anchor.width / 2,
        y: top + anchor.y + anchor.height / 2
      };
      const startingPoint = calculateRotation(startingPointBefore, centerPoint, isMove ? 0 : rotation);
      const symmetricPoint = {
        x: centerPoint.x * 2 - startingPoint.x,
        y: centerPoint.y * 2 - startingPoint.y
      };
      const client = {
        x: event.clientX,
        y: event.clientY
      };
      const rotationBefore = Math.atan2(startingPoint.y - centerPoint.y, startingPoint.x - centerPoint.x) / (Math.PI / 180);
      function move(event2) {
        const updated = {};
        const clientOffset = {
          x: event2.clientX - client.x,
          y: event2.clientY - client.y
        };
        const cursorPoint = {
          x: startingPoint.x + clientOffset.x,
          y: startingPoint.y + clientOffset.y
        };
        if (isMove) {
          updated.left = cursorPoint.x;
          updated.top = cursorPoint.y;
        } else if (isRotation) {
          const rotationAfter = Math.atan2(cursorPoint.y - centerPoint.y, cursorPoint.x - centerPoint.x) / (Math.PI / 180);
          updated.rotation = rotation + rotationAfter - rotationBefore;
        } else if (isHorizontalVertical) {
          const rotationBefore2 = calculateRotation(cursorPoint, startingPoint, -rotation);
          const rotationAfter = calculateRotation(isHorizontal ? {
            x: rotationBefore2.x,
            y: startingPoint.y
          } : {
            x: startingPoint.x,
            y: rotationBefore2.y
          }, startingPoint, rotation);
          const newCenterPoint = {
            x: rotationAfter.x - (rotationAfter.x - symmetricPoint.x) / 2,
            y: rotationAfter.y + (symmetricPoint.y - rotationAfter.y) / 2
          };
          const hypotenuse = calculateHypotenuse(rotationAfter, symmetricPoint);
          if (isHorizontal) {
            updated.width = hypotenuse;
            updated.height = model.value.height;
          } else {
            updated.width = model.value.width;
            updated.height = hypotenuse;
          }
          updated.left = newCenterPoint.x - updated.width / 2;
          updated.top = newCenterPoint.y - updated.height / 2;
        } else {
          const newCenterPoint = calculateCenter(cursorPoint, symmetricPoint);
          const points = [calculateRotation(cursorPoint, newCenterPoint, -rotation), calculateRotation(symmetricPoint, newCenterPoint, -rotation)];
          const [minX, maxX] = points[0].x > points[1].x ? [points[1].x, points[0].x] : [points[0].x, points[1].x];
          const [minY, maxY] = points[0].y > points[1].y ? [points[1].y, points[0].y] : [points[0].y, points[1].y];
          updated.width = maxX - minX;
          updated.height = maxY - minY;
          updated.left = minX;
          updated.top = minY;
        }
        for (const [key, value] of Object.entries(updated)) {
          updated[key] = ~~value;
        }
        if ("width" in updated && updated.width <= 0 || "height" in updated && updated.height <= 0)
          return;
        model.value = __spreadValues$1(__spreadValues$1({}, model.value), updated);
      }
      function end() {
        window.removeEventListener("pointermove", move);
        window.removeEventListener("pointerup", end, true);
        isTransforming.value = false;
      }
      window.addEventListener("pointermove", move);
      window.addEventListener("pointerup", end, true);
      isTransforming.value = true;
    }
    return () => {
      var _a;
      const moveable = props.moveable ? {
        onPointerdown: start
      } : {};
      return createVNode(Fragment, null, [(_a = slots.default) == null ? void 0 : _a.call(slots, {
        value: model.value,
        moveable,
        props: mergeProps(moveable, {
          style: styles.value
        })
      }), createVNode(props.tag, {
        "class": ["ve-transformable", ...textColorClasses.value],
        "style": __spreadValues$1(__spreadValues$1({
          position: props.position
        }, textColorStyles.value), styles.value)
      }, {
        default: () => [createVNode("rect", {
          "width": "100%",
          "height": "100%",
          "fill": "none",
          "class": ["ve-transformable__anchor", (isTransforming.value || props.hideAnchors) && "ve-transformable__anchor--hide"]
        }, null), createVNode("g", {
          "pointer-events": "all"
        }, [anchors.value.filter((anchor) => {
          const {
            type
          } = anchor;
          return !(!props.resizable && type.startsWith("resize") || !props.rotatable && type.startsWith("rotate"));
        }).map((anchor, index) => {
          const {
            type,
            x,
            y,
            width,
            height,
            transparent = true
          } = anchor;
          return createVNode("rect", {
            "aria-label": type,
            "x": x,
            "y": y,
            "width": width,
            "height": height,
            "fill": "white",
            "onPointerdown": (event) => start(event, index),
            "class": ["ve-transformable__anchor", transparent ? "ve-transformable__anchor--transparent" : "ve-transformable__anchor--pointer-none", (isTransforming.value || props.hideAnchors) && "ve-transformable__anchor--hide"],
            "cursor": isTransforming.value ? "auto" : getCursor(type)
          }, null);
        })])]
      }), isTransforming.value && active.value && createVNode(props.tag, {
        "class": "ve-transformable__mask",
        "style": {
          position: props.position,
          cursor: getCursor(active.value)
        }
      }, null)]);
    };
  }
});

const H1 = createSimpleFunctional("ve-h1", "h1", "VeH1");
const H2 = createSimpleFunctional("ve-h2", "h2", "VeH2");
const H3 = createSimpleFunctional("ve-h3", "h3", "VeH3");
const H4 = createSimpleFunctional("ve-h4", "h4", "VeH4");
const H5 = createSimpleFunctional("ve-h5", "h5", "VeH5");
const H6 = createSimpleFunctional("ve-h6", "h6", "VeH6");

const P = createSimpleFunctional("ve-p", "p");

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Alert: Alert,
  Anchor: Anchor,
  AnchorItem: AnchorItem,
  App: App,
  Avatar: Avatar,
  Badge: Badge,
  Breadcrumb: Breadcrumb,
  BreadcrumbItem: BreadcrumbItem,
  Button: Button,
  ButtonGroup: ButtonGroup,
  ButtonToggle: ButtonToggle,
  Card: Card,
  CardActions: CardActions,
  CardAvatar: CardAvatar,
  CardHeader: CardHeader,
  CardHeaderText: CardHeaderText,
  CardImage: CardImage,
  CardSubtitle: CardSubtitle,
  CardText: CardText,
  CardTitle: CardTitle,
  Carousel: Carousel,
  CarouselItem: CarouselItem,
  Checkbox: Checkbox,
  CheckboxGroup: CheckboxGroup,
  Code: Code,
  Col: Col,
  Container: Container,
  Counter: Counter,
  DatePicker: DatePicker,
  DatePickerPanel: DatePickerPanel,
  DateRangePickerPanel: DateRangePickerPanel,
  DefaultsProvider: DefaultsProvider,
  Device: Device,
  DeviceStatusBar: DeviceStatusBar,
  Dialog: Dialog,
  DialogTransition: DialogTransition,
  Divider: Divider,
  DraggableSortable: DraggableSortable,
  Drawer: Drawer,
  ExpandTransition: ExpandTransition,
  ExpandXTransition: ExpandXTransition,
  FadeInExpandTransition: FadeInExpandTransition,
  FadeTransition: FadeTransition,
  Form: Form,
  FormChildren: FormChildren,
  FormControl: FormControl,
  H1: H1,
  H2: H2,
  H3: H3,
  H4: H4,
  H5: H5,
  H6: H6,
  Header: Header,
  HeaderNavIcon: HeaderNavIcon,
  HeaderTitle: HeaderTitle,
  Hover: Hover,
  Icon: Icon,
  IconClass: IconClass,
  IconComponent: IconComponent,
  IconLigature: IconLigature,
  IconSvg: IconSvg,
  Image: Image,
  Input: Input,
  InputControl: InputControl,
  Label: Label,
  Layout: Layout,
  LayoutItem: LayoutItem,
  Lazy: Lazy,
  Link: Link,
  List: List,
  ListGroup: ListGroup,
  ListItem: ListItem,
  ListItemAvatar: ListItemAvatar,
  ListItemHeader: ListItemHeader,
  ListItemSubtitle: ListItemSubtitle,
  ListItemTitle: ListItemTitle,
  ListSubheader: ListSubheader,
  Main: Main,
  Menu: Menu,
  MenuTransition: MenuTransition,
  MessageProvider: MessageProvider,
  Messages: Messages,
  NotificationProvider: NotificationProvider,
  Overlay: Overlay,
  P: P,
  Pagination: Pagination,
  Paper: Paper,
  Progress: Progress,
  ProgressCircular: ProgressCircular,
  ProgressLinear: ProgressLinear,
  Radio: Radio,
  RadioGroup: RadioGroup,
  Responsive: Responsive,
  Row: Row,
  ScaleTransition: ScaleTransition,
  Scrim: Scrim,
  Scrollbar: Scrollbar,
  Select: Select,
  SelectionControl: SelectionControl,
  SelectionGroupControl: SelectionGroupControl,
  SlideGroup: SlideGroup,
  SlideGroupItem: SlideGroupItem,
  SlideRightFadeInExpandTransition: SlideRightFadeInExpandTransition,
  Spacer: Spacer,
  Switch: Switch,
  Tab: Tab,
  Table: Table,
  Tabs: Tabs,
  Tag: Tag,
  TagGroup: TagGroup,
  Textarea: Textarea,
  ThemeProvider: ThemeProvider,
  Toolbar: Toolbar,
  ToolbarItems: ToolbarItems,
  ToolbarTitle: ToolbarTitle,
  Tooltip: Tooltip,
  Transformable: Transformable
});

var providers = /*#__PURE__*/Object.freeze({
  __proto__: null,
  MessageProvider: MessageProvider,
  NotificationProvider: NotificationProvider
});

function VenoUiResolver(options = {}) {
  const {
    prefix: rawPrefix = "ve"
  } = options;
  const prefix = rawPrefix ? `${toKebabCase(rawPrefix)}-` : "";
  return [
    {
      type: "component",
      resolve: (name) => {
        const kebab = toKebabCase(name);
        if (!kebab.startsWith(prefix))
          return;
        const slice = kebab.slice(prefix.length);
        return {
          name: toPascalCase(slice),
          from: "veno-ui/components"
        };
      }
    }
  ];
}

const version = UI_VERSION;
const createVeno$1 = (options = {}) => {
  const install = (app) => {
    const {
      componentPrefix = "Ve",
      components = {},
      directives = {}
    } = options;
    for (const key in components) {
      app.component(`${componentPrefix}${key}`, components[key]);
    }
    for (const key in directives) {
      app.directive(key, directives[key]);
    }
    app.provide(DisplayKey, createDisplay(options.display));
    app.provide(DefaultsKey, createDefaults(options.defaults));
    app.provide(DraggableSortableGroupKey, createDraggableSortableGroup());
    app.provide(ThemeKey, createTheme(app, options.theme));
    app.provide(HighlighterKey, createHighlighter(options.highlighter));
    app.provide(IconsKey, createIcons(options.icons));
    app.provide(ProvidersKey, createProviders(app, options.providers));
  };
  return { install, version };
};

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const createVeno = (options = {}) => {
  return createVeno$1(__spreadValues({ components, directives, providers }, options));
};

export { VenoUiResolver, components, createDate, createVeno, defaultDateFormat, directives, message, notification, providers, useDisplay, useLayout, useMessage, useNotification, useTheme, index as utils };
//# sourceMappingURL=veno-ui.mjs.map
